/*****************************/
/*28-09-2018 OAV*/
/*   DP_GBCLINKS   */
/*    */
/*****************************/


SET SQL DIALECT 3;



/******************************************************************************/
/***                                 Tables                                 ***/
/******************************************************************************/



CREATE TABLE DP_GBCLINKS (
    D$UUID         DM_UUID NOT NULL /* DM_UUID = CHAR(36) NOT NULL */,
    POSITION_UUID  DM_UUID /* DM_UUID = CHAR(36) NOT NULL */,
    BARCODE        DM_TEXT NOT NULL /* DM_TEXT = VARCHAR(250) */,
    SNAME          DM_TEXT /* DM_TEXT = VARCHAR(250) */,
    D$SRVUPDDT     DM_DATETIME /* DM_DATETIME = TIMESTAMP */
);




/******************************************************************************/
/***                              Primary keys                              ***/
/******************************************************************************/

ALTER TABLE DP_GBCLINKS ADD CONSTRAINT PK_DP_GBCLINKS_1 PRIMARY KEY (D$UUID);


/******************************************************************************/
/***                                Indices                                 ***/
/******************************************************************************/

CREATE INDEX DP_GBCLINKS_IDX1 ON DP_GBCLINKS (POSITION_UUID);
CREATE INDEX DP_GBCLINKS_IDX2 ON DP_GBCLINKS (BARCODE);
CREATE INDEX DP_GBCLINKS_IDX3 ON DP_GBCLINKS (POSITION_UUID, BARCODE);
CREATE INDEX DP_GBCLINKS_IDX4 ON DP_GBCLINKS (SNAME);
CREATE INDEX IDX_DP_GBCLINKS_1 ON DP_GBCLINKS (BARCODE);
CREATE INDEX IDX_DP_GBCLINKS_2 ON DP_GBCLINKS (POSITION_UUID);
CREATE INDEX IDX_DP_GBCLINKS_3 ON DP_GBCLINKS (POSITION_UUID, BARCODE);
CREATE INDEX IDX_DP_GBCLINKS_4 ON DP_GBCLINKS (SNAME);


/******************************************************************************/
/***                                Triggers                                ***/
/******************************************************************************/



SET TERM ^ ;



/******************************************************************************/
/***                          Triggers for tables                           ***/
/******************************************************************************/



/* Trigger: DP_GBCLINKS_AD_DISTR */
CREATE OR ALTER TRIGGER DP_GBCLINKS_AD_DISTR FOR DP_GBCLINKS
ACTIVE AFTER DELETE POSITION 0
AS
begin
  update or insert into g$distribute (TABLENAME,UUID,SOPER,FROM_PROFILE_ID) values ('DP_GBCLINKS',old.d$uuid,2,null)
  matching (TABLENAME,UUID);
end
^


/* Trigger: DP_GBCLINKS_BI_DISTR */
CREATE OR ALTER TRIGGER DP_GBCLINKS_BI_DISTR FOR DP_GBCLINKS
ACTIVE BEFORE INSERT POSITION 0
AS
begin
  if (new.d$uuid is null) then
  begin
    new.d$uuid=UUID_TO_CHAR(GEN_UUID());
    new.d$srvupddt='2000-01-01';
    update or insert into g$distribute (TABLENAME,UUID,SOPER,FROM_PROFILE_ID) values ('DP_GBCLINKS',new.d$uuid,0,null) matching (TABLENAME,UUID);
  end
end
^


/* Trigger: DP_GBCLINKS_BU_DISTR */
CREATE OR ALTER TRIGGER DP_GBCLINKS_BU_DISTR FOR DP_GBCLINKS
ACTIVE BEFORE UPDATE POSITION 0
AS
begin
  if (new.D$SRVUPDDT=old.D$SRVUPDDT) then
  begin
     update or insert into g$distribute (TABLENAME,UUID,SOPER,FROM_PROFILE_ID) values ('DP_GBCLINKS',new.d$uuid,1,null)
     matching (TABLENAME,UUID);
  end

end
^

SET TERM ; ^



/******************************************************************************/
/***                              Descriptions                              ***/
/******************************************************************************/

COMMENT ON TABLE DP_GBCLINKS IS 
'    .
     ,    ';



/******************************************************************************/
/***                               Privileges                               ***/
/******************************************************************************/
/*
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C652C00-EC89-4286-9464-9661CCE2C048', '0052C8A6-17C8-433A-9DB5-DB05E9419040', '4607163090655', '      5  200                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49E833FD-5136-48B3-8303-6AFBA3FCB37F', '1A7D0B58-8B4C-4724-8202-A81893318D0B', '4607163090648', '      200                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87BDE531-AC50-4DE8-915C-4581DD068FDC', 'EBC37446-52C1-458E-8D69-B981177B12AB', '4607163090686', '   .  12 200                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03712A96-DB8D-461B-9552-FDF3843247F1', 'A06A43C2-F307-4871-9926-28AA25888E69', '4607163090549', ' /   200                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D45AF87B-90B5-42EF-B538-F2B8960CC6C8', 'A06A43C2-F307-4871-9926-28AA25888E69', '4607163090662', ' /   200                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EFA07D9-E866-4497-A0D2-B1620BB1739F', 'EE4FBE42-6EFD-4949-ABF9-79799682939C', '4607163090723', '     6 .  200                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB978DFD-9861-4375-A784-58CC959284F2', '1FB34CD3-BCFA-441D-99EA-C1445F0ECBFC', '4607163090846', '      6  200                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9F8758A-8A8F-4D69-BC0B-DC0674FD9F52', '5BB6E433-2D08-4A4D-A40E-4678F1291CD9', '4607163090631', '    ..   3  200                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAE0B10E-5FB5-4606-977E-200FE8E04E1D', '1CAC8A04-707D-45FF-BDE4-F9F6FECD1DD4', '4607163090471', ' /    200                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3279760E-5607-4A92-8C99-B3D3B6994393', '1CAC8A04-707D-45FF-BDE4-F9F6FECD1DD4', '4607163090624', ' /    200                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3494E16E-2704-407D-AA9F-AC4A3CFA9286', '7DBC20F4-D557-4727-8160-14728EB29393', '4607163090679', ' /   200                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('013ABF37-75FD-49AD-9FC4-A7CBFA4CBBBA', 'CDBA3D51-3F1C-4DCD-8FA2-4AA6810BBA4F', '4607163093274', '   0,2  .                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A5EEFA3-CD2F-40F0-A1BE-3032317FF1EB', '1E56088E-C0C1-4083-8860-842B554125A6', '4607163090693', '       200                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4295DF1C-7681-4C29-9D60-F529FC5445BD', '009CAB80-9A90-4AEC-A864-CA1616665C24', '8901086130013', ' 0,5%  100                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('865B0634-A216-428D-B507-F5BF8A201EE8', '324503CF-D219-4995-8285-0D075AFC064B', '4605059010039', ' 10                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7AE49DC-7D9C-4E89-86D8-4D08424D524E', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '1800026630163', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79B24EC9-AD67-4A20-86B2-62C6BEBC0492', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4036534001028', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F01AE4D6-8AED-493B-992E-227ABB0F7FE9', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4036534001035', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AA82862-E466-4E26-A5F4-D4471A62AC18', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4036534003022', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEE12D20-12FC-4CCC-BC85-40954201D629', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4036534100028', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB1BF37E-BB15-45B5-AA7F-1EE444E57FA6', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4036534100035', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83AFE023-A25B-466A-B263-4F9286CD6B84', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4250431900011', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('396422D8-7373-447E-A4A3-B0C7717FECA8', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4260090440155', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8DAF725-9839-41F9-AA3D-B096B1E305CB', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4260090440179', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69F626C5-9147-4C66-9E70-C9E229C36BA1', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4260090440216', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F2EE4B5-AD18-4A62-8D6F-BB2A44410BA4', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4260090442388', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97C31D2A-7EE3-465B-ADC5-37B965576392', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4260090443248', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67D6E960-205E-417A-A26B-321F7CC17D35', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4260090443507', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBECD1E0-6281-475F-83A0-006FB771864C', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4627105110135', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBF896AA-1478-4D0A-8FC7-97491E01FC6B', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '6923852988385', ' /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('346090FF-2A73-4723-A680-03490F10484B', '4E6F85C6-332A-40D3-B294-D9C78FDCECE1', '6938588802263', ' - 100 10 10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14B1E79C-6DCB-4339-9EB8-7F04F7E6EE07', '04DDCF17-5363-46B2-A194-B834B5B98370', '4605180003009', ' 2%  - 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6095623-04C2-4F44-AF1A-C069833AC633', '04DDCF17-5363-46B2-A194-B834B5B98370', '4605180005812', ' 2%  - 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77A6D188-7052-46B6-928D-27A06A2F6C43', '04DDCF17-5363-46B2-A194-B834B5B98370', '4820090058189', ' 2%  - 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24D23611-CD69-4FDB-9D02-EC37C4456CFA', 'FF274725-1BE1-4088-9D33-268B22B436E7', '4600828000853', '  10% 10  10                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0758D30-A081-4E00-B9C4-0477C22FA146', 'FF274725-1BE1-4088-9D33-268B22B436E7', '4602212002092', '  10% 10  10                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA061B8D-67EB-4861-B104-D80DFF819E45', 'FF274725-1BE1-4088-9D33-268B22B436E7', '4650060480012', '  10% 10  10                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F94AE45-3A25-43F2-8B7B-6F88FA4D5790', 'FF274725-1BE1-4088-9D33-268B22B436E7', '4823002212211', '  10% 10  10                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62240FDB-CE5F-4DF3-BED7-FD23FC0886DD', 'FF274725-1BE1-4088-9D33-268B22B436E7', '6930169707714', '  10% 10  10                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('644480E0-2363-4CF2-ADC7-DA3B33DA72AE', 'E42674F9-20D5-406F-BBFB-7F2C75E3189D', '8901079004871', ' 0,3% 5                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D29C73D-C9C5-420F-86CB-356F29E3B18C', '9CB9DEFD-9F02-407A-98FE-B9A1C31F13F2', '8901148052031', ' 0,1  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5974B104-68C8-4210-B556-0EF88D872AA3', '9CB9DEFD-9F02-407A-98FE-B9A1C31F13F2', '8901148052048', ' 0,1  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C719C23-CD39-47E0-B6C1-95C52500DE84', '9CB9DEFD-9F02-407A-98FE-B9A1C31F13F2', '8901148227033', ' 0,1  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('153E6DD6-18D0-4E19-973E-046DD46D0895', '9CB9DEFD-9F02-407A-98FE-B9A1C31F13F2', '8901148236608', ' 0,1  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B241E15-7947-4FA0-9F28-5F00F6B4876C', '87EC43F8-0C29-4255-9618-02C49EC545A0', '8904091112401', ' 5                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8819ACA-4195-4704-97ED-EAB1DD902495', '653CA139-8567-4664-86C5-6EB8E706E913', '4600828003908', '  10% 5  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2A652F9-EF25-47EC-AFFC-9CDCCDBC49D1', '653CA139-8567-4664-86C5-6EB8E706E913', '4602212002078', '  10% 5  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('515A4FED-BAFE-4CDF-83F1-2BE66230DC06', '653CA139-8567-4664-86C5-6EB8E706E913', '4823002212259', '  10% 5  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41ADD0F7-F1B3-4FCD-AC5C-E7E71EF1796F', '00ECBBB8-0EF9-436F-B265-BABA30559A20', '4605185000508', ' 100                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2002233F-B23E-4F98-8A4F-2818C0661E6E', '00ECBBB8-0EF9-436F-B265-BABA30559A20', '4607001761150', ' 100                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('529AED57-046C-440D-9FE4-B5B2E5D119AE', '00ECBBB8-0EF9-436F-B265-BABA30559A20', '4620007450118', ' 100                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7954C44-C333-4D98-A66E-E361CBDB778F', '00ECBBB8-0EF9-436F-B265-BABA30559A20', '4680005640188', ' 100                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('240FC139-2444-447F-9A11-BF478AB3BBBF', '6C7DF108-A9A1-46F1-8127-F828F41D0317', '4603905003310', '  3% 100 -                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EC90629-4B7F-4B24-B0B4-4357C3CF53AD', 'C7358577-D03F-4AA4-A319-BA3C9159FEEB', '4049500812511', ' 714  /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E064A3BF-0CBF-4F22-A0BE-565E64DA48FC', 'C7358577-D03F-4AA4-A319-BA3C9159FEEB', '4670003600789', ' 714  /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3D00CBF-16B9-45B6-AECB-081B74C7D52D', 'C7358577-D03F-4AA4-A319-BA3C9159FEEB', '4670003600840', ' 714  /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E698FC94-E9DC-4F42-8C5A-29F5F60B3C6E', '8987D6D7-46E4-44F5-951E-A02D06D088EC', '4607109940211', ' 7 14                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE18CB73-4C75-41CF-861B-422EBEC94FAA', '8987D6D7-46E4-44F5-951E-A02D06D088EC', '4610010010447', ' 7 14                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8689B149-653C-487E-BC31-C793219AB886', '67609DF2-949C-47A5-9B89-E9AC563D150D', '4607007361385', '   50                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85DE8543-0DED-4592-815E-F2747367094C', '9DB580C1-DF9F-46DF-BA3D-E36F65615924', '4603905003587', '    0,05% 100                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('945B8866-3C34-4F5D-A9EF-7CBF91FDC712', '3D4A9AEE-2033-43E5-AC81-01CCB8C27989', '4601026006845', '   40                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA8C98F4-AB46-45D7-9D31-07A80DEAC803', '9F4CDBBB-352A-4B73-9908-3C663E37AA7B', '4602453001380', '  3% 100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43568248-A305-4BD5-B8E9-39A963581C41', '9F4CDBBB-352A-4B73-9908-3C663E37AA7B', '4602546006919', '  3% 100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66E0FEDB-1175-40AC-A477-7ABD0FA0BABC', '9F4CDBBB-352A-4B73-9908-3C663E37AA7B', '4603933000015', '  3% 100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2845F61-9342-424E-A574-DBE7267BEE44', '9F4CDBBB-352A-4B73-9908-3C663E37AA7B', '4605404000715', '  3% 100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('569315DD-79E8-418A-BE85-C941DFF2543C', '9F4CDBBB-352A-4B73-9908-3C663E37AA7B', '4606367000699', '  3% 100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3101D39E-4551-45F5-8B1C-1A93E84C0EB3', '9F4CDBBB-352A-4B73-9908-3C663E37AA7B', '4607007360746', '  3% 100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02155CB1-3E6A-4217-9614-09F9BE163DD7', '9F4CDBBB-352A-4B73-9908-3C663E37AA7B', '4620008620022', '  3% 100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10F36CD1-FE91-4B84-9F53-25955E0007D6', '9F4CDBBB-352A-4B73-9908-3C663E37AA7B', '4813331000023', '  3% 100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6C968D4-3AC8-4988-803D-911EC633787C', '5690F630-B454-40E6-9077-A53BF5104375', '4602212007097', '- 2500                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69387937-B06C-42A5-85F4-C071F9602763', '5690F630-B454-40E6-9077-A53BF5104375', '4602435000769', '- 2500                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B0B202E-7B9B-471F-9963-F014F0E80D47', '50A08BCF-7DDA-427A-8085-D6F04F066A62', '4607007361255', '  1%  25                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAE1F21D-9202-4281-A164-CC2D7D35027A', 'C8AA66B1-87A4-44FB-AD82-AD31F16F2B9F', '4013054002407', ' 50  / 10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C76F1881-60DA-4D71-A012-4E18C639A936', '1D193BE5-0CBD-4C29-A3BA-0AC05A87AE90', '4607085312101', '   / 20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFDFF01D-77CA-4C44-AB54-56D78C8C1F03', '1D193BE5-0CBD-4C29-A3BA-0AC05A87AE90', '4630011650015', '   / 20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C38F8A42-4F62-4A06-8431-ECC381DEE412', 'E04A3155-2476-47F1-9E4F-FACDBB081BCF', '4013054004302', '   20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68B2719C-241D-4E9C-9171-CC7594CA81C3', '4A01C74F-1F11-4E93-A9A1-E8A0AE068235', '3582910041870', '- 0,04  6                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18256E48-1BBE-4F9A-A594-93A119475AF6', '2B8CA313-DC2F-4DD1-A6C0-A6C692C2C386', '3582910060758', '- 40  24                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EEC9D55-8AA7-46AB-897C-E264B5D4B82E', '7AF7BA69-34C7-4B2B-BA2C-46B539CA8C06', '3582182886223', ' 64  4                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26E9FEE0-E42C-4CA0-93AA-11F34C95438A', '82382419-E336-4970-8679-FD678D2328B3', '8901148060012', ' 0,02  30                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2B67D2F-DDEA-45A4-BDB4-EBEECB35961A', '56D31EC6-361C-4424-BB0B-D12C6404B662', '8699526132702', '  20                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB498753-AC93-4C85-ACB6-E3D2EB361165', '56D31EC6-361C-4424-BB0B-D12C6404B662', '8901083060122', '  20                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66955E5F-227D-44BB-9DD0-26D25471E83A', '13ADCEA0-20FB-4886-9267-8C673CC140D6', '4602884010326', ' /f/ 25 . .                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('361E9E7C-7B04-4ECB-BB09-4BB27428F271', '067E6F9E-75A4-475C-988E-9CB5EA468C74', '8901148224490', ' 0,01 //  20                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('396B6D5C-3883-4117-A437-9CB5A02971BE', '3D1276CB-36A2-4857-B179-744C652AF2A6', '4602676004991', ' 4% 10                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77D5B6C3-726B-4D8C-BBFE-A36F922A6BCF', '3D1276CB-36A2-4857-B179-744C652AF2A6', '4607005931344', ' 4% 10                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55DB5E0C-CB8A-4E6F-950D-82EA002877D8', '01306617-79E3-472F-9871-4FF491C0C47A', '4603182000019', '  /600/ 0,25 10                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76B8D1BD-EE5E-46F0-BD3C-DDB80F2A19C7', '9CBE1905-B4FA-42E9-8699-845921C1E6C8', '4601669000675', '   10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17353653-E651-4E17-961C-BD9F1787D085', '30C78937-FF01-4945-8FB9-54CA7F690D1F', '3582181923073', '   3 30                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D720781-3231-4D34-BDB0-0BC1DF3B9686', '2FB6FA76-6E2A-4374-A36A-86A7A834C57D', '4602824008628', '  10                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ADA458D-CD47-4F04-B62B-03AAFC45DDC3', '2FB6FA76-6E2A-4374-A36A-86A7A834C57D', '4603179000947', '  10                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22F4F108-FA37-4691-BD1F-C40D6E2389DA', '2FB6FA76-6E2A-4374-A36A-86A7A834C57D', '4603182000071', '  10                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('803D6F0D-62CA-41DB-8B0B-5E0EDD912AF4', '2FB6FA76-6E2A-4374-A36A-86A7A834C57D', '4603276006354', '  10                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94018772-1546-4494-ABB2-17CC36F623D0', '2FB6FA76-6E2A-4374-A36A-86A7A834C57D', '4604060992501', '  10                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14DE46A6-BFE5-4A1C-A01F-202339680637', '8C779B68-30A2-431A-A912-92097C39C75E', '3582186000007', '    3 30                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80743A61-3BDD-4C0F-A7E2-EA52A6C7C04E', '01FF8FF0-0904-46F0-8555-EBE706C213CB', '4810201002255', ' 0,05 20                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD035F2D-E500-4353-91B6-55919C77D262', '0A7EA2F2-1498-40D1-BA87-53D2A0AE7B05', '4601669000378', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('150BD01F-8652-462D-8592-2743A99563EB', '0A7EA2F2-1498-40D1-BA87-53D2A0AE7B05', '4602809000043', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80E186AF-F6E0-4376-AF4A-A1143E6280C3', '0A7EA2F2-1498-40D1-BA87-53D2A0AE7B05', '4602824002947', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBE5517E-F86A-40B3-A1E3-CFEA46C4243E', '0A7EA2F2-1498-40D1-BA87-53D2A0AE7B05', '4602876000380', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37039B30-643A-4D3D-A883-6821FA74722B', '0A7EA2F2-1498-40D1-BA87-53D2A0AE7B05', '4603179000046', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD0C93C3-084C-4A27-BF2A-9D3AB0880621', '0A7EA2F2-1498-40D1-BA87-53D2A0AE7B05', '4603182000033', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9F01189-C9C8-4103-BBDE-645B33A4E4AA', '0A7EA2F2-1498-40D1-BA87-53D2A0AE7B05', '4603276006217', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE3E316B-93FA-46EA-8770-C46980DCEA72', '0A7EA2F2-1498-40D1-BA87-53D2A0AE7B05', '4604060081052', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04B1E32B-15E6-4BEC-B06E-F4EDF0982401', '0A7EA2F2-1498-40D1-BA87-53D2A0AE7B05', '4607027766597', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE780950-8ACA-49D8-A69A-B9F084AAD65F', '0A7EA2F2-1498-40D1-BA87-53D2A0AE7B05', '4607100620044', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15A66575-0291-4D5A-A9C6-4AAB284D0923', '33B5F0D8-0640-4541-AAF4-544480CA7B0D', '4600828001904', ' 0,1   50                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5487F678-B765-491B-8434-2B00E7A39952', '33B5F0D8-0640-4541-AAF4-544480CA7B0D', '4601687000015', ' 0,1   50                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50C0CE33-0A20-4D7F-8263-5F6C3D78DD5F', '33B5F0D8-0640-4541-AAF4-544480CA7B0D', '4607027763572', ' 0,1   50                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B37FFAF-9B96-4265-A032-B655C9D96380', 'E8643453-C408-4EFE-961C-69647C85302D', '6432100002525', ' 18,9  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D17CB066-3557-42A2-B6B9-755DA3D5FDDF', '0170623D-51A9-46CA-A694-BCCA491F2806', '4601669002488', ' 0,01  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B32EC79-E411-40D1-B514-ED0110A4A341', 'FBB99358-BA3B-424C-A2F1-F370BC6002C1', '4601669002129', '   20                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5AF080C-B7F5-4372-BBB2-5C4C5B83EFEC', '2AC6C07D-5A09-409D-8D58-882C69915529', '5995327166193', ' 0,025  60                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('117FDE96-3A63-4EBD-89EB-868EA631B43C', 'E595E5C4-213D-458D-A477-45B08B8C8085', '9088881269526', '  0,05  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('734D2406-E011-4FDB-8E34-97CC93859910', 'D1FD10F6-77CD-44EC-904E-48168A392241', '8595026461338', ' 0,0025  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFCAA58B-8AB9-49CC-AEBC-9D78C02A4904', '994F1B0D-3B64-4E0A-B141-3E9B9A5B5A30', '4601669002112', ' 0,02  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59773C2E-CC62-4D2A-AC28-26015ACDF2DD', '1400D985-3AAE-45C3-903F-E50BA2EEE4C2', '9008732004502', '  0,05  28                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63EEF530-FCF5-4A29-B08B-8FED1B884BD3', '68FD6345-3A52-42BE-AE00-5108C59858F9', '4601669000392', '  / 10/  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81FB944E-B7F7-42B4-9968-9D8F7D9CBCCA', '227AD4E6-742F-487B-9B2F-2D95429384CA', '4601669001092', '   10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63880464-CA77-488C-9239-D2FAD1EDF1AD', '227AD4E6-742F-487B-9B2F-2D95429384CA', '4602876004364', '   10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA3F2206-545E-4ED3-A282-82743E552173', '227AD4E6-742F-487B-9B2F-2D95429384CA', '4603679004254', '   10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FBD0FEA-FB84-47E9-8E4E-AC2149DF155D', '227AD4E6-742F-487B-9B2F-2D95429384CA', '4604060021218', '   10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1274C16B-6A35-44CD-ADBB-071621A46D60', '01AAEE64-5531-4805-9B84-FCDB3A8C174D', '4603933000312', '  1% 10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA08FCB5-CFB0-4788-803A-8BE7568931AE', '01AAEE64-5531-4805-9B84-FCDB3A8C174D', '4603988009193', '  1% 10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1785A03E-BCD0-4D66-AD94-A636580637BD', '964405A6-D737-4A0F-B826-BF3145C09E55', '4603905000111', '  5%  - 10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C0AD760-9F4D-400A-8BBA-6E768F495880', '964405A6-D737-4A0F-B826-BF3145C09E55', '4603933000367', '  5%  - 10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AE748B9-E6A6-4C49-B9BA-0439CDF07DFE', '964405A6-D737-4A0F-B826-BF3145C09E55', '4603988010915', '  5%  - 10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FA98E5C-C884-494A-AE6C-E887340C2F38', '964405A6-D737-4A0F-B826-BF3145C09E55', '4605847000020', '  5%  - 10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EED170F-9582-446B-AAE7-60CFCCFF805E', '964405A6-D737-4A0F-B826-BF3145C09E55', '4606367000316', '  5%  - 10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09A21DD0-7319-4D95-B7FD-D4E321806C45', '45364574-E3CE-42E8-92EA-1DA2517CDF09', '4603256000136', '  1%  - 10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05CA9207-D713-48BF-B34F-857E9550113A', '45364574-E3CE-42E8-92EA-1DA2517CDF09', '4603988000015', '  1%  - 10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47C79837-9A05-4CD3-8578-82BE56726347', 'E435BF42-46BC-4503-8E46-FDCCA949648A', '4603256000167', '  3% 40                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42EB34F3-B71C-46A4-B75E-D9F71A2BDDB3', 'E435BF42-46BC-4503-8E46-FDCCA949648A', '4603380000552', '  3% 40                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC16FF4A-C24A-4658-A9D0-097583DF2EFA', 'E435BF42-46BC-4503-8E46-FDCCA949648A', '4605404000159', '  3% 40                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B251DC5-AD35-4982-9CF8-76F16441D01A', 'E435BF42-46BC-4503-8E46-FDCCA949648A', '4605681001771', '  3% 40                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C97367CB-DE36-4BEE-B19B-AF7D8FBB4759', 'E435BF42-46BC-4503-8E46-FDCCA949648A', '4606367000385', '  3% 40                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5ABB0FA0-86AA-4DFB-ACB9-8009F31765E8', 'E435BF42-46BC-4503-8E46-FDCCA949648A', '4607007360739', '  3% 40                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('228CB443-1CCC-48CF-9881-51FF46AF5109', 'E435BF42-46BC-4503-8E46-FDCCA949648A', '4813331000016', '  3% 40                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD64E63D-D911-4690-B196-0B24BDC74FB8', '4C55519D-2CD5-4F43-B12C-4613720D349E', '4603933000381', ' 5%  - 1  10                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCC4DF60-95B2-4C57-BF9C-396ED5729B0F', '01F16DE9-C9C5-4CD1-BBE6-F78033DD2533', '5000158105317', ' 200  / 10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F2D406C-BB01-45A5-B00B-455D0EE66580', '706B5EE6-93F8-42B7-9CE4-90A6C12F4F74', '4607009582078', '   20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A29CECCE-5616-47BE-962C-1AB918C3B403', '7BD3DBAC-2DA4-4025-B798-F9C474292F61', '4605340000312', ' 12  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3C2F0F8-95EA-4DCC-B6F4-A138C403D473', '7BD3DBAC-2DA4-4025-B798-F9C474292F61', '4610020540019', ' 12  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47E5DF1E-CE93-4D74-8194-27591FC13A90', '176FF7C6-1D5B-44AC-8B13-A714F0996C26', '4602193010635', ' 0,09  7                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('622C7741-8786-42E2-8084-96CE5657570C', 'DCF1FD0A-F0C7-44D9-8483-4A5114E5B82A', '4601669005984', '   12                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8B23DC3-0D7E-4912-B181-516141882704', '140B5F90-DC3B-424C-8FD4-7328609C3196', '5995327275147', ' 0,025  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE619A75-B55B-4C37-BA1D-07E5CB216C7A', '4344C1A0-D254-4CA6-8B8A-137BDF8D50CC', '4013054008003', ' 0,4  / 10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD8E0009-06BB-4D5C-9214-EF4224058DBD', '43275E05-8E1A-4150-A11C-8C7A57206CF5', '4601669005670', '  0,25  50                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4E3384D-B444-47EE-9692-77F51DDA1E3D', '43275E05-8E1A-4150-A11C-8C7A57206CF5', '4603988011899', '  0,25  50                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D41550F-DC28-4A0B-A645-7F0C5BDFE45B', 'D8FE03CC-48BD-4D9C-A459-108BCFCC970C', '3582181923004', ' // 3 10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F39798E4-5D54-4180-81D9-3C4FADC1C644', '448DE942-4809-46E7-8D04-8CEB854E948B', '4603182002105', '    20                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('231BB4C7-E7FC-44EC-9AAA-F9D97576620F', 'FDA3FF18-8E87-4266-BEC5-C5FBCC1DC9DD', '3582186000014', '   3 10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00B4AF6E-1AA5-47A8-A708-F47341DFA3C4', '021D9D9C-8072-41C1-97E9-2771ABCBD1CB', '4013054001264', ' 0,005  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5223F4A8-B0CE-4702-A0F6-C13D7C31E396', 'D6CC89D2-0A15-4FA6-A9D4-C749EE1CD5C6', '4013054003756', ' 0,01  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D186D4EB-5574-413F-9D76-4BF1D779624C', '33F95ECD-E71D-431C-B008-71586774D069', '4601669005991', ' /. 1 50                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B94835D4-BA38-40F7-A55C-8E638430DAF2', '070C6005-8BAF-48A3-B8E4-E6FC7373699F', '9088881269540', '  0,1  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9401EFA-5400-476D-8296-B1FAA4CE22C3', '030C7899-0F9C-4C52-B4F4-01AD188F7CCA', '8901086040213', '    N20                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBA3611C-D54C-487E-8A08-0151BB18F27A', '4414999F-E45C-4256-B2F8-E7214367C04B', '8901086180117', '  10                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2D41AF7-C503-43E1-9584-63F48EE76AEA', 'E9B0F54A-519E-46B3-BBB4-3C10A6E7E1D1', '4601669003799', ' 30                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('781B5EDD-E608-4CF0-91A9-EFFA2D43C689', '4026A310-1A4C-43F6-9EA4-05E4530B4059', '4607045190947', '       10                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21DFE4A9-5040-4442-9B3C-085D9525D515', '4026A310-1A4C-43F6-9EA4-05E4530B4059', '4607045191357', '       10                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('293958F7-70A6-4748-B94C-3F8B562D04DB', '4026A310-1A4C-43F6-9EA4-05E4530B4059', '4607045192248', '       10                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53FE1D53-EC81-486B-B74D-27F785191225', '38EB8C98-444A-4C64-BFCE-8A5170072E15', '4604060071039', '   10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6583FD27-0C0D-4879-979B-46C6B264C45E', '38EB8C98-444A-4C64-BFCE-8A5170072E15', '4604060071046', '   10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B11130E-9F75-4241-829B-6491BD47708D', '38EB8C98-444A-4C64-BFCE-8A5170072E15', '4604060992204', '   10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41FEBCEE-CCCD-487D-87C5-08C5EC16758D', '38EB8C98-444A-4C64-BFCE-8A5170072E15', '5600030071039', '   10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D07264A-61EC-4817-8565-F75A4D5CDB6B', 'EE39A474-75EA-4CA0-9577-F7B964E26646', '4603365000195', '  -10 -  0,1%                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F234B36-FD78-45F3-B59F-D9B0BA946805', '7118F886-AB06-4574-A503-44651C3255E8', '8901086041517', '    100                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D26A9E73-8C18-463F-89DE-3ED2425B1596', '2DBC0A17-869E-4B2C-AE05-0C23B9491BF3', '4603933000725', '  100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A6A6210-1925-4495-B416-EBCFCCD0DDBA', '2DBC0A17-869E-4B2C-AE05-0C23B9491BF3', '4606367000330', '  100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('792A1CE6-4D0A-4BE4-AAD0-41151C977EEC', '194F4242-F708-405B-9E1F-9EC20C25B0E3', '4607019010363', '  20                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31068B48-BB23-4930-82F2-223914282D4A', '194F4242-F708-405B-9E1F-9EC20C25B0E3', '4630009620013', '  20                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA314B87-A892-453A-B88F-9B72808F9BE6', 'D04B8699-4D3E-47CB-A961-8C52E16DCB71', '4605095005570', ' 0,1% 10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3501315A-86EF-4DFC-BDDD-86503F3EDB0D', 'D04B8699-4D3E-47CB-A961-8C52E16DCB71', '4607083724241', ' 0,1% 10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D32735CE-0709-4E28-B5D8-3943507DB571', '030E2267-4602-449D-9072-13045FD437CB', '4605286000179', ' 40000/  12                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE5B272F-9006-4E20-9D5E-EF6884FE9DC2', '595590D3-DD2B-4C59-86A9-1131EB2D80A3', '4605286000100', ' 150.   10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6CA40A9-D034-4EAA-B628-18828318AD1A', 'F2E33F53-DF81-4369-B2E1-0A45A19C755B', '4607009582412', '    N20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4896263-A240-444D-9FC6-66DC647EFC42', '9A6623A4-430F-47DF-BC38-49614A9F886C', '4607101209569', ' 3- . .   3                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC9FFEF2-E224-456B-A268-2BAF4231EDF3', '9A6623A4-430F-47DF-BC38-49614A9F886C', '4612734310032', ' 3- . .   3                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D93745BF-7454-42D5-9EAB-4F3F9143A1BF', '9A6623A4-430F-47DF-BC38-49614A9F886C', '4612734910010', ' 3- . .   3                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFFFBF1E-E526-4626-81B0-F149C120DE79', '9A6623A4-430F-47DF-BC38-49614A9F886C', '4612747430505', ' 3- . .   3                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('559E90C4-FACC-4C22-B7D3-E99B26F27AD5', '4BB37A52-F821-4521-BF7C-447503604E5B', '4602876004678', '  0,025   10                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA6D3484-98EB-438F-BF67-CDD550B2831B', 'DC9C869A-2C5D-486B-A2F9-DFC44318B0D2', '4605286000209', ' 10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09F61CB2-DBBD-4C56-9C0C-6882BD5A83C8', 'A8C58F46-2313-49F8-A5E6-E9E2E0E37002', '3870010001734', ' /  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B1E3703-C911-4C47-8268-09AB9493655B', '30042693-BC88-42B4-A97A-A497644BB44C', '4605286000117', '-2 500000  10                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('074CB3EA-E54B-405D-837B-0CB43016CBBB', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4603179002811', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('256E6D1F-DF77-4A11-B6B5-1240F9E7F57D', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4603179003672', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9E8DDE9-DF0C-44F0-B63E-2DDB6CA588AC', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4603182000125', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DAFF80C-0FC2-4A21-9EDD-2BE74BF7A81C', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4603182001207', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BFB705D-BC4C-498B-BA7C-98E42F214D62', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4603276006149', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42A63E40-08EC-47D0-85E9-13CD4D9374CA', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4603988000626', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F57C716F-910E-4648-954B-CFB9D6689336', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4604060071114', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41D5C198-5CC0-42DF-87D6-B120ABF4458D', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4605180005508', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D4ABEB5-92F5-4941-AE66-25B5DF2F055E', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4607003664510', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F529CB5E-F1AC-432A-814C-ACC07076E819', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4607003684839', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67EA87E8-9016-4370-BEF8-4A563456A102', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4870050003766', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8523A206-F651-4E70-8E2D-EBFAD8CB69D2', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4870050003773', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2731DB7-BBEF-40E7-A592-6CD0BBE9640E', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '5290880071091', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B0A8BE6-A31A-45A4-9D6D-B42E8BFC81FE', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '5609869000081', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38E456A9-0D77-4741-993C-C3BE9FDCFB34', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '9604980000626', ' 50  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('369053DB-F856-493B-BD77-59D4A9298E31', '9607F8D3-8CEA-4C38-8A48-F71CF0A95660', '4606683000014', '   100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DC8ECB6-EB10-4714-84E6-8CF23DCD71F2', '4E341CE3-90FE-4BA1-B799-8DE722104EEB', '4605180006666', '   20/                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9584F3BC-60CA-4B23-8276-84E14011233F', 'ED4CA7AF-0845-494F-A161-E3E20902F869', '4602546004885', ' 100                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B74449B0-680E-4602-AE81-EDAF46890A58', 'ED4CA7AF-0845-494F-A161-E3E20902F869', '4603933002293', ' 100                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACA588E2-30D8-4F41-8699-A2018D559E8A', 'ED4CA7AF-0845-494F-A161-E3E20902F869', '4606367001412', ' 100                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A65FD381-A15A-4C09-AE60-9EC0954F763E', 'A79DA787-ECC9-4A5C-A3F0-BD8B4A911846', '4013054001103', ' 0,008  25                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64A76659-36EA-4EA3-8D41-413BF51AC8D7', '04766B27-F1CC-42F9-990B-7628E5CFAF16', '2000621486533', '  40                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22365725-92F0-4CAD-8BB4-D14D6B257058', '04766B27-F1CC-42F9-990B-7628E5CFAF16', '4606809000980', '  40                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE853F44-5FCF-429B-8B62-47C39E4658B8', '04766B27-F1CC-42F9-990B-7628E5CFAF16', '4610011880292', '  40                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E64B9F6-2573-4053-9BC3-A7D3C8E75B0D', '04766B27-F1CC-42F9-990B-7628E5CFAF16', '4620005230460', '  40                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1317FF55-D09F-4C4C-B757-39719CB3F620', 'CCE9877E-B9C6-4E7E-A80F-922FB3E71647', '4606809000966', '  40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36D94757-63A4-47EA-A962-6D75E53FD15F', 'CCE9877E-B9C6-4E7E-A80F-922FB3E71647', '4610011880315', '  40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F17C771C-FDAF-4A93-9405-D2A35326D15A', 'CCE9877E-B9C6-4E7E-A80F-922FB3E71647', '4620005230446', '  40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('898A82AF-9371-4EDD-BB73-36889E2C6756', '18236276-4DB0-445F-8E16-0D3D22C4D5AA', '4610008490237', '    40                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04F16D6D-5025-4BEE-8354-AAA669E76444', '6B24C1CC-1F57-4D23-8788-52C0855076D5', '4610011880254', '   40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('394C463C-AEA8-4715-8CBC-CD1870873710', '520204BD-58B7-4845-9015-C6D7489FA32B', '1678005690138', '   40                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C6BC15C-54A3-4184-8FF9-38316ED20A34', '520204BD-58B7-4845-9015-C6D7489FA32B', '4607005280657', '   40                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37F24E24-A24F-4F32-86B8-A33810B9BC44', '520204BD-58B7-4845-9015-C6D7489FA32B', '4610008490138', '   40                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E380FEA6-0223-45EA-BC25-86A227594D53', '520204BD-58B7-4845-9015-C6D7489FA32B', '4610008490145', '   40                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFEA40CA-FF7E-4192-B5AB-5A09F27AE1BD', '520204BD-58B7-4845-9015-C6D7489FA32B', '4610008491371', '   40                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FF096B1-4378-415B-9C89-BA8403188E82', 'C2292932-8150-4232-866A-1798DFBE6806', '4610008490176', '  ( ) 40                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E53BCEC0-6F57-49C0-BA3B-F7A70F677A8F', '8FDF9BBE-5544-4A87-9792-1EE370B95367', '4610008490312', '     40                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC169162-F32A-4E5E-B6FF-6B18605A8270', '8FDF9BBE-5544-4A87-9792-1EE370B95367', '4610008490329', '     40                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A20E9F77-D221-4F1B-A9F4-E508BC29A5A0', '8FDF9BBE-5544-4A87-9792-1EE370B95367', '4610008494198', '     40                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD128A10-2894-4BC5-B20C-1E6BE3028524', 'B881D6F9-2418-4B33-92DE-B3D1C9E7731F', '4610008490152', '    40                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2919B177-C4A1-41A6-8BDF-54D7B16964C1', 'A5FBDDA8-CC39-4723-8A7C-5CF4FF11E78F', '4607005280367', '     40                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A3D408C-8D3F-45EE-A190-5654F412FC8B', 'A5FBDDA8-CC39-4723-8A7C-5CF4FF11E78F', '4610008494235', '     40                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70E3DDAC-4441-4E1C-81C2-254088D76792', '4E529304-B3BE-49AA-A11E-F5FFA17C57D3', '4601669007728', '   50                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCA47932-1DC4-453E-BCE0-A1AB594E0C10', 'DFD5B970-AB9D-4DB2-9EA6-75A1E6523FBA', '4606809000942', '  40                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D69D91BA-0097-4B9A-8AF0-38C4E23C5E72', 'DFD5B970-AB9D-4DB2-9EA6-75A1E6523FBA', '4610011880278', '  40                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CEB48E2-E24A-45AC-9E1C-4A98B10CC3B2', 'DFD5B970-AB9D-4DB2-9EA6-75A1E6523FBA', '4620005230422', '  40                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2868846-16CC-4500-9E62-EC1DBC3402CF', '04A5DC41-0DBB-4393-96FC-B7B8948D44DC', '3800010629386', ' 0,15  60                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A934A45E-8FC9-4036-95C0-36EA0C945C56', '04A5DC41-0DBB-4393-96FC-B7B8948D44DC', '4607027765200', ' 0,15  60                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93AB7A4C-B38F-4F6B-AADE-D6C961916848', '04A5DC41-0DBB-4393-96FC-B7B8948D44DC', '4607027766306', ' 0,15  60                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ABC6259-E7B4-444F-9A70-7B2ABE410901', 'A4E987DB-2D14-4D48-9D37-2E1A2F4527B9', '4602565015442', ' 0,02  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10ABC74B-1604-4A56-B20A-383639A9652B', 'A4E987DB-2D14-4D48-9D37-2E1A2F4527B9', '4607022750478', ' 0,02  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0DFB16A-5D3C-4C39-B3C1-2516FF6FCE45', '7BF67264-AD9F-43A3-80D4-63D9E6EDD3A4', '4600828001645', ' 0,15  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1350D06C-F20E-49C7-BFC0-98EF4826EE96', '7BF67264-AD9F-43A3-80D4-63D9E6EDD3A4', '4602565016142', ' 0,15  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB4DA5D2-E019-46EF-A833-A33E713B8781', '7BF67264-AD9F-43A3-80D4-63D9E6EDD3A4', '4602809006267', ' 0,15  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A256008-DF0C-4B6C-9429-E6F4F5B70E1E', '7BF67264-AD9F-43A3-80D4-63D9E6EDD3A4', '4603276003490', ' 0,15  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6682BDEC-B306-47DC-A6A2-96EACCED3DCD', '7BF67264-AD9F-43A3-80D4-63D9E6EDD3A4', '4607019010172', ' 0,15  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7416E37-03FC-4759-BFA4-5030C69B8985', '7BF67264-AD9F-43A3-80D4-63D9E6EDD3A4', '4607027760137', ' 0,15  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB70508D-D764-4928-A2F7-D9D1FBD985B4', '7BF67264-AD9F-43A3-80D4-63D9E6EDD3A4', '4820135585519', ' 0,15  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A00D6858-0082-4859-BEE2-070318565D62', 'D2F88A1C-4590-4917-A9A3-8CEE3C046937', '4603671001152', '  0,1% 10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('236AFBA3-0C3D-418E-A764-87FBBD874D12', '635FECE6-860B-431C-86B4-66F68ACC1ED2', '4605180003016', ' 1%  - 100                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFE8B087-82D9-473E-B539-C5B8ED93F653', '635FECE6-860B-431C-86B4-66F68ACC1ED2', '4605180006116', ' 1%  - 100                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E96227A-D5DB-4F07-BEE5-A3AC542920A5', '635FECE6-860B-431C-86B4-66F68ACC1ED2', '4820090052286', ' 1%  - 100                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B00A851E-53E2-4A03-A937-943DE87AC89B', '635FECE6-860B-431C-86B4-66F68ACC1ED2', '4823000800021', ' 1%  - 100                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4A53A5A-2DE7-41BF-BB99-376020E775FF', '635FECE6-860B-431C-86B4-66F68ACC1ED2', '4823000804708', ' 1%  - 100                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A33AEFD-E86E-49A0-BB85-FE4243DDBD75', 'B47C852A-56CD-44E7-91EB-7651F440E797', '4630008940037', ' 0,01 % 150 -                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7F536E8-B1A9-40AA-A9BC-20AC4EC0A2F5', 'CE42FE5C-DD96-45FA-92C2-B2B1F1A03603', '4029799117245', '  100                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5C36CD5-662C-4B80-9B6E-3A99A8021166', 'BFB35064-CD63-4A6A-BC53-B9747091F061', '4600828000631', ' 1% 10  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D195EB9-8D60-432F-8A55-9F38760F57DB', 'BFB35064-CD63-4A6A-BC53-B9747091F061', '4600828010630', ' 1% 10  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DCDFCAB-CCAB-4BCF-BA74-15613B4999EE', 'BFB35064-CD63-4A6A-BC53-B9747091F061', '4602212005772', ' 1% 10  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69D9E9B6-5BD6-4525-8BBF-F20BBC607DDE', 'BFB35064-CD63-4A6A-BC53-B9747091F061', '4602212006069', ' 1% 10  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A996C23-7E68-456B-9177-F03E4A68D1F0', 'BFB35064-CD63-4A6A-BC53-B9747091F061', '4602212006076', ' 1% 10  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30F7FF63-B21F-4B2F-B7F2-84CF85C281E7', 'BFB35064-CD63-4A6A-BC53-B9747091F061', '4602824001247', ' 1% 10  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('658B00CA-252E-4F10-8371-DD44731A0DDF', 'BFB35064-CD63-4A6A-BC53-B9747091F061', '4602884002581', ' 1% 10  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D19F509-D06E-4908-9986-818D4663C21A', 'A9FCFC8E-B6BA-4C2D-B856-4ACCE3C7999C', '4029799116231', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0748089-638C-495E-AD99-8F23736C0234', 'F9F4EEEC-463D-447C-BADF-CF84ABAE7311', '4601498000655', '  / 1,5 20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE478678-E5C2-4C3D-B6F7-42AC3D05201B', 'F9F4EEEC-463D-447C-BADF-CF84ABAE7311', '4602242005728', '  / 1,5 20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CFBCD01-BF17-4C74-97E2-1E98A401AC90', 'F9F4EEEC-463D-447C-BADF-CF84ABAE7311', '4603171100102', '  / 1,5 20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AD334AE-0A75-4277-9511-201DE6C08D59', 'F9F4EEEC-463D-447C-BADF-CF84ABAE7311', '4603717000958', '  / 1,5 20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C1907C1-22CC-44B8-96C6-76679B81E4A1', 'F9F4EEEC-463D-447C-BADF-CF84ABAE7311', '4603762001566', '  / 1,5 20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A39A37BD-0DAE-4016-A7D9-8FD3874DDAB1', 'F9F4EEEC-463D-447C-BADF-CF84ABAE7311', '4605113001041', '  / 1,5 20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ABF2D43-0C33-49A6-93C5-99D7B4B30639', 'F9F4EEEC-463D-447C-BADF-CF84ABAE7311', '4607066260643', '  / 1,5 20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE9C7F31-4FDF-4F7A-ADEB-AD82F6B32778', 'F9F4EEEC-463D-447C-BADF-CF84ABAE7311', '4660005620106', '  / 1,5 20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0997C6A-18CE-405E-AF67-076F5E18B471', 'F9F4EEEC-463D-447C-BADF-CF84ABAE7311', '9602490006824', '  / 1,5 20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36E5EE0B-3B2D-46DF-AE54-F77DF845D878', '7963F162-B042-42C9-BC96-FF95AA0E082E', '4603619000087', ' 10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4465E6C-806B-43CC-BE1F-352ABF9EEA6D', '0535B08B-2715-4CBB-B86D-FFD369EB3277', '4600828000716', ' 1% 10/ 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C470B969-EA1C-4BCD-A1D3-5D6DC439D109', '0535B08B-2715-4CBB-B86D-FFD369EB3277', '4600828010715', ' 1% 10/ 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42EC580B-0075-4554-8F04-E7626AF3C3B5', '0535B08B-2715-4CBB-B86D-FFD369EB3277', '4602824000066', ' 1% 10/ 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27C5D445-EB2B-4046-A04F-346CE2A2BC4A', '0535B08B-2715-4CBB-B86D-FFD369EB3277', '4602884002406', ' 1% 10/ 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6AAF4BE-3AD8-4B5A-BB32-2F9E323B13FA', '0535B08B-2715-4CBB-B86D-FFD369EB3277', '4602884015444', ' 1% 10/ 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F59FF0D2-A797-4935-A5A6-9852C61F16AF', '0535B08B-2715-4CBB-B86D-FFD369EB3277', '4607027767662', ' 1% 10/ 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CB8D798-006A-4AAD-90B4-F796CE567917', '0535B08B-2715-4CBB-B86D-FFD369EB3277', '4810133000954', ' 1% 10/ 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB29C5A2-B83E-45EB-9912-E0B027644730', '0535B08B-2715-4CBB-B86D-FFD369EB3277', '4810133005546', ' 1% 10/ 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64C8821B-F32E-4D6A-9425-BADFA00E8E06', '0535B08B-2715-4CBB-B86D-FFD369EB3277', '6930169702764', ' 1% 10/ 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEDF9283-EA4F-4DF7-8FF3-D95D75045BD7', '0535B08B-2715-4CBB-B86D-FFD369EB3277', '6930169707219', ' 1% 10/ 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4197E5C-27F9-418B-B160-0CB15C4EDE84', '0535B08B-2715-4CBB-B86D-FFD369EB3277', '6938588802270', ' 1% 10/ 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61F1788E-2A76-4725-B2F1-9960D0F15AEE', '8636C85F-806F-4AFF-BE8E-BD1377379D12', '4810201000381', '* ( 12) 500\  1 10                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2DC2F22-CD1E-4FEB-887C-2701A1944E18', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4600828000037', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2EF2774-3B83-47F5-BAC7-1C5D6B87978A', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4600828004431', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F192B53-D651-471A-839C-34718D2A14B1', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4602072021462', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B1CEBE0-5985-4E2F-94BF-90FB35942E4C', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4602212000111', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5765D07-7EAC-42E5-BE96-08D97A144F4E', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4602509002309', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CF1DE0B-293E-49EA-8EE6-2290C5F0E4C3', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4602824001209', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FCA263F-9C60-4639-99E6-5DAA43C74DF8', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4602824019624', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D56366FE-C995-41DD-B758-CC4D15F3F2A5', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4602824021023', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0642B7A7-AA97-4430-BC24-429AAAFB4AC7', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4602884000129', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCC4354A-7313-4FC9-AFD4-214A380B0144', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4602884015154', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEF8C772-E93C-4047-B485-4C539FCD0EAE', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4605260000485', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CADE274D-B3C5-4A74-BEBA-E4C539F18B01', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4605894000219', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29AC2AE8-AE8F-4D7A-A489-7813C3E475AF', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4605894001452', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82B65FAB-7063-4FB8-8609-8B0B6F04DDB7', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4820044116866', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02B81043-0812-48CB-8FD2-75B4E6183207', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4850001740063', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC280ECF-E17C-4A3B-89BF-D49E3419C157', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '6916119020515', ' 50% 2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF550470-54F7-4D75-9C17-E3942FBC82A9', '07FC8358-6599-43E3-AF14-A2EE06AA8221', '6916119020256', ' ( 12) 500\  1 10                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC28F5A3-5B88-40D3-B364-8DB4D9CD1810', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4036534202029', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A30BD6EA-4FFB-42B4-9107-53647185462E', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4036534202036', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8268473-F3B8-4A64-8338-4A2C724E5474', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4036534202074', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('752EA633-65F0-46F5-ACAB-0A1340848047', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4036534202081', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D9DDF2A-5D9A-490C-AACB-B3AE28A4AA72', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4036534222027', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('669B2291-D6D1-46DC-A98B-34C9A2F5DCA4', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4036534271025', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EAC671B-B78F-4851-B71B-CDE0FD304CC8', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4046963890179', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('131D608B-C6DE-472B-9624-9C6157A9412D', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4046963890186', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C961ED4-8E6B-4547-A647-F07B38C27C18', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4046963890414', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F89A8A1-15A1-42BA-8E12-075A9A9807E3', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4046963929367', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB356B82-12D9-4FBC-BF6B-94953A23BB35', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4046963929374', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A0D34BA-8CC3-4D00-9AD5-9456DF398D0E', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4046963929398', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FB23608-92BC-4307-B132-80E3738BA5FF', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4046964105456', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C872E3EF-790C-4BBA-A60A-432E7FB7611C', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4046964105463', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E7ED9CD-710A-47AF-A43D-006DEFD58CCC', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4046964115226', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('494ECA29-C629-4757-8942-3F34084D556C', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4250431900110', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CD78CAF-A495-45BE-B3F8-5C09BBFE583E', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4250431900325', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA6A1A96-A178-4FB4-A758-F20C00A715F4', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4250431907645', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CC0E271-6A7D-4489-AC63-7D311578E9F5', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4250431908574', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CF3E240-485F-4388-B942-3A8702349330', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4250431914872', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B32CF4EA-BB33-41E5-9E33-7FFE3D7ACB56', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4250717500102', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79466F35-B217-4257-A22B-E6FD53789023', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4250717500348', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DDAA508-A274-4557-BAFC-EAEC03980EAF', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4260090441176', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03579689-FEF8-45AA-8510-D9E322889C02', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4260090441978', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96961740-8510-4511-82D9-4FD6B4A388BC', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4260090442494', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1CDEE01-3078-4002-9512-05B7E9559262', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4260090442708', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE7EB0A1-95A4-40DB-83FC-CF3431EF9975', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4260090444504', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C492D91-6840-4675-85B7-1716A6AF4F21', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4260090445310', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1B9248E-0332-4390-BFEC-AADF6A06F615', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4260090445822', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA5A9DDB-2561-4282-B05E-2F968488E112', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4260090448649', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('357422D1-80F7-4410-A8E3-C6C783529E9B', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4630000910052', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D80498D-7A71-41B6-8F18-66BEAA771CE1', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '6959287500502', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C6D272E-2DED-4E28-83AB-7FF8D2A43BD4', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '8428235077642', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AFDB827-7F07-468C-A598-CC260E1329A8', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '8428235317816', ' 5                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA248895-C10A-4D5F-95EE-EEE5A7DFDD7E', 'D5215C8A-6246-4DC2-9965-1D13160FDF60', '4810201000312', ' 12 200/1 //  10                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC41AC9F-4207-46FD-ABC1-C78F8D848E9C', 'D5215C8A-6246-4DC2-9965-1D13160FDF60', '6916119020249', ' 12 200/1 //  10                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF265E98-E720-41B5-BC0D-54561D2AD414', '05583FE5-0B3F-402D-B0C6-E1755BCE08D9', '4607037190603', ' 0,004 1  25                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16BBA5ED-2110-4E87-9924-686CEFA2B233', '05583FE5-0B3F-402D-B0C6-E1755BCE08D9', '6916119020287', ' 0,004 1  25                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6807697-678F-4128-884E-D07D9241D912', '05583FE5-0B3F-402D-B0C6-E1755BCE08D9', '8906000572238', ' 0,004 1  25                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83EFC66A-81EB-4A82-B48C-59CB541E891E', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4036534201022', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7FF3034-4CF3-4480-ABDA-43888787719C', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4036534205020', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA7B6016-8027-4031-99D8-57AA63497D88', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4036534205037', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6A3D82D-07FC-4AD8-B927-CF0585892519', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4036534205082', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99ADC6A5-D6B4-4DF8-870F-FE83AE1E2182', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4036534205150', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75DD1DED-0DF0-4BE6-B71D-26F439807971', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4036534226070', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69F69C39-B17E-49B8-9057-9469BB5CC531', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4036534270028', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('808478E6-ADDB-4927-9A57-285FFD01C748', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4046963890162', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACEE0A14-3D1B-402A-9F42-852A2E24066C', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4046963890407', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97BF11E0-19AF-4795-8327-1FAC4F744F85', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4250431907607', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE5F4CF2-3231-4D5E-B679-3BECE71D2C3F', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4250431908536', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBF35657-9471-4C86-92AE-0792226141A2', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4250717500287', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C7D1D5E-715C-4E02-97B6-C01BEB228368', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4250717500430', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EC0AC04-6BA2-48F5-A27C-EA198148A80F', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4260090441145', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FC8079B-049B-4AC9-8A71-DE3F1EB5A38D', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4260090441619', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F8F04F3-2BEE-4782-8A73-2F4AEFED630D', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4260090441961', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A09B9B9-F853-4247-A106-64220CA8C518', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4260090441992', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5880FA70-EA1A-452D-868F-3FBCE06F6618', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4260090442401', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D67C8FCD-AAF8-4645-85B1-F595425D504C', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4260090442463', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF1D5C89-15CF-4E87-A0FE-BAB687D0BBFF', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4260090444474', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F68A4956-CCAA-4DBD-B3C1-D4C95C83B0EA', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4260090445297', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7CF2DC2-CEA5-45E2-AD99-F624E7B2905D', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4260090445792', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BEB98A0-B091-46FF-A213-8986DDD4E14B', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4630000910311', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C000B006-7914-4D17-AF2E-EE1CAD7A241D', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '5009612920022', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B334A65C-26B9-4A47-9BA3-D06627138962', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '8428235017846', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD9D7450-12DD-464E-B4EB-C90D1E547151', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '8428235077611', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E202415-D1DD-4796-B049-E775C65DB3D5', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '8428235317847', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB6F14DE-0D30-4982-90EE-3DD8EC235BF2', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '8586006518418', ' 2                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('684901D7-37F6-49CE-85BC-76A607E9F957', '53FA8387-B8D0-41BA-B81E-31D6F119391D', '4602824001285', ' 0,5% 10  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0607A30-66A1-456C-8203-85D123CD5CD8', '440F8431-BA64-4FF4-B0B1-874112CE3E34', '5944700100019', ' 0,01  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('844EB2EE-5A6C-4D13-9851-50D7D62D4F32', 'DEEF3432-5D25-4491-A34F-7F43977BC8C9', '4850001740056', ' 12 500/1 //  10                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB0A3473-C1FE-4A34-939E-F87B582CED1E', '79F0B55F-F271-4B48-B918-356385BC8F93', '9003638150001', ' 0,008  /- / / 5                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('638BD976-EB7C-452B-B8B7-06D185441EB2', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4036534204023', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81AD6F6D-8770-44A8-BFC9-EF8830B9D56C', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4036534204030', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DAA1256-CC22-4226-AB7E-62D35FF46523', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4036534204085', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50399B78-C355-4922-A513-6EF436B7103A', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4036534224021', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AD6FA4E-53B5-403F-9FF3-71AED6F6E973', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4036534273029', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('540B05A4-0971-4C29-9619-AD2C88F8114F', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4046963890216', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D42F60D1-8BCC-4788-BC59-7BFBB2A582F0', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4250431900158', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACB93B56-59FB-408B-BB7B-354437CF6B58', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4250431908154', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBFA85AF-4A64-455F-B1B5-964961BEA81E', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4250431908611', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04BD6E09-E276-4A6D-AAF1-E0DC5CA1ECB4', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4250717500164', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23A746E4-B52D-4732-A029-F673218D6F65', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4260090440681', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FECC1C03-9E64-461B-9507-86A762162906', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4260090441190', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0286F7F7-2F9A-4A10-9342-6DD64AB59F72', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4260090442036', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('672AE38A-F327-40F7-9482-E01980729F93', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4260090442456', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('979D1E17-AE82-45C6-ACB2-CC0BDFB0FB0A', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4260090442517', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('480695E2-7019-4DB0-802F-A9FA1555C516', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4260090442746', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE4DDDDB-491C-4E93-9C6C-7B6FBB0B26A9', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4260090444528', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB95FCCC-9980-40F8-BBC5-77162A959D49', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4260090445846', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09C2CA45-DD0A-413B-8819-2DA0F20052E5', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '6959287502025', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E97DA1F4-E233-4137-980E-F287A79D58A8', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '8428235317854', ' 20                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF0ABE71-D17C-4489-8BF1-59F99907144E', 'F439EEDC-8A21-46A7-BE57-1C2C99D040F0', '4036534203026', '  10                                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5309278F-EBB1-4BDC-93F4-8C7668A3D581', 'F439EEDC-8A21-46A7-BE57-1C2C99D040F0', '4036534203033', '  10                                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA0DB8A9-6C82-4C45-AA2F-849A8542D432', 'F439EEDC-8A21-46A7-BE57-1C2C99D040F0', '4046963890193', '  10                                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9B621AC-1686-4BC6-A2E3-A5DA89172EC1', 'F439EEDC-8A21-46A7-BE57-1C2C99D040F0', '4250431908598', '  10                                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F84A192-616A-449E-A3AD-376BA9E42254', 'F439EEDC-8A21-46A7-BE57-1C2C99D040F0', '4260090442012', '  10                                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('810F925C-D5A1-4955-9381-E4D14A1341D5', 'F439EEDC-8A21-46A7-BE57-1C2C99D040F0', '6959287501004', '  10                                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B155C88-026E-452F-938C-929A6526F7A8', 'F439EEDC-8A21-46A7-BE57-1C2C99D040F0', '8428235017839', '  10                                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB301287-1EB2-43A2-B0A7-E28AFFCED7DF', '9C164E6F-F396-4556-BD3D-0D8D785C5ACF', '4033033552266', ' 1                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E52E377C-6E9A-494C-926F-C212822B6819', '9C164E6F-F396-4556-BD3D-0D8D785C5ACF', '4036534200025', ' 1                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D9016F0-8254-410B-8956-8589AF6B2A19', '9C164E6F-F396-4556-BD3D-0D8D785C5ACF', '4036534207024', ' 1                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E5D0603-867B-45DF-8C8C-494229460C01', '9C164E6F-F396-4556-BD3D-0D8D785C5ACF', '4036534208021', ' 1                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28CA852C-02A6-490A-848D-51617489CAD5', '9C164E6F-F396-4556-BD3D-0D8D785C5ACF', '4046963894610', ' 1                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F44B09C2-B835-4CA6-803A-54573464939B', '9C164E6F-F396-4556-BD3D-0D8D785C5ACF', '4250431908499', ' 1                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF82E9F9-BF44-4767-B7F1-F2C64D657E04', '9C164E6F-F396-4556-BD3D-0D8D785C5ACF', '4260090444467', ' 1                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75A74F57-CD5D-4818-94C5-271D5991A08A', '0588CBB6-0422-462E-9866-B69F44334810', '4603905000098', '  1% 10 -                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35F54740-6EEB-447D-8B01-351D347A546D', '0588CBB6-0422-462E-9866-B69F44334810', '4603933002101', '  1% 10 -                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD93E077-03BE-46A2-B68C-0EECFA73D9DB', '0588CBB6-0422-462E-9866-B69F44334810', '4605681000071', '  1% 10 -                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8779AF76-8BD6-458A-AA07-09CA37A6AF33', '0588CBB6-0422-462E-9866-B69F44334810', '4605903000124', '  1% 10 -                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C37CCD3-92DD-4C1A-91A5-38D51C41A8E6', '0590AA97-CC21-485A-A2B3-F68D76FABCB3', '4013054000625', ' 0,025  100                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('580B895E-6B8C-4A0C-853F-5215B8AD3CD2', '7464CCF5-29FA-49DC-ACB5-FEAD8187CA8A', '4029799125554', '    60                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C7F7F55-121F-4531-949F-D66EE8118942', '6C9F7634-9ABD-483D-861B-4FFB56D407B7', '8715554000339', ' 0,01  / 20                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57F1A23B-0355-4713-9A00-4A77D024390A', '167C89C2-52DF-4221-9005-02B05B9BCDC0', '4602193010086', '9    400  / 30                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64C7AC62-FF21-4AC1-9C57-03F60EBE63A1', '536470C7-7C72-49A0-BE14-A5648BE34770', '4605469001726', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0496AE6-69AC-48A9-AEF4-A65BE1B88FB6', '536470C7-7C72-49A0-BE14-A5648BE34770', '5997001382516', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EECA94E8-F16B-4DBB-A956-2EC754CDF14F', '73718C02-66FA-4D9C-8CDB-83FDCD00D494', '4602509001388', ' 0,2  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AEE9089-49C3-4FE8-A587-6B6DAC10AAFE', '73718C02-66FA-4D9C-8CDB-83FDCD00D494', '4602809000111', ' 0,2  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12FABF40-53FE-4ACA-8552-4FFBB07EE9B8', '73718C02-66FA-4D9C-8CDB-83FDCD00D494', '4603276001533', ' 0,2  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBF64071-F5B1-486E-BC2C-15290ADE125B', '73718C02-66FA-4D9C-8CDB-83FDCD00D494', '4607027762643', ' 0,2  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F50F2E7-2673-495C-A0A8-971009176A20', '73718C02-66FA-4D9C-8CDB-83FDCD00D494', '4810201004815', ' 0,2  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F145FF7-35DA-4279-AEEC-FC05BEB612DB', '05A2E22C-F1B3-4BD2-B9C0-7BDE40297CBF', '3800712041714', '    10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B58DC5E3-38D7-4D56-9833-D49D3A347A3E', '7B6B2062-E556-4022-B56C-C8371F679CAB', '4607098450234', ' 16  20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CA3A1BF-BEF8-42E4-A9D4-9410C9C109AB', '7B6B2062-E556-4022-B56C-C8371F679CAB', '8715239090099', ' 16  20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26ABF9A1-DB90-4732-AA8E-F964ED7BAE96', '339A7927-6984-4BD1-8FF0-B3A94B7CF506', '4601764007111', ' 10 //  / 20                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DECAB4F-9E3F-4855-A471-DCAC915F1923', '775AD94C-B27D-4EC3-AC39-F9CA4BC230F9', '4603671001572', ' 0,1% 15                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E384FDD9-49C4-43D1-BF86-397153EDD60D', '775AD94C-B27D-4EC3-AC39-F9CA4BC230F9', '4607005930248', ' 0,1% 15                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10769389-2791-4F14-864A-E4CBFEE33EF8', '775AD94C-B27D-4EC3-AC39-F9CA4BC230F9', '4612728340021', ' 0,1% 15                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('410DB804-5AF0-49A9-90B6-8BE3938E075A', '775AD94C-B27D-4EC3-AC39-F9CA4BC230F9', '4612728340045', ' 0,1% 15                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5DBD166-D01D-4E7A-A460-A0C6320970BE', '775AD94C-B27D-4EC3-AC39-F9CA4BC230F9', '4620004740236', ' 0,1% 15                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C1EAC30-4D04-472C-A022-D0E36365883F', '10A0D632-A723-4C4B-B4D6-295618077A2E', '4601669006745', ' /  24                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D57F832C-C814-47F5-B084-8D0BC679A1F8', 'F175A321-E893-4049-8D38-42DDE9E67392', '3800712740112', ' 500   20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6569255-1DCC-4E69-8EC3-FB54F33EF2B2', 'F175A321-E893-4049-8D38-42DDE9E67392', '4605635002052', ' 500   20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9BC6447-AC8D-4040-8B67-089D09DA463D', '05A7FC91-B7F8-420C-8CF0-E8774B4B606E', '4030855000036', ' 100 3  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('633FECFE-E709-421C-A240-86CCB56DE503', 'E7A17AC0-B519-4B6A-968C-4A9643F19045', '4601498000730', '  2,5% 30                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B24A6D8-CD8D-4F4A-9C2E-8CD0131EA5B4', 'E278657D-AC4E-4072-9739-A37729A8ED75', '8717627103237', ' 500+10+200   10                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('953CDF8A-98FE-4ABF-905C-2DE1503524C7', 'D2DAD82C-4523-47BD-9C7A-A0A2ED8FE257', '4030096245111', ' 0,03  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BA91044-5180-4D3A-9EBE-7CAA868321A8', '06066AB1-2D29-4AF9-A947-1DB7BD39674D', '3592752779725', ' 2,5 % 30,0                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C160898-84A9-44F7-9B87-1ABB1EA88DBC', '06066AB1-2D29-4AF9-A947-1DB7BD39674D', '3592753779731', ' 2,5 % 30,0                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F5E6B1C-57D2-4CC4-B4FC-699B6740BD16', '227DF16E-2D86-4DAE-811F-8734119D4810', '8000036000076', ' 50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E111A40E-42D8-4195-8E3A-92AA8B367E5A', 'A27C55FF-E9EB-4363-8B8A-899A63EE0828', '4606556000417', '  500+125   20                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3A1D09B-7117-4E37-94D6-257445207784', 'BB3C3BCF-DED2-4D25-B122-B02A3E25FC80', '3583313279068', ' 15                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D22C6EE-D0F4-46EE-A4BE-729B2F987E0A', 'BB1AC6B9-CA7B-41F5-AE6C-CC532487091C', '4602193010734', '  D3 0,84  80                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA31F740-99BA-44D2-8A29-AECC0FF07AD9', '8D3E7AFA-0AD6-49A9-85C3-B4D0D7A00FCE', '4029799116248', ' 100                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C0EB4FF-B130-4193-BEDE-2C19F96DC6E9', '8ABCC7FE-EBF7-46A3-BC10-B1B591EA32E5', '4606556000400', '  0,25  20                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3423D4C4-46B2-4D39-97AC-84A79C18705E', '8ABCC7FE-EBF7-46A3-BC10-B1B591EA32E5', '4607098450180', '  0,25  20                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF7978E2-E996-452A-9F1D-E3E1B72EA617', '0624F696-78DC-4FFC-A2FB-FC296C95596E', '4600828001300', ' 0,5  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C71B8C22-068F-45C9-8FFF-DC9C18407FA5', '0624F696-78DC-4FFC-A2FB-FC296C95596E', '4602809006366', ' 0,5  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CA2CDC9-2652-4DD8-BC8B-771EFF09BB5F', '0624F696-78DC-4FFC-A2FB-FC296C95596E', '4603276000307', ' 0,5  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35B49D0E-58DB-4B5C-B049-482361711F8F', '0624F696-78DC-4FFC-A2FB-FC296C95596E', '4603276006026', ' 0,5  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2E40CC8-F6E1-4CA4-8205-6E1B84DF25C9', '0624F696-78DC-4FFC-A2FB-FC296C95596E', '4604060081175', ' 0,5  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAFA954D-652E-44A0-8AC9-6DD3C6472FAB', '2E5BB0CC-8D81-4468-B4C2-0745EBC55115', '4601808000092', ' -   0,1  10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56B23169-3DF8-4305-83EF-54EF30955387', '2E5BB0CC-8D81-4468-B4C2-0745EBC55115', '4602809000395', ' -   0,1  10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93362417-27AB-453C-9BD3-659EE70B4E31', '2E5BB0CC-8D81-4468-B4C2-0745EBC55115', '4602876000342', ' -   0,1  10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF3E2BE7-D47F-4292-BCA3-34729E133B29', '2E5BB0CC-8D81-4468-B4C2-0745EBC55115', '4602876000458', ' -   0,1  10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74697811-C459-4614-BE4B-C4792AC4AB35', '2E5BB0CC-8D81-4468-B4C2-0745EBC55115', '4603276006262', ' -   0,1  10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('640E1309-6FA0-462C-B986-0A49755A39BF', '2E5BB0CC-8D81-4468-B4C2-0745EBC55115', '4603988001807', ' -   0,1  10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94E783C3-0AC5-4E5E-8B18-3E89F070B660', '2E5BB0CC-8D81-4468-B4C2-0745EBC55115', '4607004431463', ' -   0,1  10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8A35540-C1D7-4E38-ADE5-A3CDC0F3B70C', '2E5BB0CC-8D81-4468-B4C2-0745EBC55115', '4607100620105', ' -   0,1  10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F31BED69-1C30-4675-849D-95CBF489175B', '2E5BB0CC-8D81-4468-B4C2-0745EBC55115', '4620006500098', ' -   0,1  10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F50787F-3C06-43C4-BE3A-9AB4DAB91B7A', 'DD0F2C57-8044-45D5-B81B-E8264639137C', '4601669001269', ' - 0,5  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0F4BD47-3B9E-4DE9-A390-DEFE64BEA4B8', 'DD0F2C57-8044-45D5-B81B-E8264639137C', '4602824000349', ' - 0,5  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43741F14-0AB6-477E-A40C-4FF6F6AC1398', 'DD0F2C57-8044-45D5-B81B-E8264639137C', '4603179000282', ' - 0,5  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1526A474-6FB6-4906-B9CA-B55F012F7F5E', 'DD0F2C57-8044-45D5-B81B-E8264639137C', '4603182000026', ' - 0,5  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52AEFF8A-CF82-428A-A969-4204CED007F6', 'DD0F2C57-8044-45D5-B81B-E8264639137C', '4603276006057', ' - 0,5  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1605B523-F5DA-4D3A-9897-47406C3F96DE', 'DD0F2C57-8044-45D5-B81B-E8264639137C', '4603988001951', ' - 0,5  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE76BD70-3335-4F31-AAD1-7DB66856A7AF', 'DD0F2C57-8044-45D5-B81B-E8264639137C', '4604060081090', ' - 0,5  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41AF3CCE-ED01-4D70-93AC-56293B469695', 'DD0F2C57-8044-45D5-B81B-E8264639137C', '4607100620068', ' - 0,5  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('377E4EAC-C940-4A82-A6F2-F7CC9E7F9478', 'DD0F2C57-8044-45D5-B81B-E8264639137C', '4810201004044', ' - 0,5  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ACD886B-420A-4885-B73F-70B9D390118E', 'DDCDD003-3ACC-4274-A2E8-9116711E42AB', '4603179000145', '  0,25  10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D072111-2534-4103-96F7-C443BF997026', 'DDCDD003-3ACC-4274-A2E8-9116711E42AB', '4603276000413', '  0,25  10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BE50E4C-FDCA-4CBE-A300-D164002A4C57', 'DDCDD003-3ACC-4274-A2E8-9116711E42AB', '4607100621188', '  0,25  10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BC1159E-6986-4A68-9200-1732A4CC21C8', '0659ACBB-0551-4FA0-9B6B-C7D03218BD34', '4030855000210', ' 0,03  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCBF420E-7815-42F2-879A-5C1D05E86C65', 'FD7E509E-FF0E-456F-814F-87A2E57282DA', '4601764001652', '    10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31C3FB57-D111-474C-9D13-B10F34CCD758', '27F1C010-0472-435A-9C50-13D75599E668', '8901148010017', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57602CC9-748D-4C60-B20E-8A96999C3FE8', 'EA25DE73-3B6D-4AE9-8239-C0BFE733E560', '8901148033061', '  3% 1  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4860192B-787C-4589-8E49-FC2020B1C2A4', 'EA25DE73-3B6D-4AE9-8239-C0BFE733E560', '8901148230514', '  3% 1  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FC2B525-62CB-43F0-8835-B53E314B625E', '06945F76-8E39-42FC-9EFF-7BC4407C8D0D', '4602676002959', ' 0,05  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE7F40AA-6856-4197-AB08-8303DA862764', '06945F76-8E39-42FC-9EFF-7BC4407C8D0D', '4604060071459', ' 0,05  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFB31510-9BAC-435C-93CF-9345BB64AD97', '06945F76-8E39-42FC-9EFF-7BC4407C8D0D', '4750258240128', ' 0,05  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED0632D4-AB9E-4F18-BB32-F00ACE6521A0', '10A1F6E1-FBC9-4D05-B715-9822764EAEBC', '2400004762221', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE803750-D914-4993-B0EF-4D62C5E81273', '10A1F6E1-FBC9-4D05-B715-9822764EAEBC', '4606741000475', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EEA0F89-9AA1-4A83-BE99-3300F24AE4C9', '10A1F6E1-FBC9-4D05-B715-9822764EAEBC', '8906000570319', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69606689-FF7B-4A26-9402-DD145BF72D1C', '6C64C025-287D-41EA-8A91-EF00CFB04AE0', '4601808000030', ' - 0,05  200                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C951B866-140D-484B-A11A-CBA0CDF01923', '6C64C025-287D-41EA-8A91-EF00CFB04AE0', '4602876000687', ' - 0,05  200                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B457D91C-B292-483D-99E4-455792B554BA', '24BC806B-182E-4906-8BA9-91AF82E3E1EB', '4601669000606', ' 0,5 /  20                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D64A4911-76EF-433A-B434-D2A1AB2EFC81', '24BC806B-182E-4906-8BA9-91AF82E3E1EB', '4603179004280', ' 0,5 /  20                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65A4F8D9-F4D1-417C-91CA-69B4EEED3F8A', '06B7D4A9-9975-474C-B03D-52299CC62795', '4602876002216', '   10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2775000-D819-4805-B290-33B594FAC57A', '9A5E089D-2C96-4BE1-80EA-D1B13C588B18', '4602876002155', '  //   13 10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FF6B5B7-A5E3-45A3-8861-F512866E7C5C', '0A91F9D2-1D2E-4A18-BD44-E0B9684871BA', '4607009581187', '    20                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0A5CFCA-3A50-4912-8F62-F14544CF7C2C', '0A91F9D2-1D2E-4A18-BD44-E0B9684871BA', '4607009582245', '    20                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8865047-4AF4-4353-A22E-1190249E9264', '61D9CE7C-1229-4589-A740-666C3387853B', '4022536872728', ' 0,0025  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26CCE4E5-C130-448F-B81A-5DF597828113', 'AF565DC4-3A19-4C44-9B49-9554D260715E', '3850114213189', ' 0,005  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36BA10CC-9A4F-4592-920F-B81BA58D4B71', 'DB6FB4F2-F611-4C5E-A997-F72D662D9549', '2400004732828', ' 25  / 30                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15D20C0E-9DF2-4C93-9C95-8FA7168276F2', 'DB6FB4F2-F611-4C5E-A997-F72D662D9549', '3800010629393', ' 25  / 30                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0854A35-1D9E-4BC7-AAF0-0CC825DB9654', 'DB6FB4F2-F611-4C5E-A997-F72D662D9549', '3800010643153', ' 25  / 30                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C5AE14D-F844-4611-AE6D-DE8A06CC9A0B', 'DB6FB4F2-F611-4C5E-A997-F72D662D9549', '4607027761448', ' 25  / 30                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52C5B14E-14EF-45D4-AC42-AC8DCF466EB9', '541F908C-1097-4655-8D94-0C38722BC05C', '5995327166223', '  50  N60                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93141DBD-475D-479E-9F04-C14752464449', '1CABD250-88E7-437F-AF32-2AF04412D889', '5997001381649', ' 0,025  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F422479E-B285-479B-A3B0-5039D1BD02B4', '0710CF7D-4966-4CF0-BF30-EF717FDF930E', '4603149000083', ' 0,025 //  25                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A11EE4B4-CE7A-45F5-A533-31956506EFE2', '3A21AE9E-3384-4CCD-A1AD-0E9B69EFF302', '4602193001046', ' 0,001  50                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C27D75EB-020E-427C-A9A4-AC798B2A6B40', 'AEA5C642-9A1F-4503-8543-A8E223A3F8A9', '4603713000044', '  108 25                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB4CD0DD-854D-46B0-81EB-BCE2F729730A', 'AEA5C642-9A1F-4503-8543-A8E223A3F8A9', '4605681001948', '  108 25                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8634B015-5B51-4162-9827-01269A9FD657', 'AEA5C642-9A1F-4503-8543-A8E223A3F8A9', '4605903000964', '  108 25                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('226A4ACD-8D8B-4292-9D67-1E62AB4F81EB', 'AEA5C642-9A1F-4503-8543-A8E223A3F8A9', '4606367000019', '  108 25                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B17DE2B8-2F52-4DA0-8B5C-CC666346E331', 'AEA5C642-9A1F-4503-8543-A8E223A3F8A9', '4607007360050', '  108 25                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FD26587-D278-4547-A360-BE428363F9A5', 'EE155B44-97E9-4FDC-B416-177AAC7DF482', '4602424004693', ' 0,25  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('649F9BD4-7BE1-4D72-B870-155295C191FA', 'EE155B44-97E9-4FDC-B416-177AAC7DF482', '4602676002508', ' 0,25  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2383EFD-4DDC-431D-830B-452B6B7F05F1', 'EE155B44-97E9-4FDC-B416-177AAC7DF482', '4605422005228', ' 0,25  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1860D692-D3A0-458A-B302-49CDCAA36135', 'EE155B44-97E9-4FDC-B416-177AAC7DF482', '4607024944653', ' 0,25  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B988C89-FDFA-43B4-8DDA-1629206017B7', 'EE155B44-97E9-4FDC-B416-177AAC7DF482', '4607027762650', ' 0,25  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81485EFE-6969-4B7A-A4CA-56FA6D2D7787', 'EE155B44-97E9-4FDC-B416-177AAC7DF482', '4750258002023', ' 0,25  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('998A4840-AFD8-45AD-BF3A-3DDFF678D8C1', 'EE155B44-97E9-4FDC-B416-177AAC7DF482', '4810133004686', ' 0,25  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A552C88-1B5B-469F-9968-2C06C2BD7FF0', '2DF960FC-9CCF-4B5E-AD78-BE1962DC53C9', '8594739028401', ' 15  / 30                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EEFA51D-B930-4DC2-A239-07B366D09BA9', '2DF960FC-9CCF-4B5E-AD78-BE1962DC53C9', '8594739028487', ' 15  / 30                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F5E7ABB-4AFF-4F96-9461-8BC61E524715', '78C814E6-085F-47FA-8F6A-1EE054EF3BC7', '3800010643412', ' /. .  20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AFB3B13-E46D-4F04-8609-459F17ACD5BB', '075B1D57-5BF2-414A-B83D-3B554D837336', '4602212007653', ' 0,5% 10  10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('274DF62E-52C3-404C-B332-72AD54128130', '075B1D57-5BF2-414A-B83D-3B554D837336', '4602212007721', ' 0,5% 10  10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D9B3468-B88B-448C-A0F4-1D0958DB2B69', '075B1D57-5BF2-414A-B83D-3B554D837336', '4602212007738', ' 0,5% 10  10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13578301-93D8-48FE-A6C0-602037B3E184', '075B1D57-5BF2-414A-B83D-3B554D837336', '4602884002567', ' 0,5% 10  10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA174FF8-C54A-48EA-A4DE-1634461C30F8', 'EC713951-F037-45B2-98DC-0968D78BAACB', '4606224037714', '                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD85250B-538C-4511-AAC1-AAB123567F13', 'EC713951-F037-45B2-98DC-0968D78BAACB', '4612730250028', '                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0FF9598-CECA-494E-BF7C-046276427C9F', 'EC713951-F037-45B2-98DC-0968D78BAACB', '4612730250059', '                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39894474-0450-45EC-8639-FBE419E68AC4', '8924FB9B-6C41-41F9-A560-DA22950B7FBB', '4022536645605', ' 0,025% 10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('358B4401-5EFC-4860-A9A4-258559CC7671', 'C2519826-5175-48E2-B629-602C6BC65781', '4603671000339', ' 0,25% 10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('922422CE-10FB-496E-A090-174356E4E958', 'C2519826-5175-48E2-B629-602C6BC65781', '4603671001459', ' 0,25% 10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('395E47D1-7F7F-44B4-8903-90A86B474CA7', 'C2519826-5175-48E2-B629-602C6BC65781', '4607005930262', ' 0,25% 10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('019D3945-2F0B-43E7-909C-2D0FD49ACA45', 'EDA541DB-1ED6-4F8D-A1AB-151180881545', '4605095005563', '  0,05% 10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D490BF1-9B87-457B-8FD6-E2B70E05B4C5', '07F8F355-2842-4BB7-AD97-EE7DF32E020A', '5000158068025', ' / / 150 1                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82EC7841-8EFE-4319-B702-FBFC0D5EE6C5', '5CF74687-AE5E-4BD6-B30E-521CAEC03A98', '4601026301766', '  //   0,1 10                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91198638-6CED-4E90-8A70-B46656A27350', 'B170B5CC-C386-4785-BB5F-DB6C095F7CF8', '4030096245128', ' 15 5 100                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6598321-A626-40AD-9ECD-6F4B6383B2D0', 'AD935C23-C657-4206-BB4C-B9394A9B496B', '4607028391347', '  125000  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E06CC60-0741-4ED2-934B-79C2DFE9C2CB', '714E0F32-DD22-4BEF-9580-F7BE7B9DD85B', '4601026301773', '  0,25   10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE109C09-634F-4C81-B404-2510B035CD57', '08C51BDE-481E-4CF7-A6BD-728202A09446', '4030113617792', '   30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82309C25-7A43-4061-878C-47DC0937E459', '445285FE-8BCE-44F7-86CB-FD842C05A115', '3800010643771', ' 0,035  80                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C6CDF44-915D-4F5E-AD16-C5A5D46817D7', '445285FE-8BCE-44F7-86CB-FD842C05A115', '3800010643788', ' 0,035  80                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4C84E5C-8E9C-4569-A13E-B241DE3A5E6E', 'B1D6B8F6-DD42-469B-9AE0-B8BB75E827E7', '4032128011329', ' 10000    20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DC68BB5-A378-4815-B1A9-F4102A60D0E4', 'E856D004-084B-4D5A-8E0C-F7A07552FF7F', '9008732004519', '  100   / 28                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11BAB90D-4378-46C0-AAAF-EEE3C94A7E74', '0967D908-3D3C-46FF-9DE0-3CD6CB7D801E', '4602453002066', ' 0,05% 100 -                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('007112D5-7E4A-4659-B5F7-C4B3B8CCB0C6', '0967D908-3D3C-46FF-9DE0-3CD6CB7D801E', '4605903004016', ' 0,05% 100 -                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1028355-CED7-45FA-9D72-E78B055CB75D', '28702EAB-D602-4B2E-ABF3-70A79BC3F8FC', '4601026301551', 'c  40                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0FB682F-8BCE-42B6-A56C-E17E227E8023', 'ED427B94-C3A4-42CC-BCE2-5CFAD59BABDC', '4607109940242', ' 1016                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('117B9C18-A9C4-4D2E-A605-C96438F2F1E2', 'ED427B94-C3A4-42CC-BCE2-5CFAD59BABDC', '4640000900236', ' 1016                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E64C30DD-97AB-44F0-8BF4-A0EEA5FB34E9', 'ED427B94-C3A4-42CC-BCE2-5CFAD59BABDC', '4640000902537', ' 1016                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E69E3E8-6805-4E96-B45E-F15DAA2EA6F2', 'ED427B94-C3A4-42CC-BCE2-5CFAD59BABDC', '4640012272864', ' 1016                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9D546B0-84E2-4461-B9A1-9CFCFF1D5F10', 'ED427B94-C3A4-42CC-BCE2-5CFAD59BABDC', '4680381006240', ' 1016                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBB5CF24-C6A7-4839-B8C4-92D24068D738', 'ED427B94-C3A4-42CC-BCE2-5CFAD59BABDC', '5602705960204', ' 1016                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('842CC158-59B4-4873-A766-1CACDB2E4B6F', '09D1CB9B-E18C-4D83-A138-B83D0E992382', '8901109200792', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6483BB6-8712-4055-A7E5-97181D0DB2DD', 'D0BE3EB4-B3A1-440F-8DC1-AE7D7C31B3CE', '4601669007575', '  20                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3D3317F-87C7-469E-A4C5-9333DE55DE2D', 'D0BE3EB4-B3A1-440F-8DC1-AE7D7C31B3CE', '4823045200572', '  20                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32409B69-1372-4ECD-8901-A8A4E4819868', '7D13C548-CD77-4F76-8799-3ACC56D96A89', '4603179002842', ' 500  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80DB9B8C-44B4-443B-A537-303FC698CDD9', '7D13C548-CD77-4F76-8799-3ACC56D96A89', '4603276001373', ' 500  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDAF87DE-F609-4A61-96B5-700547C3F7DC', '7D13C548-CD77-4F76-8799-3ACC56D96A89', '4603276006125', ' 500  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71FF8338-5370-4581-8CCD-695662D1E85B', '7D13C548-CD77-4F76-8799-3ACC56D96A89', '4607047720333', ' 500  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7582EBA6-A604-41AC-A22D-0A148C3B5718', '7D13C548-CD77-4F76-8799-3ACC56D96A89', '4607100620082', ' 500  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3F30572-4266-4597-AEB8-D00EB4F10D3B', 'D6933740-EFDB-46C8-9AA0-48F264234156', '4601669000590', '  500  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('293F9157-FD0D-4079-A510-79249519B79D', 'D6933740-EFDB-46C8-9AA0-48F264234156', '4603182000057', '  500  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('803D1C88-8758-4F13-A145-3CA83CAD5976', 'D6933740-EFDB-46C8-9AA0-48F264234156', '4604060071169', '  500  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D099847-284F-4A6F-BAEA-892E2A120235', 'D6933740-EFDB-46C8-9AA0-48F264234156', '4607100620372', '  500  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F339926A-6615-444A-AB7E-2E899620E18F', '0A867A2A-C7E8-40DC-B1EC-EDB6BACCB7BB', '4602242007180', '  /  6/ 0,55  / 40                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77FC1427-A56E-4C50-ACAC-7BB7D4F440E5', '7101C021-15DD-4C6B-8634-CA802759FBD4', '4602242007074', '  // 0,6  60                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F8CC5EE-EB83-4D45-9EA2-713A142204B3', 'DF07B05E-1D7C-4748-8E3D-6E2A93162ABA', '4602242004349', '  0,3   20                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9086DD9A-A16C-4A63-90C8-063C0E027E7C', 'B7B51B49-6F27-4C7B-BE53-CD0E8E67ACAE', '4607027761622', ' 0,2  / 50                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0950CC9D-8C81-495E-A9E8-0BB727FB4EAF', 'B929F94D-0342-4408-92D7-5D41A2EA77B5', '4601429005278', ' 50                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EACFD80-E100-4FCB-9335-6990943D6308', 'B929F94D-0342-4408-92D7-5D41A2EA77B5', '4603256004288', ' 50                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AC2A7C9-9FA8-4EC9-B034-3B7680891800', 'B929F94D-0342-4408-92D7-5D41A2EA77B5', '4603933003146', ' 50                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B4C3DB2-D282-4309-8D8E-FEB29CB940A6', 'B929F94D-0342-4408-92D7-5D41A2EA77B5', '4605422009257', ' 50                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A38DD90-A885-4EB6-92E8-DD0DBB55C871', 'B929F94D-0342-4408-92D7-5D41A2EA77B5', '4605847001690', ' 50                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11DCE0CA-D867-4F75-97F1-403218AB4BD4', 'B929F94D-0342-4408-92D7-5D41A2EA77B5', '4607007360715', ' 50                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD178C3B-03EB-4A97-8EB2-32237868DE5D', '6592B179-15CD-42BE-8DC7-D5CA55015665', '4602242005995', '  //  40                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A0061B4-11AD-4594-811E-6D94E381FEB2', '0AB7EC5B-E221-4945-A213-78267A2DCA3D', '4605469001610', ' 5  50                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74E3518A-4840-4429-B330-202EC407DEBA', '0AB7EC5B-E221-4945-A213-78267A2DCA3D', '4605469002860', ' 5  50                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D58D82D-20FE-470B-84D3-65BB4CA15CB3', 'B7102F23-17A8-4074-AD33-1860D7E4C48A', '4607027764425', ' 0,024 /1+1/  30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC5FD2BF-8034-4FF7-98F8-EEA6D3C3EB25', 'B7102F23-17A8-4074-AD33-1860D7E4C48A', '4607027764623', ' 0,024 /1+1/  30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('963D6592-5C79-40E0-B1C3-026B4FCB38FA', 'AFE06A16-E614-4127-BFA9-E9198510D8AB', '3760008320216', ' 0,024  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A69B0F46-E616-40D7-953A-F6A6D5A3F808', '0B32A7C4-5CB9-4866-BEE3-B7EDF5E2ECDA', '4606486002901', ' 0,015  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('456DD7FA-064C-4034-9A98-F55633195391', '0B32A7C4-5CB9-4866-BEE3-B7EDF5E2ECDA', '4607003242008', ' 0,015  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AE6B9DF-1A6E-484B-8F40-CE6912763837', '0B32A7C4-5CB9-4866-BEE3-B7EDF5E2ECDA', '4607005895677', ' 0,015  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F8A11C3-D862-450A-8E1C-0BD1D3340D85', '0B32A7C4-5CB9-4866-BEE3-B7EDF5E2ECDA', '4607020330641', ' 0,015  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('112DBBBC-E1F0-43B3-8ADD-459F50910858', '0B32A7C4-5CB9-4866-BEE3-B7EDF5E2ECDA', '4607027762513', ' 0,015  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D632DE28-D2DD-480A-B43D-58AD9CE4A85D', 'F5434831-168D-49BC-8030-8468AA37844C', '4607055131220', ' 0,0125 //  30                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D94BD76-A973-4C7D-9237-1E5C1EDCBC75', '8D912D09-7B5C-4EAA-82BD-F876D11085C4', '4605554000238', ' /  50                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0572B09D-8271-41B1-847A-B8D839589EFA', '0B949E70-218D-485D-B018-D06841FFC34D', '2400006396370', '  25    10                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85D82EC9-51AF-40E4-AADB-878E254C5632', '0B949E70-218D-485D-B018-D06841FFC34D', '4620750540074', '  25    10                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E1F7810-1C81-4C6E-AA7B-D358C3119AB3', 'F51FA2BD-2E45-4317-B9B7-4F848D5C775F', '4620750540050', '    25 10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C894A129-CBAF-4255-843B-13284F22DBA3', 'F51FA2BD-2E45-4317-B9B7-4F848D5C775F', '4670009600066', '    25 10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80458169-A80C-460F-9291-D270622C75D3', 'AEB74A6B-D938-429E-A9F4-B8D48544EA0A', '4620750540029', '    25 10                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F2DC214-DAF6-4ACA-82CC-A5F94698E3B7', 'AEB74A6B-D938-429E-A9F4-B8D48544EA0A', '4640001381560', '    25 10                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCA8ACC8-452B-42DA-A88C-A405F1AFF659', '86F56B5A-E9BC-469F-A3C9-D55CAC970F49', '4620750540036', '  25     10                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EEF74A9-1FFA-4FA5-9EB7-5CF7C772F567', '0C70F250-79AC-4F4A-8F32-2E41676E10B7', '4620006501217', '  25   10                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C6F4DDC-8F37-480E-AB90-7D5EEB9D7827', '0C70F250-79AC-4F4A-8F32-2E41676E10B7', '4620750540098', '  25   10                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CDE0298-A1E7-40C2-BB3A-8547501085FD', '0C70F250-79AC-4F4A-8F32-2E41676E10B7', '4660011212180', '  25   10                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E6EF368-FD5D-4AE9-A43B-9A1B8DF4198B', 'A427C419-3C18-480C-AF5F-47513CCA5010', '4601808009897', '  50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89A7CB46-148D-459B-8359-4F9506310856', '8741F812-52B8-462D-A011-F3E0CFB2B5D9', '2400006396417', '  25   10                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A772365-67CC-483D-897D-85C18D2D81D6', '8741F812-52B8-462D-A011-F3E0CFB2B5D9', '4620006500012', '  25   10                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6F836C1-4527-4348-899A-4BA25C5A36A5', '8741F812-52B8-462D-A011-F3E0CFB2B5D9', '4620006500036', '  25   10                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB6C8260-903C-4D17-9F1E-8457D7842DF5', '8741F812-52B8-462D-A011-F3E0CFB2B5D9', '4620750540104', '  25   10                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06D1F2F7-60EB-4059-8850-E014388BF744', '8741F812-52B8-462D-A011-F3E0CFB2B5D9', '4670009600011', '  25   10                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5B5D624-DDF6-40FD-8CD9-1971D9C29B6B', '1836619E-5F8F-4627-B8DB-E9049D3171FE', '4620750540012', '  25 //    10                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A606FA4-269C-4766-A1A0-0A115E7487A7', 'E000E352-DC1A-4949-8598-A7B785AEED3E', '4607153450414', ' -   10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE1A11F5-B323-4DC8-ABAB-9CB9E381EC66', 'E000E352-DC1A-4949-8598-A7B785AEED3E', '4610000290507', ' -   10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6B452CA-C601-48BD-9119-C44D7818FA30', '0BA02E57-F4A2-4D3D-8202-FBB423A3F458', '5700666022907', '   30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24D776C3-73AC-45E3-B1EB-41FC32E13EC0', 'F57490C0-DDEB-4AF4-B9C4-DBB4FC5A647D', '5903060006126', ' 0,25  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCA592D7-F7AB-4941-967E-B8542285714D', '8C52A6BF-6998-46C9-9B70-FD2305DD027C', '4602193010659', ' 0,2  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C005852-3F19-4EBC-8FED-D05A52C5EBA2', '99ACBF73-5912-448E-8FFD-7416DB6FB6AC', '4602565020026', '  0,9% 100                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9E2BCD6-2038-47F4-8D24-565729A10DB4', '99ACBF73-5912-448E-8FFD-7416DB6FB6AC', '4602565020118', '  0,9% 100                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71302B87-F75A-4812-A265-A6A967B8F247', '99ACBF73-5912-448E-8FFD-7416DB6FB6AC', '4602824016302', '  0,9% 100                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E14AEC5-2F56-4C90-9A9B-09E37863482E', '99ACBF73-5912-448E-8FFD-7416DB6FB6AC', '4605258000657', '  0,9% 100                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A381BE2C-64C9-48F0-B402-3E6950F1CFF1', '99ACBF73-5912-448E-8FFD-7416DB6FB6AC', '4605453000643', '  0,9% 100                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F84DE96-290D-4209-ACA5-89AD803AC73F', '99ACBF73-5912-448E-8FFD-7416DB6FB6AC', '4607002030729', '  0,9% 100                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D438D019-09CC-4CF8-8BFE-6D19CCDA3465', '99ACBF73-5912-448E-8FFD-7416DB6FB6AC', '4607069220354', '  0,9% 100                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF2F9A5E-BF78-4DD9-A723-C7B99C07AB71', '3275736B-64D4-41A6-82D0-F10F31F2B665', '9006968004006', '  20 - /                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26D56968-142C-4611-BA0D-942783B447FB', '8703E6E0-8823-47C8-BFD3-96E283CE5CC0', '4604060993096', ' 30  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04A8BBCC-0A30-4E2B-A0BF-75AE43E4B1B1', '8703E6E0-8823-47C8-BFD3-96E283CE5CC0', '4606252000971', ' 30  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('324D3A9E-50EC-4064-B6E3-251D3A17C43A', '8703E6E0-8823-47C8-BFD3-96E283CE5CC0', '4606252003262', ' 30  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7690B5D-05B4-46AA-891B-50C56B13F058', '8703E6E0-8823-47C8-BFD3-96E283CE5CC0', '4606486002284', ' 30  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7673671-E821-4DFA-AEB2-D770830BF2E9', '8703E6E0-8823-47C8-BFD3-96E283CE5CC0', '4607003241087', ' 30  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('642F2DC0-21C8-4DBF-B9AE-49026207289D', '8703E6E0-8823-47C8-BFD3-96E283CE5CC0', '5000158100985', ' 30  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA363636-DDBD-4540-9ED2-609C2DE4F4F2', '8703E6E0-8823-47C8-BFD3-96E283CE5CC0', '9006968004082', ' 30  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08666BAB-C13D-408B-AD99-A0FFA14B2B43', 'AD0B54F7-7D4E-4AFF-85C4-AEDCC47D3965', '4030096245104', ' 0,0075 100 -                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C4113C0-455C-4591-9BB0-B01E7C6F16C9', 'C0AA62E3-ED5A-422E-B2D0-A520DA5C4EFC', '4030096292733', ' 7,5 4  -                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAE5FCF5-3B04-4A44-B484-8125121726F1', '0C670C61-1B18-4E23-800E-EDEACAB48383', '4607004431395', ' 0,05  40                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FCCEA6A-B2DB-4B90-869A-FA8C9DC900B2', '0C670C61-1B18-4E23-800E-EDEACAB48383', '4810046000874', ' 0,05  40                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A7CE1EB-08D8-49B4-BC28-0658BBFC091A', 'E39B0214-D313-4EAD-BC20-2C1FC8A36A2D', '4601429000044', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BAD23E3-4FA3-47D5-9899-E189E0CB21DC', 'E39B0214-D313-4EAD-BC20-2C1FC8A36A2D', '4601669002051', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('190C8E10-7A20-49D1-A54B-6316016AF98D', 'E39B0214-D313-4EAD-BC20-2C1FC8A36A2D', '4602876000090', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C640B0C4-35A7-44C5-843E-EC8902900B51', 'E39B0214-D313-4EAD-BC20-2C1FC8A36A2D', '4603256003007', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39B844F1-526C-49A9-8145-38EA98FF5163', 'E39B0214-D313-4EAD-BC20-2C1FC8A36A2D', '4603933000749', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F752A3E-9064-4D6C-9F2F-151ECA625489', 'E39B0214-D313-4EAD-BC20-2C1FC8A36A2D', '4604060022017', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2337271B-4EFD-4661-8C7F-CAB50F42A731', 'E39B0214-D313-4EAD-BC20-2C1FC8A36A2D', '4605847001683', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26CB62FF-2517-4EBD-9604-3218F4B0575F', 'E39B0214-D313-4EAD-BC20-2C1FC8A36A2D', '4607007360708', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7BD50C1-1160-4005-9CF7-251AD1A1C834', 'E39B0214-D313-4EAD-BC20-2C1FC8A36A2D', '4607012580016', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8B0CC4D-51A7-4234-85F8-3C624DF7A3CF', 'FFE47D86-B7F3-4847-B1EC-E38C6CB20806', '4601429004684', ' 50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1B7E491-A5F1-4C77-A7C8-FA0E5162149C', '8570A9D5-74EB-43F9-B7F0-D4EE92F00BE7', '4610000290538', ' -   25 //  10                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8EFB09B-A1C1-41AE-BF59-E83610127334', '8570A9D5-74EB-43F9-B7F0-D4EE92F00BE7', '4620006501200', ' -   25 //  10                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F55AACF-3C65-47F8-8BE8-BF5FB18D5D2F', '28D7AF4E-56AC-4918-A871-B3E2B2ACB38B', '4610000290576', '  25   10                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8890EFB-7F62-4B7F-8C2D-3E95322D24EF', '28D7AF4E-56AC-4918-A871-B3E2B2ACB38B', '4620750540067', '  25   10                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56AF108D-E2EC-41D5-83B5-DF6957732BDB', 'CCA0EEAB-7484-49B6-B304-CBEC0169E4F3', '4640001381591', '   25 10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8BA9384-1810-4869-8C04-B065DB91133C', 'CCA0EEAB-7484-49B6-B304-CBEC0169E4F3', '4660011212111', '   25 10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DE2C9CC-8F9C-4EC0-A423-065303CCF82C', '2B777083-8444-4E8E-9CA6-A0D4AF5B64A3', '4033033417039', 'Evitest /. /24*18/    1                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFDED2E2-C03A-4554-84AF-7DF472201D0A', '0D309F16-12F5-46AC-85B7-5842B2C46311', '4607005280664', '    40                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2616989B-4019-45DA-97D3-B5B9C7419777', '0D309F16-12F5-46AC-85B7-5842B2C46311', '4610008490213', '    40                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28E6DB11-FAA4-4E41-8BA9-F9821B40A046', '0D309F16-12F5-46AC-85B7-5842B2C46311', '5616048790152', '    40                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6705EF5A-7773-47B2-A06A-32C3B39EB6C9', '5CD247FB-5EB3-4CEE-A31A-B1D84FFD4F72', '4607005280398', '      40                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BD6AAD6-63AF-428C-ACCD-CD78109A79DA', '5CD247FB-5EB3-4CEE-A31A-B1D84FFD4F72', '4607005280503', '      40                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C070446-F0F2-4BFF-8710-EFAD1E56AE50', '5CD247FB-5EB3-4CEE-A31A-B1D84FFD4F72', '4610008490190', '      40                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CE44C2B-682F-41E6-94B2-BF4266F0BA8E', '5CD247FB-5EB3-4CEE-A31A-B1D84FFD4F72', '4610008490565', '      40                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B83C5DF4-A870-4632-9657-D1C3F96AFF58', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4036534200032', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98F26A26-3573-4C33-81B4-2F2296D44F1F', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4036534200124', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9107BD3-A429-4EB0-8CF3-2FCF5FDFCC71', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4036534200155', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FBD7287-CD25-49BF-9F96-C6D1D72EA5C9', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4036534207086', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C888E37-BA7A-40CD-B72F-80D092E3A2A4', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4036534209028', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6C9E93F-3F3F-49A0-8F42-54AA2065E6F6', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4036534220023', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51E56A55-8F8C-4066-A80F-5E5B503BD2A8', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4250431908512', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40B24905-5F7B-4347-98C1-B8888C742480', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4260090442647', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('014AADBD-7C6B-4E5E-9E2E-95C9DABB2254', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4260090442654', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3DA5EEF-A4A0-4B43-AD4A-6131010A2C0B', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4630000910038', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31FCF5CD-325C-4D13-80FB-3FBF2C883103', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4630012461061', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F43AFF9-508B-4DE8-8059-48F2512C7F37', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '4630012461078', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('709FC18B-DAFC-4C71-93C5-2D64F684CC2B', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '8717472293305', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('308B900C-684F-49D2-B067-8B2C98752434', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '9002260026968', ' 1                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE46131A-D8D2-446A-AA9D-E5CE05950994', '0ED67A3D-9BD5-4BFE-B621-6F7DF387B97C', '4810201000084', '  -5 0,9% / 10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC5CC5DC-6973-4B8B-8626-13FEB1EF80E5', '6D612267-81C3-4A3C-A41E-281DE16BFF3F', '4602156000024', ' 0,2-5 /  5                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B392CED9-66E3-4752-8298-5C44991E0D31', '6D612267-81C3-4A3C-A41E-281DE16BFF3F', '9003638023831', ' 0,2-5 /  5                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1404DB4F-20D0-49AF-BDBC-2E91F7A11C52', '1120D73C-AB26-4AA5-97A8-600B45A132CC', '0687080360011', ' 10  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3AD0615-C118-4CCF-B0C7-70C3D87713A5', '1120D73C-AB26-4AA5-97A8-600B45A132CC', '4607008360011', ' 10  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88011CCE-FBF5-4601-A5A1-7AF04245A5FA', 'BA278B6F-17D5-4932-8450-FB3EC55639B7', '4601808007527', ' 10% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFF28C0F-2C58-4560-A433-1836A749F5B2', 'BA278B6F-17D5-4932-8450-FB3EC55639B7', '4601808011203', ' 10% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1439054A-30FA-4B52-952E-D50DF292F207', 'BA278B6F-17D5-4932-8450-FB3EC55639B7', '4605964002136', ' 10% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08ABA90D-7560-4BD0-875D-008C3DA211ED', 'BA278B6F-17D5-4932-8450-FB3EC55639B7', '4750232000229', ' 10% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('331C5641-4EF6-4707-8928-299669670BB4', 'BAC3DDBA-6ABF-4D7B-9B18-2F382D33027E', '4605964002266', ' 40 10  5                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFE4588B-3808-42C5-B360-0DEB5185F9A1', '0ED97185-050B-4847-9B5B-69418C53D5E2', '4601669001221', ' /  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F96B51C-AB86-46B1-84E0-054255FEBC20', '0ED97185-050B-4847-9B5B-69418C53D5E2', '4604060071015', ' /  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F89BA5F-4FE6-428C-9E35-FA280959619F', '0ED97185-050B-4847-9B5B-69418C53D5E2', '4604060071022', ' /  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAC475F6-CE7A-4A78-A4FE-528B3F84D00C', '0ED97185-050B-4847-9B5B-69418C53D5E2', '4604060994710', ' /  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C841029F-B34E-4158-AA36-44E3BF0237B1', '0ED97185-050B-4847-9B5B-69418C53D5E2', '4604060995939', ' /  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7901ACE9-ABB6-41C5-9EA7-037325940D5A', '0ED97185-050B-4847-9B5B-69418C53D5E2', '4605180005126', ' /  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0C2FC8B-5FE5-44A7-BCA8-B2FBAB5AC1AD', '76427B77-9DE4-4D62-A074-3488DB4D4D8F', '4601429002949', ' 0,05  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94887CFE-DD62-4B64-9BDC-DE2D076C687D', '76427B77-9DE4-4D62-A074-3488DB4D4D8F', '4601669000576', ' 0,05  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6104AE35-6DF1-4299-88FD-F4D28E2CEF8B', '76427B77-9DE4-4D62-A074-3488DB4D4D8F', '4602809000081', ' 0,05  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C534891-EA36-4863-ADEB-1F68F09EF43E', '76427B77-9DE4-4D62-A074-3488DB4D4D8F', '4602809005987', ' 0,05  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46724E18-7AA7-48BC-A073-C75ACBD20DF4', '76427B77-9DE4-4D62-A074-3488DB4D4D8F', '4602809006342', ' 0,05  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('033B75D1-F55E-4B0B-BDB0-0F2FA99AD39D', '76427B77-9DE4-4D62-A074-3488DB4D4D8F', '4604060071091', ' 0,05  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BBD7843-9147-40F1-9380-4945575CBE36', '76427B77-9DE4-4D62-A074-3488DB4D4D8F', '4605180005133', ' 0,05  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2FE53B6-6D8E-4775-BEA7-393B687DC2B0', '76427B77-9DE4-4D62-A074-3488DB4D4D8F', '4607003660543', ' 0,05  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C29FC1B-E5C8-42E8-BD40-1C4941F3979C', '76427B77-9DE4-4D62-A074-3488DB4D4D8F', '4820090052972', ' 0,05  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7DAF4E5-726A-41DE-B53C-4E842CEAD91B', '2D2EE9BB-B6CD-49A6-81E5-1D1E11D56C3F', '4605180005492', ' *50  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21B9CD89-19ED-4BE9-A726-8914821FADB4', '2D2EE9BB-B6CD-49A6-81E5-1D1E11D56C3F', '4605180006307', ' *50  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1D4576C-2B1B-47C8-B7C5-DAA2826314A5', '0F0ADDA6-57BF-4A30-9431-0539B2B6A6C2', '4607069270212', '      50                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50C1E4A7-07D3-4314-A79D-88AB6404E93A', '0124B58E-64F0-47DE-9BDC-194AF7AFBC85', '4607069270779', ' . /       50                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('162F626A-87A4-471F-B173-1088D843B491', '5FCCAE6F-F2FC-44F9-B1E2-A9A0531FB40A', '4607069270649', '   30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('164DDF86-9858-4BE8-82A3-C6DCEF99E478', '9E43E5AB-66A6-471D-8227-32B1A9FF2C29', '4640006302362', '  44                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76D38FF6-9035-44DB-A233-92755D1C039E', '45ECEB2B-8170-4E15-8C0F-852D61FA7236', '3800009130190', ' 2%  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37D72D8F-B55C-41B0-9071-E7A585739516', '0F1CFE89-6A1A-43AD-9997-DA761C26C355', '4601429003779', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1520B52-E2B1-4543-A9DC-574BF7F7DD2C', '0F1CFE89-6A1A-43AD-9997-DA761C26C355', '4603905002474', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82F43552-F57C-43FE-8949-A503A9367AB3', '0F1CFE89-6A1A-43AD-9997-DA761C26C355', '4604060252032', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEB05181-2027-47CD-8897-B7B92AB1546C', '0F1CFE89-6A1A-43AD-9997-DA761C26C355', '4604060993041', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4CC060E-BD1C-4A7B-A699-20E6D61C4453', '0F1CFE89-6A1A-43AD-9997-DA761C26C355', '4604060999173', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('731A441A-EB8D-4CF5-A838-3964B9E491B9', '0F1CFE89-6A1A-43AD-9997-DA761C26C355', '4606683000366', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3626B36-1E98-4E0D-A412-FEFD93213DAB', '0F1CFE89-6A1A-43AD-9997-DA761C26C355', '4607005390967', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DD0E667-64B4-4A68-8D24-678CC44ECF52', '56BF6B8E-1C3A-42B8-837A-F36C4EE11082', '4607007360012', '   100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0B5BBA1-003D-4CF3-BF02-4561D8EFAFA6', '8A53310A-B82B-4435-A6B7-1AC0CFA5A1C2', '4603713000037', '*  40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DBD71D3-9A42-4A34-AE0E-3EB05CF0EC60', '8A53310A-B82B-4435-A6B7-1AC0CFA5A1C2', '4606683000915', '*  40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63E56DA6-6E47-45A2-9A2E-AE17FD0354E4', '56091674-7D2D-415A-9B1E-DBB8247E86AF', '4601429003847', '  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BECED002-43F9-4341-B246-A800D7CCE105', '56091674-7D2D-415A-9B1E-DBB8247E86AF', '4602546002393', '  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF3EF2D0-F977-4748-BB32-D06D60CB881B', '56091674-7D2D-415A-9B1E-DBB8247E86AF', '4602546009620', '  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAB8089B-0BB2-47C5-8788-B625BFFE5AAA', '56091674-7D2D-415A-9B1E-DBB8247E86AF', '4602565014667', '  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('651CF1CB-D663-4AEB-8219-BCCF0619E3B3', '56091674-7D2D-415A-9B1E-DBB8247E86AF', '4603256000037', '  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C884B212-6934-42EE-878F-31B408593D17', '56091674-7D2D-415A-9B1E-DBB8247E86AF', '4603373002891', '  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9BAC2B3-D0D2-42B8-A28D-5DABC64F208B', '56091674-7D2D-415A-9B1E-DBB8247E86AF', '4603905002559', '  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FC68273-A0C0-453D-A1B9-A743B9A4B712', '56091674-7D2D-415A-9B1E-DBB8247E86AF', '4605681002105', '  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D701A72-1B9C-4C98-A4D4-F56DC93FBD02', '56091674-7D2D-415A-9B1E-DBB8247E86AF', '4606367000286', '  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4278B054-332C-4849-BAF7-CCD3EA66264E', '56091674-7D2D-415A-9B1E-DBB8247E86AF', '4607007361170', '  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('038F114A-12B5-48D5-A6D3-1CBC02A1578A', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4601429003854', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B79C577-26A2-4E3C-9930-CAD88EFF01B0', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4602546003437', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('708988B5-7807-499C-A734-9717C6DCDFF7', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4602546003451', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6748478-4558-430E-A266-2C545C976C1F', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4602546009682', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01BF6599-E1E6-4577-B6C0-320D21364DF2', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4602565005238', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01EE3F8D-6AB1-401E-9391-4D5C93F831F0', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4603184000154', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('830A6C38-13A5-4F63-9DAA-EF440A0B2EF0', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4603184002257', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9C1518F-435B-4539-80C1-13A09BBB2493', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4603256006190', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA26F2B0-9D57-47AB-8902-78F2EA4B30A5', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4603373000071', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAC20654-7FA9-496F-843B-C6AA3C4064CD', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4603713000778', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7ADA3E9-0752-4895-8054-8EABB2CCCBFA', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4603905002672', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68F356A7-FAB4-4FC5-AA1B-DB20197EB853', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4606367000309', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62C5BD4B-ACA0-42E8-AA99-B182D8FFFDAC', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4606683001721', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DA2CBB4-0BDC-4E22-9333-E3AC127EE1E4', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4607007360272', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59AFBBFB-2754-4325-A197-E726E0E5A760', '5CDAA76C-5ABE-4BE9-9092-9D36D019B2D9', '4607041270087', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBA5E41A-3B00-49AD-ABB5-5D42A8CDBFF2', 'AFEAD393-A3C4-4CF6-9986-27095929C6C9', '4607007360029', '   25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3717745-BA30-4C07-9920-107A881E315F', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4601429002482', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('307D680B-4585-4D4B-8CA4-6E2A7D334ABD', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4602546002355', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51245742-2844-4961-82F5-227819121AD1', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4602546005295', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9A729F1-DAE6-4923-8E43-26BD596481EB', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4602565013011', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C056D614-2C42-492B-8142-BD394034B4B8', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4602876002964', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9857F36-4BA4-417D-93D3-380AA5895B79', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4603184002226', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D72C18F8-0885-4581-B0C0-CEC0C6C43EFF', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4603256005766', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21B65DA8-6559-4C77-8C52-2CFD14E2C2F8', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4605681001962', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('292FD85C-D7E6-409F-BC45-ABD65C0C6D48', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4605717000297', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B3E3F50-3160-4C88-B050-7BAAA04EA01B', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4606367000033', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ACC88BF-CD3E-4322-8F04-63901AEED5E7', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4606683000441', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB6B3395-163F-4281-BD36-FDB5D96D1746', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4607007360128', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13CEB0CE-5F9B-4975-B360-D194AEAF66F0', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4607041270254', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09EAFABA-52F8-4253-8EFB-34C61D9AF1A3', '0F516718-CF84-432B-94A6-C028B79CDC81', '4604060021157', ' 0,01  50                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D6232B1-24E9-4B85-B2AF-FCBFF21E9712', '0F516718-CF84-432B-94A6-C028B79CDC81', '4605554000016', ' 0,01  50                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5027D55-8EFF-4752-B973-B29054826BBC', 'E9AE1090-1666-454C-9EAA-3314920583A2', '4605949001598', '   35   / 60                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('719634AA-9388-425C-AE75-8556C2CFCC77', '0F7D9371-2471-45EE-B3CC-74C0F348FB05', '4601372000917', ' /  /                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2DAD5DD-8A28-4F19-A36C-7B88057895C1', '0F7D9371-2471-45EE-B3CC-74C0F348FB05', '8717627100144', ' /  /                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C82EB45-DF2F-4B62-9007-5B429CA260FD', 'D26CA511-0000-42FC-96AF-D8F992F2F220', '8717627100151', '  1018                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55E691C0-E192-45AE-8126-C8437C07D42B', '765F8158-7E5D-4117-BDCD-535F14CBDB88', '8717627100168', '   silver      6  12  50                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D065C141-EE73-4CA1-91F9-FEE46940C0ED', 'E56FC54B-F867-4727-ABF3-C89E43A1CE3C', '8717627100113', ' // 36,4                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C621D3AA-6C26-4D0D-ACE3-DD10AD0D4709', 'E56FC54B-F867-4727-ABF3-C89E43A1CE3C', '8717627108478', ' // 36,4                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('082F7372-894C-4AE4-9D47-50196D6C3AEF', '4050F750-3E94-48F5-AAB1-75067DA496C2', '8717627100106', ' /  /                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EED0406D-82BD-46C6-87C5-0E593D033E13', '52133D75-0526-40BB-B884-9F2F8E6E7F17', '8717627100137', ' /  /                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48C12226-E3F8-4CB1-9CF6-7213B0E4D2CA', '3B2B7DDA-3EA4-4BEC-845C-B0D077530E31', '8717627108423', ' / .  / /36,4                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14309B19-D12C-48E8-9BB8-C232A1C554AA', '0FBF093C-7982-40BD-8DB5-2E29E88BB397', '3850343034753', ' 5%  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CCF8048-B811-47C2-8FD7-76D9C345A412', '0FBF093C-7982-40BD-8DB5-2E29E88BB397', '4603679001291', ' 5%  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05B61B43-6584-4131-8D01-5E83D3152DF9', '0FBF093C-7982-40BD-8DB5-2E29E88BB397', '4607003248291', ' 5%  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FAFF79C-D92C-4640-B4AE-1D1B5334A451', '0FBF093C-7982-40BD-8DB5-2E29E88BB397', '4607027764050', ' 5%  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4705908-339C-48A7-A67E-313CD9D4B92F', 'D33829BE-46C6-4F58-B20B-15FA868F7A0F', '4602565015688', ' 0,2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC63F9DB-D79A-444A-A4AA-ED59DD484D17', 'D33829BE-46C6-4F58-B20B-15FA868F7A0F', '4603276005432', ' 0,2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10E0DF63-0657-4AF3-8D3F-27239BC99426', 'D33829BE-46C6-4F58-B20B-15FA868F7A0F', '4604060231105', ' 0,2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D47EF82-0513-41E8-BF80-45BEAAFA024B', 'D33829BE-46C6-4F58-B20B-15FA868F7A0F', '4607027760090', ' 0,2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C60A847C-59F8-4CB0-B0FB-E7ED863CAEB2', 'D33829BE-46C6-4F58-B20B-15FA868F7A0F', '4810133008417', ' 0,2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C79A2840-4D34-49FA-A8FD-2BBF3238EF91', '6DB1E14B-5EE2-479A-B8F7-4EA427153CFD', '4607027762124', ' 0,4  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4BB404C-9388-4EB0-857A-3B9A7E12AC23', 'EDE79719-CA90-4B90-9443-CC0A82247C23', '4030855498123', ' 200  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAD0E7B8-E181-4876-96FC-F16B5FE2B716', 'EDE79719-CA90-4B90-9443-CC0A82247C23', '4601969000177', ' 200  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F98EB02E-89B9-4225-B8C7-B3A679D310D6', 'EDE79719-CA90-4B90-9443-CC0A82247C23', '4601969007237', ' 200  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE55EC1D-AB47-4211-A934-3068A3D8E69E', '648BDB88-E918-4027-8CF3-DD75D236EAB2', '4601969002737', ' 400  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E888B697-A083-42AB-8C1B-9519589ADCBC', '648BDB88-E918-4027-8CF3-DD75D236EAB2', '4601969007244', ' 400  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55D00D4A-4D9F-4318-BF29-CA30DB4FCC53', '648BDB88-E918-4027-8CF3-DD75D236EAB2', '4605077004539', ' 400  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95DA327F-A501-4236-BCEA-DE1E57DBB08C', '0FFC4576-73F1-4D6E-85CA-5607F500C1C4', '4602243001507', '  2  .   10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D5CB9BC-D078-4BD0-A2D2-709F098A1C06', '3680828A-42A4-4A89-B9C4-0E2848678A55', '2400006379939', ' 200  16                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E2E31C6-E878-43E3-B11A-A1A6CC19F8FF', '3680828A-42A4-4A89-B9C4-0E2848678A55', '3870010003714', ' 200  16                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C48FEEF-B627-42E0-9B33-A32B6084CE68', '105DC5F8-3574-4C23-991C-E1925DA5F1B0', '4607045190268', '  1% 20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAF69E02-C0BE-4125-B5FA-F753164FDA75', '7B51A350-6066-4728-AFA9-A8F69993C024', '4013054002834', ' 100  / /  2  30                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74067914-4123-4A91-9DAC-A4EBB7A04679', '3E7937A1-C1F5-48CA-88B1-D56C783C6C81', '4607037190016', ' 2,5% 3 5                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A99C42E3-D8A5-420B-9C6F-D7034B936CD4', '3E7937A1-C1F5-48CA-88B1-D56C783C6C81', '8600097300650', ' 2,5% 3 5                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B0BBD16-D9DF-4743-8C36-FC3D265190E9', 'A1AD9761-D7CB-4024-B3DC-BBB9DE689AEC', '5997001302408', ' 0,1  20                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('730D8F86-0F5F-4502-855F-7A3CA62BCB62', 'A1AD9761-D7CB-4024-B3DC-BBB9DE689AEC', '5997001362884', ' 0,1  20                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('554C7A65-FE36-42CF-88E5-3D10A7F07AB1', '107E011E-AD6F-4EB6-86E6-7537A689ED28', '3800010629324', '    / 75                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCEC58E0-CE08-4ABC-B1A8-220AB1BE6616', '107E011E-AD6F-4EB6-86E6-7537A689ED28', '3800021100584', '    / 75                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0C1C3F6-0131-47B0-84AE-26B52E6D55AF', '107E011E-AD6F-4EB6-86E6-7537A689ED28', '9001434718029', '    / 75                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAE4B409-1ED8-477D-8F7B-39E31A0F34B4', 'BF0E062F-BB64-474C-8339-DA773A5A46C7', '4605370000825', '  25,0                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9075D3E-D022-4D6C-AEDB-2E3EA91F2D0D', '6FCF06A9-806B-4C1C-89D4-7FEDBFEB9FD4', '3800010644709', ' 0,3  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB7D3487-8808-43E5-8AFE-8D6804AACDEF', '6FCF06A9-806B-4C1C-89D4-7FEDBFEB9FD4', '3800043030104', ' 0,3  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96857159-FDF4-4340-8C8E-2D2B763B4300', '6FCF06A9-806B-4C1C-89D4-7FEDBFEB9FD4', '4607027765460', ' 0,3  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04112768-8755-4CAA-B360-3A1C08C22E1B', 'E970EE0C-5219-40D9-A99B-B4638BE984CE', '4601808005073', ' //  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1BFF053-B849-4730-8F70-F8268CABC573', '400291C1-43F7-470D-A1BC-3299AFA06224', '4601026030086', '  25                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BCB1EEE-F341-45F0-83FF-780F44EACD33', '400291C1-43F7-470D-A1BC-3299AFA06224', '4603679000577', '  25                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01EFCED8-0A6E-45A7-8AEB-6129A0174C90', '400291C1-43F7-470D-A1BC-3299AFA06224', '4605370000627', '  25                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CA2CD58-97CE-4804-A38D-0DAD87D858E1', '400291C1-43F7-470D-A1BC-3299AFA06224', '4810133003269', '  25                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25A11F8C-BF8F-4007-A17C-77F7F94AB5D5', '400291C1-43F7-470D-A1BC-3299AFA06224', '4810133004600', '  25                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('354B72D1-45C5-4E8A-8CE7-1229BD1149E5', '11E40C59-DA13-4D85-8C82-53920D449864', '4030096111485', ' 0,1%                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03394DC2-C0D1-4EE7-88B5-549864FE1A31', '94B31BB6-6157-4396-9545-92F2D746E8B7', '4600828000051', ' 2  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D03CCAF3-CB39-4D57-B0BD-5A509EB49F7D', '94B31BB6-6157-4396-9545-92F2D746E8B7', '4602824001520', ' 2  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E14E0E5-0B5E-4862-A311-3E231F0FB6F3', '94B31BB6-6157-4396-9545-92F2D746E8B7', '4603988009353', ' 2  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDB583B8-ABEB-405C-AB67-ED4BC41930C2', '94B31BB6-6157-4396-9545-92F2D746E8B7', '4605260003493', ' 2  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75A194DF-AD28-4E8E-BC1D-550FA55886AE', '94B31BB6-6157-4396-9545-92F2D746E8B7', '4605260003509', ' 2  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B35DB42B-C756-4A95-B3A3-F752E3E74B36', '94B31BB6-6157-4396-9545-92F2D746E8B7', '4605518000595', ' 2  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6D57956-CFF2-4095-9277-6B0DAB101438', '94B31BB6-6157-4396-9545-92F2D746E8B7', '4605518000625', ' 2  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E691D94F-F688-4589-AD79-2E43B6D0308D', '94B31BB6-6157-4396-9545-92F2D746E8B7', '4670000362697', ' 2  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3BF3779-6BCB-4C90-84E0-58F809C5FB42', '94B31BB6-6157-4396-9545-92F2D746E8B7', '6916119020270', ' 2  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B47887BC-0A44-4CE6-9EAD-B325EF525C49', '6C2799A3-FED1-441F-BF41-526173246500', '4680013242237', ' // 2 /  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92ECE396-27EB-45B7-AE36-1A4784476275', 'A24339F3-A156-4390-A390-D62C50343DE1', '4603191001212', ' 50/ 2  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9890E020-1CEA-4DF2-8A23-7273E67EE2EC', '9250727F-E736-4E9E-81CB-3951A62B0E34', '4602212000418', ' 2 /  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAC3B358-0FBA-4C91-8EF4-A68EEEFD1CF8', '9250727F-E736-4E9E-81CB-3951A62B0E34', '4605260002953', ' 2 /  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3295D2A1-8F83-4954-B89C-0840B5E39102', '9250727F-E736-4E9E-81CB-3951A62B0E34', '4605391001542', ' 2 /  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FF4ED16-B7AB-44F9-8705-54CE1DC07C74', '9250727F-E736-4E9E-81CB-3951A62B0E34', '4670008160585', ' 2 /  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11D0EB60-A5C3-4E62-A8F0-EE58BA8FB892', 'D3AEEB24-C097-45B2-A74E-103C8FD62D4B', '4607008131857', ' 100/-200                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDEF53A9-CD10-420A-A9AE-B2E1C33AAE93', '35C1FD1A-A3C2-4EDB-8947-F6461710BB52', '4030096111522', ' 0,05%                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51EE163C-639B-47DC-9CCF-646E9DB3CD88', '12299274-9997-48D7-A09A-83C154ED5391', '4603149000113', ' 0,01 10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF81FAAF-E638-4735-B20E-766DE59C61C5', '12299274-9997-48D7-A09A-83C154ED5391', '4603149000366', ' 0,01 10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48BBB4AF-01B9-49E5-997C-592A064A3668', '12299274-9997-48D7-A09A-83C154ED5391', '4603149000540', ' 0,01 10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A415C28-8068-4FFA-B0D2-A970485ADFCD', '7F38BB36-B3A1-4147-AF90-F7A8CB922DFA', '7680500099006', ' 15                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45A5059B-418C-46CA-860B-587607269E2E', '4642217D-8FA5-4805-8232-0502A038BB60', '4607003665852', ' 0,5 30//                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E2293E1-E4E3-4BC8-9EA8-C99345518EB2', '4642217D-8FA5-4805-8232-0502A038BB60', '4607003669010', ' 0,5 30//                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FD5B37F-C94F-4DCB-8BD0-D6AD63067BFA', '0E833E3C-A1DB-4A6A-B091-355500A5B58D', '9006968003993', ' 0,025% 20 - /                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('768F314D-A6A7-4BCC-AFF5-DC828A71A91F', '464C6523-7AB6-4C18-872C-0896D792FA32', '2282667473047', ' /. - 5   1                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D40CCC9-9D7B-4951-AB7A-E3C79BADA4F9', '464C6523-7AB6-4C18-872C-0896D792FA32', '8901083190126', ' /. - 5   1                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05082240-4CE4-466E-8372-1135B9B84D0A', '12391B57-D71A-4A6C-8FA3-2AC0F8C0EC1C', '4607011664540', '   /    125                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33247BC4-7CC6-4659-9D5C-0B1A9CDAAFE1', '5F1EC310-60F0-4772-B1EC-B55CFFD7E375', '4607011660337', '  / / / 1 125                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5998FFE-0B70-487B-A433-C0DCE2A1AE61', '5F1EC310-60F0-4772-B1EC-B55CFFD7E375', '4607011664526', '  / / / 1 125                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C1BBF51-73E6-4D19-9874-D25CCD289F32', 'B161AFAD-84E5-46D7-8109-6087CA49A0F4', '4607011665967', '  / , +/ / 1 125                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('274095C4-786A-49C8-B0A6-6DD521CB7245', '7B1E06DA-273B-4C67-A652-056738AB6C9B', '4607001340379', '-   20                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28F7898F-0CCD-42F1-8E72-356CF278C259', '1246B577-9496-442A-9D12-2E96471F58DF', '3534510000269', ' //  0,08 680  12                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F55F6E5A-4D04-46DB-AC40-9C5F2B28503B', '127A0D6C-23C4-4899-A3BB-FE5BD3E72439', '4602565013509', ' 5%  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58313870-4A86-426D-9254-7B236B816E02', '63B5B57B-DEF8-4B49-AA03-AC61720A6602', '4601429000310', '  40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AD41483-989F-40F0-B544-CD7613592852', '63B5B57B-DEF8-4B49-AA03-AC61720A6602', '4602546000238', '  40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A56E9C6-4747-492E-8ACC-43FED3ACED99', '63B5B57B-DEF8-4B49-AA03-AC61720A6602', '4603184000222', '  40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('297170C7-CFB2-48CF-8B8F-0FB7D7F15962', '63B5B57B-DEF8-4B49-AA03-AC61720A6602', '4603373000118', '  40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AA38966-FA04-4729-8A55-1FC68CB4970C', '63B5B57B-DEF8-4B49-AA03-AC61720A6602', '4603905000036', '  40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD11A89A-9598-4A51-8820-148220D29B67', '63B5B57B-DEF8-4B49-AA03-AC61720A6602', '4603933002330', '  40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5536BF11-9EBE-4F9F-BC21-2403341C1266', '63B5B57B-DEF8-4B49-AA03-AC61720A6602', '4604171000010', '  40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D26A6B1-D801-4776-9118-C5E3D9C62B07', '63B5B57B-DEF8-4B49-AA03-AC61720A6602', '4607007360845', '  40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71D08BAF-61D7-473D-9088-DE4BB70C0EED', '4C50D00A-7F44-4016-8877-FB50633B82B0', '4607143560239', ' 100  / 20                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A862F56-71C1-4EC2-96D7-A9BC2FE2C84F', '2DB0F24C-AA1E-431F-B4FB-A9C96F84F7A3', '4602737004021', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE970F6D-AFE1-4F85-A8C3-9B8BF32F7967', '2DB0F24C-AA1E-431F-B4FB-A9C96F84F7A3', '4602902000445', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA1A27FC-C8A3-4C20-9ACC-8EFA98788791', '2DB0F24C-AA1E-431F-B4FB-A9C96F84F7A3', '4607130520086', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAB32B96-D07E-4C98-B5FE-EFAF6B4B4B48', '2DB0F24C-AA1E-431F-B4FB-A9C96F84F7A3', '4612690550060', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40974161-9BEA-47B3-84C6-4068B109C554', '2DB0F24C-AA1E-431F-B4FB-A9C96F84F7A3', '4620017368021', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('128C130D-E57C-4A68-91C0-21E471AF2F2E', '2DB0F24C-AA1E-431F-B4FB-A9C96F84F7A3', '4620018140022', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3063FB96-07D7-4C1D-BC0D-AFC30BC92BCC', '2DB0F24C-AA1E-431F-B4FB-A9C96F84F7A3', '4640015938651', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEC924AC-AC21-4461-B0F1-7C41A416F8D1', '2DB0F24C-AA1E-431F-B4FB-A9C96F84F7A3', '4680005640478', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4358511C-4AED-4862-B392-C051952C30F0', 'C068EC4E-A635-477C-8FE5-3A85B84BF70B', '4620017368168', '  714  .                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('497623EA-1F2E-47B0-A63A-C9257F59E8E8', '5262DB03-85C3-4D8C-9544-3CEA86825A52', '4612730250011', '  5                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C25BD3FB-B569-4DF9-8EC1-B6B0D16AB49B', '5262DB03-85C3-4D8C-9544-3CEA86825A52', '4612730250035', '  5                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F00C4A00-B3C9-4E32-9C41-0EF724C99E3F', '5262DB03-85C3-4D8C-9544-3CEA86825A52', '4612730250042', '  5                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6051518E-BD65-4647-B5C5-9B07B327C04B', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4602737003505', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62F0CC05-51AF-44A1-9119-C6606729AD90', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4602737004014', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D44209B7-3601-44FE-9A9E-E5A9A5B4822D', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4602902000452', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E3DB22D-8023-4CCF-B235-F42E8DED05C9', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4605147000133', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51023FD1-A168-4F45-B283-CC072C67BD6E', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4607130520048', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FD778DA-46A6-483E-B484-D1EA6A3C166F', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4607131360155', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B589AC1F-AEC1-4E49-9B7C-A8165D2699A6', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4612741480032', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('511FE29B-4EA9-4F15-9D36-3CB67D705691', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4612741480094', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89F13120-DC1C-498C-8ED4-75BD8BAF491F', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4612741480643', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D03CB6FF-4EE5-4F41-BF48-235214548FC6', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4620007450248', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCFC21D0-B82B-428E-A742-4FEAB097A06C', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4620017368182', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B473E844-7D17-45D5-A541-3911336AFC0B', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4620018140015', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA2731CE-57B7-4F3B-A9EC-ADE8E841251B', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4620018140305', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1FE3B85-1814-4012-BEE7-DE1FFF8B5CA6', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4640000900229', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('666765CD-5537-4630-A969-DCA70EA23BF5', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4640000900885', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50271069-1E6B-4BCF-BBB3-50665CFBF74B', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4670003605272', ' 714                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C3A57ED-5A8E-4E11-AE9C-F7A85AEB56CC', '85B2457D-95FB-428C-A13D-8781894DA82B', '4605185000492', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8108ABF7-4DB7-43C5-9EFE-52367ECD50C8', '85B2457D-95FB-428C-A13D-8781894DA82B', '4680005640195', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60458E37-BBB1-4BCD-B923-6FBF9077D79C', '85B2457D-95FB-428C-A13D-8781894DA82B', '4820037960179', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F638FE53-3267-40C5-907D-9D48AC7CD92E', 'EE30DF27-6BDF-42CE-91A2-7BEE733EA6E3', '2400006373722', '   3                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD36E738-785B-4E85-A4CD-3E7B7457D4B0', 'EE30DF27-6BDF-42CE-91A2-7BEE733EA6E3', '4602902000506', '   3                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EAD1957-B26D-4740-86C5-D5A5B158867B', 'EE30DF27-6BDF-42CE-91A2-7BEE733EA6E3', '4603188001294', '   3                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6882FFFC-A81A-4781-95EE-04D446082D6C', 'EE30DF27-6BDF-42CE-91A2-7BEE733EA6E3', '4603188001300', '   3                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5711C120-31F3-48AC-935F-F5B4BAA747E0', 'EE30DF27-6BDF-42CE-91A2-7BEE733EA6E3', '4605086000065', '   3                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B387045-B590-45DF-BD5A-36FDA7F8606D', '130BFBCA-FE2A-4E5F-9182-F9CA8AD51088', '4600702026269', '  42                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5C29F7C-7375-4E44-A8C6-F43A94131861', 'F1AB7077-0ACF-44A1-B6AE-B720868186DA', '4600053008303', '  15 0,025%                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A953EF88-ADEF-49B3-A2AB-1A1DE77596CB', '70951C73-98F1-451F-94B0-E586D289E869', '4604060081274', ' 0,025  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85BA1891-187A-4018-B231-7B1735C18BCA', '70951C73-98F1-451F-94B0-E586D289E869', '4604060081298', ' 0,025  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD601C1A-CD27-4D55-94CA-1DA8C75FF680', '70951C73-98F1-451F-94B0-E586D289E869', '4604060991252', ' 0,025  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1CAD4BA-5B2A-4772-A357-14F1E3D311CF', '6F97C726-47A7-44D5-AE79-A21795D472CF', '4607005931436', '  20%  10   -                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8227067-ED57-40ED-B2B8-AF3F17713F6F', '6F97C726-47A7-44D5-AE79-A21795D472CF', '4823002218848', '  20%  10   -                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7F6525F-73E5-4182-A324-64867DC37C03', '3168B70E-793A-4279-9D94-186602A6BF7C', '4601026001017', '   10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B2B6A9B-AB14-47DE-8A88-2F8D62354B45', '76B4AA2C-B36F-4BD8-BF2E-B883938AB90C', '4602196001760', '  / 50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42BAF21D-F002-476E-8B63-DFF6947B22DE', '76B4AA2C-B36F-4BD8-BF2E-B883938AB90C', '4602824012410', '  / 50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13ACF20A-B7CA-44E7-8583-F3C2C7E724DF', '76B4AA2C-B36F-4BD8-BF2E-B883938AB90C', '4602884000808', '  / 50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E874BBA-23B5-408F-B0AC-7F15A44D421A', '76B4AA2C-B36F-4BD8-BF2E-B883938AB90C', '4602884010272', '  / 50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0DE3B5A-FE9B-4633-9753-9259CF8BE0CA', '76B4AA2C-B36F-4BD8-BF2E-B883938AB90C', '4603179003788', '  / 50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BA24BBA-CA0E-4822-9B8D-2F6BD50E41E0', '76B4AA2C-B36F-4BD8-BF2E-B883938AB90C', '4603276004954', '  / 50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D559FD8-8392-401E-AAD5-D0069866F9CC', '76B4AA2C-B36F-4BD8-BF2E-B883938AB90C', '4603276007566', '  / 50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB8AA371-0696-46B5-9D46-0D810D2175D0', '76B4AA2C-B36F-4BD8-BF2E-B883938AB90C', '4603276007597', '  / 50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D9AE3C5-97FB-4455-9AA1-81C7C363907D', '76B4AA2C-B36F-4BD8-BF2E-B883938AB90C', '4810133003801', '  / 50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD12130E-DAB4-42E0-910C-552DFAA418EF', '7B8189A1-BE75-44C2-9293-B51F9994189B', '8901117190016', '  20                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C8953EF-6D1D-47D3-8F4B-50FE008FE8C1', '7B8189A1-BE75-44C2-9293-B51F9994189B', '8901117191815', '  20                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD245087-9506-4956-86B0-846F2541FCC5', 'F1F5AB27-3130-49BB-BDB4-54614C9C32F2', '4602930006556', ' - 5  30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CD97B7C-E655-4F62-9D66-4BF70CFCA266', 'DAF0AF0C-DB76-4630-9271-EF703FD5B45F', '5000158100275', ' //  100                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87CAFE21-0A37-408C-B250-E7E2FA671534', '14CC2A3B-55F6-44C3-B8FC-0E31369F10F2', '2373431321340', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0597A221-54EF-4F26-8008-C2C56C2377AA', '14CC2A3B-55F6-44C3-B8FC-0E31369F10F2', '2400006383462', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76D23F65-ED9B-42CF-8F26-65FC7ED4102A', '14CC2A3B-55F6-44C3-B8FC-0E31369F10F2', '4601026002014', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5CCBBEE-B3F5-4C70-B197-0C1A936FF51C', '14CC2A3B-55F6-44C3-B8FC-0E31369F10F2', '4602884000761', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C1A8E1F-CC5C-4CE6-B44F-C237190580D9', '4857C9DC-53B3-488B-85CC-77574B7443CD', '4602824000103', '  0,5  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('199924A3-D5AA-4F08-B853-C35A761BF491', '9D22F75D-1555-491A-A0C4-0EEBA32EB04A', '4602824000080', '   10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD67D27A-1AC4-47E7-BB65-BFDB896E2709', '9D22F75D-1555-491A-A0C4-0EEBA32EB04A', '4602884001454', '   10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7896FBD-C4B8-4727-8A45-2D064236F3D9', 'FBA20E18-8265-40BC-AC81-31D01A16B370', '3800010644457', ' 0,001  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79EB41B9-E163-4B15-8FCF-A0BD3B52B1B2', 'FBA20E18-8265-40BC-AC81-31D01A16B370', '4600828001188', ' 0,001  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3A3CC0B-2A8C-4726-8C54-78E51E9E9130', 'FBA20E18-8265-40BC-AC81-31D01A16B370', '4603276003698', ' 0,001  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('910124C3-6E18-492E-BB38-ABEAB28173DA', '1948CCEF-A1F1-4B3C-8F52-812341A29B97', '4601026301667', ' 500 20                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C03AA87-B288-4812-AF32-C9CE9F5147FB', 'B5EDF945-E89B-45E9-A7F3-A082E63252D6', '4607027764784', ' 40  /  2%                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('678DB19A-D81A-4343-A231-7FB6F436CAFD', '15CC295B-603F-4B4F-9CB4-D52D3F7FE21D', '4601372001754', '  12                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1000082D-C238-42C9-8C0D-30B96FB66F35', '371B3A9D-D75C-4C54-90C7-8FCD9C566C86', '3574661065885', ' 0,2% 40                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38596031-6D1C-46D4-BD54-7A588AF1EE45', '371B3A9D-D75C-4C54-90C7-8FCD9C566C86', '4603365000034', ' 0,2% 40                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('224A4126-115B-4AAC-97D7-C4A77BC469EA', 'A13B8CDE-86F9-46DE-89BD-20D36E25F387', '4601372001747', '   12                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC2FCB92-646C-4B4F-8255-3052F0172241', 'B7CE3902-100C-4D4C-8393-C938B85C0C27', '4601669003911', ' 30                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E687C91C-3438-4057-8A2C-0FF79D92882A', '15D1FAB8-C72F-4E63-BF2D-97A67616AEAE', '4031083005787', ' 0,075+0,0152  / 100                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9737CD85-806F-4AE6-ADC2-B0E851D3B729', '15D1FAB8-C72F-4E63-BF2D-97A67616AEAE', '4602156000123', ' 0,075+0,0152  / 100                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84193C54-26DB-4D03-A6CE-7283E78D0CFD', 'B3F872EB-7559-4ED8-8A7B-FA67C0E6E6E6', '4601669002563', ' - 0,5  20                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97DE566D-7A4B-425F-A389-8DD7AE01EB5D', 'B3F872EB-7559-4ED8-8A7B-FA67C0E6E6E6', '4603179004235', ' - 0,5  20                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67C0C10E-8647-4672-9BB9-64D842F72EE6', 'B3F872EB-7559-4ED8-8A7B-FA67C0E6E6E6', '4603182002488', ' - 0,5  20                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E89C2246-1FAB-4290-98DE-062B51C251AB', 'B3F872EB-7559-4ED8-8A7B-FA67C0E6E6E6', '4603988001982', ' - 0,5  20                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F5EDDF4-C720-412E-8BBC-BC635A978F84', 'B3F872EB-7559-4ED8-8A7B-FA67C0E6E6E6', '4604060992754', ' - 0,5  20                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98BA5765-653D-4E96-8044-9F3BC82B7366', '9B47E309-43F7-4AF5-BA8E-C713272DD0B1', '8584005053985', '    200 30                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F72EACD9-9569-4DA6-A641-37BFE4DB14C5', 'C4F2848C-7B47-4380-A444-5F7C98D828D1', '4013054004647', ' 100  100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A01EC1E-5ECC-4213-A2E8-7CDB2C0FF85A', '751F5836-CDAB-4EE0-99A6-DB5966620084', '4013054004654', ' 200 0,0002  100                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC9999FE-B344-4433-A5C3-884B0C4EDB5B', '7F8DCA49-B545-41D1-9350-8405B14E7A34', '4607004430497', '  / / 100  10                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59E5ECCC-628E-4D97-B598-7040B10C79B7', 'B6E8ABC5-301B-48A7-AC62-2470D5969E12', '4601026004018', ' / 0,02  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF536571-844B-4622-8F36-C3AAF3E0D0E3', 'B6E8ABC5-301B-48A7-AC62-2470D5969E12', '4602509006451', ' / 0,02  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C29786B-CD8B-490F-A184-72335F580B6F', 'B6E8ABC5-301B-48A7-AC62-2470D5969E12', '4602824000110', ' / 0,02  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01CBDC94-7AD2-44F0-981F-ED12395E2524', '5BDEFCBC-57DF-40C4-9FEE-DA903AA53E4C', '8584005053978', '    100 30                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1C606F7-7033-4A4F-A8AB-B394E299C2C2', '98DEA582-2107-4AC7-B39E-1D40B6C7363F', '4602884001461', '* / 0,02  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCCD9115-E8B9-492F-9E47-5DE8BAAB3B80', '2C67AAFA-F9D1-4BC4-8DA7-B7C7B886AB5A', '4602193010703', '9   0,7  30                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A46EAA7E-FB70-434A-AF30-22ABFFF7039A', '2C67AAFA-F9D1-4BC4-8DA7-B7C7B886AB5A', '4602884012566', '9   0,7  30                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B733747F-05CA-4A27-9324-A4E2C9682049', '2C67AAFA-F9D1-4BC4-8DA7-B7C7B886AB5A', '4607035440120', '9   0,7  30                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6D5802A-4417-4C83-A722-C2C1B7EDE9FD', '173545A0-6EA8-4554-8FE0-6816CB2C9BE2', '4602233003924', '    /   40                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A23ACE0-8720-477C-8E92-51CE3FC20B97', 'DE450676-E2AE-4C1F-8207-F521A365C05F', '4047400011003', '  /.   30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11D16220-BB8B-4B3A-A10B-8044DB086788', '9985FAE3-AB51-47E1-93B8-A0F40CF74190', '4602233003931', '     /   40                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C47ECC98-ACFD-492D-8DE2-EA20DEF77EB1', 'AEF6CFC1-55A2-491B-AD41-8DB302F216CC', '4047400115350', '  /.  //  30                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0D2C296-0AE9-4B24-8904-56064934D2BB', 'A6DFB35A-A13D-4F6F-88C7-A0D0CFD04769', '8594739028418', ' 0,05 //  30                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E049F28-551C-438C-9C17-593136F67582', '46523090-BA38-4557-A691-96ADAD6CE44A', '8901302057285', ' // 0,5  20                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F772D63B-BA36-4A25-BF9F-C53508E466CE', '17569841-0101-4916-8193-8F4861C1C7B2', '4605108000226', '   100                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B38266B-B458-49C2-9D43-6391C6DC0798', '17569841-0101-4916-8193-8F4861C1C7B2', '4607051790636', '   100                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E138C39-26D6-4CAF-930B-7DC8839ECDD7', 'B122B384-0523-4CA0-9F60-EB89CA1A423C', '4605108000233', '   100                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1759AC0C-95C1-4904-9F8C-1BB982573425', 'E284DCB3-C336-4818-80C8-857853445321', '4605108000264', '  100                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7CF6933-5766-4889-AEA2-F62225B1ED38', 'E284DCB3-C336-4818-80C8-857853445321', '4607051791916', '  100                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77FA515D-253F-4724-9C73-EDC8BA1C7A7A', 'E284DCB3-C336-4818-80C8-857853445321', '4751006750012', '  100                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DAB14BF-7BF7-4B9D-BBDA-53F5B93CCEE3', 'A8DE28B2-DD11-451E-B2B6-7FCB8BDE9AD5', '4605108001964', '   100                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('282097B8-ABE2-468C-8C20-452959883EC7', 'AB0835F1-B995-4D0E-BBD4-559E6E583B1D', '4605108000257', '   100                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('432806AD-5370-4524-B701-29103AED8BBF', '92CF6AA1-E630-4DFC-A8AA-F43C60A5C857', '4605108000240', '   100                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42A83945-B0E5-4FFD-860B-8CC81F2AE383', 'B528047B-A8E4-431E-AED2-FC05D8990CB1', '4605108001957', '  100                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94EAD943-5D7B-44F7-B3B5-AF9038151007', 'B528047B-A8E4-431E-AED2-FC05D8990CB1', '4751006750067', '  100                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E1792B7-A5BF-4122-9530-C751CEA1781D', '2BAE85E7-C2C4-447B-B1E5-E6894BC80BCC', '4602193010772', '  / 10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4339A5B4-43F0-4069-892B-2079BF9B7157', '2BAE85E7-C2C4-447B-B1E5-E6894BC80BCC', '4602196000015', '  / 10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB2CF7FF-5A5F-42D8-BAAD-A89B5710646D', '2BAE85E7-C2C4-447B-B1E5-E6894BC80BCC', '4602196002866', '  / 10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0914BE7-8669-4D51-9563-6975B5C741E9', '2BAE85E7-C2C4-447B-B1E5-E6894BC80BCC', '4602824001476', '  / 10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E836CCEC-2930-4279-8965-AA5048145471', '2BAE85E7-C2C4-447B-B1E5-E6894BC80BCC', '4603179000053', '  / 10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CAA27AF-0A45-465D-BD02-E8CA6F835694', '2BAE85E7-C2C4-447B-B1E5-E6894BC80BCC', '4603276000017', '  / 10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('789793F7-B9A0-4D8D-A3D6-BA7171DF8D28', '2BAE85E7-C2C4-447B-B1E5-E6894BC80BCC', '4605180006154', '  / 10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DC94EEB-1745-45D8-ADD9-E23403BB6468', 'D93B80F9-17FE-4917-9A1C-C515914795B3', '4607045192170', '  // 10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('850965A0-452B-4F36-B870-8460A12F55F4', '17A79B52-4622-4378-AF7D-199E4E8F8156', '3838957033720', ' 25  48                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA290F9A-CE9A-4FCB-9711-8A007E54C69F', '9F065349-B356-4DD5-BE03-3ACA028A38DB', '4606556000080', '  500  20                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9CF7D97-4194-49BE-ABAD-2B432F2301D3', '589B9EEB-6172-411A-A782-8646024AFA0E', '4602193007406', ' 0,1  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('148D6736-93D6-4ACB-B90D-30428AFB9A90', 'C75B5B72-2EC2-4F2A-BE89-4C2D54CCE66A', '3838957014408', ' 25  32                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('427C957B-2F95-4EB1-91F9-6642F9358891', '00D13E9D-2D2B-4776-8793-C25AFC2352C1', '9006968004099', '  1,18/                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE97B905-4377-4018-92A7-AB2D97B746CC', '17CE18D5-AF01-47DF-8F07-D660C1493E9E', '3800009130022', '  45                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EE26986-D198-4C10-8E23-693FECB8631E', '17CE18D5-AF01-47DF-8F07-D660C1493E9E', '3800009130039', '  45                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82222E81-E93C-4957-8FE9-696A793B7324', 'F5CE284C-BBA4-489D-866E-52F32B094EE3', '4601774000041', ' 1,58                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A97204FE-3329-46BE-BAEE-88423F4C1554', 'F5CE284C-BBA4-489D-866E-52F32B094EE3', '4601774004148', ' 1,58                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A976DAA-597B-4169-BB2C-C6AAA44CBC3E', '50A6D08A-849A-4724-8954-11B6CD620C0F', '3400970002146', ' 0,6  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3172917D-78B4-4C68-A622-F6F12A610AB5', '180E5517-DAD4-453E-922E-B4EEC6C7D050', '4630008940099', '  0,01% 10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5197C27-2F6A-43E5-968C-5D0E6E17078A', '180E5517-DAD4-453E-922E-B4EEC6C7D050', '4650068810033', '  0,01% 10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A72D837-8CD7-4D1F-B9BF-24896C925CFF', 'EC9B3F76-124B-4A06-9FEF-A5AF430B2742', '4606207000322', ' 10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D9B0ECB-FFA4-4F58-A806-C9E5A125B834', '9703ED84-9750-4C89-B48D-DB712FEE4792', '4670014500030', ' 2  15                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AF356AC-6A95-4C0C-B339-5B2C1C325FF1', 'DCAEF753-2431-4E8E-BD16-0ED1F98A00C5', '8901236004508', ' 0,3% 5                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB9D4961-C8A4-42FF-AE06-20C15FB3BC2F', '1961BAAE-6B7A-453C-B1F2-87A46EBBC604', '4604060203034', '  1% 3                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA89D76A-CE57-4293-A73D-61CB64FA3BCC', '2A764F4C-B22D-434F-A1A3-1D462D2CC045', '4030571000075', ' 5% 5                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB286933-1E0A-4954-8F54-140497ACB453', '814685FB-FEBA-4149-B406-1B8C1C872979', '8901236011605', ' // 0,5% 5                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B8E571F-11D4-4023-9D2D-7DF66D69D2C1', 'E070BA60-06BF-4570-AA13-E44B6AE0A7B1', '5944728001589', '- //  0,5% 5                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2361FDD4-C014-46DB-929B-DFFE475E6DB4', '950B5FBD-8E4B-47E2-97C2-2BE398E89F93', '8901148011014', ' 0,3% 5                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7809F22-5C0D-44CE-ABC8-38431CF55AC3', '950B5FBD-8E4B-47E2-97C2-2BE398E89F93', '8901148220713', ' 0,3% 5                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D4FBDEB-BDD9-4468-956E-940B03B8AE6F', '181B8F3C-A8A3-439A-88B1-60F64695D1CB', '4013054007792', '- 50 50  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79CC3BBD-1CCE-4A3F-B101-8FE495279B84', 'EEFEA7DD-1A66-414A-8C6A-54D8F3DBD302', '4013054008416', 'L- 100 100                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAE0A22B-1784-4B82-913F-4FFD4D64B0E5', 'EEFEA7DD-1A66-414A-8C6A-54D8F3DBD302', '4601969004229', 'L- 100 100                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6F046D6-3028-4E96-9D07-C759AE2E132F', '9FB6584C-8224-443D-96B8-D8B9D60D53B4', '2400006374323', '    40                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1702D9E-AA92-4F89-83B9-E27939C1D962', '9FB6584C-8224-443D-96B8-D8B9D60D53B4', '4610008490183', '    40                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3BAF44A-3810-40F8-9BAF-3F8D22501716', '9FB6584C-8224-443D-96B8-D8B9D60D53B4', '4610008493153', '    40                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6306BE0-6772-446E-BC67-FE35F33EC53B', '9FB6584C-8224-443D-96B8-D8B9D60D53B4', '4610008494211', '    40                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D568348E-3EDA-4DC9-B5DC-CEBBC20708C6', '189EC129-7E33-49F6-8DDF-92D0C680912F', '8901109217493', ' 0 ,1% 10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D9A49F7-548D-4942-88CC-9EBD25649E3B', '8016F2BA-1464-41A2-9227-A3EBD2407235', '8934901710015', '   4                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45309DCE-BD42-45E0-AC01-99DC4BD76C3A', '1941BC3E-F58C-4D70-8C36-74021200BB1A', '4603720417262', ' 60                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDE4E245-E9FC-4B3F-9CA8-F90DA5B9B18E', '1941BC3E-F58C-4D70-8C36-74021200BB1A', '4604461001529', ' 60                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAD08C18-0400-481A-9355-1EB241052157', '1941BC3E-F58C-4D70-8C36-74021200BB1A', '4627117390013', ' 60                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44BECECC-626E-48D0-819D-99A95C62FA3A', '1941BC3E-F58C-4D70-8C36-74021200BB1A', '5280015090011', ' 60                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3573F6AE-CC5C-4A54-889E-B4480C617BB3', '59EB42E5-63CD-4113-BE1C-FC87B55FC9E0', '4603720417279', ' 120                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F23967F3-2D77-4D0E-95E7-0A8C4BE30F7B', '59EB42E5-63CD-4113-BE1C-FC87B55FC9E0', '4604461001482', ' 120                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F1ECF0D-DBDC-48E4-B31F-735E781838E0', '59EB42E5-63CD-4113-BE1C-FC87B55FC9E0', '4623720554279', ' 120                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27E77A5A-548D-4C41-8EB4-E3AE74754CEC', '59EB42E5-63CD-4113-BE1C-FC87B55FC9E0', '4627084350041', ' 120                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCEF2D62-D543-4410-85BB-9D82BCCF4162', '59EB42E5-63CD-4113-BE1C-FC87B55FC9E0', '4670009340016', ' 120                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E141D1A-7CB7-476D-84F0-375C9DCDE79F', '59EB42E5-63CD-4113-BE1C-FC87B55FC9E0', '4814488001949', ' 120                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAD63DFC-5B8F-4F84-A0E9-1F9613C09A4F', '59EB42E5-63CD-4113-BE1C-FC87B55FC9E0', '4814488003622', ' 120                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E9920C0-8362-4552-862E-416B8FD49377', '59EB42E5-63CD-4113-BE1C-FC87B55FC9E0', '5280727420021', ' 120                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58EB8EB0-B359-42FE-B1E7-47CD39793BB8', 'B73B43D5-9DB7-41D1-BF68-090EEA3EED63', '4627086700059', ' 100                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DA99F7B-F2C0-4CB1-8C77-FE69DADA4955', 'B73B43D5-9DB7-41D1-BF68-090EEA3EED63', '4814488001567', ' 100                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B458C3F0-0E87-4479-944C-DF046F61FCDF', '834BF7DE-028C-446B-930F-723380A8383B', '4627084350027', ' /  60                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA99C855-D00C-4456-82F3-EA422717A8CD', '834BF7DE-028C-446B-930F-723380A8383B', '4814488003424', ' /  60                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CB8C708-6B37-4D18-A8C0-2365806E1EA6', 'EFAA814F-8863-4988-BC96-1C19E46EFEF2', '4601956000272', ' 5 4                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9170B59E-1D1D-4D96-AC03-8D290E9978A7', '6B9606BA-515C-4941-A538-3A3D84529093', '4602242005834', ' 0,5  40                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8088EC5-170F-40EC-ABB1-4184835CF840', '7FEE2DFB-1D4C-444C-A03D-6E66DABF8429', '4605095000483', ' 0,75% 15                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83223F44-7F97-411E-8FD9-DE9C7886F171', '7FEE2DFB-1D4C-444C-A03D-6E66DABF8429', '4605095008892', ' 0,75% 15                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88299C69-20EB-4382-B2A8-426231ACCF06', '54FAE047-A866-45E0-9508-461E07868764', '4602242002444', '  20                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E842349C-EBD1-43EB-AC33-4324217DE763', '7AD1AF9F-7D24-41D8-BDFB-00EBA14DC846', '8715554000063', ' // 200                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7990A99-0E7B-4C3D-96AF-E3B6263896D8', '2E3C0BBA-0FF9-44B0-AD1D-F93D119A5730', '4602676000412', '  20% 1,3 2 -                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C717109-39EC-43C5-9444-BEEEDEC0D00B', '9659A018-C455-4552-BD96-43FBA4BB487D', '4603761000881', '  20% 5                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ECA294B-5519-4064-90C9-249EB17D1C7F', '9659A018-C455-4552-BD96-43FBA4BB487D', '4603988012506', '  20% 5                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E119BC7B-E90B-4978-BEC6-FE5D816ACB35', '196C5E3D-701F-458A-AEDB-5A6F78EA54A6', '4604060011073', '-. 100  6                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB070F6F-97B2-4DBE-996C-F7C44391109C', '986AAD26-FD77-4D14-A894-46CC5A513E0D', '4601669002709', '   10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14408354-5B7F-4445-BD93-D33FFC9940B7', '986AAD26-FD77-4D14-A894-46CC5A513E0D', '4603179002583', '   10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F08A84D5-5D7D-426F-B70C-5C09C4B83147', '986AAD26-FD77-4D14-A894-46CC5A513E0D', '4607047720098', '   10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('204AFD89-9DC9-4CF3-9786-54FE673F675F', '986AAD26-FD77-4D14-A894-46CC5A513E0D', '4607047720838', '   10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEA81D0D-21A2-4FAD-8B05-37383BD5C0DA', '478EE262-FA74-4339-A987-6638766B1288', '4600828000693', '-  20% 1  10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DB4BCF4-C836-4D8E-A985-FF26EA92462A', '478EE262-FA74-4339-A987-6638766B1288', '4602824001254', '-  20% 1  10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('430B5EF3-5975-417F-879C-023FDEA5878B', '478EE262-FA74-4339-A987-6638766B1288', '4810201000138', '-  20% 1  10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CABE8E5-D68E-47AD-881D-D11CD1F5CC0B', '19E6CA9D-4E20-4C5D-A253-98D6B633A06D', '4013054008010', ' 0,4  20                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DCE6DA3-E611-476B-A341-38B34DD7AE70', '623550FA-3D1C-4B58-8992-8AFBA814980D', '4602242005711', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('239ABF53-482A-4372-B4BD-6AF6ECBFA8F6', '623550FA-3D1C-4B58-8992-8AFBA814980D', '4602884008408', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EC84CEF-2269-4264-9CBB-15FEB0A7C609', '623550FA-3D1C-4B58-8992-8AFBA814980D', '4603276008266', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1C87E6D-8E4C-44ED-B438-854991A81991', '623550FA-3D1C-4B58-8992-8AFBA814980D', '4604060071473', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D80BF02-540F-4A36-BE8E-B80DF1637E05', '623550FA-3D1C-4B58-8992-8AFBA814980D', '4605077004775', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2301365F-763A-47F0-93A8-CC9114787B88', '623550FA-3D1C-4B58-8992-8AFBA814980D', '8594737371516', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B441B12-C779-4B6B-8645-AF3FF51F9EE6', '4FDA8CD2-F9E4-4B3B-B3D9-3D930298840B', '8595026463387', ' 0,25  100                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF9EAD54-E396-48A6-AF42-8AC066FDDC12', '1A5921D4-F74C-42AF-9E6F-21D4DF9584D6', '4601808004984', ' 0,025   10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03728BC7-C31B-4322-8FB9-F67452E202B4', '1A5921D4-F74C-42AF-9E6F-21D4DF9584D6', '4601808010718', ' 0,025   10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39D94719-8CC5-4A48-976B-18EA3303002A', '1ACB7645-9DE1-4422-A408-E22BBF1A4A2B', '8002660019400', ' 10000 0,15  20                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E238E14-20B6-4413-8F16-F148EC7E3D89', 'EEF11B25-C880-4606-8206-BA278CF49F16', '3760008321725', ' 200   30                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D108B994-80E2-4811-9C58-3BA527E875B6', 'EEF11B25-C880-4606-8206-BA278CF49F16', '4620011582232', ' 200   30                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49FD79FB-4349-40D3-83D8-29DA3EA929EE', 'EEF11B25-C880-4606-8206-BA278CF49F16', '8715554000278', ' 200   30                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC02F69A-168F-4AF6-B25C-B42ED56EF28D', 'C53B5436-9379-4CDA-92AF-A0F19D4CB803', '4603671002258', ' 10    30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EDC1C48-1A4B-4BE4-AB37-514B438CEAC2', '78CBE736-5216-4D9F-B25F-7B6E19E8A3B6', '4607009510019', '-  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27FA78FC-E65C-4B5D-BAE8-5E3906F04AF4', '1B438181-01D0-4C82-ACDC-706573279872', '4028352000123', '  100                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D48992B4-8835-442C-8C5C-FBD5A47E0E48', 'C9CF202A-1737-4995-A5CE-F4EBF494FD71', '4607011664496', '  75 /                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3B404DC-372D-44D7-9125-379E40684804', '2AC40F20-D34D-4158-B192-E4C533CD3946', '4602210000038', ' 1  1                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23B16B9A-F6D7-40FF-97A8-664FAA090ECB', 'D80DD45A-914C-45DE-8E67-9B2B0FB689FB', '9006968002293', ' 1,5/1,5  3                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44534673-C06D-434A-A2E8-BA72E2B61644', '1B9382BF-1F39-465B-A010-D8EA7FBD9018', '4030855000920', ' // 2 10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('310C04A0-D333-4ED7-B59D-3BD3EA494592', '5D121379-FBC8-46B8-BA80-1F6E744424CD', '4030855000890', ' // 2 10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5835642-A582-4B5D-89B0-D94BEB5142BD', '1BEA841E-02C4-4C45-90E9-5EE580A29E6E', '4610008490725', '   35                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B3D1582-16AF-43F3-8CEF-7A99C66516B7', '2AC90777-150C-4CCA-8928-BDDE74329079', '4610008491838', '   35                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D84008DF-569B-4ED4-96E4-6D7C715A66D6', '1D2ECD22-AE85-425E-84F8-C04B9C4F00E8', '4610008491753', '  ,   35                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A024DEF-2979-4D85-A020-B0825AD247A7', '1C4991A9-8EC1-4CD7-B806-1A7959BEF86E', '8901079000705', ' 0,1  28                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7C70B70-8F7A-4D10-8DE9-1D172E5414C6', '2FBD8FDC-28A3-483D-9EF1-EF73E8DCD59F', '8901079000699', ' 0,05  28                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('168751DB-13E3-431F-88DD-525ED0A561D7', '1C5206AB-C94D-4399-B446-3502BE16124E', '4607027760182', ' 0,02 /  30                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7034997A-0ACE-4698-8625-6D34CAD397E2', '3EF18811-22B7-4637-9378-7970B4945278', '4603276005159', ' 25    60                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58075B62-FFDB-4898-8375-6C0CC83536B5', '74C420B9-183E-480B-96A4-F59704D18322', '4602884003434', ' 25   /  60                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2639BE0-8666-4914-A445-79C20A09348F', '1C52A4EC-A23C-465F-ADCD-7D00E7DEB34D', '4601669007346', ' 2 150                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EAF68DF-E851-46B0-B480-353300506241', '3375F20F-5D65-4DAD-993D-D013AEB58861', '3592752847714', ' / / 15                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('454F0E20-0623-47B1-998B-FEB3F921BB62', '1C81CC8F-5247-4DC4-BD19-0E6C26F439AC', '5000158100237', '     50                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02C4F219-9A9D-425D-B64D-60BED634E90F', 'F9C5F818-325E-4E60-983E-C9B4B910F177', '4601808005202', ' 2  5                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82548237-3612-486C-AEB8-568492DAC76B', '1C9A3310-8289-4256-97CE-EFFA8138DF1C', '4030674000538', ' 0,5  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B1016DD-5E07-44C0-837C-733EB5DA2BF8', '606CC9DC-B794-48B5-95C1-ED8A51BCDF64', '4030674000194', ' 0,5  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11DF03A6-6CE2-466D-98EC-7A46CDC8AB82', 'A83738F0-F2E7-4735-B044-43A8A8498B3E', '5997086102610', ' 0,025  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('774C6A66-0851-471B-A79F-CE4726C1CBCB', '3A918902-24B5-4545-A5F2-0401AA19A3EB', '4605469000743', ' 0,00025  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62B3BFB0-46FD-49D3-939E-A1AAD5209F75', '3A918902-24B5-4545-A5F2-0401AA19A3EB', '4750232006924', ' 0,00025  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7229195D-16CA-4635-A7C8-8C704A6BAE12', 'E031E20A-D15A-4C65-B045-7717AF3BBEF3', '3850114213196', ' 0,01  20                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAF7FAF1-B310-41AE-B92B-D7737F918562', 'BD64D328-DFEF-432D-B872-135822ED41E5', '5903060004559', ' 5  30                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('216D3AF4-9658-48F5-AFD0-3343CCE22D03', '4084B830-7B58-4344-AF9B-960425C28CB8', '4600338001623', '    0,33                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C6D125C-D232-47BE-8242-CA56E145CEAF', '4084B830-7B58-4344-AF9B-960425C28CB8', '4600338001852', '    0,33                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E3ADCD2-7DDE-48C4-9C3B-E0EBB7AECE83', '1CFA76D3-F750-4E5D-9F4F-DA9425DAC96C', '4607003243784', ' 0,005  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11AEF820-A520-4BEE-A624-FE5ACFE75F50', '1CFA76D3-F750-4E5D-9F4F-DA9425DAC96C', '4607027761356', ' 0,005  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A591BA69-8533-40D3-BAE2-1F6F94945D43', 'B611F9A5-53D6-4EEB-B950-E096268A94D4', '4602509011424', ' 0,0025  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4403F7AF-C611-4396-AE3B-F91DBA76FA0E', 'B611F9A5-53D6-4EEB-B950-E096268A94D4', '4606486005681', ' 0,0025  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB3C6687-9222-4A0B-A1CF-DA8AEBF0440A', 'B611F9A5-53D6-4EEB-B950-E096268A94D4', '4607020332492', ' 0,0025  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E9AC119-A6D7-4D80-BA88-35E978927316', 'B611F9A5-53D6-4EEB-B950-E096268A94D4', '4607027763206', ' 0,0025  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CED3915-43DF-4ACF-85E5-E1844DA6C263', 'B611F9A5-53D6-4EEB-B950-E096268A94D4', '4607143560185', ' 0,0025  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB551D0B-D6BE-4691-9FC9-2F912A163055', 'B611F9A5-53D6-4EEB-B950-E096268A94D4', '4680020180263', ' 0,0025  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('028368E4-2B6D-4F9D-850C-A9D143C3431D', 'E5EBFAF2-3FA0-45BC-8005-F67E1E8ECA4B', '4607055131329', ' 0,05 //  30                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('578ED8DB-256E-4D6C-9A88-FF6249CDCAE1', '1D9091A4-4C92-4AB7-B774-CE2A1652B87A', '4607116940020', '   0,9% 200 - / 28                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9C766B5-0282-4754-90D1-56405A64E5BB', '69E07B5D-A26C-479D-BDBA-40A6DBA092F9', '4607085319094', ' 0,25 2  20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19090EB2-C7C1-49F6-95C2-E1A68914E8AA', '69E07B5D-A26C-479D-BDBA-40A6DBA092F9', '7321838730871', ' 0,25 2  20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58A06D75-9310-44BD-A16F-2F637D805009', '1D93B960-3439-4C38-925C-310B8C78EB19', '4620764310892', '  /                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('624384D3-412C-455A-B588-89D3BE145277', '1D93B960-3439-4C38-925C-310B8C78EB19', '6959287502001', '  /                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('145AA4CE-8677-44F6-B89D-EA9C58999572', 'AFEF0496-5286-4769-9DFE-5C240BD4898E', '4620764310243', '   // 3                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19790547-6E89-4A12-9A6A-65B986B8B8F0', 'AFEF0496-5286-4769-9DFE-5C240BD4898E', '5292452000843', '   // 3                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC8E6738-C84B-4B04-92DE-47659CD4ED6E', '1D99E50B-DC82-4793-99BE-2D467C074BE3', '4030031898310', ' 50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C973D8D-C6CD-4366-B579-0CD47F8565E2', '4D407D4C-CA6A-47B3-8450-94CE7DF86BA3', '3850343034760', ' 5%  5                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16BBE25F-3F6E-46B0-8D57-A8298E7B2C79', '4D407D4C-CA6A-47B3-8450-94CE7DF86BA3', '4607003245757', ' 5%  5                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('443C5970-E48E-411E-88EA-72148634AECB', '1E1BB364-AD86-4599-B409-DF0F3CCB0C1F', '4603713000020', '   25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C850EF37-6D7B-4817-A6FE-F42650EB1BFF', '1E1BB364-AD86-4599-B409-DF0F3CCB0C1F', '4606367000026', '   25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C57E626-C5BD-4F73-B932-C03834D91B3F', '1E1BB364-AD86-4599-B409-DF0F3CCB0C1F', '4606683000106', '   25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('367659B3-DDF5-4D75-8DA2-322FC4D188EF', '4EAE1F63-DE7E-41AE-916C-437DC8273133', '4602546006469', '  25                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('242753EC-1AF7-46E0-940A-9192C194B77D', '4EAE1F63-DE7E-41AE-916C-437DC8273133', '4602565014094', '  25                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6D51136-045E-455C-AB50-8809D832B8B6', '4EAE1F63-DE7E-41AE-916C-437DC8273133', '4603184003582', '  25                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A6F2124-EC2B-40FE-8627-DFD37ECC877E', '4EAE1F63-DE7E-41AE-916C-437DC8273133', '4603373003867', '  25                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1994B05D-AB1C-4E7C-8FB7-D9D7060E092E', '4EAE1F63-DE7E-41AE-916C-437DC8273133', '4605180005997', '  25                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C86F8506-3D04-41C1-8C93-68D312038C0F', '4EAE1F63-DE7E-41AE-916C-437DC8273133', '4605903000926', '  25                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E32CCE34-7CB0-42B6-97C3-B1C74D4FCA99', '4EAE1F63-DE7E-41AE-916C-437DC8273133', '4606367000293', '  25                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('444D8360-24A7-4321-902D-E9BD2D04ED59', '4EAE1F63-DE7E-41AE-916C-437DC8273133', '4607007360357', '  25                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76033E96-1CD1-4317-921A-729BEE3B09E1', '1E914BDE-D2F8-4C39-A3CB-3B56C04C837A', '4602565022969', ' 100  5%                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B508DC8B-882A-4EB9-979F-8114098050D9', '1ECFF222-A539-42DB-95EB-48AE23B8062F', '4602565013134', ' 0,1% 10                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A382131E-3880-4F05-828A-576FBC44ED46', '67F3CCF8-7FA5-4B23-910C-69A85021F012', '4602565013127', ' 0,05% 10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B5A5EFE-4635-482C-AFBF-16050954BD46', '1EE4717F-B4B9-4F07-8CBE-91E226377852', '4603380004710', ' - 3%  - 10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C881986-9A38-4AF4-9A49-F32FE91CD26A', '24ABA4A2-49F1-48C5-A2FD-F2F71F8BE641', '5900516400354', '    50                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46FE6240-D5AD-41E3-B7A4-2E20942C9B83', '24ABA4A2-49F1-48C5-A2FD-F2F71F8BE641', '5900516401054', '    50                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA83ADCC-4113-4C49-84DC-D82C60610D39', '1BA37CDD-8D28-4B9C-92AB-659F270A0AD2', '4603184000420', ' - 2%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E3FED2D-F965-4D86-B142-7912BE312AFA', '1BA37CDD-8D28-4B9C-92AB-659F270A0AD2', '4603184003957', ' - 2%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4430FB61-7F8C-4CA5-9BD9-8254C1828D25', '1BA37CDD-8D28-4B9C-92AB-659F270A0AD2', '4603373000415', ' - 2%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A5429BA-7825-4643-A905-BE2D0DF308EE', '1BA37CDD-8D28-4B9C-92AB-659F270A0AD2', '4603380003164', ' - 2%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12356338-0864-4C24-A19A-833D4BBD871B', '1BA37CDD-8D28-4B9C-92AB-659F270A0AD2', '4603905003518', ' - 2%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9480EBB-D413-4217-95D6-4390D8A73392', '1BA37CDD-8D28-4B9C-92AB-659F270A0AD2', '4605404000265', ' - 2%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1BFEB03-1AF1-4E8B-B703-65764B04D113', '1BA37CDD-8D28-4B9C-92AB-659F270A0AD2', '4606926001037', ' - 2%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56C8A67A-B4F2-4262-96BF-0477FAB86BB7', '1BA37CDD-8D28-4B9C-92AB-659F270A0AD2', '4607007361378', ' - 2%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('117F77BD-2A1C-44FC-8752-93297DA47F11', '6705E277-8E00-40A4-A9BA-866B8731DD9D', '4603373000392', ' - 1%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDD5B7B9-0D63-4567-9111-EBC3A4A449B2', '6705E277-8E00-40A4-A9BA-866B8731DD9D', '4603380000170', ' - 1%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C55CB3DB-08D4-4CEF-8FBE-8DCB57EC0859', '6705E277-8E00-40A4-A9BA-866B8731DD9D', '4605404000203', ' - 1%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B08A9380-8F90-461E-AFF0-84F37D4413EC', '6705E277-8E00-40A4-A9BA-866B8731DD9D', '4607007361194', ' - 1%  - 40                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BB265A8-60BC-4BA0-9434-E32C789C602A', '1F09AA06-5153-4970-8EE2-F61D464BF286', '3800714202045', ' 0,3 50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B1D282D-4994-457D-B38C-0AAF5A5C1366', 'A3D25247-B55D-4F86-BD6B-BBC842C674E9', '4607141998102', '  40  /                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA85A8D1-6BE3-402B-BE26-441B7A4EF822', '1F4F35C3-C709-482A-8911-9979D54A2000', '8595026463356', ' 0,25  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69AAD135-44AC-42EB-9C10-F46BAD804CCD', '1F9D2F92-BC2A-4B37-9605-3A525B3A447D', '4602212005406', '/  1018                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE3DBCC3-0581-4359-B05D-EF79812A3B93', '5FCEBA34-02E6-472C-A842-82D415366B69', '4607083721011', '/  1018                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56F7A2C9-645C-4ED7-AF8C-D751E7AE02C2', 'B32F5FB7-6D19-4764-86FC-9739B0529014', '4602212005383', '/  610                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25DE74C5-C4B1-4BFC-9814-70B8B14AEBC8', 'A1B92A59-725A-4C4B-B87D-ADC1AB7D5813', '4602212005420', '-  1018                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7733F0C9-DF00-4033-8756-83703FA52446', 'A1B92A59-725A-4C4B-B87D-ADC1AB7D5813', '4602212005437', '-  1018                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93F0BFB1-A647-4699-9F24-24F8525A4F90', '56C62733-3C24-43E2-8F7F-00A04A5ECF29', '4607083721004', '/  610                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B11F901-E9FD-4A4E-9AF0-043F185D9F73', '1FB983F7-01F7-45CE-A144-7E98D65A563E', '4030096245166', '  30                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBC5A1B1-F1B2-457B-9C7B-2C1744D87464', '1FD7E72E-1780-4521-85DA-45916948F40E', '4603569720691', ' 0,05  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75AF8208-255B-4985-AA5F-79C7441AEB22', '1FD7E72E-1780-4521-85DA-45916948F40E', '4607020330030', ' 0,05  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E3F3ADD-86E9-41E0-9211-92ADA17CBCD0', '2076BA1E-E962-4FAB-B388-989237E951FE', '4601026302619', ' 0,125  / 6                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6122B420-1D58-43E6-906F-E0CC499BF2E6', 'FE61649E-FE82-44E9-AC19-44E7E8B6B651', '2658933347440', ' /    / 60                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEACA6D1-5799-4F24-8BFC-16B17A217A8B', 'FE61649E-FE82-44E9-AC19-44E7E8B6B651', '4627084350096', ' /    / 60                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8766E972-8B6F-461C-A361-C0259559E69E', 'FE61649E-FE82-44E9-AC19-44E7E8B6B651', '4814488003660', ' /    / 60                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F51B7B67-79C0-4340-82ED-89EA19EACD80', '16CEA06B-B6FD-4622-B7CD-69325C989079', '4607004855030', '-  / / 125                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59D932D9-CF96-477F-8B3F-DB618580AEB2', '0B682277-702A-457B-8C74-17A6806542B5', '4607106002080', ' 100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6A86A1B-D476-4E65-AFDF-6B745DD5E65E', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '4600828000594', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BEF8888-2DFC-4B2C-97D2-0A2AD6DDF362', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '4602424000206', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFAA08E0-E33B-490D-9218-CBE099A71A7E', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '4602424002439', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA5099FF-AFA5-4AD0-99EC-A60E00F1A5C2', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '4602824000363', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BD0079B-80C8-43A1-9A17-A5E28B57A30F', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '4602884001881', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4DD2175-95C2-4466-8527-2D25F3E4E65C', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '4602884015680', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4823A5F-48A3-4493-A0B6-E831F49FB4C2', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '4603988009407', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76B3C31F-DCD8-4E3D-B3F9-3B397B960D4E', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '4607027767839', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF7CE97D-84B4-475B-8283-C249A2CAC9C8', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '4820044113919', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B16688B-0572-477B-BB02-193CACC4D218', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '6916119020454', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA13BB72-7CC3-4843-8B11-079A12ED762F', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '6930169701644', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97A7979D-E90A-4BDC-8C63-46D14274C33A', '2127794B-1FB8-46C4-AC7C-A7E982776A1A', '6930169702702', ' - 1% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D149497-8B9B-489C-BD26-70CA080E7832', 'A1D9A509-FBFA-402D-AE57-322FC184263F', '4601808006834', ' 2  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('425D4152-7A40-4ECE-863D-5AA524B6FF05', 'F644A6A7-803D-4640-9D69-BD2B868E777C', '4030674000118', ' 2  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D53FE6A-30EC-4A7A-B25C-16EB7FF7FBF9', '216859B6-80F4-4CE8-9E85-AD4872186268', '4680013242961', '  20% 5  -                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('519F2FC2-3514-4E2C-9243-DBF839D90218', '2D5F9EBF-2EE4-40A9-8B58-20F26F361288', '4604060994291', '   1% 5                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4276A3B-A869-4E4F-B99C-B0C80F8C3F8C', '216D36E7-45D1-4AC7-B41B-072731173844', '4607009581231', '   40                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D098ED2-1125-4E21-836C-A26DE84BF9B0', '216D36E7-45D1-4AC7-B41B-072731173844', '4607009582153', '   40                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0EEDDEA-F519-4AA2-BAC3-3A05116568D5', 'FFA2F65E-CA3A-4404-B4B9-6FF4D37E1935', '4607009582269', '   40                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF156FCA-D804-40B0-B2EC-3F9D4882A7AC', 'C4F76FC5-8F1E-4C7D-A318-837F968277AB', '3582910000303', ' B-6 50                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('961CF4EA-652E-4854-A92E-D34F138F162B', 'E6F9EBE0-37E3-4951-8F7D-B956D057123A', '4601808006919', ' b6  / 50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('733DCD8A-7632-4F60-BE0F-F842E6FABD77', '98E77C4B-844D-4A99-8AB8-90383A45A4B3', '4602193009448', ' 250  50                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C40A6119-967D-4AA4-B1F0-879E8E4F79E0', '4AA08E37-E616-44BD-BA2F-70173196F056', '3582910000297', ' B6  - 10  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1D26072-C79E-45BF-AF91-AC5B50D3B1FE', '4AA08E37-E616-44BD-BA2F-70173196F056', '3582910026723', ' B6  - 10  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E819EB6E-6F27-45EF-8D7E-66EDA3DAA102', '21BCCF41-184D-43DA-BAA2-90980DFF04C6', '4013054000793', ' 50   10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8860E7E9-0D18-4D7B-B998-551553DDDE28', '21BCCF41-184D-43DA-BAA2-90980DFF04C6', '4607035440113', ' 50   10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FEC0E31-750A-4A9E-912F-854CFCA2B0B3', '1D77AE12-B354-49FC-9A39-F4C4C5E82652', '4602930008185', ' -  0,5  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A58CF8DC-250E-42A2-BC7F-A5E4601F0C5B', 'D0974871-65A6-42F1-85E0-E3844FA6D642', '4601669002198', ' 0,25  20                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4171E06A-A9AC-4760-B8C2-530BCBA6D12B', 'D9D17037-69F5-4665-93F3-C9F6BEFBE9F2', '4030142016207', '   200                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA4B59A5-31DC-4C2A-89D9-B2BA4D804B4F', '43D74AB8-929C-4DC3-9A45-35A7478D00F4', '4601026160905', ' 0,016   10                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80182BBD-FFEA-4D56-9004-30D2F165454E', 'D5490487-8DDD-4C8C-8811-C0E6ADFF8CBD', '3400970000968', '   12                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('988F5269-9478-47FB-81B1-747EA829F0F3', '21C7020F-86E0-461F-BA85-4AA13747BC49', '4604060993423', '   20                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50940A7A-744E-4A78-AB0E-4AD6D6043371', 'D381F4AF-D8BA-4183-9E47-5F35455C84F1', '4603184003865', '  25                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EF770CA-3A84-4BEC-BFBB-D10CACA8A403', 'D381F4AF-D8BA-4183-9E47-5F35455C84F1', '4603380003935', '  25                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F44112C-2076-4C34-87D6-9C0F229786A0', 'D381F4AF-D8BA-4183-9E47-5F35455C84F1', '4603905004300', '  25                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79B65BE7-7517-4EF7-B270-9F3CE3EE985D', 'D381F4AF-D8BA-4183-9E47-5F35455C84F1', '4604060072050', '  25                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A2A34DF-7935-4951-90E4-2BBBAFA9C10F', 'D381F4AF-D8BA-4183-9E47-5F35455C84F1', '4604060072067', '  25                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3215357F-03E7-4BD0-8421-422555BB4F9B', 'D381F4AF-D8BA-4183-9E47-5F35455C84F1', '4605180004372', '  25                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76AEC3BA-2301-44C2-8115-6D84A29970D0', '21D052B3-5F3A-42B2-9EC3-544A2D91073B', '4603179004327', '  0,25  20                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0740687-0FA6-4D8A-93AC-FB1193652E54', '21D052B3-5F3A-42B2-9EC3-544A2D91073B', '4603182000200', '  0,25  20                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45D3A201-A72A-4990-840C-1A6D4A0FA718', '21D052B3-5F3A-42B2-9EC3-544A2D91073B', '4603988011851', '  0,25  20                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('158EF852-04D6-4E55-AF18-594C53B99983', '91708F3A-D4CF-4DEB-AB1E-6C5D41F1D378', '4810201002477', ' 0,5 // /  20                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42349D22-CD81-4BD9-B90B-F04446BB27FB', '2256D4D7-EA22-4AE7-96A8-6794F1F2EF32', '9006968001746', ' 15/5  100                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59EEC86B-DDAB-4B54-860A-3E9D67752CDF', '6D43F2AB-B6C7-4B1A-8043-50FD86A35E97', '5000158100329', ' // 100                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5209794E-5117-4FF4-BC59-A4CF8CFD783F', 'D7DC80E4-9D9D-4E81-97AC-C9B2AE0E414A', '4601669004581', ' 0,05  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF351B11-2E2D-4458-BF44-EB7F6DAF5F64', 'D7DC80E4-9D9D-4E81-97AC-C9B2AE0E414A', '4601669009227', ' 0,05  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81ED9832-3A3C-4D9A-91D8-18385432E43E', 'D7DC80E4-9D9D-4E81-97AC-C9B2AE0E414A', '4602196002200', ' 0,05  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('783C5BCF-69BF-47F7-9F4C-591020A4A2CF', '225F800E-EBC1-4579-9960-3EB52808F6AD', '4603750000243', '   5  5 10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0EB0660-AC9D-40BC-9E1F-63B8EFB18630', '97FE69FC-4FF3-47D8-8C02-F1E9629E8EE1', '4603750000250', ' 7,5 7,5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBE6EBB2-C83B-4AF1-B722-C37195E8AA38', '97FE69FC-4FF3-47D8-8C02-F1E9629E8EE1', '4612741480278', ' 7,5 7,5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA511A33-4F1D-4AE1-8C06-7539BFB02B49', 'E1376665-A68C-42CE-88D3-25A835B48706', '6941762681028', '/ silkofi .  1*500                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DBA578A-A2BC-4436-8547-BD396DE29F1D', '6927C02A-F06A-43C0-BEC8-4B62BBFBFF10', '4600665000184', '  510                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BB2C32A-DC48-4377-AECF-BB735DC531AA', '6927C02A-F06A-43C0-BEC8-4B62BBFBFF10', '4607109940198', '  510                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8812AF54-C7E4-482B-B553-5A390B985FF9', '6927C02A-F06A-43C0-BEC8-4B62BBFBFF10', '4607130520024', '  510                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('087B6D0E-5494-4445-AD7C-81D10DE26C00', '6927C02A-F06A-43C0-BEC8-4B62BBFBFF10', '4640000902513', '  510                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76CF929F-8370-48AC-BD16-C3A5F762A5DD', '6927C02A-F06A-43C0-BEC8-4B62BBFBFF10', '4680381003386', '  510                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8C08F82-ED80-4C68-A15C-E7F43CA4CFE6', '6BC0EB9A-B7EB-4AF2-A8D5-E69AFC86CF97', '6941762681042', '/ silkofi . 2*500                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67777677-0A02-4257-9F16-316AE829F9FC', '233FDC58-EC22-460E-BA62-BEA9FAF5D75E', '5944702000010', ' 0,01  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA9C1336-E607-46DF-A15F-529CEA894FBB', 'FA98F8C5-7BFA-472F-B46A-56B8DB55DF65', '4602809006465', ' 0,02  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12A01966-61C2-41A6-8098-B54351F8E23A', 'FA98F8C5-7BFA-472F-B46A-56B8DB55DF65', '4602824001438', ' 0,02  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87980056-C261-4D80-A8F0-2130166FF4C5', 'FA98F8C5-7BFA-472F-B46A-56B8DB55DF65', '4602824019990', ' 0,02  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('451218C9-9221-4AAA-A9C4-1E38828653B2', 'FA98F8C5-7BFA-472F-B46A-56B8DB55DF65', '4603276006477', ' 0,02  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('192E34B9-9115-44C1-B7A9-CB00D1AC307C', 'FA98F8C5-7BFA-472F-B46A-56B8DB55DF65', '4604060201139', ' 0,02  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('151DD143-3582-4F52-95C4-7E78AB51E27C', 'FA98F8C5-7BFA-472F-B46A-56B8DB55DF65', '4605422010390', ' 0,02  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79557727-2C1F-46B9-B4CE-39E23DF41F08', '23879F68-37E3-42D5-96D9-B1C3A6AEF219', '4603179001586', ' 0,5 , 10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBE609E0-EB0A-4E7A-8BEE-7CE7648A9B11', '24637ABC-DAE0-44BD-B4CA-EDBF3B01C6DE', '9006968003214', '  200 10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9A5571C-ADA2-4649-80BA-10FFD7840B86', '821DB938-2B70-40AD-A306-CE67AA477A4D', '4607027766238', ' 80  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A795A593-D197-4AD5-ABF3-D8AFD81D40AB', '821DB938-2B70-40AD-A306-CE67AA477A4D', '5310001203825', ' 80  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3906A3B2-2FA9-4FA7-BABA-1F64BFCC02F2', '45D2D5CE-D66F-4A50-837F-1C79FCF0D484', '7321838730888', ' 0,5  2 20 /                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4447D6CE-D70E-4BB0-A824-28CF182BF939', '280C2D6B-4DB8-49C9-B958-2C553217EDE9', '5023497032700', '  200 250/                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDB81CEC-2A6F-4B72-AA38-E0A4CE2CAF04', '280C2D6B-4DB8-49C9-B958-2C553217EDE9', '5050963015639', '  200 250/                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DBDD27B-C601-4E91-9872-E194530CD144', '91A82FDC-3CA7-4CBA-9E25-1B42410C5863', '4605147000126', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('109234EE-4E25-45EF-B3B1-D97A1D5AF5D1', '91A82FDC-3CA7-4CBA-9E25-1B42410C5863', '4612747430253', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C9F4F08-B2D4-4E1E-9F43-DAB86E56D590', '91A82FDC-3CA7-4CBA-9E25-1B42410C5863', '4620018140268', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F9B3BD7-091A-46B0-A433-F72D1B5FDFCE', '91A82FDC-3CA7-4CBA-9E25-1B42410C5863', '4640000900212', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61ABF93D-47C2-4F3B-B8E9-1F52716132B0', '91A82FDC-3CA7-4CBA-9E25-1B42410C5863', '4640000900878', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D0FFD81-731F-4B87-A010-AD51BC8CD4EB', '91A82FDC-3CA7-4CBA-9E25-1B42410C5863', '4670003600727', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3901EE4-7776-4F4F-881D-0FD1CBAEFCD2', '91A82FDC-3CA7-4CBA-9E25-1B42410C5863', '4670003600826', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B1F0B42-CC4F-4241-99DA-A73A166A1FED', '91A82FDC-3CA7-4CBA-9E25-1B42410C5863', '4670003605319', ' 510                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AA6768F-653A-4BF0-8550-9BB92CF536C2', '24ABA74B-8E68-4F6A-8537-B007D1C1A431', '4601214001645', '  / 1,5 20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E83DCA42-6A04-493C-B658-00373611CA61', '24ABA74B-8E68-4F6A-8537-B007D1C1A431', '4601498000662', '  / 1,5 20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B1E52EA-A66E-4E37-A32C-3D3C10ED9580', '24ABA74B-8E68-4F6A-8537-B007D1C1A431', '4603717000972', '  / 1,5 20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2588FA54-0D65-4BE9-9233-7A032BFDF4D1', '24ABA74B-8E68-4F6A-8537-B007D1C1A431', '4603762002280', '  / 1,5 20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('330AFA30-A32E-4B3A-9FB3-193311C63BB2', '24ABA74B-8E68-4F6A-8537-B007D1C1A431', '4603782002574', '  / 1,5 20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B8017DE-AEAE-4A6E-A2FE-57C1008C60A3', '24ABA74B-8E68-4F6A-8537-B007D1C1A431', '4605113001102', '  / 1,5 20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82799F29-34C8-4704-BCF9-18C6862B53B6', '24ABA74B-8E68-4F6A-8537-B007D1C1A431', '4607066260650', '  / 1,5 20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('216F4100-1900-4050-9D93-1DB5FCA0765E', '24ABA74B-8E68-4F6A-8537-B007D1C1A431', '4630000892853', '  / 1,5 20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('940768DC-1765-4DED-86FE-7D74E4EA3D82', '3D097A5C-C2AE-4D35-829A-573BA1839E96', '4603671001336', ' 0,05% 10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D834010-8DE4-4A34-A2B2-E4EFDFB1858A', 'B31CFA86-9C57-47F0-945E-89CEFBD9079F', '4601214000587', '  50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('181FBAA5-8493-4A8F-B0EC-8FF73D9F6DED', 'B31CFA86-9C57-47F0-945E-89CEFBD9079F', '4601498007104', '  50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37EB7334-29C2-4BA5-BFE8-DC4465C43539', 'B31CFA86-9C57-47F0-945E-89CEFBD9079F', '4603762002242', '  50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3DEBF9F-D4E4-4E77-B668-5D0847AAC998', 'B31CFA86-9C57-47F0-945E-89CEFBD9079F', '4605113000099', '  50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B50EE64A-8AB3-441E-94A9-1BCE3D91EA71', 'B31CFA86-9C57-47F0-945E-89CEFBD9079F', '4607066260544', '  50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB0B39C-E6EC-46D5-BC2F-9E964B887217', 'B31CFA86-9C57-47F0-945E-89CEFBD9079F', '4607102610395', '  50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB2ABB3A-05B8-42FD-8987-C231B578F9DF', 'B31CFA86-9C57-47F0-945E-89CEFBD9079F', '4640001381348', '  50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82AFF158-A26D-41E5-B393-AE2EA4A7A314', 'B31CFA86-9C57-47F0-945E-89CEFBD9079F', '4680002550312', '  50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88906028-9804-4A61-9E34-9F148B9CB964', '7C1C584B-F3D3-4EA3-A8D2-A5D5D9D08C6C', '4603182002198', '   20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB6C2ED4-1D1D-4CB1-B3A3-3A70F584E04D', '24D64F54-94E7-47A4-AC2D-3A4BEFC93271', '4607003240332', ' 0,0025  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2814AB92-737B-4DED-B74A-23FA453AE6E2', '24D64F54-94E7-47A4-AC2D-3A4BEFC93271', '4607003245436', ' 0,0025  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0787E90-2A48-4BE9-8CBE-07753D199948', '24D64F54-94E7-47A4-AC2D-3A4BEFC93271', '4607022750430', ' 0,0025  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('387279A0-2A2A-4B1A-B313-96309AA9D531', 'F7283468-B8D7-4892-B03A-E3AC3428CCB2', '4602930006594', ' - 10  30                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC2F4F41-FFCE-412B-A106-74A1DD122E3B', '45B5CD85-E852-47B6-A704-9145398A6F50', '4602424003030', ' 0,01  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC604D68-7E99-4C5D-98C2-67EFF81401C3', '45B5CD85-E852-47B6-A704-9145398A6F50', '4602884008125', ' 0,01  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9EC888C-CE1B-437B-A41B-AF3341AC66C5', '45B5CD85-E852-47B6-A704-9145398A6F50', '4603988008592', ' 0,01  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8377175-951A-4750-B15A-633DEEFF504A', '45B5CD85-E852-47B6-A704-9145398A6F50', '4607027760021', ' 0,01  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FC5847E-AFD8-4703-9C6B-3075D900DFC6', '45B5CD85-E852-47B6-A704-9145398A6F50', '4607143560161', ' 0,01  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2AB70D0-BC08-4B68-B1B0-961640BEF3FB', '45B5CD85-E852-47B6-A704-9145398A6F50', '4810201002392', ' 0,01  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C7AD1B0-B4A5-44D9-8EC8-3B07754096BC', '2652909D-F197-4A4D-A02E-21360EE7AAF9', '8600097302296', ' - 400  / 30                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DABB7D4-D1F1-4231-BC2F-08A10DBE99B5', '267AE42D-958E-4B65-A1CF-E6D6A2DB0819', '4602876003169', ' 0,2 50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42C6C8CB-78B0-425D-BF8F-10B626A2F775', '267AE42D-958E-4B65-A1CF-E6D6A2DB0819', '4602884006756', ' 0,2 50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD463AE8-CE9B-44CC-95D4-9A3B72D621E9', '267AE42D-958E-4B65-A1CF-E6D6A2DB0819', '4810133006345', ' 0,2 50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB798862-0D0F-4C14-8879-C07570E3FBAE', '267AE42D-958E-4B65-A1CF-E6D6A2DB0819', '4810201004471', ' 0,2 50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFA9635D-1378-46C9-B8F6-EF5BBF2F7D50', '36A4AD16-72D8-4DE8-B2A1-20F70674FE37', '4603182002518', ' 0,5  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3DD6EEF-7267-4191-BA44-FBE40F616E39', '35661243-BBC3-4CFD-8693-EC87B8E47514', '4612741480056', ' 710                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0AAA1D1-24AC-4443-B338-B745BC2E02B9', '35661243-BBC3-4CFD-8693-EC87B8E47514', '4612741480131', ' 710                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('800778D9-71BD-4462-92FB-B0F031650194', '35661243-BBC3-4CFD-8693-EC87B8E47514', '4612741480650', ' 710                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('657DFA41-DA99-4518-AA9F-C01F61603CAA', '35661243-BBC3-4CFD-8693-EC87B8E47514', '4640000902131', ' 710                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6AAC068-FE0A-4519-B675-27289F6DC87E', '35661243-BBC3-4CFD-8693-EC87B8E47514', '4640000902520', ' 710                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DCA945D-D816-44E8-9C81-1C7ABF7E395B', '26F656A5-1A4D-48AF-BF2F-DCC164F05573', '8717627104159', '     10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B507CEB1-F165-43D6-8F70-AA7A706F375C', '96BF8D81-DEFF-4F8A-99E8-3F32C0FA6033', '8717627103213', ' /    10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60C8CF84-7CE6-4FC1-BF2C-32FDADFBF587', 'C8DBB443-E065-4F6F-982D-0A3E8815BFA4', '4011548002988', ' 0,1%  15                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAAAB93E-B027-4643-BEB6-B15473AE4466', '277C8D81-D265-45C2-AF3C-F2E94195A826', '4602930008154', '- 0,5  / 3                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71812C27-0C15-49FB-ADBC-FB4DE513C200', '674B559D-D16C-4D3E-A4F7-AE161694F78B', '4602930007423', '- 0,25  6                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85E808D5-1FF7-4409-990C-812F1343957D', 'D89E8860-E7D8-411D-8194-4BED11DF6AB9', '4030855000067', ' 600     6                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D764E4F1-7E57-4260-A463-9065BCB0D747', 'DB865E03-3D83-433A-88A7-D67B485D900E', '2400004706904', '  20                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('779BFAB9-68E5-4EF4-83BA-08BA7E398059', 'DB865E03-3D83-433A-88A7-D67B485D900E', '8904091106417', '  20                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC0E5090-55B0-48E5-A3FD-F919A11B188A', '27A6DD7E-0A16-491A-B8FB-AD774FD9E65E', '4600053006811', ' 0,025%  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A58EAA30-9EB3-4F52-BE97-A2B660BE9171', '27A6DD7E-0A16-491A-B8FB-AD774FD9E65E', '4600053006828', ' 0,025%  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56FA0D03-D504-4B37-8971-8EB643E05EEA', '27A6DD7E-0A16-491A-B8FB-AD774FD9E65E', '4601969000498', ' 0,025%  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01416D5E-F4A2-47AC-A193-1DA2983039AB', '27A6DD7E-0A16-491A-B8FB-AD774FD9E65E', '4603679000676', ' 0,025%  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DA25C84-644A-448A-90B1-33D6B955C051', '27A6DD7E-0A16-491A-B8FB-AD774FD9E65E', '4605370006636', ' 0,025%  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD56A715-0BD8-4F61-8C6C-B013A6C7B02C', '27A6DD7E-0A16-491A-B8FB-AD774FD9E65E', '4607027764821', ' 0,025%  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86F47129-9AB0-4426-88B5-588340793671', 'FC159363-A5DF-4168-B724-F9D711F21629', '4601969005493', ' 0,05%  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66915DED-DC5D-40F1-ACAF-A8323E2E28EE', 'C01091BE-52E3-4AD5-B4FA-8EE2DD9455A5', '4607007360401', '  100                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF23AB7A-96DA-45D4-9D65-75A4E974D09B', '27AF0713-D8A2-4549-AF31-42449AF68588', '4600665000207', ' 7 14                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78FA3C81-A36C-49BC-9DEA-B9F692DCCAD2', 'BED51AF2-F715-4C55-AC1A-D8C81D4A2061', '4600665000177', ' 5 10 /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('128D4FF6-6C65-4CFA-9E35-1D5A202D6395', 'BED51AF2-F715-4C55-AC1A-D8C81D4A2061', '4620018140053', ' 5 10 /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50A87EA2-D2C5-4C32-B439-E7147EABAA49', 'EC09E8DD-8C9C-42B5-875F-602EBA5BBCAA', '4600665000191', ' 7 14 /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB68185A-927C-4E9B-8551-9DA0D6C909CE', 'EC09E8DD-8C9C-42B5-875F-602EBA5BBCAA', '4607130520031', ' 7 14 /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B92C996D-A625-490A-A56B-A14889C4903C', 'EC09E8DD-8C9C-42B5-875F-602EBA5BBCAA', '4607151710442', ' 7 14 /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F248BD6F-8740-4CA3-B9F4-AF58533D87D4', 'EC09E8DD-8C9C-42B5-875F-602EBA5BBCAA', '4670003600772', ' 7 14 /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6DDB43E-151A-4F8A-BA53-C2A6A3C13923', 'ABBAD7ED-E976-4E9A-B4FF-EC33B6C210AB', '4607083721097', '/ 610                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38D85567-20AC-41DF-BC8C-28675BA4492B', '2AE59CA2-8740-4B1F-A4D2-9C05525A8D38', '8901148007017', '    20                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFE658B8-BC9B-4DEE-ADFD-AECE8E4D87BD', '42559C42-0624-4232-806B-0E55EF3B8268', '4601808008333', ' 0,1  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('549D6EF8-3F95-41D8-A3CD-74D3CB946D84', '42559C42-0624-4232-806B-0E55EF3B8268', '4602876004791', ' 0,1  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9894C59B-9789-4F7D-BE8E-630717378CE0', '42559C42-0624-4232-806B-0E55EF3B8268', '4607003665036', ' 0,1  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEBA14FC-623B-45E3-8127-BC7126FE0B80', '42559C42-0624-4232-806B-0E55EF3B8268', '4607024942611', ' 0,1  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32118DB9-FCF0-4650-9A39-073EDCC82049', '42559C42-0624-4232-806B-0E55EF3B8268', '4607027761912', ' 0,1  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41C2AA83-AD03-4AFF-AD31-60C345A99D14', '42559C42-0624-4232-806B-0E55EF3B8268', '4823002203745', ' 0,1  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3482421E-E5B9-4504-B7A0-CCFA98428AD3', '42559C42-0624-4232-806B-0E55EF3B8268', '4823002204896', ' 0,1  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B6201CC-4A06-4951-B874-3B734098E40F', 'D79ECE8E-952D-4B9D-B6BC-33D8E82DE9EB', '7290102066599', ' 10  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A3AD4A8-1476-4565-90D9-73512B1594C9', 'D79ECE8E-952D-4B9D-B6BC-33D8E82DE9EB', '8901148228726', ' 10  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F57710DD-A749-4602-88DD-7AF8E4BDCF8E', '280E9EC2-75EB-4FEF-8147-3B38F98F446B', '4605964003706', '  //  5 6                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C1CD582-CCD7-45D1-A07E-735E4E6A08CE', '280E9EC2-75EB-4FEF-8147-3B38F98F446B', '4605964003713', '  //  5 6                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A86AEA1A-0E49-4E65-9BA1-36D82380468C', '280E9EC2-75EB-4FEF-8147-3B38F98F446B', '4605964003836', '  //  5 6                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A9CE337-2189-475F-A85E-75D6D4400159', '280E9EC2-75EB-4FEF-8147-3B38F98F446B', '4605964003867', '  //  5 6                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7D62739-84C2-4A7F-A19F-D61DBA6423B8', '280E9EC2-75EB-4FEF-8147-3B38F98F446B', '4605964003874', '  //  5 6                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97668C1B-724E-4DC0-901E-724ED3B8F209', 'D14C8AE2-BB62-434B-AF0E-6E3186192458', '8584005040985', ' 10                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1094D6B-0787-4A99-9384-61250C413C75', '72E44241-E983-479E-8EE8-35ED7F8C440A', '5900257035020', ' 0,1% 10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0A51E6C-5B04-4851-85AD-BA3C26737D72', '28D32CB5-0F1F-43A5-9568-72E993836E6B', '4601026157486', '  100  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EECD4493-FD45-4604-9587-19922CC5DC79', '28D32CB5-0F1F-43A5-9568-72E993836E6B', '4601026303388', '  100  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1686DB56-ADE9-4F31-A13D-E1E2D7A3E36A', '28D32CB5-0F1F-43A5-9568-72E993836E6B', '4601026307331', '  100  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('410F99E3-4965-475F-B7BC-2362D6A99D9F', '28D32CB5-0F1F-43A5-9568-72E993836E6B', '4601026307348', '  100  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFF19C29-8BC8-4804-A73D-8B0F08E16120', '28D32CB5-0F1F-43A5-9568-72E993836E6B', '4823000800014', '  100  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F6DBC47-065B-4B7C-9DD9-2B4F59E3556C', '5979C66F-DB80-4012-A649-F2AFBF439B24', '8901138030711', '  100                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FD7D6E0-7F70-42ED-888C-F60F726D8342', 'C17DCAA5-5E89-448C-BA71-DC27B63BB3E2', '2400004727169', '   30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('143E9D54-4D72-481A-99E2-9CCFF5927ED6', 'C17DCAA5-5E89-448C-BA71-DC27B63BB3E2', '2400006382823', '   30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FD01804-0F0C-4B6E-9BF6-F99EC8AB4598', 'C17DCAA5-5E89-448C-BA71-DC27B63BB3E2', '4601026304613', '   30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C55F266-B0A2-45B2-B332-EAFE3ADCCA51', 'C17DCAA5-5E89-448C-BA71-DC27B63BB3E2', '4601026304620', '   30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6205F52B-04AF-4909-A493-DCD2774CD8FE', '290B8F18-93DC-4A6D-9C7D-7C0959C3EEF0', '2400005549982', '   4                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E004776-56D4-4D99-AFB4-FF8C157174F3', '290B8F18-93DC-4A6D-9C7D-7C0959C3EEF0', '4602902001251', '   4                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C6BDAEB-B4E5-45FF-8E66-DDD97ED11EBA', '290B8F18-93DC-4A6D-9C7D-7C0959C3EEF0', '4603188001317', '   4                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACF0CA00-782F-4046-9AA4-E70C1C4116E9', '290B8F18-93DC-4A6D-9C7D-7C0959C3EEF0', '4605086000089', '   4                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E36256AA-B42E-4533-A06D-E2BFF12F1472', 'F0E12E90-7804-494C-8E7A-51D6264E4761', '4602902001268', '   5                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E27D6B1F-12E6-4063-8E91-1A06AB4E5B47', 'F0E12E90-7804-494C-8E7A-51D6264E4761', '4605086000102', '   5                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96378F38-B696-42DF-8F87-89AF848D4C7A', '6DB95D09-509F-4D6A-A9D7-BADEC6B05239', '4602902001244', '   2                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E2DF1B8-28F2-4EF0-A5F1-4A273502361B', '6DB95D09-509F-4D6A-A9D7-BADEC6B05239', '4603188001270', '   2                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24E82C4E-1FBF-4CF0-BC8B-2A820AAB52A7', '6DB95D09-509F-4D6A-A9D7-BADEC6B05239', '4605086000041', '   2                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BD4E86F-43D3-48EC-B816-106451C773A0', '6DB95D09-509F-4D6A-A9D7-BADEC6B05239', '4605086000591', '   2                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B3BADE9-01BF-441F-91D5-5AEE128FB723', 'E729E50D-142E-4042-9E77-6763B6366C54', '4605086000126', '    6                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4105CFDD-68B7-4109-9BCA-0059D9F700A7', '2A5DCD5C-0C53-447E-A38F-8EEF7525E9E6', '4602546000214', '  10% 30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('823CC147-3080-46AB-B3BA-16A439914877', '2A5DCD5C-0C53-447E-A38F-8EEF7525E9E6', '4603184003810', '  10% 30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04371FF6-A639-4586-8B82-243CE7D46CC4', '2A5DCD5C-0C53-447E-A38F-8EEF7525E9E6', '4603373000491', '  10% 30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FBFA419-D6A5-481C-A8BD-E0E61DDFCC10', '2A5DCD5C-0C53-447E-A38F-8EEF7525E9E6', '4604060173054', '  10% 30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E98A7A0E-516E-4998-9333-B02D82F403FA', '2A5DCD5C-0C53-447E-A38F-8EEF7525E9E6', '4605404001774', '  10% 30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FBE33B8-B26A-400D-B79E-742E9D3CC1AA', 'F2B9CD6A-25EC-4B9F-B55D-BFEEF5BD61A5', '4603933002477', ' 10% 40                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F3FC521-4FEE-4FD2-AB05-BCB3DA22814F', 'FFC8B232-23C4-4147-9279-5BF62246B6C4', '4603184003421', ' 10%  40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29D19CA9-5D89-4D3E-B1A3-61BF83709CAB', 'FFC8B232-23C4-4147-9279-5BF62246B6C4', '4603905000418', ' 10%  40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8197E8B-4F71-4D62-9D60-C9DE4F9ED37B', '94EBFCAA-D496-4DBC-80A1-5ED4477451F9', '4603905001934', '  20% 25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77057B97-7B30-4449-87EE-E35F0B86377E', 'C2ADC062-6C77-49BF-8019-86F56FC22B2D', '4603184000307', '  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89894996-5C06-4708-B4E2-10A377F68BF3', 'C2ADC062-6C77-49BF-8019-86F56FC22B2D', '4603380001184', '  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDA17DE7-4364-439B-ABC0-9C248D08C37A', 'C2ADC062-6C77-49BF-8019-86F56FC22B2D', '4603905002412', '  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58DEEA47-F088-4857-A50E-D413CAE5B626', '2A7BB996-9A51-495B-B003-2D977B698B70', '4604060203010', '  1% 10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA956C99-89C9-46C4-AFEB-A674ED0382D3', '6AC1855D-BAB5-400D-A05B-FD14FF207BF9', '4603988007250', '  20% 1,5  2 -                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4A6E1AD-A52B-4545-A260-92B1FF11DF0B', '2A8EC31D-6338-4AE0-AEFA-EFBC00D51F2B', '4602876000717', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B5C128D-32CD-4FDC-A52E-10220169C502', 'F16DF62E-6679-4BFE-989D-AB39652DCB17', '4601808000047', '  100                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9794127B-3F51-4EB2-9C7F-E48AC40570EF', 'F16DF62E-6679-4BFE-989D-AB39652DCB17', '4602876000700', '  100                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FCFC312-81D6-47FC-969D-ACEB4A069460', 'F16DF62E-6679-4BFE-989D-AB39652DCB17', '4603679003196', '  100                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26F621CA-8E7A-4079-9F53-B499D4098658', '85F7ABCE-C2D6-45AA-8B1A-B6ACC30D914E', '4602876000724', '  500 10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13D2E598-8398-419A-A4D8-08D7F996BBAE', '912FB8C9-522C-466B-9B4D-D31C91F85589', '4601808000023', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33437C68-C812-4B8F-AD87-FA114702EBBC', '912FB8C9-522C-466B-9B4D-D31C91F85589', '4602876000557', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F9129B6-9EEF-402C-9115-C8464445D211', 'F932F350-7E62-4C46-8152-4B53DA0AFA92', '4603905003815', '  25% 25                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1DE73BF-1520-46B9-8291-F78BA8790E64', 'ACA7745A-5536-485F-A39E-B184DD224D9D', '4602565000516', '  40                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('038F4211-42D8-44E9-98E6-FB4E08D6D682', 'A7E60141-FAA6-46A2-9543-45980C299FBC', '5907529413241', '  / 3/15. 10 -                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('224F78DA-58FB-43A6-9149-0E84AA356039', '5014F690-FC9D-4654-A0A6-5B65B6E6CA48', '5907529417126', ' 0                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCCB63E8-01ED-42DE-AE7B-E799B01E805F', 'E04B19A8-47A9-4284-8B06-5FECE3E652E2', '4603933000695', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CEC01BE-7423-4B26-BB04-E6FF736461B4', '6307E7F5-4400-4132-8E69-9B502E123AC3', '4601969003581', '    0,05%-30,0                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74E1C871-4F7A-4BB0-A3CE-A11E64C7EFC0', '2B1C4C0E-A8ED-45FF-88EC-EAAA4AEA51A6', '4605949001499', ' 10   30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('811D5D63-3903-401A-A5EB-AD68B8F37493', '2B1C4C0E-A8ED-45FF-88EC-EAAA4AEA51A6', '4607011631801', ' 10   30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B378D800-254B-4012-A5A0-4C45CDDAC8C7', '2B1C4C0E-A8ED-45FF-88EC-EAAA4AEA51A6', '4690655008344', ' 10   30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6027BBD4-B9FA-4195-8E8D-B02B3E40CB37', '8A0B67B5-DC8F-4DFD-822E-DF02ABC43F65', '8901148213517', ' 75   30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B36E3511-B2FF-4BC3-9165-F356104E3804', '4F99D8B5-A412-446C-8F70-4B334421745A', '9008732005288', '  0,1  / 100                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78CE5235-1845-495F-B480-22A899C93D91', 'EFA2C485-7C12-4484-90D9-BE9B3ACF35F9', '4601834003487', ' frautest   espress // 1                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5F714B3-A98F-41D4-AF5F-ACE118E96BCD', '58994FEA-41CF-4B55-AD4A-21FB3694D74F', '4084500980952', ' /   easy                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8307D92-1F0B-4BA8-B77B-7A2D0A0E06E8', '58994FEA-41CF-4B55-AD4A-21FB3694D74F', '5011321727595', ' /   easy                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AEEE1D8-ECBB-4264-A2E4-F1BFFF68AD72', '0261FB00-B93D-458C-A339-A0FD839A2939', '4600053020176', ' 0,025% 15                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2902C30-4D94-457A-ADA4-4395B7149674', '7837965F-1C2B-4AEE-BDEC-5101E571D3B4', '3592751842130', ' 5  / 25                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94CA8D07-2E66-4E45-9EAF-6752A0DD8F63', '7837965F-1C2B-4AEE-BDEC-5101E571D3B4', '4602193011649', ' 5  / 25                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2132E8AC-7D42-48E9-A5BF-4B5FCB2A335F', '2CFF1044-85BC-4C65-B814-577C10CEF672', '4607003240158', ' 0,4  60                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BE15F51-9C8F-4BD8-9C49-8081741F6A4C', '2CFF1044-85BC-4C65-B814-577C10CEF672', '4607005893772', ' 0,4  60                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C3800EE-AD35-4A4F-B5D0-FF8B89EFE0A3', '2CFF1044-85BC-4C65-B814-577C10CEF672', '4607019010011', ' 0,4  60                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D156BF83-082D-47A0-861B-39C94C95B747', '2CFF1044-85BC-4C65-B814-577C10CEF672', '4607027762247', ' 0,4  60                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22C9E8F9-1D0F-4147-A4BF-37FFC205385C', 'B851288D-CE5D-41CD-992B-2B0CA9A661A1', '3800010641814', ' 0,025  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6238358F-36C9-4A6D-AD92-FC09048F52AE', 'B851288D-CE5D-41CD-992B-2B0CA9A661A1', '3800033710207', ' 0,025  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B9B9C47-814A-4874-80B6-89D3A43CE98B', 'B851288D-CE5D-41CD-992B-2B0CA9A661A1', '4602884010401', ' 0,025  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF365671-8A34-4363-A519-F7165FFF44B8', '2D315701-3878-4528-B5E3-EFF01F9F4EE0', '4607153450339', '  2,9 14                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6121701-E148-4DB3-93EB-172EE5CC4856', '67896B6C-C800-47BD-B6AC-5529A2F3F783', '4607153450407', ' -  50 10                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('348C0A9A-E0CD-488D-851A-380952A93DEF', '67896B6C-C800-47BD-B6AC-5529A2F3F783', '4607153453132', ' -  50 10                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7C92B8D-5618-4FF0-A368-F610362E1F51', '6CD8C16E-5157-4BF1-B81D-24A2F13CCAEB', '4607153450445', ' -   2,9  10                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2FAFE2B-C0BB-4362-9444-B5C7199B7426', '603317E2-7620-412C-B1D9-D9514E96012C', '4607153450346', ' -  50 10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1E26BC4-2610-410C-9871-91505383E440', '4B2134B2-8D11-47DD-94D4-3F41C8513533', '4607153450421', ' -   10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15B32410-6EF9-4454-A1AE-15A67BE25D25', '4B2134B2-8D11-47DD-94D4-3F41C8513533', '4607153456232', ' -   10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('861E4058-9995-48F4-896F-96DF64A2D5C1', 'CD94E6D0-542E-4F9C-BAD7-BC966AF655F3', '4607153450438', ' -    10                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A82DBA68-94D8-422F-9E1A-D039F15FCFB7', '19AFC85E-F975-472E-8675-6960EF0E12E8', '4607153450391', ' -   10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0158C5EC-DCF5-4742-83A4-DDD1FCF57E46', '7B52E600-B2BF-4BDE-AE79-1A0C9570D587', '4607153450377', ' -  25 10                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7305201-19CB-46A1-A30D-98F2F7D1EB13', '540DDAAF-B81C-440B-B80D-06BDC9F712FA', '4607153450360', ' -  10                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86AA1AA8-3FAA-42D2-9043-929DF3D89950', '540DDAAF-B81C-440B-B80D-06BDC9F712FA', '4607153450452', ' -  10                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F68744E-6093-4AD5-BA61-01946B446791', 'CAC66851-F3F2-431A-8B18-5170A03A4787', '4602565006280', '  20% 5                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D96C5CAC-D3D1-4CF7-BD46-1DF8D660BD96', '2DB3F2E7-7DE8-4838-B576-5A85E75D80B8', '9006968003726', ' 0,03  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF50C05F-AF80-4AC9-8298-43137BBC3BA6', 'DF99DE8C-54C1-4F87-A53F-0CC2AF4FE3B6', '3594455000021', ' 0,08  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F37FF55E-51A4-4555-87A4-5C982BEFDC19', 'DF99DE8C-54C1-4F87-A53F-0CC2AF4FE3B6', '4607159860439', ' 0,08  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E553FD4-4B4B-4BF5-9FC6-51AE26AF57B4', 'DF99DE8C-54C1-4F87-A53F-0CC2AF4FE3B6', '4607159860880', ' 0,08  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D93B22A-5F9B-4391-BEB1-1D4EB0A6318E', '2DFC2CC2-219F-40B5-9D3D-B7E6EB67CD71', '4030855000128', ' 0,2   20                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A99B41F-4776-4A1F-ADAE-0F9C6709AB7C', '2E049EB1-EE3C-49C2-B9EF-6FBD767A4C57', '4600053003827', ' 0,25% 10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F09A0B9-D4B3-4BF0-A1B4-07AAE0BD24DE', '2E049EB1-EE3C-49C2-B9EF-6FBD767A4C57', '4602565008932', ' 0,25% 10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32873D7E-74B3-479D-B24C-14439B5872DF', '2E049EB1-EE3C-49C2-B9EF-6FBD767A4C57', '4603679000324', ' 0,25% 10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDBD230C-F197-4475-AEAB-298DCDA5CACB', '2E049EB1-EE3C-49C2-B9EF-6FBD767A4C57', '4605370000122', ' 0,25% 10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96F0C765-02F0-4578-B60C-5332D08F78E5', '2E049EB1-EE3C-49C2-B9EF-6FBD767A4C57', '4607027764791', ' 0,25% 10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6870D068-2FC1-4B7C-900D-1B8280CB6AA6', '5AE45E2E-1907-4E46-9821-DC85828E6FF7', '4607131360902', ' 3- . .   5                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2904F9EC-E32B-4122-B998-8CC176673801', '5AE45E2E-1907-4E46-9821-DC85828E6FF7', '4612747430499', ' 3- . .   5                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C926114C-9671-436B-BEA2-20FE0FF3BC17', '383B34F5-DFBE-457D-9A53-FFE35225CD15', '4602228001430', ' 3-    3                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BB7A7A4-0909-4087-BB34-469405BA8C51', '383B34F5-DFBE-457D-9A53-FFE35225CD15', '4602228002178', ' 3-    3                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('881399E2-CFBC-40A6-B9E2-DBA9D8A60C67', '2EEA5EBC-1D6F-46DA-8C43-BDD6966B729D', '4605469001665', ' 0,005  28                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6D1438A-CC5D-4A7A-8144-D7121CC370ED', '2EEA5EBC-1D6F-46DA-8C43-BDD6966B729D', '5997001357804', ' 0,005  28                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEF79574-ADEF-4752-AA3A-9EEE3D852903', 'C2BC5E9A-57C8-4E2E-BA7D-619C276C1AEE', '5997001359426', ' 0,005  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('063AC1B9-F5D2-406C-9361-AA762B3C6280', '2F5FFCFE-C9A0-4EE7-AB3A-F7718D88ECD4', '2400004732736', ' 15  / 30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97953A17-3594-4546-84C3-71EA245258EA', '2F5FFCFE-C9A0-4EE7-AB3A-F7718D88ECD4', '4602505007698', ' 15  / 30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA323320-1566-4698-B94F-2370A1443951', 'FE0981F2-D986-43EA-A294-19172CCFEF7A', '4606207000025', ' 10000 10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6B04D35-8592-411E-9789-39AAECE15DE1', '306245FC-F11B-4721-BFF3-7E1C4FC7584E', '4022536645599', ' 0,05% 10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('799A46BE-4DEA-447F-B52A-24E083A03562', '3083E94A-1C16-4F01-B721-402CAEEEF42B', '3838989513139', '   150                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6B953E6-8985-4454-97A1-2F47D7AEBE04', '3083E94A-1C16-4F01-B721-402CAEEEF42B', '3838989513948', '   150                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08B4C8A8-59E2-4778-AA56-C9275A37754F', 'B283D152-3A36-4CD8-A86C-E07E3416679C', '8901086040022', '     20                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47FDCB98-4017-4171-8FCA-02BC82A358DC', '3097AE7D-16DA-4615-BC36-1E4871E1C0F9', '9008732004564', '   30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D25E297C-1B8F-47D2-AC09-92A1D8744E19', '3097AE7D-16DA-4615-BC36-1E4871E1C0F9', '9088881289487', '   30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('777B6A22-B07B-4A61-813A-4B3A6BFE3048', 'FA7EFAED-3885-470B-AF47-13AD79D61DE1', '9008732004571', ' //  20                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D54114D6-0F58-4EB4-84CB-1E443D0F6488', '6D122952-6311-4EA9-8AF0-4FFED8AC95CD', '4605469000934', '  150  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43CC71D4-ADDE-4498-9516-7E1D86D6CD86', '8FE0BA88-CE71-481D-997B-C3D42CF09A5A', '5903060004658', ' // 0,01  50                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38938545-54F3-4665-8D99-58F59335A373', '6BD06875-F0B3-4BEC-90D7-7986F447A1FF', '4601026306198', '   30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E37A6C5A-D693-4356-8D25-9CE7F63F6B6C', '5BE43E73-F5A1-42EB-A06C-75D269908105', '4605469000798', ' 0,05  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C24E1F8-5A8F-40F7-862E-20464898880F', '5BE43E73-F5A1-42EB-A06C-75D269908105', '4605469000927', ' 0,05  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AB5AB7E-B48F-4461-B83B-D99F31DD77A3', '809377EF-4758-4A10-B096-EC10F45959EF', '4605469000804', ' 0,15  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76D3B224-9756-4076-B67A-253781A36869', '809377EF-4758-4A10-B096-EC10F45959EF', '5997001358924', ' 0,15  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5E91C89-33EA-4DF1-AF22-E3683B0A4A1E', 'EC472778-1941-4934-BC23-302E2ED8FF35', '4605469000064', ' 10% 1  5                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCB4CC3F-2957-4772-BF98-AA494699FFF9', 'EC472778-1941-4934-BC23-302E2ED8FF35', '4605469000811', ' 10% 1  5                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39CB746B-31C7-4FA5-A61E-E1E104358C25', 'EC472778-1941-4934-BC23-302E2ED8FF35', '5997001391228', ' 10% 1  5                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0673E02E-640D-4DCC-86E6-7A1E8388B065', '80A7D1AD-84CE-4783-B43F-153168129309', '4603276006248', ' 0,05 10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B40D058D-81E2-4435-9E74-9F507C6B13E2', '30E1C33F-EBB5-40D3-BEAE-6F14A558D932', '5060068527029', '     25                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D042327-51FF-42E8-87F8-CE90799419AE', '62B8C2E4-BF88-45F5-98B4-D64551EFEB2C', '5060068527012', '  //   25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('922DE7C9-BB36-434B-AF26-3C4720967C26', '31210EA2-BA48-41A5-A0A2-C91FD6EADCC3', '4660003080018', '   16                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A912A83E-17E8-4009-91E4-910088ECF66A', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4601429000174', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12EBB5F0-5A97-4A21-82A0-1E4A333C9C8B', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4602546002362', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F8E2782-CA3C-4CDE-A050-FC6C6A89CB78', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4602546005264', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84924AF2-B21D-4422-BA47-300414F15384', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4602876002988', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E235699-204B-4DB9-8BA9-E761CB36BFF8', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4603184002240', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F9B2145-9578-4B8E-A7DA-641017A9FDD3', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4603256004486', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8135F865-A486-41F1-92BD-5393553A24D5', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4603905002610', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49872902-A901-41E1-A0CF-146F08299C8F', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4604060012018', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F43B343-9DE7-4A8F-89AE-41DE0A3E5BF1', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4606683000137', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB48B388-D955-47E7-8F4F-F5002D0ACFB7', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4606926000047', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21D9415C-FB10-48FB-A95A-FACD650444D6', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4607041270223', '  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('107B71B5-2F2A-40E7-A596-F884CDBDFAAC', '3128C97B-18FF-43D4-9DA0-F45ECF20063D', '3582910050049', '- 0,04  20                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E441399-9501-4F93-9BC2-FD76D67F557C', '3169AD6F-1FDE-4F5F-A63F-64CB10A9B5CE', '8901149009737', '  0,5% 5                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8EF0CEC-F783-4A88-85BC-140B7E7B68DD', '66E5AF95-BD5B-4341-B705-F00BE4B9B164', '5413895021503', ' 2,5                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DA5CAFB-258D-41DA-BF4F-C188FD9861F1', '9F488D91-81C1-4CE3-8F80-206F6E3EFEF5', '6419716950006', '  /-                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75B53E66-6947-44B8-A67C-5FC354D07456', '5B134C24-0A54-408E-847D-52D5408A4D54', '2400006382670', '- 1% 5                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B9681BC-3759-491A-8E98-621ADADD96D8', '5B134C24-0A54-408E-847D-52D5408A4D54', '4602565017118', '- 1% 5                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C85B560-631D-466E-B28F-8657F9AEEB9A', '5B134C24-0A54-408E-847D-52D5408A4D54', '4602676003758', '- 1% 5                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('387771F3-E8AD-4987-860E-E78F87EC3F46', '3F0AD7D4-32CA-401F-A302-5B77C140396E', '5413895001918', ' 0,015% 15                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB4DAAC2-AD4C-4A82-9622-707BD44564D3', '32108A2C-A1C0-409A-8451-80F8706E558A', '4605962000059', ' -10 - 0,25%                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45048F2B-4FFA-4A90-A817-065CA48CF50E', '32108A2C-A1C0-409A-8451-80F8706E558A', '4607173030085', ' -10 - 0,25%                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BCA73DB-7210-4543-A430-567435F4D104', '32180820-6496-474A-95D3-6963156FEBD3', '4810046001253', ' 0,2  20                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18164DBE-6390-4F0C-9EBD-034F272AE68E', 'B5A8E244-1518-4E60-8295-618522418B79', '4601808000115', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55DC57BC-D76E-481F-8864-CC09C815D539', 'B5A8E244-1518-4E60-8295-618522418B79', '4602876000106', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A30A29A4-F4F7-475D-927C-72E8AF76ED91', 'B5A8E244-1518-4E60-8295-618522418B79', '4603179003764', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40981943-EC13-4D59-A6D0-8F9DEDD7EBBC', 'B5A8E244-1518-4E60-8295-618522418B79', '4603182002440', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8E9421A-12F6-4E5A-8349-77418D19F062', 'B5A8E244-1518-4E60-8295-618522418B79', '4603679000102', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('530E4D84-EB31-4FF6-A8AD-5D57B6428729', 'B5A8E244-1518-4E60-8295-618522418B79', '4605180006055', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73DC30D9-EB26-4B67-B19C-7F1A677BD08E', 'B5A8E244-1518-4E60-8295-618522418B79', '4605691000436', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B4144FC-D79B-4C94-9D1B-87A896703346', 'B5A8E244-1518-4E60-8295-618522418B79', '4605691002485', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('396E0B7F-5BFF-41C2-A0E6-7F67333B0612', '322EDADE-5806-46D9-A506-24B53B27B99B', '4605964003805', '  //  5 24                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7989C81A-44CB-4FAD-9C09-7461907EDD88', '322EDADE-5806-46D9-A506-24B53B27B99B', '4605964003966', '  //  5 24                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CA4B5A9-FD83-41E1-88FA-7B5DAB3E948D', 'D26A4BF8-24AC-46D8-8673-899C7BC43291', '4605964004642', '  //  5 24                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05C8E1EA-6D40-42BD-90BE-BF45DC213F4D', '5EA13FAE-377B-4A3F-86D6-17DBD5E29B65', '4605964003973', '  / /  5 24                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAE71773-262A-416B-80A8-4038A52FDD76', 'FCE7E171-740F-4476-BA5D-558F1910E931', '4605964003782', '  //  5 24                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E01D214-752D-48B7-9723-C154D40A5556', 'FCE7E171-740F-4476-BA5D-558F1910E931', '4605964003942', '  //  5 24                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8ECD8AE-4734-4E5F-AB9C-696F1716758C', '51103827-FFD8-4DA4-8DDB-D13F3B4956D6', '4605964003959', '  /- / 5 24                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E28BF19-B5CF-4898-9CA5-EA439375AE98', '326E9107-DBC3-4252-8775-F41D1451F5DA', '3838989500511', ' 0,005  20                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77239B33-E1E6-4F69-B0C2-C0CC48EEFBF8', '326E9107-DBC3-4252-8775-F41D1451F5DA', '4605635000164', ' 0,005  20                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3244BD12-00A9-42BA-9DE0-1B5F0FF20292', '326E9107-DBC3-4252-8775-F41D1451F5DA', '4607055131817', ' 0,005  20                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24C0954E-89DC-4B49-B300-2CC69B93C2DB', '7B2A0616-A2CD-455D-BB90-F75051667E8B', '3838989500528', ' 0,01  20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E85BDCE-3B98-4FA5-A664-DD57DE813147', '7B2A0616-A2CD-455D-BB90-F75051667E8B', '4605635000171', ' 0,01  20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A9D03B9-4670-411D-A307-38EE0F3E2DC4', '7B2A0616-A2CD-455D-BB90-F75051667E8B', '4607055131824', ' 0,01  20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47D7B7D2-3D3A-4AD6-815E-E72C65F80093', 'C4F49A4B-FEFF-4FA2-B39F-A71B34B476A7', '4602509000602', '  0,9% 200                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63CB1F8C-7CEE-43F0-B8BB-AE07A382F4C5', 'C4F49A4B-FEFF-4FA2-B39F-A71B34B476A7', '4602884000334', '  0,9% 200                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D11C0956-C16F-489A-A087-A91FBA86709B', 'C4F49A4B-FEFF-4FA2-B39F-A71B34B476A7', '4605453000100', '  0,9% 200                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10540380-944A-46A7-A3C5-D3679D533FF2', 'C4F49A4B-FEFF-4FA2-B39F-A71B34B476A7', '4607116940013', '  0,9% 200                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2A5F651-BA45-454A-B04B-17B6BB0666D4', '32B0790D-E163-42DB-AC6A-B095A5E7CA8C', '4029835000029', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EDF5498-F616-4D45-8BAE-367199D39FD9', '32B0790D-E163-42DB-AC6A-B095A5E7CA8C', '4607039970326', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98901F80-C016-4F62-9A80-8B9DF8C57946', '32B0790D-E163-42DB-AC6A-B095A5E7CA8C', '4660014120390', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2370D8A0-D887-4E42-A3A3-D7EC8A54F5A2', 'B9FE6E3D-1487-4C18-9F61-778A738564BA', '4607039971934', '  12                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70B90D6E-6353-4C1C-8CEC-70BF5A1D4059', 'B9FE6E3D-1487-4C18-9F61-778A738564BA', '4607039973082', '  12                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4B0351B-8CFF-4598-9D09-901DA4104466', 'B9FE6E3D-1487-4C18-9F61-778A738564BA', '4607039974553', '  12                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A17AAB3-9237-4F8C-AD7E-B6D71CB129E9', 'B9FE6E3D-1487-4C18-9F61-778A738564BA', '4607039974584', '  12                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51FCBF9A-1E57-4EB8-83CE-1AEA94F5337F', 'BF4A400E-560E-402E-8B31-BE10640D6CD5', '4607011664373', '  //   /                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45C750CF-B53E-465C-AE6D-2B226D17BB4F', 'BEC54C0C-EEB9-438D-BD42-C0C0C61BDE03', '4607003245672', ' 30  5%                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8B684E8-CF28-4F14-991A-53E01A0390A6', '32BD1AC1-68FA-430E-89F9-EAF4470068BF', '7680500109002', ' 10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('769D9833-3AEC-4543-9BB3-019891C430CA', '8689511E-F277-4215-BB97-EABDCDE93B4F', '4601669004598', ' 0,1  20                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B01A2033-74C6-4FDE-9C3A-96F3B9D438DB', '32DD1504-5F12-4DBC-B0A0-D32A0BA378A8', '8594737176210', ' 0,1% 10                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE457E8E-F6A1-4CA0-813C-0C1038A2E804', 'C9CD407D-A2F4-4D9A-8FE7-E41509888889', '8594737176012', '  0,05% 10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A260C58A-E377-4D7F-9433-8EC0B69943DA', '33104A64-71F8-434E-9C6C-904865DC89AD', '3596540060125', ' 5+500  30  /                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFD074E2-91E6-49F6-9607-3F637ECFC087', '9206FAAB-8A4C-48F1-A349-0E496F6C8A84', '3596540050027', ' 1 //  60                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB2E4D1C-B2C1-4D84-AAC3-982EA3214D8C', '9206FAAB-8A4C-48F1-A349-0E496F6C8A84', '4640017590314', ' 1 //  60                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D85DF1E-BFBB-4B21-9CBD-B0976C2AD5FF', 'BAE3B549-944A-45C3-8503-3EB0F7CC8588', '5995327182070', ' 0,02  //  60                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB3F9C66-5DA8-4348-9A62-71BEE9857A9D', '3346C6B1-8E68-491F-A170-C2B720A22D81', '4600728002261', ' /   100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89898D22-611F-4536-8DEE-31C8580DA96F', '3346C6B1-8E68-491F-A170-C2B720A22D81', '4600728007457', ' /   100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A98C785C-AEC3-4B3B-89EC-E816983E9AFE', 'E32C9A5A-4ACF-47D7-A803-5B16CCAE6211', '4600728003916', ' /   6 100                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00A609E2-49B7-47FB-8404-BE9B1E5DA88C', '5181BD36-3B0F-42E3-9E84-8B2817F8FE9C', '4600728003992', ' /   6 100                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10488897-E861-4B43-901A-47934E1817F2', '477EBCEA-D13F-4833-A3CC-E58139FCF4F1', '4600728000069', ' /     6 100                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BE84066-1F7C-47E2-A703-05FE79F1D1BA', '32C2D121-C2C6-4C08-9D20-BE873ADED470', '4600728002254', ' /    6 100                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AE4EC5C-F570-45B2-84DB-24237FF1659A', 'B801E130-EFEC-4CCD-BE47-1D4D447DD1DA', '4600728003466', ' /   100                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C11EE7A-97F7-4330-AC92-1BF145269B36', 'CD992CBA-01BC-4E7E-A9F6-E923FAE2491E', '4600728006566', ' /    6 100                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('790076E4-3891-4315-AEA1-81A29BF95079', 'BD34F567-D977-4BD5-AAB9-9AD5487EC434', '4600728006481', ' /     6  100                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5163127-DED6-4553-8C89-3700F991DD98', '22F916E6-2E51-488C-891A-2401A73B0FE4', '4600728002735', ' /     7  100                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('181DF6F3-E71E-4720-BCFF-D64E1007E7AA', '7C48CB8A-7278-4646-AEB1-9E5C157117A4', '4600728006306', ' /    100                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38299821-C743-47D7-A8B1-1F8068A73A79', '3351BA06-4E6B-4E78-A225-84C17FC50819', '4602228000716', '5   10                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3326D8B7-5378-440D-82E8-67D92C71061A', 'BC9886DA-2F96-4306-8708-D546B7C8F1DC', '6941762681066', '/ silkofi .  3*500                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('915CBD18-BDD7-48F5-AB94-A4C9E5C68DC1', 'A0C0FD67-A860-41AB-A8DB-BC8254F02468', '8904091116621', '   100                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8250928A-CE40-4198-8B92-203249FB472C', '33B6DD3D-7EAF-4A40-8478-DC79F124A8B3', '4602193005457', '  0.57 60 .                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D082F6CA-D3A7-4765-8966-3ED09BA82286', '33B83D7E-C6E8-490F-BB29-7DA707677225', '5000158103368', '  200  20                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E3F5001-D27F-40AC-89AD-819FFD093E30', '396DD1BD-74CC-4F52-818D-CD1D74A22660', '4011548020777', ' 0,1% 15                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C618CF1-8A18-4D94-9582-F6F4BE7041BB', '76A2205E-56A1-4CEA-A090-D3381908544C', '4600053008334', '  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B82031D-DBEE-4138-95A1-045A2D753EC4', '76A2205E-56A1-4CEA-A090-D3381908544C', '4601429004431', '  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C69C703E-9E6D-4EDB-81B1-80DBF2A90B90', '76A2205E-56A1-4CEA-A090-D3381908544C', '4603905002696', '  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82BE83C4-AAA6-4920-8BD7-3B70E244AFCA', '76A2205E-56A1-4CEA-A090-D3381908544C', '4607027765231', '  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70545289-2457-4ED6-85BD-A4FC4CA61EE6', '76A2205E-56A1-4CEA-A090-D3381908544C', '4810201004242', '  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('073D4C50-D07B-48BD-BA02-C7ABA16C16EC', '3E1372C4-B91A-4A1B-8C4F-6123CB0BC8FC', '4036534512067', '- 3500                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('120D1BA0-35FB-4977-A062-3A3A3172C405', '3E1372C4-B91A-4A1B-8C4F-6123CB0BC8FC', '4602435000806', '- 3500                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0CE0941-6C4E-4D69-9D6C-B33487FF00D0', '3E1372C4-B91A-4A1B-8C4F-6123CB0BC8FC', '4607155640110', '- 3500                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60D4B505-A6A7-4B52-9523-8FCF32314026', '3566042A-BA14-406A-8B15-A5547F5ADBCC', '4601808005738', ' /  ..  / 60                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95F1B352-F101-41D6-9312-C5C1546F5BD2', '89C9731F-40A7-4FCE-A673-9D3EDD8327B9', '4601808003925', '  60                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BE12095-E262-4BBB-98E2-42A4698EA999', '8739289F-ACA5-4351-8C04-14C32BEE42DD', '4601808004137', '      30                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06F96807-7858-4F7E-9519-EC4750B9ABD6', 'B524F197-C09F-4AF8-AD7A-C72C17A029AD', '4601808007688', '  / 3  10/    30                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68603FCE-7FC4-48A6-AA2D-8AEB99FE1514', 'C468755E-EC4A-4E24-8460-0BA4E8A319B0', '5904398249025', ' 0,025  60                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FA3A122-047F-48F1-88D6-30CDF9FCD46D', 'C62F3054-24F6-4127-97F7-974F48CDDD2B', '4603276000451', ' 0,05  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('299B325E-B436-4408-BFC6-67D00BE634AB', 'C62F3054-24F6-4127-97F7-974F48CDDD2B', '4607100621775', ' 0,05  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A992A327-8B74-4D70-B1E6-2808A252C8CB', '7F5B2B2E-AB00-49A8-8D8B-B0E5A37719AA', '4607100621799', ' 50  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FF7DFD6-DC60-4020-AED6-A4311474E37D', 'A881D5BD-2E9F-4FE1-90F7-C12A083FB037', '4602930003128', ' 0,002  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC35E193-6B3A-47B0-A798-34D342BF51C7', 'A881D5BD-2E9F-4FE1-90F7-C12A083FB037', '4603569720301', ' 0,002  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAB5E0C9-B784-47BE-822D-2EF93E5201BF', 'A881D5BD-2E9F-4FE1-90F7-C12A083FB037', '4605949001406', ' 0,002  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75E0002E-83BC-4748-AA85-7936334DAD79', 'A881D5BD-2E9F-4FE1-90F7-C12A083FB037', '4607027760052', ' 0,002  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B7E4F63-0AFC-4642-917B-A29AF3EAE3E4', 'A881D5BD-2E9F-4FE1-90F7-C12A083FB037', '4820014490651', ' 0,002  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D6EFFA6-FE86-43ED-9050-ABEF2F86DE56', '361C0829-3784-47A1-A109-620435B221AA', '4601764002598', ' 10  / 20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C681D288-CE4D-4734-B17D-F87135D31A62', '361D6FAE-A87E-43BA-A98C-48059022A93C', '8717627104296', '  //  39                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BBA5D80-0256-40B1-AABA-B30805D01866', '85A7EEA8-307D-40AA-937B-A45CD57C9583', '8717627103251', ' / +  / 17 39                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E003635B-7B49-4FF0-B058-80B07A74967B', '85A7EEA8-307D-40AA-937B-A45CD57C9583', '8717627108690', ' / +  / 17 39                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40102B62-4DEF-4E00-A88A-970007C32724', '7C127897-C5E1-442C-A22F-6213CC3323A8', '8717627103244', ' //  39                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C727333F-FD49-41B9-B60F-D1A2F41E38C1', 'A227CDEE-83B2-48A9-BFA3-5D5F77F4A55C', '8717627103282', ' //  39                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5564C133-490F-4494-ACE6-30B2E33E5F23', 'A227CDEE-83B2-48A9-BFA3-5D5F77F4A55C', '8717627108751', ' //  39                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67188C1C-2E88-4435-A22F-778944793ED1', '562DCE4A-5561-406E-B100-852677BC5F18', '8717627108577', ' / +/ 17 39                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9963DDC0-AD10-46DF-A465-8715ADF8D4A5', '36900F7E-2FE6-47D0-93B5-DB8E546A1193', '4607027761264', ' - 0,04 50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A982A36F-432B-4710-9073-FCE2A992AC3F', 'C0A502DF-EF2D-4E52-AB43-49DF98DE0EEC', '4601669000682', '  20                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8D2B066-547D-4BAE-B0E9-37C97DEA65C2', 'C0A502DF-EF2D-4E52-AB43-49DF98DE0EEC', '4602824010942', '  20                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18DA8F3D-C5BB-4613-AB26-8DCE888A43A7', 'C0A502DF-EF2D-4E52-AB43-49DF98DE0EEC', '4603179002156', '  20                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AEA2342-8C7E-43B9-AAB0-53D5952B612C', 'C0A502DF-EF2D-4E52-AB43-49DF98DE0EEC', '4603988010601', '  20                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FDD81DE-8F2C-413B-9635-39DC32B6B7CB', 'C0A502DF-EF2D-4E52-AB43-49DF98DE0EEC', '4604060992525', '  20                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0402D1F4-9335-40B6-B19A-1847A293E1C3', 'C0A502DF-EF2D-4E52-AB43-49DF98DE0EEC', '4607100621836', '  20                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65B1DECC-C316-4C5C-B937-685DD0AFD98F', '7C493EDA-C372-42C0-A25E-6BEC8B2D1F8E', '4601669002020', ' 0,5  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E661A5FC-F544-4936-B54D-6471D8C6C5A1', '7C493EDA-C372-42C0-A25E-6BEC8B2D1F8E', '4602876002469', ' 0,5  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A64AA0C-9E74-469D-BFAE-E67DA63C9F6F', '7C493EDA-C372-42C0-A25E-6BEC8B2D1F8E', '4603182002501', ' 0,5  20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC384326-EC75-471C-A0FD-7050E7A41F8A', '36D3BE93-80EE-4BC3-984B-EB0314B6BA1A', '4607003662318', ' 0,05  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6E25EEA-DAC3-4C0A-9229-85E5361E82F4', '36D3BE93-80EE-4BC3-984B-EB0314B6BA1A', '4607003662332', ' 0,05  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAD97D46-32DB-42E0-BDE6-9A28AB2F1E61', '36D3BE93-80EE-4BC3-984B-EB0314B6BA1A', '4607020330276', ' 0,05  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B7EF71B-D496-4B68-A6DD-1312740B7977', '36D3BE93-80EE-4BC3-984B-EB0314B6BA1A', '4607027767280', ' 0,05  40                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD99A65E-AA70-4688-9126-F68CF4DC4B96', '47CCE3EA-23B4-4CF2-B4F6-BDD4B777DDBB', '4607027766337', ' 0,025 /  40                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D81948D3-6863-4EC4-812A-32BD9D69664F', '47CCE3EA-23B4-4CF2-B4F6-BDD4B777DDBB', '4810201002651', ' 0,025 /  40                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDA2FB47-B0E6-4D24-9D8A-C758758FF799', '3757BB1B-6EA3-4F0C-A631-5D81B4FDC85B', '4602435000714', '/ 1500                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43C611ED-F2A4-4D7C-877A-E4546FF302E5', 'C0981F1D-6255-4855-8247-0FD38FB4EFE5', '4607083720953', '/.  610                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52AC8381-CEF1-4C44-8548-F95968281594', '37837530-27D4-4AA8-BF9D-71252B1C274F', '4602212008339', ' / 5% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93CA64EA-9C1E-4D9C-B956-899BE86713F1', '37837530-27D4-4AA8-BF9D-71252B1C274F', '4602884004493', ' / 5% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26BC7985-5322-4A8A-BF57-F02BB400C6F3', '37837530-27D4-4AA8-BF9D-71252B1C274F', '4602884014003', ' / 5% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C402742A-3765-4AA8-874E-6C0187DF4EAC', '37837530-27D4-4AA8-BF9D-71252B1C274F', '4820011030041', ' / 5% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3762A3AB-E388-4308-858B-AF6A77F58243', '37837530-27D4-4AA8-BF9D-71252B1C274F', '4850001740018', ' / 5% 1  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('788619DE-D429-4909-91B9-48B041E0307B', 'DBED0B1E-68D2-42CC-89E6-243ECEDCF31F', '4600828000464', ' 0,05 / / 1 -  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('233BD378-C1B6-4127-82E3-9F3D362DEBF8', 'DBED0B1E-68D2-42CC-89E6-243ECEDCF31F', '4602824000301', ' 0,05 / / 1 -  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDC685A7-A1F8-40C6-98A4-C567E03BA9D4', 'DBED0B1E-68D2-42CC-89E6-243ECEDCF31F', '4810201000183', ' 0,05 / / 1 -  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CC038F8-DA4B-496F-B4C1-F18E4F427310', 'DBED0B1E-68D2-42CC-89E6-243ECEDCF31F', '4850001740025', ' 0,05 / / 1 -  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9935AB6-F663-472B-9B6E-245D08FD06FA', 'C0548069-330D-402A-93C2-28473445A35A', '4607027763428', '  5% 1  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E666650C-587D-4058-9510-1BDB5F8F4B39', 'C0548069-330D-402A-93C2-28473445A35A', '6930169702726', '  5% 1  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE4559DC-6CAC-42AF-BAE7-2EF96EF8591D', '8E0132F9-78A2-4714-8CF5-F2B835F1689B', '6959287500205', ' / 5                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39E0A0A0-4A54-49CC-9E08-7FADBF6FEECF', '37D17AB6-6CC9-442A-9768-5176596A5776', '4602876001998', ' -  0,075  10                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B197D585-551D-4E18-BC30-70F8B04A8EB5', 'A2AF1BEE-AE80-449D-B86D-4A5337B218CE', '4601808004564', '/ 50                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DEEAF18-7E15-469B-B846-328041E06FEC', '67E41C3F-3C54-4024-9D8C-B5F6E321757D', '4602876001974', '  25   10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F883B8F1-D16D-485D-B52F-589130388398', '67E41C3F-3C54-4024-9D8C-B5F6E321757D', '4610000290590', '  25   10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6B984A1-AF09-447D-9239-07EACF43A561', '37E56A86-DD2A-4CF6-BE44-68F3BD6ED4B5', '4603184002141', ' 5%  - 25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4B143D7-AAAB-4E01-91FD-C19D7CEC7B20', '37E56A86-DD2A-4CF6-BE44-68F3BD6ED4B5', '4603905004270', ' 5%  - 25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C8C8092-CD9A-49C4-B1D8-B38CFD54A516', '37E56A86-DD2A-4CF6-BE44-68F3BD6ED4B5', '4606367000729', ' 5%  - 25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0122A188-9190-4F67-A84F-DC65EED8F4EA', '5D8545AE-022F-44FB-8F53-3E499EDF6083', '3800737000666', '-  20                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('560C4408-C59B-47C3-B8A3-CA61E79D97A3', 'D00DCDF0-821C-4D8E-A77C-9060F9681860', '4601429000167', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC6B4C97-67FB-4FF2-8725-878A3AC0ACA0', 'D00DCDF0-821C-4D8E-A77C-9060F9681860', '4602546002669', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8338431C-A925-413D-9E36-2E1B07917B5C', 'D00DCDF0-821C-4D8E-A77C-9060F9681860', '4602546005318', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0DAC64C-A0F3-44BE-9E7E-5A24F58906AA', 'D00DCDF0-821C-4D8E-A77C-9060F9681860', '4603184002233', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78DF67AE-10A6-41D1-9629-6F296A3ABD84', 'D00DCDF0-821C-4D8E-A77C-9060F9681860', '4603373000033', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01EB2EAB-9D93-4E35-8144-DC02B02007ED', 'D00DCDF0-821C-4D8E-A77C-9060F9681860', '4605681002112', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8492CE7E-EAC8-4A14-BE49-CC5D509B6CB7', 'D00DCDF0-821C-4D8E-A77C-9060F9681860', '4607041270070', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA07C54C-5023-42A5-AE7D-F656E1DF53AB', 'D00DCDF0-821C-4D8E-A77C-9060F9681860', '4607041270216', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53A34339-6481-495B-A589-330DE2C3B942', '3826A14D-D14E-4A61-8E1D-7BFCDA7C8E57', '4602243002221', ' 0,002  6                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FCFD241-6664-4846-9D17-04E22869D800', 'DC3EB02A-5142-4E0A-92F7-5510A6E34412', '9557955001411', 'DERMAGRIP HIGH RISK POWDER FREE M ..                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D15F5A17-0217-49D1-826D-B7332CE3C2A8', 'FB42B019-81CB-41FE-AEB5-4FE5FDCCE2A5', '4607101204465', '                                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C149C37A-4199-45DB-9616-B43ADC56522F', 'FB42B019-81CB-41FE-AEB5-4FE5FDCCE2A5', '4612751230016', '                                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D05F2F7-7B1E-4EB7-A088-BCBE010C1AE0', 'FB42B019-81CB-41FE-AEB5-4FE5FDCCE2A5', '4820135150700', '                                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B010EC6-CD2B-4FD7-AF54-2F3832282D85', 'CF23D66B-47B9-4E1D-A231-A40F5C7FF2B2', '9557955001428', ' eamination powder free .. s                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('394F1495-61BA-422F-9529-6575BDE6903B', '3862C034-4F4F-46EC-9601-6D988413A3ED', '4022536645582', ' 0,05% 10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F294195-7C1A-40FD-9E15-71317A53FCEF', '38BB321E-0BF3-483F-AE41-2F627B127735', '4603191000888', '    air   10                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AC624AF-B929-423F-85B5-AC729389C1F1', 'AFB78158-667D-4F26-B050-5376ED1EDC8B', '4603191001427', ' 0,15 //  20                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B657F184-587D-482A-B124-0165878B8AF6', '924011C1-CF19-4F2E-92AB-002F6D5D963B', '2400004746849', '- 25                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46539792-7290-40AE-B2F4-B3A4481AEA1D', '924011C1-CF19-4F2E-92AB-002F6D5D963B', '4603373000231', '- 25                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F762BF5B-8A6A-4997-B885-C547B66D44AE', '924011C1-CF19-4F2E-92AB-002F6D5D963B', '4603380000866', '- 25                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB813134-F5BB-44E2-8384-D99759AD3341', '3915C61D-5609-46E5-8C83-B2E4F1612257', '4607045191418', '                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A57A4594-AEFA-4D88-8DC4-35904735CC5C', '3915C61D-5609-46E5-8C83-B2E4F1612257', '4607045192156', '                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4398B011-E27A-44D5-9481-13DAC7A75F86', 'BBC6883B-F737-40B6-B42A-F5B35F61DE7A', '3858881054738', '  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35F6E843-0B7F-467E-9DA0-5BF4A0CB1BFC', 'B527AE68-04FE-447F-B730-F40EAC90B25F', '4022536645612', ' 0,01% 5                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D826233-1DC1-4899-AB8B-03EDE2A5279F', '476D8B4F-7A79-4ACF-AAA7-A60E3FFC1863', '4601026308345', '   15                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('279491F5-7CAB-460C-87FE-A9F1DE679E89', '3D447060-1ABE-4273-9815-D03928997137', '4607045192163', '   ./ /10 / 1                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('029EFDC8-AA1D-460C-B0B7-117022D14E6A', 'A1C4FF1F-DB9E-4B2A-92FB-0B1FF70CBB0F', '3800712004313', '-  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46F431D6-617B-4B9B-918E-5B698FFBCB02', '3ACC6095-FE2B-4B7D-AD99-84729527DC6D', '4601214000112', '   50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D51B307-32DF-4080-9153-5875C776D976', '3ACC6095-FE2B-4B7D-AD99-84729527DC6D', '4603717000071', '   50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A0B7EB7-C795-4BF9-AA25-2BDE852A4C25', '3ACC6095-FE2B-4B7D-AD99-84729527DC6D', '4603762000750', '   50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('970A5BE3-8659-4BE9-9514-0BEA52BDE28C', '3ACC6095-FE2B-4B7D-AD99-84729527DC6D', '4605113000068', '   50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F89F2E2C-F142-480A-8FFD-B0835CC5655C', '3ACC6095-FE2B-4B7D-AD99-84729527DC6D', '4607066260162', '   50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4EC801B-E858-4C4B-B249-2576326B90AD', '3ACC6095-FE2B-4B7D-AD99-84729527DC6D', '4630000890163', '   50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C64F7C2-14BD-4C19-B0F7-398D70F2E013', '3ACC6095-FE2B-4B7D-AD99-84729527DC6D', '4630000892785', '   50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7091EDE0-0B22-4548-AFF5-7E694583A86A', 'E41C7F38-7E96-4173-A0EC-998952544919', '4601214000280', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9555A8EC-4909-472E-BFCB-5D30229D5166', 'E41C7F38-7E96-4173-A0EC-998952544919', '4603762002976', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBB8334E-C6FA-4B65-AC0C-9C92C0BA65E5', 'E41C7F38-7E96-4173-A0EC-998952544919', '4605113000228', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97D6253C-884C-4995-8556-F64F9B8E0AE0', 'E41C7F38-7E96-4173-A0EC-998952544919', '4605126004282', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0181D629-F8C1-459D-B39D-6BEC12C4E290', 'E41C7F38-7E96-4173-A0EC-998952544919', '4607056590033', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9370C145-9210-4F1B-9B61-4618A448B7E3', 'E41C7F38-7E96-4173-A0EC-998952544919', '4607066260018', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('106BB6F3-1CE4-4A9B-A7E6-F70741C771C3', 'E41C7F38-7E96-4173-A0EC-998952544919', '4680002552033', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4382902A-968B-4BD4-89BE-07C80460CE33', 'ECF96B3E-F4EC-4FE3-85BC-7BDF7F0F2E7A', '2400006372558', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8819A564-537C-4F49-AB41-ABF4F0B828DB', 'ECF96B3E-F4EC-4FE3-85BC-7BDF7F0F2E7A', '4601214000297', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC767BAE-BE42-4514-AB5B-47FC22D51D08', 'ECF96B3E-F4EC-4FE3-85BC-7BDF7F0F2E7A', '4603762000095', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD1609CD-45CB-4480-BEAE-FFFC0BC02276', 'ECF96B3E-F4EC-4FE3-85BC-7BDF7F0F2E7A', '4605113000211', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE98A64C-4B9C-4571-AC0E-F295E0B1519F', 'ECF96B3E-F4EC-4FE3-85BC-7BDF7F0F2E7A', '4607066260025', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B20B1DA1-8FC0-4E5E-B33A-6E26657814B3', 'ECF96B3E-F4EC-4FE3-85BC-7BDF7F0F2E7A', '4630000891412', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAD24573-ABBD-4391-B2DF-C6B8F8CF67E8', '87625E8A-58A9-4435-94A5-B479D0AD5BC8', '4601214000471', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBC656F8-1E90-40D5-899B-AE59DDC5CFA7', '87625E8A-58A9-4435-94A5-B479D0AD5BC8', '4601214002116', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E78330D-3494-4393-A677-C619903F97F8', '87625E8A-58A9-4435-94A5-B479D0AD5BC8', '4601498006688', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AB714FF-BB83-4B29-9A74-3B30976FB1E1', '87625E8A-58A9-4435-94A5-B479D0AD5BC8', '4603717000019', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AEDA7AB-AF8A-4F5D-963B-32C4986D5751', '87625E8A-58A9-4435-94A5-B479D0AD5BC8', '4603762001511', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1602B994-F474-4DB5-99D5-1C72D4B3DC6B', '87625E8A-58A9-4435-94A5-B479D0AD5BC8', '4605113000013', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E4D81F8-7230-41EE-A528-A7ED52878507', '87625E8A-58A9-4435-94A5-B479D0AD5BC8', '4605126000888', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FE60CD5-A49D-40A4-BEF8-F6BF5CF0544E', '87625E8A-58A9-4435-94A5-B479D0AD5BC8', '4607066260537', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEB0760E-D3C2-4404-A43F-373BCCF9F901', '87625E8A-58A9-4435-94A5-B479D0AD5BC8', '4630000890224', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65295ACB-00E9-4698-A190-A3D16F7C49F3', '63B349F7-F778-4ECE-A1A4-0FE1FE2E467E', '4601214000976', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CF8C798-D8CF-4A79-9128-69A9B447E5E9', '63B349F7-F778-4ECE-A1A4-0FE1FE2E467E', '4603762005830', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2425DDE-DAC5-45AA-83CF-BEFA9EA5928C', '63B349F7-F778-4ECE-A1A4-0FE1FE2E467E', '4605113000662', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6FFF5D6-43FB-4228-9927-8B1920E01C51', '63B349F7-F778-4ECE-A1A4-0FE1FE2E467E', '4607066260131', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E756B847-DAD8-4F37-947F-B3D79C8DEF62', '21D7DD45-5CFF-4FA6-A390-06938CC2919D', '4607066260421', '  50,0/ +/                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7EB8FA1-20D1-446D-98A8-D2CD3866FBAF', 'EE65B0BA-C51C-4648-BA1A-68DAD107CEE4', '4601214000389', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E24A099E-D337-44C8-A484-40582C0F83DE', 'EE65B0BA-C51C-4648-BA1A-68DAD107CEE4', '4603717000286', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABBCBE5B-1BB5-4514-BDDD-E0E3B8B60C2C', 'EE65B0BA-C51C-4648-BA1A-68DAD107CEE4', '4603762004499', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6446701B-5906-415F-B797-89AF9987CDA3', 'EE65B0BA-C51C-4648-BA1A-68DAD107CEE4', '4603938001437', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13768A1B-C943-481C-A729-38867E9A066A', 'EE65B0BA-C51C-4648-BA1A-68DAD107CEE4', '4605113000419', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69E4021D-D26B-457F-B9C9-6D376C070CF6', 'EE65B0BA-C51C-4648-BA1A-68DAD107CEE4', '4605126003919', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADC938DB-1DD8-4873-8D68-49422009D414', 'EE65B0BA-C51C-4648-BA1A-68DAD107CEE4', '4607066260704', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADF8CE48-863B-4227-BA69-D344F97D299F', 'EE65B0BA-C51C-4648-BA1A-68DAD107CEE4', '4607102610555', '  50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF5D9ECF-D9E0-460D-83B1-B905D7A54029', 'A4099784-80C3-4EDB-B55A-C7DC159EE96D', '4607066260360', '   30 / +                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6277B401-7F7A-4CAD-91B8-B18B69B08666', '8303464C-1DA4-4009-A167-542FF60CCBF3', '2400004732668', '    50                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F724231C-72D9-4D51-9326-2FA2F57A8CB1', '8303464C-1DA4-4009-A167-542FF60CCBF3', '4601214000068', '    50                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5E4635C-96DA-4378-8F73-31FF8A5B584A', '8303464C-1DA4-4009-A167-542FF60CCBF3', '4601498006794', '    50                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A944401-33B7-4356-B1ED-92FAC21D0185', '8303464C-1DA4-4009-A167-542FF60CCBF3', '4603762005854', '    50                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD33BCF2-682D-4F81-B0CF-06D77C318242', '8303464C-1DA4-4009-A167-542FF60CCBF3', '4605113000617', '    50                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75F7843D-24B3-40A3-96B5-5E2B87457080', '8303464C-1DA4-4009-A167-542FF60CCBF3', '4607066260261', '    50                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84737E5B-2B66-401E-8CAA-D0B5877A1134', '3C59A78F-2C2A-416A-9A64-B6996F4B3F49', '4602242003694', '  "". . 40  0.2                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0974C8B9-A78B-488D-92A2-6B1FA19EEA1C', '9DCCA97E-5121-4E08-8887-A06D07BC123B', '4602242001683', ' 0,25  30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D836419F-35DD-4EF3-9679-065461FBA838', '9DCCA97E-5121-4E08-8887-A06D07BC123B', '4602242006473', ' 0,25  30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7E26502-D799-4564-ADFD-44379CC48C9D', '78E463B0-4CA7-42CD-80BF-913F97770A5B', '4602242004714', '  0,5 40                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EA4812D-C212-49DA-843B-BE26D9201A40', 'AC3DCCF2-1923-43B1-A690-1EFC3838FFE5', '8901148025011', ' 0,005  20                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57E116CB-75DC-4154-8494-C8DF54BCB863', '3C988962-0B7B-48D0-91E1-D3A5E807B339', '4607174650077', '   60100                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C297665B-6176-47EE-8F78-9951F466FCD5', '3C988962-0B7B-48D0-91E1-D3A5E807B339', '4607174651043', '   60100                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82636309-CACB-4A9D-9418-E22366B8BEF7', 'A2D87D73-9DA4-44E4-9C35-0890A17070E1', '8901236010806', ' 2,5% 5                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43671E2D-17A0-431E-A976-95787E8FE62B', 'C0725393-1303-44BF-B3B1-2F32CC3DA5DF', '4602565017101', '- 1% 5                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76B42CFB-4447-46CF-929C-0A68A8DC7701', 'C0725393-1303-44BF-B3B1-2F32CC3DA5DF', '4602565017903', '- 1% 5                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF55C4B2-565B-41B8-9890-06D60422CF5F', '3D7B1765-5AEC-49EB-9900-FB1D87D0E5FA', '4607045190220', ' 0,001  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB7ECE35-D204-42E5-8D43-E4CA54991C96', '094A2C29-2D2F-4870-91E4-61F41A7712C7', '4607143560208', '  / 10+ 2,5/  30                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EDD7063-BAD9-4F8A-8891-3A89B6CFEBE4', 'AF613676-8C36-441D-8816-537CE0FC6CCC', '4603179000442', '  50  200                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05C4EFD6-569D-4D5F-82C5-DCF6194DD3A5', 'AF613676-8C36-441D-8816-537CE0FC6CCC', '4603679000010', '  50  200                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5035AF78-1F33-4492-8C60-286CEB69ACE2', '3DACA90F-B976-44CB-A8AB-C68A175E3F4B', '4602509002286', ' 2% 2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B14880B-F4FC-4C12-9091-5DC5A49B71A4', '3DACA90F-B976-44CB-A8AB-C68A175E3F4B', '4602824001292', ' 2% 2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86C0CB65-A010-428E-B1BA-2C2DA47D81DF', '3DACA90F-B976-44CB-A8AB-C68A175E3F4B', '4602884012122', ' 2% 2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61EE9E98-E202-4289-811C-250CB04A872D', '3DACA90F-B976-44CB-A8AB-C68A175E3F4B', '4602884015185', ' 2% 2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('502A6711-F3DA-4EF3-A14F-67CCB60B6B03', '3DACA90F-B976-44CB-A8AB-C68A175E3F4B', '4810201000282', ' 2% 2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90922399-230D-47D2-86D4-2860D2632C64', '3DACA90F-B976-44CB-A8AB-C68A175E3F4B', '4820044110673', ' 2% 2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('059B16C0-FB93-4D5D-9CD7-77A4E74AB2AD', '3DACA90F-B976-44CB-A8AB-C68A175E3F4B', '6930169707134', ' 2% 2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E11012DE-7100-4D72-B387-0A2A57CA57DF', '7A968D1A-888B-4474-BDCC-4ADCA8F13F64', '4602876000748', ' 100                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE2D3558-66B7-4B00-A133-02453AF6AC33', '7A968D1A-888B-4474-BDCC-4ADCA8F13F64', '4603905003129', ' 100                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3792585-7C33-4C12-962F-E7987F1C54A3', '7A968D1A-888B-4474-BDCC-4ADCA8F13F64', '4604060172019', ' 100                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85CA61A3-98A7-4BFA-AB9F-AA8386886CC1', '7A968D1A-888B-4474-BDCC-4ADCA8F13F64', '4604060999135', ' 100                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28465B85-E0C7-4259-8C1D-B52220F88A31', '7A968D1A-888B-4474-BDCC-4ADCA8F13F64', '4605404001569', ' 100                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF87E0D8-4552-4367-9EC6-F18D91863182', '7A968D1A-888B-4474-BDCC-4ADCA8F13F64', '4605404002092', ' 100                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59919393-9AE5-450C-A632-D71DC6DB3D69', '7A968D1A-888B-4474-BDCC-4ADCA8F13F64', '4607124000013', ' 100                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7F62326-2EFE-4E0A-B713-D650B89CB8EA', '7A968D1A-888B-4474-BDCC-4ADCA8F13F64', '4640018640070', ' 100                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B75C4FF5-E641-49C5-AD90-914D23E9261E', 'ACE4200F-DB18-4346-8909-BCF77DEC1170', '4810201000022', ' 0,5 / / / / 2 -  10                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7991C1E9-7E32-478D-B49D-E6C862C7A015', '3DADCC8B-2763-4509-94A1-1257CDED48FE', '8934901740036', '    1,3                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54BAF974-990F-42F0-8C67-BCB204A14FE6', '3DDB79E2-7CD6-4326-9A74-6AD868CD6456', '4602824000554', '    10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60EC96AC-5B64-42D6-ACF9-2626C0A17140', 'B87F9FC0-8836-42FF-8549-1B60D5986695', '4602435002268', '- 4500                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF6608AE-20AB-4CDE-B2C8-D81C4F0EC999', '8EAD7100-BEC1-4E24-8BD2-B8C25201AD9F', '4602435000820', '/ 5500                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F65A32C-9549-4A1A-AD86-4D53078C3F74', '3E4FF7AE-D560-4F33-9C90-85E8F16299CD', '4603988004136', ' 0,5   20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6B36F1F-3B23-4C4D-8405-377061EBCCAB', '442014B1-1727-4992-BD2C-B68A1647A4B4', '4602424003818', '  40  50                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12FB4D39-F4FD-475C-84E5-4F68E53C10D1', '442014B1-1727-4992-BD2C-B68A1647A4B4', '4603276003414', '  40  50                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6FFD82C-B70B-44B9-9CFE-1EBF26121B7E', '442014B1-1727-4992-BD2C-B68A1647A4B4', '4607027767204', '  40  50                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58125E77-3371-4E46-944D-EA6AF06214E1', '3EF4CA25-5F83-42D5-8364-789F68C9FE1C', '8901148053021', ' 1%  20                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2020105-94C9-4514-B00D-E81B98686603', 'DC6348AF-2B17-4FA0-9248-97C7D78B63AE', '5413895053276', ' 0,5% 5                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E754206-ED8E-4D73-86D9-B30E70CC84BE', 'DC6348AF-2B17-4FA0-9248-97C7D78B63AE', '5944728000032', ' 0,5% 5                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D466EE55-4B19-4F50-A545-D9C3A4AAFF0F', '3F4B7C11-C400-4C0F-A816-FD467FC59B81', '4607010244095', '911  - / 100                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1ABECF7-BECC-4556-880F-8EA61B89FBB0', 'E237A2A7-390F-4BD2-AE09-4BDBDB9113BD', '4607010244101', '911 -  100                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67985385-FD18-4843-9942-6B4CE07BEB4A', 'BB995BA2-BE62-4FBB-AAFC-ACCF8CE14F97', '4607010242558', '911   100                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('058E037B-7930-42A8-B37E-0FD2CC9DD8A2', 'FFB4FD47-7E81-48F6-8695-D52882FF1EB2', '2400006372657', '911 - /   100                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D603F35-AAB5-4977-B7CA-7D0174081BC8', 'FFB4FD47-7E81-48F6-8695-D52882FF1EB2', '4607010244897', '911 - /   100                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0E4EBF6-7421-451D-84A3-53EEB62C9C65', '502ADFE9-92A0-4D2D-9BFC-382F55299F76', '4607010245184', '911   - 100                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C8F4A26-767D-47C4-8865-395CF730A12F', '580EB2CB-2680-4F70-99DA-F322BF5D22F9', '4607010245481', '911  - / - /.100                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('841B1E11-F0C4-4EEF-928A-3071015D81BF', 'A4A3EBE1-FB8B-4CD7-96AA-0B07912DE186', '4607010242534', '911 -  /100 1                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAD820A8-502E-4D2B-AC09-D9AF8D048782', 'DA2E0044-0F24-4123-9EA6-BEF7549BD301', '4602565015770', ' 0,2 20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73F74DDA-68A0-4815-AB01-1596994CD4E7', 'DA2E0044-0F24-4123-9EA6-BEF7549BD301', '4604060081199', ' 0,2 20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5A07906-3AEE-4399-9215-1C6BC7D97B6B', '3F92A7CE-2B90-4AED-9605-DB4ADCEB8F12', '4008500130414', '   100  56                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2C68B3F-E7A7-454C-8E1C-C7EBF39F0710', '3F969D82-4D83-49E8-AA2D-FA951D1C2B63', '4602196003597', '  0,02  50                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A9F62DA-3986-4904-9390-B01B381287D1', '3F969D82-4D83-49E8-AA2D-FA951D1C2B63', '4602824015916', '  0,02  50                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CBFDB59-8CAF-4DA8-98BB-EB53008853F7', '3F969D82-4D83-49E8-AA2D-FA951D1C2B63', '4602884002413', '  0,02  50                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECA90E1B-69B1-444F-941A-593BB186BEF2', '3F969D82-4D83-49E8-AA2D-FA951D1C2B63', '4602884010357', '  0,02  50                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAED1424-3EDA-4E1E-93A9-C5C82FB8DCB6', '3F969D82-4D83-49E8-AA2D-FA951D1C2B63', '4602884012542', '  0,02  50                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E9900EF-6CF1-42EA-ADE3-76F02D087EEA', '3F969D82-4D83-49E8-AA2D-FA951D1C2B63', '4604060021263', '  0,02  50                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9335A299-1594-45AB-9851-14A6661FA4F5', '3F969D82-4D83-49E8-AA2D-FA951D1C2B63', '4604060993485', '  0,02  50                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAEBDB51-53D7-455E-BC3E-337CE5FBFB81', '3F969D82-4D83-49E8-AA2D-FA951D1C2B63', '4810201001838', '  0,02  50                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCDCB9DC-164F-4D01-8647-6197B2E7A9C2', '3F969D82-4D83-49E8-AA2D-FA951D1C2B63', '4810201002866', '  0,02  50                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ABF7626-D77A-4FA6-B015-E78310382196', '3F969D82-4D83-49E8-AA2D-FA951D1C2B63', '4810201004075', '  0,02  50                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77A87BEA-14CE-4663-A3E1-746F04362C8B', '48B1D3D8-19CF-4302-8BDD-1D96490F04D1', '4602196002477', '  0,014  10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8DB1993-9F66-4965-AE9A-89151049B4B6', '48B1D3D8-19CF-4302-8BDD-1D96490F04D1', '4605180005447', '  0,014  10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('486BE4C2-713C-4D7A-B5E3-1E4F8DFE04EF', '3FD89578-7CC7-43EB-9E03-F0D096139B9A', '4602196001890', '   //  10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C4A5BE7-A074-4511-814A-3D958C856896', '84853109-2A71-4590-9FC1-9E795C41E3F5', '4601429000419', ' 0,02  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DF4E754-5892-4A1E-95B7-11843B672513', '84853109-2A71-4590-9FC1-9E795C41E3F5', '4603179000312', ' 0,02  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5D09ACC-2A99-48AB-A9A3-2DEC46B7B60E', '71BD4178-ADFF-42E7-9602-257DBC35D025', '4607045191340', '  /+/ 10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D802457-D994-42D6-BB12-A3B6E4CE8B4E', '71BD4178-ADFF-42E7-9602-257DBC35D025', '4607045192194', '  /+/ 10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4A5C654-011A-45AC-BA75-417BF5C4D096', 'AC6610CC-E077-45D9-88E1-DC3275BEEEA0', '4600338001616', '    1,5                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8321E1F-41B3-4ECF-9DCB-9898CED2070B', '40AE9E92-7999-4A3A-AAAA-E17C1A0CCB80', '4607029291370', '  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('017DAA1E-A797-49C0-8186-5A61ED69CE35', '40AE9E92-7999-4A3A-AAAA-E17C1A0CCB80', '4607111278142', '  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBCAAF5A-27E4-48B6-AE9F-4AB6F780F87C', '40AE9E92-7999-4A3A-AAAA-E17C1A0CCB80', '4627074840040', '  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3091E0A1-651B-4C99-961F-7D8F343BA554', '40AE9E92-7999-4A3A-AAAA-E17C1A0CCB80', '4627129210668', '  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3065B79-E06E-47A9-971A-5CC85EAC56D2', '40AE9E92-7999-4A3A-AAAA-E17C1A0CCB80', '4630010960061', '  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3066620-29E6-4A79-B738-F2AAD0E1D31B', '40AE9E92-7999-4A3A-AAAA-E17C1A0CCB80', '4650001790101', '  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02630395-DBA0-4EC2-9B17-AA0A74284322', '40AE9E92-7999-4A3A-AAAA-E17C1A0CCB80', '4650054820022', '  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D62A31FF-4A23-47A0-8B4D-B30CB1D45CE4', '283524C0-7823-43B0-A515-97A00D36A96D', '4620001090082', '   10                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAB6DC91-2BBD-47DC-B1FA-847C0CA26A11', '283524C0-7823-43B0-A515-97A00D36A96D', '4627074840132', '   10                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0DE016D-A6EE-4348-B2AB-C08F29EEA645', '83570882-CE63-46CF-BE3D-52B6AFB91A87', '4607104130976', '  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76CA1B1D-E07F-408B-A340-2B8A13BFFF64', '83570882-CE63-46CF-BE3D-52B6AFB91A87', '4607111278685', '  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0FCDECA-866D-4D53-95EA-23672FA3186C', '83570882-CE63-46CF-BE3D-52B6AFB91A87', '4627074840330', '  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ACCE5F6-E115-467D-A0FE-598C77D159BB', '83570882-CE63-46CF-BE3D-52B6AFB91A87', '4630010960146', '  10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('709F2053-DCFB-49CE-87A7-E614E4E10F1C', '539E01C4-BD44-42DF-922A-AF3912452DC2', '4620001090143', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C84655B4-A906-49D3-A440-27E76D9CF380', '539E01C4-BD44-42DF-922A-AF3912452DC2', '4630010960139', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EAB658A-C8B9-45E2-BAC3-550FC98978EC', '545D675C-ECFA-4EEF-855A-34AEF279DDEC', '4607104130433', '  10                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67932B81-E328-4252-B320-4D512BB38C8D', '545D675C-ECFA-4EEF-855A-34AEF279DDEC', '4607111278180', '  10                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BDABCE5-2F0E-47AD-A3BB-E5BD789EB66D', '545D675C-ECFA-4EEF-855A-34AEF279DDEC', '4627074840309', '  10                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D66198DD-7055-41ED-88A6-EE09050583CA', '068A27A8-BB73-4A6F-8164-4478B3F094F9', '4605108001728', '  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C849C74A-9AE2-4AEC-BCD4-6D78F28734D6', '068A27A8-BB73-4A6F-8164-4478B3F094F9', '4607104130426', '  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40BF8754-FB7A-4921-94CA-A29B8BF93DE0', '068A27A8-BB73-4A6F-8164-4478B3F094F9', '4607111278173', '  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4E77BA6-FD0E-41A8-9B9D-29B79D190C74', '068A27A8-BB73-4A6F-8164-4478B3F094F9', '4620001090136', '  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3807087-6423-40FA-8DA5-4906BA0043AB', '068A27A8-BB73-4A6F-8164-4478B3F094F9', '4627074840279', '  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A42F4A69-72FA-4A8A-9818-9DD34EC059C2', '068A27A8-BB73-4A6F-8164-4478B3F094F9', '4630010960122', '  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBD098F1-085B-4963-9BCF-5C2D02269593', '068A27A8-BB73-4A6F-8164-4478B3F094F9', '4650001790224', '  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14406AC4-8A5F-488D-B97C-D8AD6E7B5BC2', 'BD246167-976A-4CFE-8FC6-22E11B765016', '4607111278227', '  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4B52B08-4AD1-4BBF-AA67-4028259EFD18', 'BD246167-976A-4CFE-8FC6-22E11B765016', '4620001090198', '  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E4A3008-C5C5-4589-8FCD-6788044F658F', 'BD246167-976A-4CFE-8FC6-22E11B765016', '4620001091140', '  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF73B739-3270-48B2-87CD-6B2B376758CE', 'BD246167-976A-4CFE-8FC6-22E11B765016', '4627074840491', '  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABE3A84E-9F27-494E-8AC4-795DE27DD107', 'D2A47DBC-7BE7-4876-BD22-354A357793CF', '4627074840682', '    10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDC6FAB6-F807-4E44-BB83-09D6E05CF4D4', 'C77D6EC9-BB06-422C-960F-95BC78DFB58D', '4627074840422', '  10                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8587FA1F-8EC9-4E52-8FA7-DD83C7C10FD4', 'FB297B1F-F99C-4EFD-B21C-7B38A1A27964', '4620001090167', '  10                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1C51E4A-CEAF-445C-ABF3-5FFA25C3E025', '40D5A73E-6B73-46D2-B144-DFBAB08AA5BD', '4604060997421', ' 0,025 ///  20                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2EA7770-7AE5-4E2D-8FFE-3A1D812F0DA1', '904A3CA2-3BD0-4B31-B146-BD7B32558796', '4607003240806', '-  5%  30                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CAFB6D2-C1CC-4338-ABC2-E669AA6CF297', 'DFD74066-D1FC-4ED0-8EA8-F9298C15CECE', '4607003243678', ' 2%  30                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('466A30E4-F32A-4509-80F2-BFB0B04B6784', '4135EF13-F484-4190-8AD4-DF3B1ADD740C', '4600828001034', '  / 24                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FD950B4-D3E7-49A7-BB8D-CA6FCC77DD97', '4135EF13-F484-4190-8AD4-DF3B1ADD740C', '4600828011033', '  / 24                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C57E26A6-F403-4C5E-B507-4A0A106AE2CC', '4135EF13-F484-4190-8AD4-DF3B1ADD740C', '4603179003818', '  / 24                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8552EBB2-CC13-44CA-AD81-F46CADC427EB', '41B167BB-DE6D-4169-B4C6-FC6DC91AC894', '4607159860354', '  0,0015  / 30                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AF4C114-5EA6-4B62-92FD-A9939BAF1AC1', '585E308B-B7CE-4979-90C0-B6A776EB0F27', '8584005033512', ' 0,05 //  30                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89F061A5-538E-4E07-A5FF-74AFC6D2A22A', '4BC4FE5B-082A-4F46-95B8-32A43BFB0F4A', '4022536645872', ' 5   / 30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF0B8991-F0D9-4A93-A569-6800959A45C5', 'BA16ADC8-24F8-40D9-9786-0F2A57726C02', '4043589001835', ' 100  / 20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C1D552A-624E-48BF-A486-04ED40891898', 'BA16ADC8-24F8-40D9-9786-0F2A57726C02', '6436548032496', ' 100  / 20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC90226E-CB07-4FA8-B724-499F75B045DE', 'F4426142-6345-4B54-8785-E85D3CD02DF5', '4602565000936', ' / 0,25  20                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9FC4DCE-ECA8-4506-9C7D-4686EEBA283D', 'F4426142-6345-4B54-8785-E85D3CD02DF5', '4607022750300', ' / 0,25  20                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40495254-290E-477C-8C0C-3C3E6A31B27C', 'F4426142-6345-4B54-8785-E85D3CD02DF5', '4810133003405', ' / 0,25  20                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB115EFE-D622-4046-B70C-DAE16CE89AE3', '42AAD932-E636-4266-83B3-DBD52E0FA576', '8901148022010', ' 0,01  20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABD9C1DC-CC93-4948-B4A0-E3DFECDD9BC5', '80D12F87-3386-4436-B502-54D05BC9AB26', '4602884000082', ' 8  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE6BCAA9-77BE-44B5-9D45-86C95E419E81', '80D12F87-3386-4436-B502-54D05BC9AB26', '4603182002471', ' 8  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8160425-26E5-4824-A68B-059BAB1FBD94', '80D12F87-3386-4436-B502-54D05BC9AB26', '4603988009698', ' 8  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD955C32-380F-44EE-941D-2A878D310396', '80D12F87-3386-4436-B502-54D05BC9AB26', '4607027765453', ' 8  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29DE2192-4D77-4CBA-B814-B894DACCBDAF', '589AC429-4AB5-4F47-BC8D-C271B5EA320F', '4604060991597', ' 0,03  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E9BE7BE-7215-4847-AF30-A66E3B32D8EB', '589AC429-4AB5-4F47-BC8D-C271B5EA320F', '4607003245375', ' 0,03  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88942CB7-67B1-4ACB-A6EF-7A7B17C32E86', '589AC429-4AB5-4F47-BC8D-C271B5EA320F', '4607011631917', ' 0,03  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9C5F39C-0B1B-471D-8FE3-919C3D56D674', '589AC429-4AB5-4F47-BC8D-C271B5EA320F', '4607027760540', ' 0,03  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3B3FD85-7696-4BB2-A9F3-1B5E678B3348', '589AC429-4AB5-4F47-BC8D-C271B5EA320F', '4810201005089', ' 0,03  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB04AFF9-5ABC-4179-9513-D2A54279AD99', '8D6A5378-BB53-4808-948D-7B9BABDC6B00', '4602565013950', '  500  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ECB52C2-E3C1-4F89-AC37-E8BC38E45B62', '43266488-397D-4854-9E8B-9FE6854DEFC1', '4607066261183', '  / 1,5 20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('300D6DCB-9D18-4294-B227-2445AFA90EFF', 'D15DEB5A-B438-44AC-A0F3-1D267EAC7E3C', '3838957090570', ' 0,25  100                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6274B73E-5CBE-4011-AFB0-900A17673847', 'CD8DF492-E85A-4FA0-AA1A-F691F9DB4D42', '4603713000860', '    25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7559DE76-F87A-41E6-9797-7BA98C98A132', 'CD8DF492-E85A-4FA0-AA1A-F691F9DB4D42', '4606683001462', '    25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83735935-D298-4727-A47C-ACD071309A55', 'CD8DF492-E85A-4FA0-AA1A-F691F9DB4D42', '4606926000122', '    25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BF9B11C-2F52-4AA0-ADF2-85D752288F34', '56ACECE8-3E25-4D52-AFF9-0B3069427A6D', '4601669001238', ' 0,015  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20CA088F-8598-4C5A-BC59-6B8654B25C4C', '25696064-5BF4-491D-B4A3-8B791863BCAA', '4607024942321', ' 0,25  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B07BC8DE-ED20-4CCD-894D-468767C9F82B', 'FF504D88-031F-437F-8CF0-FD1BC6C1353D', '4603762000057', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A02E99EB-9D49-4ACD-B878-14F848A42CE2', 'FF504D88-031F-437F-8CF0-FD1BC6C1353D', '4605113000372', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A6E816F-4A76-41E8-8798-7CFC7CCD5426', '43872615-7128-4E2D-B741-ED300435BB81', '4602876004784', ' 50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C0D1CA2-A680-4EAD-AC14-139C5C479A44', 'EAE284D7-A057-493B-B14B-2CEC079AD9D3', '4601429000969', ' - 3%  - 25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('068C17BD-B047-4737-A479-5AC391867AAD', 'EAE284D7-A057-493B-B14B-2CEC079AD9D3', '4603373002303', ' - 3%  - 25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07643617-5273-4532-8524-397813EF1F02', 'EAE284D7-A057-493B-B14B-2CEC079AD9D3', '4603380002587', ' - 3%  - 25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F511AB4-DD93-4DA1-8759-3404B7E7F48C', 'EAE284D7-A057-493B-B14B-2CEC079AD9D3', '4603380004734', ' - 3%  - 25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4945651-7791-49CA-8C1F-8B8F2D4F9FB9', 'EAE284D7-A057-493B-B14B-2CEC079AD9D3', '4603905000135', ' - 3%  - 25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7962D545-8886-4B12-8F6C-A9614FA632DA', 'EAE284D7-A057-493B-B14B-2CEC079AD9D3', '4604060272153', ' - 3%  - 25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('693E498D-4033-4F3D-909F-50A5A9927AB3', 'EAE284D7-A057-493B-B14B-2CEC079AD9D3', '4604171000072', ' - 3%  - 25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5FD9922-F44D-401C-A08B-1EDB602590F5', 'EAE284D7-A057-493B-B14B-2CEC079AD9D3', '4605404000449', ' - 3%  - 25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BEB9D42-A3DC-45BE-A076-2FBBB55E91AD', 'EAE284D7-A057-493B-B14B-2CEC079AD9D3', '4605681002389', ' - 3%  - 25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A241DAC-EC24-4088-B6DF-E59A16614FCF', 'EAE284D7-A057-493B-B14B-2CEC079AD9D3', '4606926000511', ' - 3%  - 25                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C99DF63B-AAB7-4FBA-A7C6-3FF30A8113E5', '52E63122-2A76-4156-B3E3-B1F1AFBA4AD2', '4607007360999', '*  3%  - 25                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('725FB83E-3849-4074-8EA7-DD1FEDB314CC', '83D77497-8EA1-4513-B3B3-E8D262E667C8', '2896145981490', ' 1:1500  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85FB0B99-D8A1-4660-80B2-3B9BB1F058B2', '83D77497-8EA1-4513-B3B3-E8D262E667C8', '4603184003803', ' 1:1500  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9457DE9B-28A0-4C87-8F36-1C49A153FC0A', '83D77497-8EA1-4513-B3B3-E8D262E667C8', '4603905002986', ' 1:1500  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55BB8FCE-6F1C-494A-B342-831F8519C5FA', '83D77497-8EA1-4513-B3B3-E8D262E667C8', '4605422011656', ' 1:1500  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB275ADF-35E8-4870-9DF9-591E56D190AA', 'C5805C0D-0F45-4E82-8E4E-2067DEBFB6DF', '4605962000028', '  0,25% 10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6D905FC-AAD9-482D-8699-103E347A32B5', 'A31FA517-C6EC-4541-A3CD-40787B8A58A3', '2400004706942', '   10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70CBD674-2333-4035-BAE6-9BDC71D9B377', 'A31FA517-C6EC-4541-A3CD-40787B8A58A3', '4602689000126', '   10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46629354-0672-46B2-8EDF-4431F7A242F7', 'A31FA517-C6EC-4541-A3CD-40787B8A58A3', '4603041000044', '   10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D19EC98-D343-446C-923A-8E77ACBC1909', 'A31FA517-C6EC-4541-A3CD-40787B8A58A3', '4607006820234', '   10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA46BC7D-90EA-4D5B-B688-5CAE5078ECD7', '6F942D63-AF56-4C19-8351-2D2E0BC14F45', '4607028390029', ' 500000 10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A171127C-8A63-4D0A-A07A-785DC53DF0D9', '41CE88AB-53F1-4C10-AA0D-E06144E42131', '4601026306082', ' 500  30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9840CA4F-ECDB-4A00-AD64-DAFDF2F8E016', '87360F20-FEEE-49B9-845C-7710A252BD4A', '4602186000063', ' 100   5                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC9EF37F-1462-41C8-AC5D-3B509E509BAA', '43DA5D7D-19E4-4A1D-BEF9-A76CA0365C60', '4602196002774', '   10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFF21EDE-7297-44C2-B2DB-B1F7ADDB6085', '43DA5D7D-19E4-4A1D-BEF9-A76CA0365C60', '4620006500234', '   10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ED3B25C-E4DB-4872-B03C-20983A7BCCD7', '43DA5D7D-19E4-4A1D-BEF9-A76CA0365C60', '4620006501736', '   10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67FAD0B9-2044-487B-AA45-25D7F10FAEBB', '44788667-B7C7-408F-8CCE-9D1A127C3D8F', '5997001362891', ' 0,1  60                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49ACB8C5-EE0C-43C4-AB78-505894D1E5A2', 'BB0855DB-8791-4AEB-9673-0C86EB9E7E81', '5997001362907', ' 1,5%  60                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F79A432E-A14D-4F1F-A01C-6A0D39788F3B', '2701074F-9243-4C11-A340-5B8F6F94D874', '4605964003089', '  100 2 /   10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FE8ECBD-0FF2-4CA6-8827-055010419D0F', '8BA20630-5DF2-4188-B3BC-C1C2FB35C197', '4603184001229', ' 1% 25 .-                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15549955-D9F8-4B5F-85DD-1B435F61F99C', '8BA20630-5DF2-4188-B3BC-C1C2FB35C197', '4603380000941', ' 1% 25 .-                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28B44880-2E73-4972-AC0D-4218435AC073', '8BA20630-5DF2-4188-B3BC-C1C2FB35C197', '4603380005106', ' 1% 25 .-                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D481CAE-ECE5-4754-B6CE-130C51C04D66', '8BA20630-5DF2-4188-B3BC-C1C2FB35C197', '4604171000249', ' 1% 25 .-                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43A92AA6-C0C6-4429-8BA2-4F2221DAADC2', 'DA480E44-0184-4B27-AD65-550571C61285', '4603905001651', ' //  1% 25 -                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEFD6685-5466-46AA-B542-4AA5DF8E795D', '44EE7D85-A914-48F9-BB03-6440296EB47C', '4607083724944', '-    20                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A66232E-FE79-4DF9-9201-F5C392E821C9', 'B8D1D24C-4529-47A0-8654-A7F7E7D3727D', '4601429003878', '  - 25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C3E3554-3427-4E89-A381-51AC14DB16E1', 'B8D1D24C-4529-47A0-8654-A7F7E7D3727D', '4602546009651', '  - 25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE10F599-28DE-471B-BA94-C9DA1B2D8EE1', 'B8D1D24C-4529-47A0-8654-A7F7E7D3727D', '4603184002424', '  - 25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0B61548-C696-46E5-9AA2-317F7EC958FC', 'B8D1D24C-4529-47A0-8654-A7F7E7D3727D', '4603256007029', '  - 25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48970269-9CFE-4918-AD15-1776A81AAE95', 'B8D1D24C-4529-47A0-8654-A7F7E7D3727D', '4603905002597', '  - 25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C6BDFA5-E7CE-4ADB-85EC-41EEFB6AB246', 'FDF6B690-41B4-49DB-8D90-C94B493842ED', '4603988009032', '  3                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('805D4D2D-6BC1-44B8-9C11-944DADC8AD61', 'FDF6B690-41B4-49DB-8D90-C94B493842ED', '4604060271033', '  3                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49A8BF6C-3279-4703-B7E0-562D79CA8F98', '455595E4-8899-48C7-9A4F-09C5DD020B30', '3838957011025', ' 0,625  15                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8185C3FE-4159-4777-915E-24E6CA34E8C1', '455595E4-8899-48C7-9A4F-09C5DD020B30', '3838957872244', ' 0,625  15                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5C0807D-F040-4BA6-AE2B-711AC1221C0B', '4574A208-01AD-43BE-8852-73BD3070504B', '4605501000083', '  20                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFA9D039-850F-422F-981E-57F4D55C9691', '70B6FA82-3DE6-4000-B711-D71FABB066B1', '4603276004930', '  20                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31BC0211-1A5E-4B93-8A95-CDF81EB91215', '70B6FA82-3DE6-4000-B711-D71FABB066B1', '4605422000070', '  20                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16470B5A-FA37-49A9-9614-85107873B429', '457F18B9-9A02-48D0-9259-AF87F0B407CC', '8901148059016', '  20                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23310FB6-3A66-48EE-AE5D-5B4ADBA73C9D', '802C9B19-9047-43E4-A3DB-D3F864B65014', '4602884008149', ' 0,005  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C945DD6-331F-4302-956D-EF6E9D078FAD', '802C9B19-9047-43E4-A3DB-D3F864B65014', '4603988008585', ' 0,005  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A99EF77B-9F43-42F2-B9F9-78D857851926', '802C9B19-9047-43E4-A3DB-D3F864B65014', '4607027760144', ' 0,005  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E601528-8D46-4AA7-AD97-E574C918AA24', 'E840FE75-4385-450A-8B43-604C99E3E0AE', '4030855038046', ' 0,02  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D85ECCD-C452-45C9-8759-21E1EF4B7D4D', 'E840FE75-4385-450A-8B43-604C99E3E0AE', '4603988008608', ' 0,02  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81C65174-7F02-4986-B6E0-59DEDB68E7CB', 'E840FE75-4385-450A-8B43-604C99E3E0AE', '4606486002499', ' 0,02  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D26D5516-CDED-4BFA-9577-9CFC2D381FBE', 'E840FE75-4385-450A-8B43-604C99E3E0AE', '4607027760045', ' 0,02  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C33BDFD-62F9-4624-8467-AE8CB141EFEC', 'E840FE75-4385-450A-8B43-604C99E3E0AE', '8901043000632', ' 0,02  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16C70B3A-395D-4CAA-B5A1-D6F0127DBC99', '87B16208-C900-4549-B5F8-27A7F1F48CCD', '4810201002408', ' 0,005 /  20                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('859D2B5D-E514-4379-A8A5-DACB0D01A14C', '45C69CCF-5259-47AE-ABD7-8461C789D462', '4607141998706', '  20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02AF0192-9734-44E1-B103-E5292492FF19', 'C433CCAB-B7C7-443F-9EAB-BDCAA04E85CC', '3800714255553', ' 300  100                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4595F3C6-A8F4-451F-AA1D-ADBED05E6C11', '464EE725-1D2F-4F25-9340-DDD0ADAF2AF7', '9008732005271', '  0,05  / 100                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BCBE461-1A21-4B06-B3BF-FB3C08CF06F9', '468E49DD-E377-4DB6-A97D-1C01E9B26988', '4681747429017', '/  . 79 3                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D3EC1CF-6A97-45C1-856E-AD7486DC8644', '7BD576C8-7BDE-4BED-8393-88D2FBC4BBF6', '4681747429048', '/   912 3                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E70590C-B21E-45B2-9039-CE3F7FAB4BB3', '7C6F9F87-B3AD-42C6-A4FF-C7B9A17F3694', '4607083721028', '-  1018 .                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9FBCF98-8DBB-4AFE-A827-25FFB6772476', 'D6FF1DC3-C750-446B-ACF1-3BA5C718704D', '4607045191258', ' - 30 2                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF086D26-B02E-4DA9-B8D9-67EA0C58BB92', '469C91F7-4866-48F0-9B73-509F6075B683', '2400004702982', '    20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ABAF66E-B578-4A16-ADF0-3BE69E361C7C', '469C91F7-4866-48F0-9B73-509F6075B683', '2400006284875', '    20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98ED438E-80CB-4C88-8758-4DD44F749EB1', '469C91F7-4866-48F0-9B73-509F6075B683', '4607009581071', '    20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0833236-CD61-49C8-BE7E-C4CC6EBB2855', '62F65BC4-1BB7-4174-B189-B6127EB88F3B', '4603679000416', ' 30                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('366E8E1B-EFF0-4B2B-B8BB-676808D676D8', '62F65BC4-1BB7-4174-B189-B6127EB88F3B', '4603679000881', ' 30                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF0FCC70-51CA-4722-A74A-D1987017E9F9', '62F65BC4-1BB7-4174-B189-B6127EB88F3B', '4603933003863', ' 30                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBB7B1B9-E71D-4934-8C63-5054DFE8BD84', '62F65BC4-1BB7-4174-B189-B6127EB88F3B', '4610004580024', ' 30                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17FD1419-0F72-4567-9A38-945BB888C2D5', '62F65BC4-1BB7-4174-B189-B6127EB88F3B', '4820014860065', ' 30                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1A059E4-CABB-4646-8EF2-40ADFD7918E9', '62F65BC4-1BB7-4174-B189-B6127EB88F3B', '4820085040151', ' 30                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('560CC424-F183-4695-A634-B17715341837', '47501896-D6D4-4A1B-AA30-DAFEE3CB39B5', '3850114223997', '   12                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05CDAA9F-BF25-448F-8E3B-4A8AE1B8AF0C', 'FC6ABCC3-8E04-4E0D-8A5E-2F8115A8B282', '4602509006048', ' 500   10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C4286A7-0ED5-41D2-9C79-94157B46F3E5', 'FC6ABCC3-8E04-4E0D-8A5E-2F8115A8B282', '4602884000754', ' 500   10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02062BB3-A12C-4C90-9C2B-0216EACDF8F2', 'F5AA58C7-94DC-4904-8F5C-733F4385BB34', '4601429000112', '    10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B8F4200-B495-4560-8B4C-46361CF89099', '4980F54F-1852-413B-ACBF-FE0601EADBA9', '4601214000143', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C87F5FE-CEED-4972-A0A9-2039462192A4', '4980F54F-1852-413B-ACBF-FE0601EADBA9', '4601498006398', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24EB41EF-CADC-45FE-8107-ACA6391D7052', '4980F54F-1852-413B-ACBF-FE0601EADBA9', '4603717000101', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7FCB959-6270-4CF7-A57C-C05AD06E49C1', '4980F54F-1852-413B-ACBF-FE0601EADBA9', '4603762000699', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('521D7DF0-C5CD-4F89-9D0A-E709387E591D', '4980F54F-1852-413B-ACBF-FE0601EADBA9', '4605113000075', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20B45F90-DA41-4797-A10F-5D9B026B14EF', '4980F54F-1852-413B-ACBF-FE0601EADBA9', '4605426000984', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('325F5573-FE4E-4A0C-8AE5-B47EF8554894', '4980F54F-1852-413B-ACBF-FE0601EADBA9', '4607066260742', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3154F45E-537C-4CE3-8670-822FD438E4B6', '4980F54F-1852-413B-ACBF-FE0601EADBA9', '4630000891429', '  50                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A08C463-49D3-4A99-B26C-0713024792B1', '5A285938-5A2C-488E-9ECF-2EA6F9554A0C', '4601214000457', '  50                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('776B255C-9D06-4D64-BBEF-1ECBAB2D7C73', '5A285938-5A2C-488E-9ECF-2EA6F9554A0C', '4605113000037', '  50                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0419DBF8-125A-4907-B9B0-9E4CE3802EB9', '5A285938-5A2C-488E-9ECF-2EA6F9554A0C', '4605126000758', '  50                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('670DD84A-9A4A-4145-AC7E-2FB5D4DE6716', 'D0B453F0-A773-45D2-BA5B-7B71D208FB61', '4607066260568', '  / 1,5 20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01C57C7A-9B87-41AE-97D3-E8CF4C505149', '4A0DB704-56E0-46F1-9719-B7FC9BCF14A2', '4607055135372', '  50+12,5   30                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('428AB2DC-8AC6-4140-827E-3C071B6110FA', '4A0DB704-56E0-46F1-9719-B7FC9BCF14A2', '4607055136201', '  50+12,5   30                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DCE85D7-87E4-4825-A7B2-C7EF296880DF', '4E518499-6CCB-4FB2-9A64-31DB6FB6DDB6', '4031083006005', ' 7,5 15                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EF8C520-55A9-40E2-9D1E-DF1A554C2EEB', '4A4FDC6A-C03E-459D-ADB4-F65D4A942F98', '4600338000039', '     200                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19B84DE6-E005-4635-BFF6-7BCB07B6D6D0', '955215F4-5729-4DFF-8718-F489D5484E81', '4600338003429', '   200                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A72C9D8F-07C9-46E4-8AA1-39309A672517', '0F418AB7-EB36-4701-A618-A5DC6FBABCCA', '4600338003337', '      200                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DA40C0E-5688-49ED-9072-819C84CDF480', 'A92E325F-F6A2-42D3-9999-1E101B7CBDE4', '4600338002316', '    200                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F15B5C65-D93A-4C3D-A81B-40BBEC120ED8', 'A373F67A-9D9C-4CD2-ACBA-2B026AF20C19', '4600338000053', '      200                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C678F30A-AB54-4DD9-B2C5-FDAC448607AA', '94402C02-8B05-4C8D-85E0-F328514175CC', '4600338003290', '   200   .  5 .                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2FD23E4-95EF-410C-8782-65435E7BC697', '007C220A-70A7-4D9F-8B8F-92227EED34C6', '4600338003412', '    200                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3C828CC-74AC-45A4-B557-874790174F7B', 'E811A96B-B034-42C4-9B76-6E816E7DF59A', '4600338000114', '     200                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('152F1F0D-21A2-4A82-8D1C-341C12B34E36', '4A646855-E9CD-4A8A-9F54-1ADCBB09C9AB', '3800010629690', ' 0,001 100                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11080D68-6AA3-4474-8F00-7212CF8E9516', '6B5A3233-1E30-4646-A361-94849656A962', '8600097301558', ' 250/5 100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9A40D20-4185-4C8B-82E4-8AE50F857A92', '4AB0434F-6DCF-4C33-84D1-44D41163880E', '8901315200128', '    20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1BD7E4C-C9C3-4AF8-85D9-596E1AC928AB', '4ACF753B-F4B3-441D-A13A-2A971D608E79', '4620006500173', '  250 10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('192D8921-C30B-4775-B115-8EEF711C3936', '4ACF753B-F4B3-441D-A13A-2A971D608E79', '4810201004013', '  250 10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEC7240E-F186-4B12-96E5-6611AB2E7F6C', 'C427D765-7FD1-4099-83EC-5CA65C155E88', '4602876004692', '  0,075   10                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5250C1F-55D6-46D9-9FF8-18FCEBD40757', 'D3D79191-BC7C-486E-A70C-6EFA232480B7', '4602565022204', ' //  5% 50                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87D58E3F-2322-42E1-A062-C23E30EE1BFD', 'CD840921-FD22-4E10-89A5-852C097662B5', '4603695001138', ' 0,004  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC803157-96C1-433E-B9B1-D387BF9174BD', '4C6A8496-D6A3-41F1-A0BD-AF8EC8215C8B', '4605964004116', '  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05279F1D-0D04-4121-8E54-7C8BFA5AFFD3', '4C6A8496-D6A3-41F1-A0BD-AF8EC8215C8B', '4605964004123', '  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8C3997C-41EA-4225-A575-01CA0B9B4E04', '4CC52FE2-AAB6-4B68-AC28-B745B2243B89', '4603988004259', ' 40  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A59C8A39-5492-478B-9DFB-F5A89E8024BD', '4CC52FE2-AAB6-4B68-AC28-B745B2243B89', '4604060011400', ' 40  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E0571F4-2F27-4AA0-91EF-392AC3E5E057', '4CC52FE2-AAB6-4B68-AC28-B745B2243B89', '4607011630071', ' 40  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6259627D-3F92-4D3B-BAFF-760715476B17', '4CC52FE2-AAB6-4B68-AC28-B745B2243B89', '4607019010264', ' 40  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34D261AD-F256-41CB-A03A-6F1A53DE8B26', '4CFA7B1F-66D4-498F-A6ED-4BA06E599909', '4601214001775', '  / 1,5 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFDA28A0-8CED-47FB-85A3-F7D9CBA97D86', '4CFA7B1F-66D4-498F-A6ED-4BA06E599909', '4601498001997', '  / 1,5 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D4467F4-A9D8-444F-AFEA-7D1E884F31CC', '4CFA7B1F-66D4-498F-A6ED-4BA06E599909', '4603762001306', '  / 1,5 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8890D210-12A5-4B0E-BB42-E4F14187DD93', '4CFA7B1F-66D4-498F-A6ED-4BA06E599909', '4605113001003', '  / 1,5 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A287D20-7E37-4CDD-870F-017408FAB400', '4CFA7B1F-66D4-498F-A6ED-4BA06E599909', '4605126003520', '  / 1,5 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2430056-C477-4474-94BB-1864FF44ABAD', '4CFA7B1F-66D4-498F-A6ED-4BA06E599909', '4607066260605', '  / 1,5 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FDB268D-CA2A-4647-AEC7-1E176F88F9F3', '4CFA7B1F-66D4-498F-A6ED-4BA06E599909', '4640001381829', '  / 1,5 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFCD6EA3-F417-4B73-A4A4-7470C918EF9C', '7A0AB985-E33B-4532-B470-960334F0693D', '4601498006824', '  1,5 / 20                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC5BD38C-B4E6-418A-863B-7D25F9E0266A', '81DB94E1-442A-4075-81B8-2EECC1E4BF4F', '4601214001638', '   / 1,5 20                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E963D477-82CE-4E02-972A-7FC4F5088F42', '4D164571-09A4-45DC-B63A-C9FCFE0CF389', '5997086103280', '- 0,04  100                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3FA8CB6-4EF6-49D8-A9DB-AFF0126B3417', '4D4108EB-BD18-4CE2-81BF-98C1E5745C2B', '4607045190046', '   0,1% 10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6933BDF-FEC7-479D-9758-A6DB3808B23E', 'F7970069-8264-40D7-BD87-8C6365A9365E', '8595026441354', ' 0,15  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FE23AA8-451C-4CC5-B7C0-AC682FAC3AF5', '4E9BE626-4CA8-4C19-9794-055978EF7D95', '4601669002600', ' . 250 / 10/  10                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFD328AD-D836-4EEE-A72D-AC721732BAA0', '4F8AB667-A774-47E4-ADF1-F1FFDAB7691F', '4602929000091', ' 0,01% 150                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A1D335E-8C6F-440A-82B9-BA573F449A8A', '4F8AB667-A774-47E4-ADF1-F1FFDAB7691F', '4650068810026', ' 0,01% 150                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B3B0181-5BA9-447A-9E2F-E25686E172E0', 'AB7F545E-3C63-4B31-B3F6-514859B2C46A', '4022536645889', ' 5 /.  50                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('536D2F3B-FBCF-4621-83CE-75EAC74DD65D', '06B343C8-B9D5-42E5-BC6F-D4C84335AF25', '3838957874088', ' 5   /-  10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04653E10-29F6-4B1A-8E28-F235827F2FED', 'F0C60F01-77FB-4583-A751-19F1632DE825', '4601429002383', '    10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3A9E864-01BC-427D-A449-A745DCAF515F', 'B44B3066-E21E-43D9-AE00-AFBC341026D1', '4601498006978', '  1,5 20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33B8957A-B2FC-4972-AD71-E45A7AAE3DC1', 'BABF908A-350F-4C75-B37B-CAA4FDB75A1B', '7290003441501', '  15                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA7F79AF-89D2-4079-81ED-CBC820C24E69', '505842F1-8837-4875-95C5-D69288AA512D', '4605095009158', ' 0,1% 10                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('956A8A3A-971C-4EC3-B170-997463664A09', '6191E5B5-186F-4884-8D21-8AD974FB8386', '4603184003896', ' 5%  - 25                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF600A4E-77CD-441D-A090-075E6F78C113', '6191E5B5-186F-4884-8D21-8AD974FB8386', '4603905000647', ' 5%  - 25                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03CB5F90-CB19-4131-926D-71A41C9F750A', '6191E5B5-186F-4884-8D21-8AD974FB8386', '4603988006581', ' 5%  - 25                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC6EC568-3850-47BC-93BE-E9685186CEEC', '6191E5B5-186F-4884-8D21-8AD974FB8386', '4604171000027', ' 5%  - 25                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('375BD58D-8AF4-41D7-958C-34BCB5B45A3D', '6191E5B5-186F-4884-8D21-8AD974FB8386', '4605847001218', ' 5%  - 25                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2C9B0A1-01C9-4C2C-9BC0-A7654563F571', '6191E5B5-186F-4884-8D21-8AD974FB8386', '4607007361330', ' 5%  - 25                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('175E3B9B-1408-4A8D-BA7D-4469DAA6355C', '6191E5B5-186F-4884-8D21-8AD974FB8386', '5604953000381', ' 5%  - 25                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28801D71-CFF6-4D98-8C88-48F0EF1449A3', '83EEFCCE-13DE-4968-8896-FDA003614A4E', '4601969005134', ' 40                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('375599BB-EB52-419E-B92E-56D3F40FB5CB', '3DD2A103-5567-4F78-8DB7-F9422526DC09', '4011548001691', '    10                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2AA52CC-552A-4BB4-883C-1149F0906F63', 'CA6DF021-41D5-451C-BCF5-F3DB31A41774', '4013054003923', ' 1000  1                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('885A429D-A7B0-4A44-BC83-A5C1B7D4524F', '882FBB1C-3A57-4C40-AEFD-DA5C55D60CCA', '4601026305238', '  1000/ 50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA2C126E-D849-4E3C-A680-6B0C36FDCC52', '50C6AE62-768B-41AA-9AB6-65CED3A79F1A', '3858881054691', '    30                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2D236B3-3A48-41A3-BFE5-A8E522F45543', '9D0AE2E6-AB47-43A4-919A-5421541703E2', '4603182002099', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0791E671-DA47-44A7-A877-B4DD5DDC0291', '9D0AE2E6-AB47-43A4-919A-5421541703E2', '4603988007786', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('000C33C2-597B-466C-B002-C705AA02E367', '9D0AE2E6-AB47-43A4-919A-5421541703E2', '4607027768041', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C7C09B5-A1E9-414E-AEB6-59EE966FA05C', '9D0AE2E6-AB47-43A4-919A-5421541703E2', '4820005740987', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F24A1EF6-34A3-4778-8C76-4F255A2C4D2F', '9D0AE2E6-AB47-43A4-919A-5421541703E2', '4820044110826', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9DA4D22-6C7A-44AE-B38C-156A355D37CF', '9D0AE2E6-AB47-43A4-919A-5421541703E2', '4823000800304', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AA6E54F-701A-47A7-9745-670723EFE498', '9D0AE2E6-AB47-43A4-919A-5421541703E2', '4823004500514', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75A57AA5-5A3B-45CD-A21B-796DD91F3D59', '9D0AE2E6-AB47-43A4-919A-5421541703E2', '4823004504505', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D94CCD3C-3432-4313-9010-90B0872A1A1A', '965B3C91-4183-422B-94C2-77E97DA58202', '4810201001289', ' // 0,04  50                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3DBC363-F3D1-4CE9-9966-FED944F90493', '9FC2148B-BAFF-4AFC-B0EB-BD2B040047B7', '4601969006308', ' 0,25  24                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E4CE940-6CE1-4585-AA81-51119743BEAB', '9FC2148B-BAFF-4AFC-B0EB-BD2B040047B7', '5903060000445', ' 0,25  24                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7BB0C2F-B7D7-44A4-8E24-D46FA7723FDB', '51967C2E-7E0D-4718-93AC-42745CF88A95', '4043589001811', ' 0,01  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D6A6635-E1A9-4C7E-A903-C508B61D0C59', '52529B39-4BE6-432B-B5BE-37DDDB2A1D5B', '8594739033344', '  0,05+0,0125 //  90                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('096B2C1D-F389-4386-887B-C9F50A6C51DF', '52529B39-4BE6-432B-B5BE-37DDDB2A1D5B', '8594739222243', '  0,05+0,0125 //  90                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C5DF965-EE49-439E-BD07-8ED19A50BD99', '60A6B4F5-0663-4626-9A02-A5CE1E95D88C', '4013054001912', ' 2,5/400 40                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9BF7D82-AF98-45B0-9572-9B54BBE87B68', '664F948D-C0EF-488A-8285-704F40E95F38', '4607083721141', '/ 2,57,2                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B437609-B9FB-4C07-9D1F-F100AF8E9F8C', '6193AEA1-463B-4ABB-8D41-900EFDC3FC78', '4607083721134', '/ 2,37,2                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED4C8F97-E188-4B4C-974B-E8E5218BDF74', 'F30D74EA-ED0D-4386-AC1A-E0D8046DE869', '4600053008563', ' -6  15                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65969EB1-EA0E-45B0-A8E9-1D0E0D62BF08', 'F30D74EA-ED0D-4386-AC1A-E0D8046DE869', '4603905003433', ' -6  15                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E234DD2-A044-4AA4-900B-D052B850484A', 'CD8C2A98-8E4A-4D68-91C5-3223C37C7B0B', '4607006670372', '- 1,97,2   100                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B28CC0D-01AB-4780-A303-7BC846978184', '529E9562-535D-4C9F-BA45-59B5558F08F0', '4603276008747', ' 5  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91484C2A-7018-4774-80C6-58BDF835D73E', '529E9562-535D-4C9F-BA45-59B5558F08F0', '4605949001536', ' 5  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15142E3D-155B-423A-AD5D-0FAD9BC239AB', '529E9562-535D-4C9F-BA45-59B5558F08F0', '4607003244668', ' 5  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D9CCA56-14F9-4438-B1EE-F6A16F4534CD', '529E9562-535D-4C9F-BA45-59B5558F08F0', '4607005897923', ' 5  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E614AD6C-EC53-4213-B4AF-4EAC87AADEFB', '529E9562-535D-4C9F-BA45-59B5558F08F0', '4607020330757', ' 5  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCD77A10-01E9-4589-9349-33A3D9EA5BC7', '529E9562-535D-4C9F-BA45-59B5558F08F0', '4607027765033', ' 5  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A2AC057-8CDF-491B-8895-321D3D3A7803', '529E9562-535D-4C9F-BA45-59B5558F08F0', '4660007700226', ' 5  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BF73F84-90AC-456A-BF77-0310F7A0CF24', '529E9562-535D-4C9F-BA45-59B5558F08F0', '5995377480218', ' 5  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD940ECD-004B-4BE7-B8F7-81F5278A9A25', '7D228035-C42F-427D-8639-780B1720874D', '4607146760025', ' 100/2  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F2A1FC7-CC4B-4DCA-8E91-3162C1525000', '52C9198E-918C-4D22-A8F0-74CC703A5672', '5000158100251', ' 0,2  6                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B05C83F5-7523-4666-85D1-308E2A4E9E76', '7A3A1D93-87B7-473A-B07E-B55B65045706', '4602196002729', ' //  4                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DC18B7A-F0AD-434A-AF66-F9C5F1F6EDC5', 'FAD6CBFC-21D9-49DF-B20B-C3632E4BAE0B', '4601764005100', ' 10   10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57E7DB12-56C9-4250-91CB-FF2E07BDD7F2', '5332FB4D-BADA-481F-8F0B-CAF5DEC7E4B3', '4030855000029', ' 100 3   20                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2217BEA-7CB6-4A34-B71B-1C4384E6319B', 'C6A8F69C-E2BD-494F-893F-5993735B389C', '4602521004732', '  0,9% 200 - / 24                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4062BDB-9F7E-49BB-B739-4C44905D9D6E', '9F3A792C-03AF-40FE-BA4C-A29F7182E7CA', '5310001059286', ' 40  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76751442-1319-44FF-92F2-D47083BA2AF2', '9F3A792C-03AF-40FE-BA4C-A29F7182E7CA', '5310001203818', ' 40  / 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9A15B9E-FFFF-4278-8653-1F724DF42D5E', '53D2B43F-C0C9-4BEC-8871-3792CE25F1EF', '8584005703392', ' 10                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6610CD7-4FE2-45EE-8EBA-D5E7DF8711E0', '53D82E2A-DC67-48F2-B2BF-F839544FCA72', '8901149005524', '  20                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AA32428-B769-4D86-9271-73ED761B352C', '3A4CEA27-703B-49E7-9260-DC59ED5F25CC', '8901149002288', '-  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEF15E33-BB8F-403B-AC7C-D81E204EC959', '8AEB0BD4-7861-4415-8D57-7BFEE66817A1', '4601669000408', '    20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D818C98-F9F6-47C5-A3ED-985BF9D718A5', '83DD6AD9-B2B7-40BC-838B-A0DDBC0CC65E', '4043589001842', '  0,02  30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79973D12-81F2-43F8-8F11-25653407756A', 'D48D7FD6-3856-46F9-B1BA-8B92CE58BD92', '4602158004877', '    0,5 /                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E23744C-85DA-4421-AB97-15D20AC74EAF', '54AA9B7B-1D6B-4EFD-A9A0-E092AE231669', '5000158100213', '  400  / 12                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3043352B-BF21-4728-AD0A-9ED3C5AE2DF0', '55B06DE2-0089-4FD4-9451-B9BDA5BC4131', '4603179003108', ' 5 5   /-                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC3D2D04-F776-45A6-8B50-730E90CFCA4A', '73A020A9-0F67-450B-81F8-C3BA6EC07898', '4603184002271', '  /. 1 25                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3ACEAF0-BD53-43B4-ADE2-140F5086F0AE', '73A020A9-0F67-450B-81F8-C3BA6EC07898', '4603373002952', '  /. 1 25                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A407AE14-4873-4425-A737-096666CA015B', '73A020A9-0F67-450B-81F8-C3BA6EC07898', '4605180005737', '  /. 1 25                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59980F5D-4C0B-4E7C-B622-8D7366C9D3FD', '73A020A9-0F67-450B-81F8-C3BA6EC07898', '4607007361002', '  /. 1 25                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE26C4FC-9D85-4135-ABC9-74607E7A136E', '56284F2C-DCED-4895-87D1-DAA4895DB2DB', '4601669006752', '  0,0015  100                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE2D6A20-3439-487D-BE4F-918C0E344E95', '5666A005-94FA-48CD-A0AC-59652EDF6F18', '4607027766719', ' 1%  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C6F0DD1-8E82-4DAE-9AB0-94A639EAD6F8', '5666A005-94FA-48CD-A0AC-59652EDF6F18', '8902030000017', ' 1%  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('409A8A76-6DB9-4CD6-BC8C-BD51B4652A4A', '8BF12BF8-BEDB-47A3-B1E6-BFB29D8CA026', '4326003241230', ' 1%  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D40324C-DCF1-4868-AA66-F7011C4A01F4', '8BF12BF8-BEDB-47A3-B1E6-BFB29D8CA026', '4601969001969', ' 1%  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF9C1FAC-F3A3-48D1-8AB0-10D49158C1A2', '8BF12BF8-BEDB-47A3-B1E6-BFB29D8CA026', '4601969007336', ' 1%  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7771C06E-D637-41EF-B902-756C22CAD358', '8BF12BF8-BEDB-47A3-B1E6-BFB29D8CA026', '4602565013349', ' 1%  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83A88CB0-0096-40A0-97E1-41F590AA2084', '8BF12BF8-BEDB-47A3-B1E6-BFB29D8CA026', '4607003241230', ' 1%  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('901F70E1-CB95-49C3-ACE8-073907293706', '6E3600DD-7C89-4CB7-AFBD-FC4F87D1AA0F', '8904091105816', ' 500                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D107802E-7BB3-49C4-B3AF-433B548F74E2', 'F80BC2AB-C44F-4A65-BB9F-CE1F29129280', '4601969007398', ' 100   6                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAB80244-D75C-4F7C-88A7-851DCCC361A2', 'F80BC2AB-C44F-4A65-BB9F-CE1F29129280', '4607027760175', ' 100   6                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73414EFD-C623-4935-9363-CB2F13AD948C', 'F80BC2AB-C44F-4A65-BB9F-CE1F29129280', '4607027761837', ' 100   6                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('445012C1-8A7B-4FE8-BF88-7020AD519361', 'F80BC2AB-C44F-4A65-BB9F-CE1F29129280', '4607085310152', ' 100   6                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('713C2D94-D6D6-4827-8F9D-AB8AE7391BAF', 'F80BC2AB-C44F-4A65-BB9F-CE1F29129280', '5900008013413', ' 100   6                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43A00046-7EE5-425E-B7EA-E80C7938CAEF', 'F80BC2AB-C44F-4A65-BB9F-CE1F29129280', '8906000570371', ' 100   6                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F89508BE-996E-4645-BF14-EFD5C3FFBD06', 'B624B003-3368-4F07-900D-84DB6087312C', '4601669004246', ' 0,15  1                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CFABABE-4B54-4B21-A9DA-35EE224D26FD', 'A18C2A73-8931-4848-93DF-035029F5E3CC', '4606486000419', ' 0,15  1                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98AE8205-6421-4DA4-8303-52B02B73B4AA', 'A18C2A73-8931-4848-93DF-035029F5E3CC', '4607019010769', ' 0,15  1                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71AEA2F7-3E16-414E-B425-30E5BE2A656D', 'A18C2A73-8931-4848-93DF-035029F5E3CC', '4607022750522', ' 0,15  1                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6B1C827-E239-4085-A2B1-7544D117A89E', 'A18C2A73-8931-4848-93DF-035029F5E3CC', '4607027764746', ' 0,15  1                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D60000F0-3B10-48DD-B763-C7FF4D48EBDB', 'A18C2A73-8931-4848-93DF-035029F5E3CC', '4607047720982', ' 0,15  1                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7DF75D3-333D-45A9-BB41-2F6B2603B220', 'A18C2A73-8931-4848-93DF-035029F5E3CC', '4607143560499', ' 0,15  1                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9974204A-0015-450A-996B-CC5A0EB487F1', 'A18C2A73-8931-4848-93DF-035029F5E3CC', '4820044110345', ' 0,15  1                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CF77823-56E1-478C-BED2-0A7356FDD05C', 'D03932A3-6923-4D1A-85D4-923DB94BB297', '4605949000348', '  150  1                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44D102D5-47FC-43C5-BC0F-AB4D79FB939B', 'D03932A3-6923-4D1A-85D4-923DB94BB297', '4607003243692', '  150  1                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D20F10A2-24D0-48F7-8FDB-2C71F53558F7', 'D03932A3-6923-4D1A-85D4-923DB94BB297', '4607027760670', '  150  1                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05E52A1C-D904-4C92-8102-546A01FBBEAE', '2D110AD4-EB38-4510-973A-DD225C1C23B7', '5907529415122', ' -15 1% -                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2AD1288-6B14-406B-8BB6-3BF6A94164A6', '56788556-15E9-4326-AC96-074025CC683D', '3838989559526', ' 1000  21                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AEA30DB-5889-4741-A7DE-F3A3781A4747', 'CEDC6F39-6DAE-4448-A73A-8EFBBBF02795', '3838989556983', ' 20 //  28                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E56EAD6-BA90-4677-ABC9-6997CFAA3D47', '5687B83B-092F-40C5-B7A6-E63CE7706BB1', '5944702001161', ' 10 //  20                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3698F570-0241-4C26-A880-761F57860C07', 'C2C3ED76-DBA8-410A-9775-A5ADB3D07177', '4607007360548', ' 100                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4FC3CBC-5A7C-4A4B-97E9-1FE7B07886B6', '870BFDCD-DEA4-44C5-AB66-C0C24DB3B11B', '4607007360562', ' 100                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F77BAA33-E163-4E97-A3FC-088F2FA15C3E', '702D052C-5D1E-42B5-A51D-7170648E0618', '4630001190101', '68880                                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BF8EAC2-72D7-4D75-8109-FE218CBE1967', '57264394-576F-4494-9C05-BC1FF25C31D1', '3585551030500', '  500   16                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71BBCD22-05D5-4199-ABED-A8EB248601B1', '57264394-576F-4494-9C05-BC1FF25C31D1', '3585552591710', '  500   16                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F39352A-B8F5-4E4B-8E05-3176DCE907D1', '57264394-576F-4494-9C05-BC1FF25C31D1', '4602505007643', '  500   16                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('423AF23D-998C-4A85-A02C-F6E5FDADB2AB', '57264394-576F-4494-9C05-BC1FF25C31D1', '4602505008459', '  500   16                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29532877-B0CF-48CC-BDD2-725E90F9065A', '5769FB2E-F5FF-4E2B-BB00-9BCEBBCB66D6', '4607159860170', '  0,005  / 30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('050B62EB-F571-4DF5-8834-2E48DFB76FA5', '5769FB2E-F5FF-4E2B-BB00-9BCEBBCB66D6', '4607159860408', '  0,005  / 30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45928C8B-E172-4584-912C-9DCFBDA92A36', 'D9DFC1EF-E4F5-4B62-B082-711E9B655CE2', '4607159860422', '  10  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('808D5CAB-2520-4959-8791-3752AB961174', '577839D9-076F-4541-A464-5FCD9A5CE9A6', '4607004430558', '  2                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43DBE033-FAE6-4163-8D4F-6BD9AB9E0722', 'BCC3F4DF-52FC-43F7-B062-6568F972006C', '4601026065163', '  5% 30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('613CBC55-D3EF-45D9-89A5-097928ADE6B8', '5779F20E-7750-4564-AD3F-071A2CDC084E', '5900008011358', ' 10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AC18000-57F6-4B30-93F0-BFB111AB6776', 'F3C14A4F-FEEB-40FC-B956-46739671897B', '5000158068032', ' // 100                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A3025FB-76A6-4B1F-AF29-F8EE5695AB89', '9D3AAF6D-D02A-4FE1-AC9A-B0208D7A280B', '5000158101470', ' 0,06   10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59E4BB96-87CB-4CF6-9B32-3AD0CD5BCF28', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '3838957029983', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCF2F52F-D5CE-4086-98DF-B22CB5665615', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4603569721346', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CAEF373-CFB5-4054-BC04-9A189F68EAA5', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4605691001532', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('838309BE-597A-47A5-8A35-8588C70FC388', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4605949000843', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B88C49C-E208-4785-B660-6816494387C9', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4606486000563', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65936946-DED3-4C74-8A60-681C5CCFA1DB', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4606486001973', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA2864FB-CD7A-450F-BB32-1A5C985B75AB', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4607003242749', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A4DC0B4-20C7-4FB3-84EB-F2264EE474D6', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4607011632426', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C659B331-D6D9-41CD-B9DF-4C1A228D4D65', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4607020330696', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5131FE7-0181-4974-A857-C0A406AACBED', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4607027761349', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB17D551-B892-4F29-9184-27801A740AF7', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4810201014500', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF6DB2D8-1C19-48A0-87B4-51EC917ACE15', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '8594739010512', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FDC0D75-150A-42DB-886F-2E3746AFF262', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '8901043006139', ' 5  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ACC037A-85BD-452D-A925-EA7F4EE63480', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '3838957029990', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8708DFD6-AD48-411C-AC80-B074F3E301F2', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '4605691001594', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('939F9A2B-038C-49AB-B0FF-61AD03791847', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '4605949000898', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EA35EE6-74CA-4E2F-A55C-2A4B006994B0', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '4606486000570', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE98C567-BA5C-4B2D-81A8-EED30380B2C6', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '4606486001980', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('447D59E3-7B60-42EA-910F-99194A2CB03F', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '4607003243609', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F313F0A-D332-462A-AA45-C2BBEC93F323', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '4607011632488', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03229C86-33D6-4E34-AE04-4459C3024D8B', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '4607020330726', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8EFEDCD-A5DA-4170-97BD-94F74A1AD72B', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '4607085311524', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8F8A119-B38D-45C8-A36B-F14CFEBC86F5', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '4810201014517', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5D6F95A-D515-47D5-A173-B57558DFCADF', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '4820135586097', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F8BE1AE-04FF-4E31-83B2-C82CD67EFDE5', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '5310090002729', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14946211-D107-4C46-97C4-F63F2930251C', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '8594739010536', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E39E2609-0842-4991-B1A9-67633557605F', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '8901043006146', ' 10  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0005895D-10A9-48B8-9DCF-329899CB512D', 'F79F5EF8-1F4D-466F-BA90-C5B68AD4203B', '4620750540111', '  25    10                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A83CEA07-D1D4-40C2-BA93-7745C46F0990', '7F7ADDBD-561D-4D1E-BDC5-45AC221799B6', '8594739033337', '  0,05+0,0125  / 30                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA3AC1C4-16CA-42C7-B4BC-EC773BFC1F86', 'EAD8D784-1FB5-46AA-B6DF-D2134CFB90F6', '4602565020286', ' 0,5  10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED6E0469-DB16-4F07-82F3-42190B913071', 'EAD8D784-1FB5-46AA-B6DF-D2134CFB90F6', '4605077003716', ' 0,5  10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A92757B-3BA6-4846-8E85-CAC471649221', 'EAD8D784-1FB5-46AA-B6DF-D2134CFB90F6', '4607027761721', ' 0,5  10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CD0EFD2-EFDB-41CE-8AA3-69EC99B3D29F', '85FE02DE-0C0C-4EDC-9FFE-F69B477583B7', '4607047720265', ' 0,5  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1B072F4-D44E-4826-8C7C-7620537475CE', 'FBEA5741-9D13-49D6-8343-98248FFC9F44', '4602193001039', ' 0,0005  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A268762F-4680-4C08-BAAA-39603667B134', '0C8D169D-FCE6-4DD0-B7C9-E9F7B02DB09B', '1661193010499', ' 0,005 //  25                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67AEB392-F414-4CA2-9E1E-3001B47ADFA0', '0C8D169D-FCE6-4DD0-B7C9-E9F7B02DB09B', '4602193010499', ' 0,005 //  25                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6578D5A-D321-4918-AAEE-829353D42D21', 'CD7841EF-FB42-437A-8FCC-111C55C78421', '4823000803237', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D265FE5-9B98-4A60-AE3B-EB50040D61BC', 'CD7841EF-FB42-437A-8FCC-111C55C78421', '4823000804760', ' 25                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('204F4F0C-BEEB-46CF-92F6-140DF491B1C4', 'DF4F82B8-DF15-40C3-B9B0-266442117713', '4605964000873', '  500  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC79B596-E181-40D6-8AD9-10D6CF8E79E0', 'DF4F82B8-DF15-40C3-B9B0-266442117713', '8901083020164', '  500  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B45C00D6-0DAB-49D4-B9C1-3F9412AC6349', 'E34B6D89-9913-4291-B6F5-B8974BB564E8', '4601498005797', ' // / 2 20                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C34E9718-B0E7-408E-B7E0-C5294994678C', 'E34B6D89-9913-4291-B6F5-B8974BB564E8', '4605126004862', ' // / 2 20                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9B2EAF0-7201-4B5D-9800-182498269732', 'E29A27BD-DF53-49F8-85D9-E05F66187A15', '5902614103014', '   100                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B8C3AED-8C68-4D91-9459-B93DFBE03B7C', '164447AD-249B-4103-9228-8551F6AAE7C3', '4607004855023', '-  / - / 60                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9333473D-13EF-44F3-8151-20231224F44A', '4314F0FE-0CE0-49D7-AD25-4F58FB995950', '4607004855016', '-  / / 60                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D015553-0971-4378-AA3D-6D2A4DE70DAA', '14EF09F8-2F64-42E0-B54B-80520B4AC282', '4610010012717', ' / 60                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1A1F7AC-A3BC-4D18-B112-BEAB2877A8F4', '14EF09F8-2F64-42E0-B54B-80520B4AC282', '4670009340023', ' / 60                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23C10CE1-089F-4F55-A75B-FC35DF62F2BA', '14EF09F8-2F64-42E0-B54B-80520B4AC282', '4814488001598', ' / 60                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA180098-22F3-4DBF-AB40-70FDE787AA15', '14EF09F8-2F64-42E0-B54B-80520B4AC282', '5280005650027', ' / 60                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0A83768-23BF-4822-A883-A2EB144D1E07', '6CFF05F7-E21F-4AEC-8522-F96EF2CF32A1', '4260090441381', ' 100                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8776EC26-153F-4A35-B391-77C320A9035B', '6CFF05F7-E21F-4AEC-8522-F96EF2CF32A1', '4260090441398', ' 100                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2270900-DDA1-4490-B0E5-E8F803F29B60', '5A36AEA3-30B3-465C-9940-9A622FACB428', '5060038501042', 'OLA    Silk Sense  15*30                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AD8F284-D4B6-4F59-839F-D7C488F1F19A', '8E21A295-0851-4C3B-9F79-D5765535BD39', '5900516002770', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE64FBF0-5935-4F94-B68D-B112162F963C', '8E21A295-0851-4C3B-9F79-D5765535BD39', '5900516008093', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CB7E174-B615-4310-9C65-611AA620DD37', '8E21A295-0851-4C3B-9F79-D5765535BD39', '5900516062200', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25718422-8946-45CB-9E4D-2E5BD135A920', '8E21A295-0851-4C3B-9F79-D5765535BD39', '5900516420543', '  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61D4564B-7466-49F5-8F46-819ECCA31702', '8FC2DCEB-3D1F-4911-B3BC-D85DD11788DC', '5060038501035', 'OLA    Silk Sense  15*30                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA501656-FA4B-432E-BC47-D1C74FB0AF04', 'B2AF9E1E-A2C9-4B18-A767-16372464E909', '4607015591156', '   10  01                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1223AD78-173B-4B71-A421-B4541CB13306', '4B5B1C10-510C-4578-A050-9E923ED65B7E', '5060038501059', 'OLA    // 15*36                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DED63DA-A3BB-4B43-B614-C7D66111F8BB', '92A496E2-D006-4D62-B51D-A7AE44FA95C6', '4603671002401', ' 4% 10                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E954C22A-4A6D-4F98-8833-C5817AF009F7', '92A496E2-D006-4D62-B51D-A7AE44FA95C6', '4607005933829', ' 4% 10                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AF04BA4-5813-4771-9F0B-DB3D436AD9BC', '0BCC2D4A-80D8-453E-9819-243CF43475E0', '5903060232976', ' 850  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('359355AB-E6B6-4EEE-91CA-038235AE8271', '5B434017-216F-459E-86D6-AA68DF25912F', '4603907002397', '  0,13  50                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2434AAE-1AA6-40D4-9483-0F1920F05146', '395339BA-893E-40B5-AE07-08A1968B6969', '4605920000305', '  200  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F63D95A1-FD03-4CF1-9934-0FD438256AAF', '5BD6DDB3-04ED-4D57-B746-F2B44D4933AF', '3574660619126', ' 0,05% 15                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A70589A-C7C2-40F2-83B0-7C51DC9FE8F7', '5C5B244D-C491-47BD-9D3E-AFAB76E20911', '4601669009302', ' / 10/  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('099EF509-F4A1-4D4E-83E9-A3D85E0056D1', '5C5B244D-C491-47BD-9D3E-AFAB76E20911', '4602196000336', ' / 10/  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1C9B553-D653-4C37-8978-45BFD877400D', '5C648659-F6F3-4954-B20C-F01E1E1C643E', '4602824000721', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39BE773E-15D3-4CD9-B36B-93E7BFD50C1F', '5C648659-F6F3-4954-B20C-F01E1E1C643E', '4602884000303', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA61B059-8FCE-4CB8-BF07-3BDE06640044', '5C648659-F6F3-4954-B20C-F01E1E1C643E', '4603276007047', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA2B5A95-7E2A-4F82-AFA0-D14893D8C026', '5C648659-F6F3-4954-B20C-F01E1E1C643E', '4605422000636', ' 0,5  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93DBF63C-B29E-436B-917D-E796C92E62BE', 'D16AAA43-CECA-44CC-B483-575828542987', '4610008490299', '    40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F64A6421-C2E9-4B54-B693-5BC74997902C', '5E33DBD6-5B62-4288-9838-B27887434B82', '4601808000016', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06168680-F13C-4970-A4F5-304D7A420705', '5E33DBD6-5B62-4288-9838-B27887434B82', '4601808004045', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACC48620-2B12-44E3-9A94-A97DD1EA77B7', '5E33DBD6-5B62-4288-9838-B27887434B82', '4603179000060', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20D006F4-9378-4862-9B16-C422A0379815', '5E33DBD6-5B62-4288-9838-B27887434B82', '4603679000034', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56AA1CA9-4B7A-4A78-9993-8387CA84E11C', '1EE974E7-0C3C-4BCB-B671-8C6947C41E1D', '4601808000054', '  50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21A6A2F0-FF55-4B90-AD24-B9FF2938C307', '1EE974E7-0C3C-4BCB-B671-8C6947C41E1D', '4603179001197', '  50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3855156E-202F-4D56-A1A9-4248BE898586', '1EE974E7-0C3C-4BCB-B671-8C6947C41E1D', '4603679002939', '  50                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3384A56-0F84-4C7B-8266-BCCAB760F33B', 'CB4E93AB-22C3-4E60-8E31-C3DAF522FE75', '4601808002683', '  100    10                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7690D06-83EA-4229-B189-6A231441D5F2', 'CB4E93AB-22C3-4E60-8E31-C3DAF522FE75', '4603276002158', '  100    10                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CB99D46-64EE-4BBB-B204-12208AB68276', 'CB4E93AB-22C3-4E60-8E31-C3DAF522FE75', '4660011213583', '  100    10                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('291F6BBE-9934-4080-A57E-4CFCFD1623F9', 'CB4E93AB-22C3-4E60-8E31-C3DAF522FE75', '8693495039062', '  100    10                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96DE3D70-9830-4AC8-95DF-10C47523EE56', '5E3C5002-58F6-406C-B550-EA505B186A99', '4607109940136', ' 714  . .1 /                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF29E5B6-DA68-4B38-9820-AB4BCEBF9E5C', '9059409F-C0BC-4BE1-88B2-6AA18AD35F47', '4607109940112', '  ...510  .. //                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91F95290-4278-4B62-99C7-4153A717700C', 'FAB00712-2A6F-472A-8931-E75EBA79B77E', '4602260007766', '  1614 10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('042E8552-1D58-4E40-9EC2-37AB76A3EBCC', 'FAB00712-2A6F-472A-8931-E75EBA79B77E', '4605147000201', '  1614 10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AABDCB56-7F84-42C7-99D2-67B1D13CCB07', 'FAB00712-2A6F-472A-8931-E75EBA79B77E', '4607109940280', '  1614 10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FF3084E-1D4B-47C2-8E01-65A57A9ED0DD', '3950DCA2-1735-4B0B-9A0E-7EC948AFFAC3', '4607109940129', ' 710  /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F4869E6-22EA-4120-87BB-C4A109507F12', 'F9F6EA33-2580-4ECB-B572-4B0A8093BF77', '5900516401047', '     100                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0DE298F-3428-41B7-92D9-5794EAAF5BEF', '5E41C9F8-5F4C-48C8-A430-C389F267BCA4', '4602196002873', ' //.  50                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75EB0CAC-9CC5-4DEC-B886-116C43AB32C0', '5E5357AB-6539-4A39-9CB0-5C5C74CAE428', '2400004762573', '       4                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('401FD9A3-1864-405F-A9A8-7730D4C84F01', '5E5357AB-6539-4A39-9CB0-5C5C74CAE428', '4607045192101', '       4                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51E78C8A-0A7A-49B2-AB01-4B165538F805', '5E5357AB-6539-4A39-9CB0-5C5C74CAE428', '4607045192224', '       4                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6E125EB-5ECC-4318-8B91-9283E752585E', '5E9A85AD-DEB4-48F3-908C-3923F2A740F6', '4607009582023', ' /.20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8F5C28E-0318-4249-9F29-CF1899EFB77E', 'AFB70447-8C47-402B-867A-844A1254C02E', '4601669007209', ' 0,05%  15                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9C222AA-2F79-42A3-8EE0-A0649FD1138B', 'AFB70447-8C47-402B-867A-844A1254C02E', '4601669007223', ' 0,05%  15                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C28B489-2161-445D-A2A3-390654FEA008', '5ED3BA16-D5E6-4A72-B7CF-150B12982523', '8901148232037', ' 400+325 //.  10                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7713C17-39C7-42C8-914F-86229FE044F7', '5F936D68-7709-46E3-A5AB-9DFD5CC54F37', '5997001358832', ' 50  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6144D495-DA2E-4BE5-8CD0-ADEC7ECD9F79', '98982169-BDD4-42BF-BE9F-2120D5200795', '4606367000323', '  1% 10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC15D525-8086-45BC-9740-8D94B1762B3D', '98982169-BDD4-42BF-BE9F-2120D5200795', '4607007361248', '  1% 10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CB5C0D6-05BB-459A-B87D-6374BC323FE2', 'CEFA9F05-C81E-409D-8770-1BBCC9E9798B', '4607007361323', ' 30 5%  - 10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF1275ED-EC7F-487F-AD6D-208471209786', '5FC84D6F-8F7D-4259-AD59-40040B03B94D', '4607055131275', ' 25   30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F3DCE78-C2A4-4799-81C1-F727FBE8966E', '0326902B-AC42-44E1-98AA-8C827AFAC06C', '4607083721523', '-  1018                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C745C0E8-5312-4C21-837A-0549E390D57D', 'C0AEB67A-99C4-4F15-9474-AD3707E3973E', '4823017800625', '-  1015                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56DBD137-1673-4CE5-96BA-CD58EC81C137', '600D89BC-8192-419B-9037-52C15868DD52', '4602546001600', ' 25                                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9874C87B-C99A-4ECD-862F-B77565CBC42E', '600D89BC-8192-419B-9037-52C15868DD52', '4603380000156', ' 25                                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E297DE74-2238-4BAD-8B11-18FA37605ADE', '600D89BC-8192-419B-9037-52C15868DD52', '4603933002743', ' 25                                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F8046DE-DDC4-46B3-A402-FF45910380BD', 'BCFE5145-3984-4A27-BBE5-83D5228C69CF', '4607100622093', ' 0,02 /-//  10                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61EC00D4-3895-4AE3-9373-E17FDCE0ADB8', 'B4AF7197-ACF6-4376-9CF0-2ABF2785C8FE', '4750232005910', ' 0,25  40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3977E0C-2493-48D2-BFF0-B1E87E0B7A8C', '7724ED16-FA0D-47B8-A6CB-5635FBEE74E0', '4607027764531', '  0,035 60   /                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77053326-9D8C-413F-9E0B-2D4196114270', '60D62A64-7D32-4D34-87D1-EBEFDD3CB922', '4605964002679', ' 1% 1,5  5                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51D0029F-764F-47E8-B1CA-7CA2D3DAEE35', 'AFD54F52-3FA8-4941-B769-5CDC09C58FBF', '4030674003447', '  2 -  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('867AA115-2CEE-4B7F-87DB-57F90A69DBE4', '1072BDF1-3F9D-4FA9-918E-4F53F138B2DD', '4607083721158', '/ 3,83,8                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0374A5F3-FDAF-4A25-9C29-F339DAF3FCA1', '61B619E2-004C-4205-B4BE-01CF5A8940AF', '4607004431050', ' .  30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29A68D71-0A74-4910-A84B-B23D385EEE2A', 'F2FD755C-3FA5-40BF-AFD5-255F484DCE15', '4607011664854', '  / 30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDA6ABDA-420F-473A-B3A9-FB6AB4288DE5', 'F2FD755C-3FA5-40BF-AFD5-255F484DCE15', '4670003600833', '  / 30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A06097D-634D-4072-865D-DF4CDC216E3A', '62A9FAB2-2B66-4331-B224-F0F3617C3CBC', '4601372001693', '  24                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9B40B34-D032-4CB5-9FA5-EFAB44ACEA4E', 'BC1B04F5-AE93-4203-B986-1A29A9131EB5', '4601372001686', ' - 12                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B6C57EF-512E-481F-B85E-235B4F6C64DC', '3473AE66-4860-4273-8E54-889CE3C03314', '8901248101240', '    25                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF198119-37ED-4F61-B38F-0F038CE123D4', '3473AE66-4860-4273-8E54-889CE3C03314', '8901248333054', '    25                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98BBD997-0C09-492A-AFCF-C06D6470FCFB', '62BF2D2F-E51A-4B7E-AF84-41C114EE8A1D', '4030096114363', ' 10  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D5D287E-7527-49EF-B5D1-AC33726EF2E3', '62BF2D2F-E51A-4B7E-AF84-41C114EE8A1D', '4030855038060', ' 10  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F965D53-F89F-475D-990B-E78A3157FD90', '62BF2D2F-E51A-4B7E-AF84-41C114EE8A1D', '4601969002621', ' 10  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3B02FED-7451-49A4-A094-8E969FB4F38A', '62BF2D2F-E51A-4B7E-AF84-41C114EE8A1D', '4602565014360', ' 10  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F1C4C5E-9932-42FC-BA6C-7E545A703ADD', '62BF2D2F-E51A-4B7E-AF84-41C114EE8A1D', '4603179003658', ' 10  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD850323-3B82-4E9C-8DDC-1DBEF712026D', '62BF2D2F-E51A-4B7E-AF84-41C114EE8A1D', '4603988002804', ' 10  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F628C6A-DB9F-49AA-B641-7E27529ED603', '62BF2D2F-E51A-4B7E-AF84-41C114EE8A1D', '4603988010472', ' 10  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14E6D403-4601-4A5E-AC05-519756E95CDC', '62BF2D2F-E51A-4B7E-AF84-41C114EE8A1D', '4605077005079', ' 10  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A45FAD3C-C247-4FA6-AEF4-90D50BC1645A', '62BF2D2F-E51A-4B7E-AF84-41C114EE8A1D', '8901043000625', ' 10  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44EB9416-5FDD-4C9D-8CC5-EC36C3E8A7D5', 'D85E84A1-9078-46EA-B340-0FBAF8D4BB4A', '4030855027804', ' 0,01  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79D7E9C8-1F2C-4D9B-97E3-4A14EBBAF21C', '6325F185-16D2-4B32-AC1C-36D80282946D', '4606371000333', '     50                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('522AF438-6EB7-4DFD-B1EC-AF7307B7A6ED', '6325F185-16D2-4B32-AC1C-36D80282946D', '4606371000357', '     50                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4642CE5-ACC4-4D44-80CB-78112B41A0D1', '6325F185-16D2-4B32-AC1C-36D80282946D', '4606371000395', '     50                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('554F6B2F-89E5-4583-BA65-AD7009FF39B8', '6325F185-16D2-4B32-AC1C-36D80282946D', '4606371000593', '     50                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CD54FCB-1C86-40CC-8E90-03A18CC560B3', '6325F185-16D2-4B32-AC1C-36D80282946D', '4606371000609', '     50                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A474593D-A213-4C0B-9510-6A2AF903DFC9', '6325F185-16D2-4B32-AC1C-36D80282946D', '4606371000616', '     50                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF2ADFB6-21F9-4239-ADFE-41B2F05CDADC', '6325F185-16D2-4B32-AC1C-36D80282946D', '4606371000623', '     50                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FBC9ABA-570E-470A-A9D2-AAA180281141', '6325F185-16D2-4B32-AC1C-36D80282946D', '4606371000630', '     50                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB9261E-5C84-4051-A469-D4704BF3FD09', '6325F185-16D2-4B32-AC1C-36D80282946D', '4606371000685', '     50                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4B7DB76-3110-44FF-9AB5-2AA668637754', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4602546001488', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('949C83AE-B9A2-4775-936D-9F90CEDC88AE', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4602546009606', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C03151FD-870F-462A-8EAB-ED73B83D6262', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4603184000239', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BE88E39-CBCD-4B39-89CD-C4AF0CC02B33', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4603256000174', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA7209B3-3A9D-4AC9-B409-5A5E02E7B82F', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4603373001092', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2CB5B2F-A419-49F9-BBE7-2E2DABB29EB9', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4603380000255', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5865218C-D6A4-44C2-B9DE-C6EDDAAA62AE', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4603905000609', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33202FA7-005A-4ABF-BE64-EDA546488E28', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4603933002712', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CDB233F-F491-4C72-B0F6-AFF62589538C', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4603979000109', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ADFF653-7259-4A80-9E35-19DE387742E5', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4605404001798', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B48B988D-DAEA-482D-B037-1789517C31D4', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4605404002320', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44749129-3E08-4A79-9A26-D3894BB8D52E', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4605681001788', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7717638-0847-4B4C-A54A-132ABA1BF88F', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4605903000155', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49E2CF15-3997-4286-855A-9C243C2D8F58', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4606926000658', '  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80EA3D9D-68D3-47D1-A63A-E310F07CE912', '6516DB20-1923-4FDC-8B21-B5F7309D42F1', '4607056065036', '     / 500                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51ED1D16-5364-415F-B9EE-F00662E9DBBC', '7F4B753F-6B1A-4FB9-8371-FBC6ABB19F11', '4602242004752', '  0,25   40                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9EB06FC-3C1E-442D-805E-78A784CF9CA5', '65ED6077-B82B-4E16-BAA0-C83C03ADFEBD', '4602876004586', ' - 0,001  50                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D24714E0-6755-4EB6-A07D-8AD4CEB3314F', '65ED6077-B82B-4E16-BAA0-C83C03ADFEBD', '4607027761226', ' - 0,001  50                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3850219C-9209-429F-B27F-D1DF248047BA', '65ED6077-B82B-4E16-BAA0-C83C03ADFEBD', '4810201003603', ' - 0,001  50                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FA85260-26D1-4BE1-9156-21ECB7B8D3DF', 'B53E1818-AEAF-4306-ACC4-345152C4D086', '7640114721687', ' 50 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8997F0C9-BBFF-47E7-A33E-F800306982C7', 'E2B7BCA4-95CE-48EA-8DC5-3151DD15037F', '5995327274089', '   / 50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B44CAE53-6D9F-4F4A-A3C8-8FBF000D320E', '667766AE-19C3-4D0E-A379-A18D2E551A7B', '4607100622109', ' 0,02 /-//  20                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C45EBC60-C808-4C15-BF42-F9EAFFC7CEA3', 'D6A31297-6B73-47A7-815C-495D9E35A2F6', '4607003660277', ' 400  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36B1B023-7D89-4AD1-B95E-87F3189F1D80', '682213E5-E846-4AEA-9C0E-3202D159FCF3', '4602565019617', '*  0,1% 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('973A347E-30F5-43FC-BA40-752E234B731E', '682213E5-E846-4AEA-9C0E-3202D159FCF3', '4680381010292', '*  0,1% 20                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C8E60CD-8DDD-4841-B016-A1DF1BBE205C', '683DF231-B176-4495-B87E-D0119640EFA2', '3850343023016', ' 5%  2                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E62EA97-81B7-4488-A6F7-54FCC6937BDF', '683DF231-B176-4495-B87E-D0119640EFA2', '4030855000166', ' 5%  2                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD729F90-08BD-4AC6-8582-980806A0B7DA', '687270CE-81F8-401A-8B56-5521411926AC', '4600828003915', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DA4AE94-69D5-46BF-AF9B-888B2EA8E84F', '687270CE-81F8-401A-8B56-5521411926AC', '4600828004998', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('043B1CF1-028B-4161-9F94-CD4B82138E1D', '687270CE-81F8-401A-8B56-5521411926AC', '4602212000050', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFCE02DC-4742-4B69-A17E-233F2494322F', '687270CE-81F8-401A-8B56-5521411926AC', '4602212006847', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D73D2707-1D93-40A7-92E6-F81A58B8311B', '687270CE-81F8-401A-8B56-5521411926AC', '4602424000237', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F02B6DA7-4BFF-4204-B158-12D1E29618F0', '687270CE-81F8-401A-8B56-5521411926AC', '4602509005638', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD82D1EA-9EFA-4755-9691-A85140298B9D', '687270CE-81F8-401A-8B56-5521411926AC', '4602824006082', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BACB1EEB-83CC-4EBD-8274-D3E758A89CD8', '687270CE-81F8-401A-8B56-5521411926AC', '4602884000389', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAFEEBFD-18DB-41CF-B8D9-C4C637BCD950', '687270CE-81F8-401A-8B56-5521411926AC', '4603988009438', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F692BD00-3D83-4E46-B6C1-5420C2CA1812', '687270CE-81F8-401A-8B56-5521411926AC', '4605260003417', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D902CE8-A0E7-469F-B983-F068CD1DFA58', '687270CE-81F8-401A-8B56-5521411926AC', '4605260003424', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('495CB96A-00DD-42EE-8F8A-A09A855568B9', '687270CE-81F8-401A-8B56-5521411926AC', '4605453004443', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E440929-B55D-40E4-B90A-FC478601DA6C', '687270CE-81F8-401A-8B56-5521411926AC', '4607027767860', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DC3F44F-1BD0-4525-BC96-BA6BC2BAFD5F', '687270CE-81F8-401A-8B56-5521411926AC', '4820135585540', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB16BED8-10EE-44BC-A1AB-7F4ACD217CDA', '687270CE-81F8-401A-8B56-5521411926AC', '6930169707127', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F79936D-F4BC-43B7-8D71-97CD6C1A8DFC', '687270CE-81F8-401A-8B56-5521411926AC', '6938588802256', ' 0,5% 5  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A574A5AC-1601-4532-9F05-525B9D1A8452', '6885D65F-9A87-4F30-8FD1-E3A23864CA53', '4602212007011', ' 5  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EE6C7D7-0D37-4183-BF62-EF86F8DC8B46', '6885D65F-9A87-4F30-8FD1-E3A23864CA53', '4602509007083', ' 5  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B8C68ED-0742-4A14-B5FA-ABC71BD960AE', '6885D65F-9A87-4F30-8FD1-E3A23864CA53', '4605260003516', ' 5  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('670E1459-A37D-4FDC-986E-F4DABBFDE3CA', '6885D65F-9A87-4F30-8FD1-E3A23864CA53', '4605391001528', ' 5  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6FDA7E1-A70E-4E89-9DB2-F84716ADF13F', '6885D65F-9A87-4F30-8FD1-E3A23864CA53', '4670000360785', ' 5  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44539539-986D-437D-A684-C13F6C1ED321', '6885D65F-9A87-4F30-8FD1-E3A23864CA53', '4670000361621', ' 5  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B02BC759-0C48-4DC0-B2CE-7C3BF48F676F', '6885D65F-9A87-4F30-8FD1-E3A23864CA53', '4680013242244', ' 5  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A2F2E7B-0F8B-4E91-B6A6-4088247F41B9', '6885D65F-9A87-4F30-8FD1-E3A23864CA53', '4810201008172', ' 5  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BF0AF35-8B36-401D-B864-09551848F7F1', '6885D65F-9A87-4F30-8FD1-E3A23864CA53', '6916119020263', ' 5  10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90E90A65-CAC1-4FF7-B363-AC36996664B2', '9EC7A5B7-0981-4F2F-B6EC-E64BDF114E2F', '4810201000169', ' 2% 2 /  10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B9201A8-870C-4451-9C26-66F7B7A4BC91', '688C2148-6E22-45ED-A6AC-7A7B98BA2D1D', '5944709000013', ' //  1% 20                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0001997D-7903-4603-AAAE-3B0F7037EA3F', '688C2148-6E22-45ED-A6AC-7A7B98BA2D1D', '8901043000076', ' //  1% 20                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D2DD803-407B-47D8-8C0E-84F89AE82499', 'EB65956B-2F8C-4E0A-BC24-508B79BB6A51', '4607003243708', ' 0,15  2                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82E5F465-1B9A-44BF-8027-A6CA171AFD33', '693D9B43-8869-42F0-A7F1-B8F37BE50BA1', '4602902000438', ' 57                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E96DAD8E-BF29-4270-B233-D133F48BEDED', '693D9B43-8869-42F0-A7F1-B8F37BE50BA1', '4602902000964', ' 57                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD6D5336-BCC2-4A5F-A05E-2CB0BC3E7B48', '693D9B43-8869-42F0-A7F1-B8F37BE50BA1', '4607109940181', ' 57                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('484A638E-7040-4812-BBD6-5FD03E75AC60', '693D9B43-8869-42F0-A7F1-B8F37BE50BA1', '4607145960143', ' 57                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6C7C045-CA64-44C7-B7EF-2374ABAC10D8', '693D9B43-8869-42F0-A7F1-B8F37BE50BA1', '4640000900205', ' 57                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('651706F4-F8A8-413D-93CB-A77A6968F173', '693D9B43-8869-42F0-A7F1-B8F37BE50BA1', '4670003600703', ' 57                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40736E0B-28E2-4633-958D-071D6173F751', '693D9B43-8869-42F0-A7F1-B8F37BE50BA1', '4680381003409', ' 57                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19F1021A-005F-4315-9B0F-0BEE790545C9', 'A644D8BF-7DB7-4452-A9C9-98980FF59F15', '8594739055209', ' 0,01 20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78495308-02F0-4DA2-96A4-D8BD6AF79256', '6A6A4440-2F45-4714-A586-9FE3A92707D1', '4013054001509', ' 0,025  120                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8A018FD-A9C9-41E8-98EA-E0195C853237', '6E927D83-7B3D-4895-97B5-182DC434B172', '4602228000693', 'Sanitaplast   1  10                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F61D122-3ECA-44E5-95BA-F49F73B08B66', 'F98DEFEE-82FC-4B3C-B383-BEA12706A90B', '4071300156403', '   30  /                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF97342F-B3FC-4595-9498-D680F10F5724', '6D4333C8-47A7-4869-860F-12D608F17438', '3850114224017', ' /  60                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7821924-C78F-4238-B643-CE0542563FF3', 'D2B73A66-96B7-4A05-A6B3-6AC6CC91D6BE', '4607005933652', '  - -10 0,9% 10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A11066AE-FB2A-4A7D-89FA-7B3A1D9A5566', '904E50EF-9AA7-4883-AA97-6AD5DECEB9EC', '4600828000303', '  0,9% 10  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41D4AB8E-BDB6-476B-BC43-209F5BF4FD00', '904E50EF-9AA7-4883-AA97-6AD5DECEB9EC', '4602212007035', '  0,9% 10  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('351DA9B5-FC77-4701-A59F-3DA33969CF9B', '904E50EF-9AA7-4883-AA97-6AD5DECEB9EC', '4602824001278', '  0,9% 10  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CDA76E2-DCC4-4CE1-8D95-DCC0DE65E83C', '904E50EF-9AA7-4883-AA97-6AD5DECEB9EC', '4602824019426', '  0,9% 10  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ECD89B1-C46B-4099-92C6-EA9AFD326877', '904E50EF-9AA7-4883-AA97-6AD5DECEB9EC', '4602884003168', '  0,9% 10  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6919873D-4487-445E-8BE3-5E5CFAC6E468', '904E50EF-9AA7-4883-AA97-6AD5DECEB9EC', '4602884015475', '  0,9% 10  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5DFFF24-BED9-4361-811E-579AC6E189A8', '904E50EF-9AA7-4883-AA97-6AD5DECEB9EC', '4603988009018', '  0,9% 10  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7550AC8F-56E4-4606-9E9F-3827413AAD7E', '904E50EF-9AA7-4883-AA97-6AD5DECEB9EC', '4605310010624', '  0,9% 10  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41E3DD3A-DF57-45D4-8D9A-BBF8C8A70062', '904E50EF-9AA7-4883-AA97-6AD5DECEB9EC', '4605453003347', '  0,9% 10  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F6C3A9C-5261-4C49-8FC9-7F97B561202F', '904E50EF-9AA7-4883-AA97-6AD5DECEB9EC', '6930169706427', '  0,9% 10  10                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D35B7E6-9D17-4483-BD41-13EAB6757FE7', 'E781A80C-62D5-4835-9375-98A72E63F140', '4680013242190', '  // 0,9% 10  10                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('089F4FEC-B1E8-4B88-AE62-F60744B6FCFE', '23F831F4-EFFE-466E-8698-9DE54B87604C', '4607002340088', ' 5% 2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CA0BBDD-6736-40D7-ABEE-3C78E94606A9', '23F831F4-EFFE-466E-8698-9DE54B87604C', '4670000360051', ' 5% 2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35761438-959B-4A92-9457-9D30C744F297', '075F3E1A-984E-419B-80B6-8640C4563CE8', '4603188001256', '                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('384508F7-0B88-4AA7-8BFC-A38FBFE9E2D2', '075F3E1A-984E-419B-80B6-8640C4563CE8', '4605086000027', '                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9541BF17-93A2-4D49-AFEC-A4DE5995CF83', 'ED628B7C-D891-4215-B07D-5B3B6C26EE99', '4670003600710', ' 510 / //  /                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55899B9E-0D73-4E29-9491-6ACABABD35B9', 'ED628B7C-D891-4215-B07D-5B3B6C26EE99', '4680381003331', ' 510 / //  /                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0656B769-99ED-4253-A4E5-60D7EF2E5498', '6DC00872-57CA-4557-B3AB-564F951D635A', '4011548002971', ' 0,05% 15                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('414CE338-52C7-4139-AB24-DB43912C014B', '6DC00872-57CA-4557-B3AB-564F951D635A', '4011548020760', ' 0,05% 15                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('658999B7-4B90-4216-BEAD-3F537F8CC2E0', 'BD1947D4-5290-4783-9F80-D2B4B9817FF6', '3400970000951', '   6                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('971951C5-8F79-438B-AE4D-2C90A6891109', 'BD1947D4-5290-4783-9F80-D2B4B9817FF6', '3400970000975', '   6                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B48B7CAB-6D11-4727-A281-0D3E2E5CCFF6', '70A88E88-7E9E-472C-82D6-34412EEFABE3', '3838989500122', ' 275   10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F0214FD-D6DC-4FD5-9800-761EE091A07B', 'AAB1A829-0DB6-4D9E-8496-3211BA6EBD8C', '4602242002055', '   125                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('032571D0-D367-4B66-B63F-D5BC46ACC26E', 'AAB1A829-0DB6-4D9E-8496-3211BA6EBD8C', '7332343001295', '   125                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28A1943E-4892-452B-B5CC-A0063D387A98', '71A502C3-1A5F-401B-A5A4-E1BAC348CA46', '5060038500014', 'Ola    100 /  /                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A86B66DE-2344-4E77-A547-0F42FE25D11D', 'BAB78E64-293F-4F1B-AE2E-C501B9DCEE17', '5060038500038', '    50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEA928DA-EDDD-429A-BB01-6CDE55B81A01', '8BFD2CB3-B358-485A-94B9-145518627C76', '8588001193867', '   80                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F17F38EA-9513-4CC0-9D36-18BD76F47B64', '71B09311-F39F-4D4D-9AB2-CBB474234FB9', '3582910000044', ' 0,2  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A67CC62-A979-413F-B53F-6B1E32BC478B', '71B09311-F39F-4D4D-9AB2-CBB474234FB9', '3582910022183', ' 0,2  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('519A43F3-6AD5-4D2D-9E3D-B66ECDA4931C', '9F9E338F-7CE1-4503-8D10-F57A8E2EB3BE', '4607045191760', '    10                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74BFDAF2-97C6-4426-A8AA-20EFDDDBC066', '727B02FB-DD26-44F9-A671-FDF575D8535D', '3800009121075', ' 170                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF5433BB-FD3C-48ED-83EB-0AD5693727E0', '727B02FB-DD26-44F9-A671-FDF575D8535D', '3800009121082', ' 170                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57F49571-8B59-4AE5-902C-624E1DDDB624', 'FC22C9B9-7F91-4281-A451-88BA8032AA0B', '5900257035013', ' 0,05% 10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06A3F875-F37C-4261-AEE6-35544CDFF1F7', 'FC22C9B9-7F91-4281-A451-88BA8032AA0B', '5900257037192', ' 0,05% 10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FF8FEE1-8DF8-468C-8C44-14773BCACF54', 'A59EC8D8-1438-43CF-ADEB-C6050A67F5EE', '4605554000290', '  60                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BFB5062-951E-41F6-A934-96A364655A45', '740EDB26-FB6F-444C-ACCA-120207AF6F73', '4602546003666', '  / / 10%  - 20                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6E4346B-4698-4F28-997F-E6496BFD8C8A', '740EDB26-FB6F-444C-ACCA-120207AF6F73', '4603933002903', '  / / 10%  - 20                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AA36669-A6AB-4EBB-B848-CAE33B065EA6', '740EDB26-FB6F-444C-ACCA-120207AF6F73', '4605059004007', '  / / 10%  - 20                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('245E8180-BB53-4413-ACA4-1119602FBE11', '740EDB26-FB6F-444C-ACCA-120207AF6F73', '4605059007466', '  / / 10%  - 20                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AC2BC0B-62E5-4C3C-8E74-CD332C471650', 'BAC27367-D7EB-48C5-A978-916A6DE29452', '4602876001202', '  ( ) 3,44% 50                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C746E2AE-CD45-4D95-B013-F24F0782A652', '23F0C91A-478F-4D3A-BEA4-E063EFB88558', '4601607000194', '  / /  - 10                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('413EC011-31FC-4387-834B-6F8AF6111439', 'D1E7606A-6E3F-4093-A2F2-F8783E912FAF', '4602876004746', '  3,44% 10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF05F265-9666-4911-85A1-05F2422007B4', '5227DAD4-3D9C-4B47-B38D-A247CCDF8626', '4602546001518', ' 25                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3297539F-1D00-4AE0-A008-D70F5959AB21', '5227DAD4-3D9C-4B47-B38D-A247CCDF8626', '4603184001663', ' 25                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE92C399-F761-4563-9F72-E0C7BFA64C61', '5227DAD4-3D9C-4B47-B38D-A247CCDF8626', '4603373001016', ' 25                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50850A9E-5FA0-4AA4-A42C-3A5798DAEC78', '5227DAD4-3D9C-4B47-B38D-A247CCDF8626', '4603380000880', ' 25                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B82C7CE7-F2B2-4F66-BF26-0BD1AC3AA095', '5227DAD4-3D9C-4B47-B38D-A247CCDF8626', '4603905000319', ' 25                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79306D4D-F02A-4BC9-BF91-9119CC5AC709', '5227DAD4-3D9C-4B47-B38D-A247CCDF8626', '4603933002682', ' 25                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F0B760F-388C-4A05-981B-C8C92B6F86FF', '5227DAD4-3D9C-4B47-B38D-A247CCDF8626', '4604171000300', ' 25                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC83F359-8FF4-42F4-BBE7-1197483D52E8', '5227DAD4-3D9C-4B47-B38D-A247CCDF8626', '4605059016536', ' 25                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D6207FA-EA1D-48F8-B356-050EF414CBA7', '5227DAD4-3D9C-4B47-B38D-A247CCDF8626', '4605059018172', ' 25                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98A49E38-4922-4203-BA66-DE2478399CB3', '5227DAD4-3D9C-4B47-B38D-A247CCDF8626', '4605404001736', ' 25                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D39FB777-2BBC-4F3B-B630-CBADF96F6BE7', '5227DAD4-3D9C-4B47-B38D-A247CCDF8626', '4605903000650', ' 25                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B50E794-D9C8-4241-9BBB-094CB1DC161D', 'C9E0740E-B94B-4CEE-B06F-668222341E1E', '4603933002699', ' 40                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37A3CC80-DE8B-4E4F-8DE1-E7BEA6DF0929', '74194AE3-CE2F-482D-846C-8F18A2412B47', '4603933003009', '  (.-) 3% 100 -                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AEE5806-7482-441F-AA91-BA3061F1CA65', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4602737002034', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B9EB473-E75A-4E23-A2D5-40A22C06C4FE', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4602902000407', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D74226E-4D3C-4791-850F-7ED183372C4B', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4605147000034', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36206BEC-DA3E-454A-B6BF-422EF5F6CE73', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4607130520017', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('972E6318-D59E-41DF-BEBC-9CF792243723', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4607130520147', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD1F04EF-68FE-455C-9B2B-E3302F9937C9', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4607145960266', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD172B74-9F2A-4AF9-9C39-40B6D266E22E', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4607151710268', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22D52DF7-66B6-404A-97E9-C5F9621DE210', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4610010010249', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25AE4026-BA06-48F0-B88B-69E26A0DE16C', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4612741480438', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11C0C0E7-98E2-4074-BC46-D9E8ED6C0A7B', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4612747430208', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0144FEF7-1A29-4C5D-84E2-E5587869C1E6', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4640000900144', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01F719D8-6059-4173-8AD5-AC30701C44F2', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4640000902445', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9504DD60-153A-4EFE-9A02-A558630FAAA5', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4670003605296', ' 510 /                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18B0F31F-01CC-447A-8872-007A48153D2C', 'D3B7F5AA-5E31-4BD1-B8DA-3A2CE568E5F7', '4750258314676', ' 0,05  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F317342-A9DC-4D1F-8C26-591BD1005319', '94E9ABE1-8F44-40F7-93DC-0E79FDDB73A9', '3838989505721', ' 400  / 20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A1A6ACC-F44D-4C02-8E32-734BF7AA8CCE', '94E9ABE1-8F44-40F7-93DC-0E79FDDB73A9', '4605635001505', ' 400  / 20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8BE59AB-139A-4A77-8E9D-DC729DA2CBB3', '94E9ABE1-8F44-40F7-93DC-0E79FDDB73A9', '4607055130162', ' 400  / 20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4604D77B-D56C-48DB-87DC-CA8141FFB655', '94E9ABE1-8F44-40F7-93DC-0E79FDDB73A9', '4607055130261', ' 400  / 20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74150068-B9FD-4B06-AE90-0FB3259FDF01', 'F25DFC89-40F6-4005-BC91-99729600EFE9', '3838989529871', ' 400  / 10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('950CDCFE-0C62-40EE-9BF5-564EBD1C0CC6', 'F25DFC89-40F6-4005-BC91-99729600EFE9', '4605635001499', ' 400  / 10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8C68928-87C1-42F0-BE35-442A37F3AF19', 'F25DFC89-40F6-4005-BC91-99729600EFE9', '4607055130254', ' 400  / 10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E4A82E2-21CA-4083-8D39-A57A69BE8E38', 'B513AFFA-B6C6-4EC5-A939-27E59C5F2E4B', '4601498005650', '  2 20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8E6D784-159A-4BF1-A4B0-B5B54B79AB9A', '1BA3C661-91E4-4387-A8DE-4F8CC9FAC665', '4750258026142', ' 0,025  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13DB1BD8-DE1E-4119-95FF-262C09856E7A', '1BA3C661-91E4-4387-A8DE-4F8CC9FAC665', '4750258202263', ' 0,025  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB306428-BBFF-4958-900A-1C59E5E75246', '1BA3C661-91E4-4387-A8DE-4F8CC9FAC665', '4750258314669', ' 0,025  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37E3A35A-C04B-475A-B902-29CFEF9D2AE6', 'B394DAE6-BD25-42E1-82C0-AC80520AF97F', '4603619000155', ' 1% 10/   30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('624EC823-2136-44F6-86AB-55EB9D99F3F8', 'B394DAE6-BD25-42E1-82C0-AC80520AF97F', '8901086130211', ' 1% 10/   30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD11ACB1-B7B4-4D6D-BC7A-E42BD3D1E223', 'B394DAE6-BD25-42E1-82C0-AC80520AF97F', '8901086131317', ' 1% 10/   30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B78DC47-E9D5-4C68-9796-F0B4F5347AC9', 'E464B6F6-E7AA-41FC-8105-4CDC10046A01', '2400004747204', ' 100  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA4CFC46-0A9E-4700-9CF8-0E4B8FFC10A5', 'E464B6F6-E7AA-41FC-8105-4CDC10046A01', '4603276008099', ' 100  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('745BC399-6F7A-4F55-804D-E70FB7E5EC46', 'E464B6F6-E7AA-41FC-8105-4CDC10046A01', '4750258314195', ' 100  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B734BEB-76F9-47C9-8837-BE9E0F37F880', '2D1B9BCA-EEB8-434E-A5FF-EB1F7D6BFFDA', '4601214002376', '  1,5 / 20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DCA5BAE-51D7-4020-A619-28100637BED1', '2D1B9BCA-EEB8-434E-A5FF-EB1F7D6BFFDA', '4601498003762', '  1,5 / 20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACEE0932-464A-45B2-A43B-F1A6A62B3473', '2D1B9BCA-EEB8-434E-A5FF-EB1F7D6BFFDA', '4603762005991', '  1,5 / 20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92F6566A-F866-4747-BC04-D18D23E18BEA', '2D1B9BCA-EEB8-434E-A5FF-EB1F7D6BFFDA', '4605126003285', '  1,5 / 20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A688664B-E7AE-4BFE-A988-5538FAD7FB35', '75593BDE-1490-458E-8CF1-E30A5E124765', '4607011631290', ' 0,01  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('635BC505-DEE5-4C11-93FE-49E1B6ABEF6F', '75593BDE-1490-458E-8CF1-E30A5E124765', '4607027762278', ' 0,01  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD277432-1976-454D-BB83-14BE1F451DE1', '76C7DC31-87C9-4800-A61F-6095AD7FA7F1', '4602809006182', '   10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1EAA661-E62D-4FC5-AFA2-97F73D5325FF', '76D05D75-AA7C-456C-BC64-D70028663D99', '4605501000069', '  10                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B10532F9-DEA5-429B-822A-759490E73305', '773DA459-B607-410C-A966-9D0EB37FFB07', '4602884002239', '  25                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1CF5864-B918-431C-B42B-BBA0A13A90D6', '778F98E5-90B9-4A77-87E2-EB4A865D598D', '4607027766290', ' 0,15  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC46F774-E31E-4FB5-9EEF-A4C0A0287726', '778F98E5-90B9-4A77-87E2-EB4A865D598D', '8600097300407', ' 0,15  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('245A32AB-787D-446E-9CF7-4AE1B1CB1D74', '78162489-C1F4-4A55-9CBF-F2F123E53977', '4600053008990', '  10% 25                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA2D5818-5461-4227-ACAF-C29AF4448691', '78162489-C1F4-4A55-9CBF-F2F123E53977', '4605059001495', '  10% 25                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07BF6A98-364A-49C5-9AC2-10BC79221741', '78162489-C1F4-4A55-9CBF-F2F123E53977', '4605370000115', '  10% 25                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1BCC0D8-C835-4540-B371-E85FBA5A3B48', '5EB67F82-CC51-4EDD-8595-CAF6E6B12CBE', '4607098451248', ' 500  / 10                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C95F12F-C1B4-41E4-A077-1D3ECCE52FB0', '8B0FEC3E-224B-4E99-9159-2A3E8ACD4ED3', '8901168228010', ' 0,5  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70EB2209-6ABE-464F-A17C-873BB938D303', '789BD4D5-D82A-4E89-AF26-8148DA1B1AFC', '4603679003264', '* 50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A88A89F-8042-4D29-9152-8556EBE05584', '78A6A63A-9247-430D-AD66-E9581028B324', '4601669006967', '   20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED00B602-9A52-455E-9ED3-2F4590357D69', '78C7C149-FA10-4F87-922A-DBD192F9AC22', '4602509006369', ' 0,5  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B319D66-2E42-4255-868A-C476C0C2EDBF', 'B39ADD98-FCD3-45AC-A60E-826C62A0CED2', '3870010002717', ' 0,2/5 90                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2AACDFC-C5A7-44E4-AA1A-6A81D5C28F5C', 'F923E0C8-CA9D-41AC-9A60-B0451E12F166', '5700666018887', '  7                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FDA4FAD-3094-40CD-8235-DF1D70755779', '796E318B-BA94-401D-8F87-0C9756FF3035', '4008500120057', '-  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F42DFF7B-5A6F-40A7-96B6-EDA6912AE2B2', '32C14740-7DB4-425E-A723-D18E16D2EDD4', '4602193008618', ' 250  2                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F218C72-1CD2-47E9-8C7A-F257DD4E5E06', 'A457A141-E360-40D1-81F1-2969152DEC71', '4607001010739', '-  4                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('782E8ED6-69E9-4EE6-BEB3-A99851619E6F', 'A457A141-E360-40D1-81F1-2969152DEC71', '4607001011736', '-  4                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38B665B8-71F2-42E4-838A-3FE7A3F21D00', 'A457A141-E360-40D1-81F1-2969152DEC71', '4630017310098', '-  4                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B68A9F83-9165-49BB-A70A-E25E205EB8D2', '04B2C231-D27C-4062-87F7-CA0F46E3DA37', '4602193009912', ' 0,25/0,01  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CC9C8F1-4C85-483C-8579-867E1CAC48B8', '7A3250EF-5A0B-47F0-92F5-D7628FF9E03C', '4601214002970', '  1,5 20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74B8F13E-A429-4400-883D-53CA4ACB53F6', '7A3250EF-5A0B-47F0-92F5-D7628FF9E03C', '4601498003809', '  1,5 20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E904A7E1-4233-4012-98C1-F6E19313E0EB', '7A3250EF-5A0B-47F0-92F5-D7628FF9E03C', '4603762006028', '  1,5 20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3492B9DD-7B1B-462C-B5C2-B0B2EBD5AFB0', '7A3250EF-5A0B-47F0-92F5-D7628FF9E03C', '4605113001218', '  1,5 20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F69A8451-FCC3-443D-A1B6-56669C3B7F5F', '7A3250EF-5A0B-47F0-92F5-D7628FF9E03C', '4607061508245', '  1,5 20                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AACB66B8-AF43-4DF9-8FD6-C728747D84A0', 'D49B0433-5FED-40F3-BFDA-3DAF264AAE1C', '3838989501235', ' 0,004-1  25                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE324620-8AC7-40FD-A3DC-8308EFB8B4A0', 'D6CDEB1D-9446-49AB-A6D3-3743787E7CD7', '7680263960346', ' 10%  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2495719E-8547-4C50-A3E3-7B92F3424EFB', '5EEA2860-85E1-4196-A225-171F793F90A9', '4601026306303', '   1,24 10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('137CE7D4-14A3-4308-8038-2DE7E110ECF1', 'FBE4D0C8-36E2-4DD2-8330-11BA8DCE8B90', '4605964002693', ' 76% 20  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('855573C0-1F98-4FF6-9697-057AE8F23185', 'D829366D-943C-4CF5-A358-9C0179DDAB8F', '8901083020133', '  5  5                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F643011-4E6B-4387-AC15-E6A0752B321D', 'D829366D-943C-4CF5-A358-9C0179DDAB8F', '8906000572177', '  5  5                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A982C33-DE20-4819-9C9C-F6AF734F053B', '2E303A14-9C0E-4B34-8C5A-E2C662B2D1CA', '4603373000279', '  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('077D6897-F9AF-4829-918F-F1A0AA3364EA', '2E303A14-9C0E-4B34-8C5A-E2C662B2D1CA', '4603933004440', '  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33C521F0-7405-423C-8885-510FBA948986', '2E303A14-9C0E-4B34-8C5A-E2C662B2D1CA', '4605404000944', '  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3BE3E42-F724-459F-AB6B-1814C83B534C', '2E303A14-9C0E-4B34-8C5A-E2C662B2D1CA', '4620006501682', '  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9DE403B-0773-489C-AE9D-109BEE243D8A', 'ECB3CB43-F185-4DF4-8289-212DC9DA171F', '4602930004354', ' 0,01  30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6A47D46-F0C5-46C4-9DCC-9AAB81EF27EB', 'EF52FD0F-F1C0-4C31-9EF0-D88543FFB068', '4602193011182', ' 0,1  10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1611BBC2-0881-48CD-8F71-5A72F13E6099', '42B04B96-0AA0-430D-8F9B-0F446FEF29C0', '4605180000077', '  50                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7D4F7E5-C677-40DE-B5A2-E0B5FEA93888', '42B04B96-0AA0-430D-8F9B-0F446FEF29C0', '4605180005638', '  50                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFBDD4F3-1064-485C-9D4D-E62CF89D999C', '7BE0CD17-8511-4B7D-A923-E65628097D2C', '4600828001256', ' 40  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DEB6570-AA8E-4246-A475-2E3AE5A29E8F', '7BE0CD17-8511-4B7D-A923-E65628097D2C', '4602424003474', ' 40  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C8A6318-0521-4585-AA71-3D0A9728DFD7', '7BE0CD17-8511-4B7D-A923-E65628097D2C', '4602565016852', ' 40  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDB410AC-2AAA-4344-B230-65B383FF0132', '7BE0CD17-8511-4B7D-A923-E65628097D2C', '4602884005704', ' 40  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CB06E36-3AEC-483A-99E0-D92FDB511C00', '7BE0CD17-8511-4B7D-A923-E65628097D2C', '4603182002150', ' 40  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('312E66F6-6E2F-48A4-9498-E7748FE1C08E', '7BE0CD17-8511-4B7D-A923-E65628097D2C', '4603276003025', ' 40  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87BEE637-E669-4190-A546-F62504F684A5', '7BE0CD17-8511-4B7D-A923-E65628097D2C', '4604060998435', ' 40  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEFDD5CB-BA9F-4C7B-AB23-40F482031DD1', '7BE0CD17-8511-4B7D-A923-E65628097D2C', '4607027767198', ' 40  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8671D9A7-5CAC-4AB5-8BD4-919791DB7805', '7BE0CD17-8511-4B7D-A923-E65628097D2C', '4607100620228', ' 40  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3AB583C-9C9B-4DB8-A228-8A48FCEDE432', '7BE0CD17-8511-4B7D-A923-E65628097D2C', '4810201002316', ' 40  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8C4C674-0AB5-49AD-9BF4-53C4FC83BC61', '7C5C4D30-9171-40EF-AC90-23B07C520DC5', '4602196002446', '   40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50DE6018-BEB7-4AF0-8687-95C97E0367EC', 'F4D6A68F-8B76-4F69-B903-0099752D69BA', '4029799116255', '   60                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81C2AE97-DA1B-4BED-9A10-E33F454A5BA9', 'B61B2474-7FE8-4497-A651-C7FA073D1248', '4602196002385', ' 19  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BE1EDD6-06E9-4D48-927E-0685969DC683', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4601429004523', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEACC9C4-0CF8-415C-8C8F-498AA6841197', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4602329000158', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B7595F9-0955-4633-9943-826F08DEF49D', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4603184003308', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C82B7CC3-4161-4CD5-8259-EDEEBBC1DB35', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4603256002314', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42E0A178-A79D-496A-B4FE-C28E51F52F39', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4603373000590', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C43709CA-118B-490C-8B37-DD127991D1DF', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4603380000194', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('042FB888-37C7-49FD-A536-012151ED0C66', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4603380002471', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('405D184A-0189-482E-B7EE-26C40A81C83A', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4603905004324', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68363473-1467-4A76-ACC5-97B00B716D65', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4605180002989', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B092523-9FD3-428C-B0F0-264678C4EE18', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4605180005263', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12186466-BD50-47E6-8220-D73B43031940', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4606351003545', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F15CB43D-CF7D-4A26-B873-EB85526D3B28', '7CA8EAA4-E715-4CC9-95F3-D23ED44B324A', '4606683001370', ' 50                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('830949C2-81CD-47A8-ADF4-EAAC06831791', 'C37B403D-C407-49FD-9DD8-CB7B93ED0357', '8901086131065', '    20                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('437DB351-E499-45DD-9527-FA7A0CB3C142', '7E203B24-892C-4679-BF59-F43A58B174DD', '4607085318707', ' 3ok 25  14                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAA5798D-3C83-4CCD-89E1-681FEE5A805C', '7E3B0C90-B44B-436E-87FA-99F787A2D27B', '4605077000449', ' 0,002  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABED4A15-365B-43FA-A8E6-C4CE729DF296', '7E3B0C90-B44B-436E-87FA-99F787A2D27B', '4605949000195', ' 0,002  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AECDFCB9-28D6-4621-8124-0A948CEEC5B4', '7E3B0C90-B44B-436E-87FA-99F787A2D27B', '4607022750348', ' 0,002  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50FA5E62-BD07-430F-B592-5BDF58855EC7', '7EC3D82B-E228-4E43-B48D-EA712F482123', '4601429002253', '  15                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E689FDD-71EE-4402-BA40-7AFDDA1805B5', 'B1CEAC01-6A32-410C-8405-2FE296DCA458', '4016369660942', '            00-025-281 75                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB2DFD35-9246-4292-B977-F85331DAC097', '7ED209C4-14A5-434C-BEBC-7BB29AED52DE', '4607174650121', '  20                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('516817B6-0603-4E0F-9CC3-5783843DC358', '7EEA5F33-114D-47B8-A392-15F6805CAA2E', '4602196000480', ' 0,2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D51C4C4-791C-4CCD-82EE-294EC0768C2E', '7EEA5F33-114D-47B8-A392-15F6805CAA2E', '4602809006380', ' 0,2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18411C4B-11ED-4AA2-BF05-A47C6A87C31D', '7EEA5F33-114D-47B8-A392-15F6805CAA2E', '4603276005999', ' 0,2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('425E03C9-8836-4DB2-AD60-BBB65C17F924', '7EEA5F33-114D-47B8-A392-15F6805CAA2E', '4604060071121', ' 0,2  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0988875-07AE-46DE-A227-A35BF48E0DAF', 'A66E7192-EC1A-4469-BDFD-FBC6EA93A7A6', '4602242002185', '   30                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E7C5582-AF0F-44D5-850D-C47D7E262631', 'A3B9D791-785D-4AB7-8061-C05CD0CBC95D', '4607004430480', '  / /  10                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73D47656-C8CF-4306-AABD-ED0042E08592', '6C5F757C-6B72-426A-B1CE-DBADBED94745', '8934901730037', '   5                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('834F52FD-0904-421B-9535-4432094281AE', '80823E13-695D-4F3B-A565-CD2853628972', '4602242000921', ' 0,15  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2BF2EC5-1032-4ABE-91D1-8597EDC56DA8', '80823E13-695D-4F3B-A565-CD2853628972', '4602242004677', ' 0,15  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1CE75CC-3CFC-4D90-B62E-A36646B34544', '80EA7B3E-C31C-4DE9-A7A4-7C6443D9B716', '4605180006260', ' /  / 50                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82A94C84-D625-4581-8DD1-91A345189CCE', '819EEBA0-DFC8-45AC-A460-8F5554206894', '5900516401405', '  "bella cotton" 100                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C6EDFAB-575D-4721-9E1D-C15BBD3B7FA6', 'C8427F11-677D-4977-8464-EC124D583501', '5900516401474', '   80                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('828CC41B-0ECC-4712-95C2-1DE7E983496B', 'D56529E8-7E96-4DA7-B5B9-62B55DDFCF8D', '5900516401450', '  25                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51E3DEC7-3839-4582-9090-30315CF8A1CA', '832FA302-386A-4762-B7C2-00105A57CCFE', '5900516401498', '  "bella cotton"  100 ..                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('022094EE-3114-4BED-8C43-31B723E2F942', 'B764F9C6-D6D1-461F-B942-4BE7075A0E84', '3800009121020', '  170                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0F50AFB-CE11-4175-A20D-22BC2A12734D', '82816FD0-3018-41A7-AA4B-AAC6174D5D19', '8717627104135', ' 500+10+200 /  /   10                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB9A5387-DDDA-4AE7-A41E-42382F54D767', '8318BB04-5ACF-4E21-811C-89436EF8400E', '4602565005788', '  125                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC4B0BF3-5EF4-44CF-841B-66F04472658D', '8318BB04-5ACF-4E21-811C-89436EF8400E', '4605180005867', '  125                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51FFFE4A-3051-4862-A9A3-E0B97143D88E', '84181B98-1553-4008-93C9-654B290DCC37', '4603905003167', ' -  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09F85836-6D69-47B8-B05A-6E7D3F21F254', 'BECF40A3-ED16-4E0F-91AC-5984D195BE4A', '4603905013098', ' 10% 100                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28AF9277-5EE1-4BA3-BE62-B07E55CB4FF3', 'BECF40A3-ED16-4E0F-91AC-5984D195BE4A', '4605404001347', ' 10% 100                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B73029E5-8C38-4210-B340-FF5BD179BE31', '0478B9D0-34B0-4852-A2EB-927BF4869FDD', '4603988009056', '  3                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06A882CB-F64A-4A28-BD71-462518651520', '0478B9D0-34B0-4852-A2EB-927BF4869FDD', '4620008620053', '  3                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBCBEA74-F196-485F-B782-06E374CC32FC', 'D3EEC32D-9195-4C65-970A-CA436B55C88F', '4602196000558', ' 40  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8C7B73F-3F23-4181-9278-2C60B9EF663F', 'D3EEC32D-9195-4C65-970A-CA436B55C88F', '4603182000095', ' 40  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('395B3B03-1CD7-46B3-AE36-0E6D918ED9C9', 'D3EEC32D-9195-4C65-970A-CA436B55C88F', '4603276006545', ' 40  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D811A39-88BC-4D38-86FB-EE35DF881502', '84B6B857-AD35-46DC-8E8E-593D066D6318', '9006968001340', ' 15/2 100 - /                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9318214B-8C99-4C35-813E-635F00B6315B', '84B6B857-AD35-46DC-8E8E-593D066D6318', '9006968011479', ' 15/2 100 - /                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50FCA2CD-607C-4890-B849-11321BFDA3EC', '84DBFBE2-85C5-4307-A964-1DB7AE5BCA02', '4601619000687', '  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC68F415-3A5C-49C1-8371-F61A4CAB6C20', '84DBFBE2-85C5-4307-A964-1DB7AE5BCA02', '4602480000905', '  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A97C0377-8ABA-4FCE-BE14-7F8264694273', '84DBFBE2-85C5-4307-A964-1DB7AE5BCA02', '4606939000027', '  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('118D71EF-6FAA-4BAE-B3F8-257F952B244C', '84DBFBE2-85C5-4307-A964-1DB7AE5BCA02', '4606939000317', '  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4B88E13-5810-48DF-9956-82F11A536102', '84DBFBE2-85C5-4307-A964-1DB7AE5BCA02', '4607074610249', '  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A76D09B-6E39-488B-956A-62AE72EDFF65', '84DBFBE2-85C5-4307-A964-1DB7AE5BCA02', '4620005420045', '  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89E867A5-9018-425D-AD09-23702ED22989', '84DBFBE2-85C5-4307-A964-1DB7AE5BCA02', '4820031540117', '  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD777CCB-0F5E-401E-9CC3-9F97C7E11D70', '84DBFBE2-85C5-4307-A964-1DB7AE5BCA02', '4823017802902', '  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B777D567-E071-4250-A1BA-38717311C1C6', '84DBFBE2-85C5-4307-A964-1DB7AE5BCA02', '4823017805101', '  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A14E428-D723-4049-8036-0AEE547F2D62', '852BD112-DA9F-4381-85D2-AB0FEB2A9687', '4607006670457', '  // 16                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34562D5B-BD38-4C35-94C6-327D871D944D', 'B8ED4794-A9B6-416C-9AC7-408474BBFE7A', '4607006670495', '  // 16                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('114DB678-CDB2-4CCB-BE45-F24B813A5450', 'EA721516-4244-474C-BBD6-C7767E0A528D', '4750232000731', '  5 -  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FD92822-6DF3-40AE-B7D0-52F2541AD86B', 'B93340F0-5738-46DA-B056-3E6F2D765A20', '4602676007534', ' 50 2  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72CA420C-AF91-4216-ADFB-0F05CEE73CCF', '85B4D154-D13B-432E-B48B-C10A6554196B', '4603730001277', ' 0,01 / 1,5 -  3                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('989F2A1F-B95D-4E47-932A-C09AAA05F915', '85B4D154-D13B-432E-B48B-C10A6554196B', '6936187400309', ' 0,01 / 1,5 -  3                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67BDA0C5-5C4F-4DC2-A3CD-6C70A8505024', '86213EAC-11A3-466C-82CB-DC67A6166575', '8594737207211', '-  100 -                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F7DADC7-5FFD-4E56-8168-D047466E207D', 'D9FB7828-0FED-43E0-8F4C-42D3DA1645BE', '8594737170317', '- 0,2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70D0BCAD-CDE3-42DC-8AFC-D7291598786F', 'D9FB7828-0FED-43E0-8F4C-42D3DA1645BE', '8594737211317', '- 0,2  10                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('881C1E43-4E40-4FE8-B076-DA4E971CDB43', 'BAC6F226-B85C-455D-855E-23C69CBCD337', '6916119020225', ' 5% 1  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('584F4882-2925-4D20-A04F-0F9AD11D2B87', '049DEE75-7AD4-40B4-9313-7C5C7F64470C', '4602824000387', ' 0,05 / / 1 10                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('970C9E2C-AA1A-4FC2-B7CE-F41361865859', '049DEE75-7AD4-40B4-9313-7C5C7F64470C', '4810201000374', ' 0,05 / / 1 10                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF7EF761-692B-445E-BAFC-F73F6865F403', 'BB961CFF-8878-4AAF-BC21-252F65F73106', '4602196002217', ' 0,05  / 20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6269628-CF42-466A-AFC5-62865AC04649', '86CEE91F-684D-4155-922B-56C8869ECDD7', '5904374005973', ' 0,48 20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47A289D4-8D17-4D12-9823-008FC1C77E5D', 'F10470FC-49E2-4AF9-ADE0-1C5D77C915C4', '5904374000992', ' 0,12 20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86067647-9F5E-478C-8DB3-844373983A2E', '86DE9779-7CAA-453A-935C-6795C2952712', '4607027763695', ' 0,05  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D85FAF4-D5F2-41D5-AC8B-4DE7A9769EDC', '86DE9779-7CAA-453A-935C-6795C2952712', '4607143560222', ' 0,05  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D18115A-3C59-4DB6-BF92-EC3E97501E51', '870E80F9-6FCC-4750-BDE2-EDFBA0289E67', '4602242004165', '     0,2 20 ()                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2532C41-F202-495D-BAE2-45D515D99A13', '15B6C6BC-A74F-4EB7-B72F-8533BA02B13C', '4607055560235', ' - 2                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D2C6BB6-C3A1-418B-8D13-A3CFCE2C132E', '15B6C6BC-A74F-4EB7-B72F-8533BA02B13C', '4607055565209', ' - 2                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C497642-2DC0-4DE0-90ED-4B200ABF1FB5', '873236E3-C07B-4C07-AF49-3CB55040D625', '3582910130055', '    125                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90257C24-8849-4C44-A657-F9F2027587DB', '873236E3-C07B-4C07-AF49-3CB55040D625', '3582910130147', '    125                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('971CAA03-42F4-41E9-8C0B-9B6410A08CB6', '873236E3-C07B-4C07-AF49-3CB55040D625', '3582910131052', '    125                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E582F43-8BFB-4C4F-918D-3078906EB47E', '873236E3-C07B-4C07-AF49-3CB55040D625', '4601026308383', '    125                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85CCD136-6F8B-4A52-8D96-00843EA401D8', '873236E3-C07B-4C07-AF49-3CB55040D625', '4601026308499', '    125                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0D15952-94EA-47DC-BB65-938C00BFA2B6', '873236E3-C07B-4C07-AF49-3CB55040D625', '4601026308741', '    125                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9E1DBDC-1B29-416C-99DD-1A9A671D33D1', '197DA98D-B024-46EB-8679-E7334E2A74C2', '4601214000396', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13E67121-218E-4E33-92E6-C8C0F53FC825', '197DA98D-B024-46EB-8679-E7334E2A74C2', '4601498007135', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEC2AAC7-D698-4115-A3CC-EE312AE5D337', '197DA98D-B024-46EB-8679-E7334E2A74C2', '4603762000118', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD4AA885-B9EC-417B-9966-71FA049846A6', '197DA98D-B024-46EB-8679-E7334E2A74C2', '4603938001451', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5ABEE94D-87B6-42FE-87E1-1080CEA451BC', '197DA98D-B024-46EB-8679-E7334E2A74C2', '4605113000501', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61E445F0-5FA5-4E57-89C4-1BA472737358', '197DA98D-B024-46EB-8679-E7334E2A74C2', '4607066260728', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFECDA69-DFBC-47F5-9A95-B83B72F8EB2C', '197DA98D-B024-46EB-8679-E7334E2A74C2', '4640001381317', '  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DA978E6-42BB-44BE-96FE-535C4851C75A', '539A8010-58B4-4F7D-BA6A-FC6CAC81589C', '4601498007203', '  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9B8E4A3-CE0E-474D-8CFF-7AFD7C2DE000', '539A8010-58B4-4F7D-BA6A-FC6CAC81589C', '4607066260179', '  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65FB81F5-FCA8-4F84-9188-CDCC638C726E', '539A8010-58B4-4F7D-BA6A-FC6CAC81589C', '4680002552224', '  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF34D727-8C5A-47E4-B28B-26EDA11D5C30', '969674FA-50B3-4E4A-BF70-A742501A1A42', '4603276008785', ' 10  / 30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B636F52-1BB0-4E1D-8FBD-AA9B72434AFB', '969674FA-50B3-4E4A-BF70-A742501A1A42', '4605949001543', ' 10  / 30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B9B254F-331D-4A11-80BA-95784FED18DD', '969674FA-50B3-4E4A-BF70-A742501A1A42', '4607003244675', ' 10  / 30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11D18249-B7FF-4012-9943-A77443E418CE', '969674FA-50B3-4E4A-BF70-A742501A1A42', '4607020330795', ' 10  / 30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('723ACB80-54C7-4605-A2BF-37CE8A48DEF2', '969674FA-50B3-4E4A-BF70-A742501A1A42', '4607027765040', ' 10  / 30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF87AF2E-D51F-48DD-B73E-11EA5C29C63B', '969674FA-50B3-4E4A-BF70-A742501A1A42', '4823004502457', ' 10  / 30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E88B376B-0534-45D9-BF8F-7E399A2E4491', '969674FA-50B3-4E4A-BF70-A742501A1A42', '5995377701047', ' 10  / 30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2332ECBB-BB7C-4B00-807D-F99481DE3660', '0F8D5F04-DCB0-4482-8A3B-2AF7445EEB42', '8906000574683', '   10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8506C8F2-700B-4D88-8BEF-56E8C3D3E646', 'E419A456-46E9-41BC-BE63-F959EAEAD924', '4603933003108', '  100                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('156D9C82-49D8-453A-B939-3D01B5218C14', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4036534201039', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58939C21-48E5-42C2-A7A6-CF95D8B6E36A', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4036534201077', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('136955C2-C4B2-4CCF-8AD1-5D641B419FCF', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4036534201084', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4536B28-FA15-425C-A6BF-3C6111C872FB', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4036534201176', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06AFCB71-581D-40C2-85FD-6224148965D9', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4046964105418', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09CFE839-F6B5-4580-972B-C7B15F38CA9C', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4250431908093', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2DC221D-C4EA-4C81-8945-AA4CFB7086C9', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4250431908550', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B2F6244-B9EC-4997-B119-CAEA71901A9C', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4250717500072', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5F8E70B-489A-4981-82AF-A03C1C1DB81B', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4250717500584', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D29E2F7-C3AC-46E3-A2AB-CCF25569ADFC', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4260090441169', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29BBECB1-7EA0-4E81-9A25-F6FF76BD8C23', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4260090442739', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B797A50-E0E1-4AFF-B14D-0B40BB181EDC', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4260090444498', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('330F22A8-F61F-41F4-9995-6E33BC60AAD8', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4260090445303', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13BA8B1B-0C9A-4428-AD10-71A6D02F52AE', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4630000910045', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('002AE1B8-34AB-4923-AC69-CDECF96B2923', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '5009612920039', ' 3                                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32AE002F-5F24-4950-97F4-A288FC06FB03', '8B694962-C7F6-4E5B-A7DD-05CF59E21CE4', '2400004762559', '-  100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32B13DA8-B706-4DD8-8A02-3C8A2E80BBF4', '8B694962-C7F6-4E5B-A7DD-05CF59E21CE4', '8906000573549', '-  100                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB60628B-A521-4904-B36A-368808EFB630', '8BDC516C-2A3D-4613-B595-6C43F4E5733B', '4603905001477', ' 2 /                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54F4EFB3-3405-4E56-BFE5-AAC9BC2F062E', '8BF619B2-0D4E-4195-9815-F16E665DF49B', '4602824000745', ' //  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F57B3E9D-F0FA-48D8-A9C6-2DAFF5B89538', '8BF619B2-0D4E-4195-9815-F16E665DF49B', '4602824005115', ' //  10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDDD02AC-FF39-40C4-8203-AADDB51F150C', '8C7C2811-18FE-4DA5-B0B8-767AEF208AA3', '4602676004052', ' 0,05 /// 2 -  10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8440233-9ED3-49DB-959B-4BC57BD2F217', '8C7C2811-18FE-4DA5-B0B8-767AEF208AA3', '4605894001339', ' 0,05 /// 2 -  10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E622E9DA-6B2F-4B37-A616-8CE37B3A94CF', '8C7C2811-18FE-4DA5-B0B8-767AEF208AA3', '4670008161469', ' 0,05 /// 2 -  10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACA85D80-F024-4918-B657-2467CC46D751', '8D36A455-3D59-49F4-B307-70831601EC2C', '4030674001573', ' 0,005  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F76F0E73-A53D-4C37-9BB9-2801A7F4BC01', '8D36A455-3D59-49F4-B307-70831601EC2C', '4030674014092', ' 0,005  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('971BF5FD-A22F-414C-BC70-2BC679B495B2', 'B09EC990-0C25-4B29-B76F-43694D2BF7F1', '3592752066993', '    15                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('349B61FA-BD21-48D1-AF0C-9F22A9FE4E3C', '8D43FD76-8B87-44BA-B1EE-2D7F80EB7B5A', '5907525348790', '  1000   20                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBFF767D-4064-4A60-93EC-55A0B73E629A', '8D43FD76-8B87-44BA-B1EE-2D7F80EB7B5A', '8600097301350', '  1000   20                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17D77FE8-B540-4814-BE4A-DEF463ABC1AC', '8D43FD76-8B87-44BA-B1EE-2D7F80EB7B5A', '8606013060011', '  1000   20                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FB09ADA-7E64-4E01-AA40-3BF7CF9098B5', '8D8843E0-1C07-46E6-956D-ECDF79A3EB52', '4601429001096', '   / 1,47                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EB4FF18-1266-467E-A9F3-4BE0D17B6D84', '8D8843E0-1C07-46E6-956D-ECDF79A3EB52', '4605180006529', '   / 1,47                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94BD2BEA-3888-404D-8EE7-378948E53C77', '8D8843E0-1C07-46E6-956D-ECDF79A3EB52', '4607004430572', '   / 1,47                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1D668C1-1448-412F-A3FA-FFD89E432314', 'B9370438-38EA-4805-84B3-B7A3D0F12701', '4601429001102', '    // 1,7                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E05E8FA-B9D5-40AD-B6BB-373A72C45DAB', 'B9370438-38EA-4805-84B3-B7A3D0F12701', '4603905003488', '    // 1,7                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80EF1386-04B2-49A9-BFA0-67F22B129DB5', 'B9370438-38EA-4805-84B3-B7A3D0F12701', '4605180006512', '    // 1,7                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38EB8884-F3AB-4D57-B338-BB179E2C818A', 'B9370438-38EA-4805-84B3-B7A3D0F12701', '4607004430602', '    // 1,7                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B05B596-8378-4243-8E24-0BBFACA23766', 'C6BCADBC-8F1F-40B0-9825-4F79573A8AC7', '4603905003495', '   / 1,47                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06E3A64D-5240-4275-84CD-595189130E06', '87655047-158E-4ECE-B533-4D5320170307', '3800010629416', ' 40  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0EA1008-F32E-4BFD-B035-D2E9437EC1A8', '87655047-158E-4ECE-B533-4D5320170307', '4602284010834', ' 40  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6FBFDCC-623D-4776-8CDC-44330E9B8E3C', '87655047-158E-4ECE-B533-4D5320170307', '4607027765002', ' 40  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D3494B5-F61A-4C25-8E5B-E854848F63B5', '87655047-158E-4ECE-B533-4D5320170307', '4607027766313', ' 40  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C547013-0906-45B6-BD8F-6CEB063AEAD3', '8DBF6325-173E-4122-95B3-D006E573CBF7', '4602424005041', ' 0,2  60                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AA35150-7364-42FA-B7B3-6F8900A37488', '8DBF6325-173E-4122-95B3-D006E573CBF7', '4602876001875', ' 0,2  60                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B40FE863-246A-41A4-8730-5AD68D9F0959', '8DBF6325-173E-4122-95B3-D006E573CBF7', '4607027762230', ' 0,2  60                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B9F19F1-24C6-4568-BF08-FC4E113454BB', 'AA349101-E311-4E67-80B9-08E2E32E8856', '4620004740014', '   3% 100                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40F80E73-31A4-45F0-A138-F013ED4DFE9F', 'F7AD8F24-09A5-43FF-89CE-080C4431B38A', '4600828005278', '  200 12                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8295EAB9-3D96-4E11-943B-F2B78C97A677', 'F7AD8F24-09A5-43FF-89CE-080C4431B38A', '6921665001048', '  200 12                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F34B4FAE-F49B-4B4E-B17C-58688AAF5058', 'D44EF9AF-C4FD-4833-BD44-9873596AE54D', '4601669004208', ' 0,15  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('939A7936-2828-4BB7-AA08-48C3EED01496', 'D44EF9AF-C4FD-4833-BD44-9873596AE54D', '4602424000411', ' 0,15  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05B868D2-D45A-4D8D-9975-A6C7CB1BE9D2', 'D44EF9AF-C4FD-4833-BD44-9873596AE54D', '4602884003052', ' 0,15  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE7BD549-3EBC-42D7-94BC-B4439EC815F8', 'D44EF9AF-C4FD-4833-BD44-9873596AE54D', '4602884004561', ' 0,15  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52BFB8E7-84DD-462F-939E-832F492334DB', 'D44EF9AF-C4FD-4833-BD44-9873596AE54D', '4603179000848', ' 0,15  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10724713-1356-475C-BD5C-430C5D1ABDF8', 'D44EF9AF-C4FD-4833-BD44-9873596AE54D', '4607100620693', ' 0,15  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A3223F6-413C-46E7-AEF3-DBDE8ABC1BF2', 'D44EF9AF-C4FD-4833-BD44-9873596AE54D', '4810201002309', ' 0,15  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91D4AC7A-6ABD-419E-BE44-CE2AB24D1D97', '9001A99D-B450-4891-A713-CE893D599E83', '4600828002697', '  12                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C56ACCD8-F91C-49BD-9643-CB0E8D0A5310', '9001A99D-B450-4891-A713-CE893D599E83', '4603679000560', '  12                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10077997-4ACD-4EDE-A89A-37CEA845A1F5', '9001A99D-B450-4891-A713-CE893D599E83', '4610004580321', '  12                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE00B724-C23A-4B17-AA0A-D8AD72CD8D4C', '8F3BFD72-2124-4315-9755-79B3F532CEE3', '4013054002902', '  2,5% 30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('768E1213-A1E2-4C19-9F81-00073D65AF9D', '8F545FBA-88C8-4998-8508-F967314ED578', '4607146760131', ' 0,5  / 3                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C20160E-ADC8-4A47-A2FC-1BABC1D69D42', '8FBAA059-59ED-4AED-BD8E-A36952F08C32', '5000158100220', ' 0,2 24                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB31B13F-0AD0-4409-8A9D-1704DBDFFCB0', '9060504F-6226-40C7-9F32-5F4C5DD26173', '3838989541262', '  50  / 60                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC162C3F-3D35-4EA6-A3E9-AEBC8533C265', '9060504F-6226-40C7-9F32-5F4C5DD26173', '4607055135389', '  50  / 60                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F13B33B-2D9D-4A29-AA19-1CDA8BB54421', 'B8EED219-958F-432E-869E-292B78BA6962', '4640000902490', ' 1016 /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B2618F6-3267-4473-930E-B85A0CE13A97', 'B8EED219-958F-432E-869E-292B78BA6962', '4670003600796', ' 1016 /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E63844E-6534-4C70-B8FD-B1460D0BA109', 'B8EED219-958F-432E-869E-292B78BA6962', '4680381006288', ' 1016 /                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D101FE5-F4C2-48A3-9B3A-C495E7B49B51', '91BA9C91-4A0B-43B0-BC81-EA092F8448F7', '4607083724920', '/  / /  20                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF20F2AC-32FA-4751-B533-D26D22FD5AFB', '9257409B-F1B1-4419-AC9E-3BDD75C3B669', '4602737000207', ' 1614  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1684376B-256A-4930-A6E3-DB311B5DD433', '9257409B-F1B1-4419-AC9E-3BDD75C3B669', '4602902000773', ' 1614  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C0EC0F0-B920-472E-8874-11EF16311B44', '9257409B-F1B1-4419-AC9E-3BDD75C3B669', '4607109940297', ' 1614  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C646C45-B789-46A4-8B1C-7B8E4320CF9E', '9257409B-F1B1-4419-AC9E-3BDD75C3B669', '4640000900571', ' 1614  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBD7154F-1F5D-4574-BD07-FB6FBEC1F154', 'FF6359DF-EF48-43E9-9B3E-9C3ED6FCF657', '4602260007773', ' 4529  5                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70A16145-AD67-4E06-97C8-9240F8612ACD', 'FF6359DF-EF48-43E9-9B3E-9C3ED6FCF657', '4602902000766', ' 4529  5                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A9FC394-A1F5-49B0-8337-65B193848EF3', 'FF6359DF-EF48-43E9-9B3E-9C3ED6FCF657', '4605147000225', ' 4529  5                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79BA1B49-9E6D-4F9E-B8EF-F8F1FD4EC3DD', 'FF6359DF-EF48-43E9-9B3E-9C3ED6FCF657', '4607109940303', ' 4529  5                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8293E5B-753A-48CE-8AD3-8A5D4E2D5DC0', 'FF6359DF-EF48-43E9-9B3E-9C3ED6FCF657', '4640000900588', ' 4529  5                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D049D50B-34C5-4D78-94FD-1D87A5BCAFA9', 'FF6359DF-EF48-43E9-9B3E-9C3ED6FCF657', '4640000902612', ' 4529  5                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F5E5ACD-F1A1-4EBE-B1CA-405365297180', 'FF6359DF-EF48-43E9-9B3E-9C3ED6FCF657', '4680381003553', ' 4529  5                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E21C240-10C2-465B-A07D-CE9FBFF7F16D', '92BADC07-C6BA-4FB6-A483-AA86682E513C', '4601669000552', '  0,5  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29FFBD05-1E43-4B42-B2CB-F79061FFE305', '92BADC07-C6BA-4FB6-A483-AA86682E513C', '4602809000166', '  0,5  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB90AA15-6E41-4157-8415-B681DE970FE1', '92BADC07-C6BA-4FB6-A483-AA86682E513C', '4602884000846', '  0,5  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A937F8A7-536C-49A5-92A2-37DBB089728D', '92BADC07-C6BA-4FB6-A483-AA86682E513C', '4603182000231', '  0,5  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC8FEB18-8D4C-405C-8007-5B710CD5ABF6', '92BADC07-C6BA-4FB6-A483-AA86682E513C', '4603276005586', '  0,5  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29227B01-65F8-4372-A5C5-71A13BAAED94', '92BADC07-C6BA-4FB6-A483-AA86682E513C', '4603988001173', '  0,5  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FEAEFD5-7E42-4DCC-826D-0893C3536395', '92BADC07-C6BA-4FB6-A483-AA86682E513C', '4604060251059', '  0,5  10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF872184-261A-4BBA-AEFF-B0B73251EDAB', '942FF41A-7BE0-4EE8-9AAF-F30CFC934347', '5000158103351', '  0,2  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C46C322E-0132-4B4F-9EA8-BB6CAC761C5E', '948EB7BD-43ED-4632-A1E6-4F64C1C789D3', '8584005101105', ' 0,005 //  30                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB7C7F62-79EE-41C2-B894-8F81419B5BC1', '51AAEDE1-4C32-4105-A441-9D6F6E750FF5', '4605095006041', ' 100  ( ) 3                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE6E96A8-13F4-4675-99D8-7DE1DA71CB5C', 'E23865FC-2F4D-46F5-9DC1-3BBF7842B59D', '4605095000254', ' 100  ( ) 1                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFF83A57-0BDF-4277-9950-04AF635E5292', 'E23865FC-2F4D-46F5-9DC1-3BBF7842B59D', '4605095006034', ' 100  ( ) 1                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A18449D-AA11-4E39-8895-670D80F24E33', '5F8B3628-635F-488E-940A-0F7AB352EB5A', '8901236004607', '- 0,1% 5                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77BCFDEB-E2B3-426E-BC31-CEF12DFD322A', 'E78697D7-C653-4E3D-AC4E-1335A4355C90', '4602565011079', '  0,1% 5  -                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BEA15DC-1CB6-4382-BCAA-D3F30D182BC8', '955EAEE4-CF32-4ECD-9712-6C95DB6E6FA5', '3800010643450', ' /. .  100                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72FD1C61-4D63-4828-8AD6-2CF84D2C3298', '78E23DCC-3596-48B4-BA25-E45A9EF15A17', '4603988010847', '  1%  - 10                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6884D09-5D1A-4851-B475-7E69480348BD', '972F24B7-71DA-4BD2-A092-16431DEBDA32', '4607085310916', ' 0,125  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA2B98BF-2171-44B9-B966-2AE062CCB5DC', '972F24B7-71DA-4BD2-A092-16431DEBDA32', '4607085319421', ' 0,125  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77EA77F8-4B19-4EBC-B8DC-D58059CA9B74', 'A191718E-3A7F-4791-B8A3-B61BF8E0F050', '4607085314266', ' 0,125  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D9D5B99-FAA5-4DA5-B6BB-F2183A32C263', 'A191718E-3A7F-4791-B8A3-B61BF8E0F050', '4607085319445', ' 0,125  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80DB0A70-0475-4765-A4EF-DDFB9893E016', '97C08E27-32CD-46F7-B934-54B9B9A13A6E', '4607085318714', '  50  30                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77E0B6DF-EA39-4187-9002-B59E9F940F80', '97C08E27-32CD-46F7-B934-54B9B9A13A6E', '7321838740184', '  50  30                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18E95582-6119-40BC-9AD4-C8A7F4662DB6', 'CEE4C8F4-E680-4E13-A50C-4FBCFEFAB085', '4013054001370', ' 0,04  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85C0B5C6-0184-487B-99E9-86B7BE85E56E', 'E9AE5DC5-F680-4001-8D69-226D6A41E3DF', '4602233005065', '   /     40                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81A1DD62-CA8F-4318-8CB9-AF79C2DBB516', 'EF3D7754-09E5-4BDE-B625-C5D1F7A909F6', '9006968011882', ' 15 5 100  / 157,55/                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C88F9E9A-4136-4ADE-8A4C-B64288F62316', 'C115FB8E-56D7-4E10-9A7F-DB995A6BB8A3', '4600828001911', '-  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B42DAE4-CE10-4111-997A-922E2A818D0E', 'C115FB8E-56D7-4E10-9A7F-DB995A6BB8A3', '4601669000668', '-  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA547431-1211-4133-9551-CFEB6EB9CC1C', 'C115FB8E-56D7-4E10-9A7F-DB995A6BB8A3', '4602809000135', '-  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CEAF762-C143-434C-BFB3-34DEE542F8EE', 'C115FB8E-56D7-4E10-9A7F-DB995A6BB8A3', '4602884004936', '-  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63CE3F63-89C6-4A97-83BC-08ABD549CDCD', 'C115FB8E-56D7-4E10-9A7F-DB995A6BB8A3', '4603276001779', '-  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A32845DF-03B1-4905-AC78-152E524E97B1', 'C115FB8E-56D7-4E10-9A7F-DB995A6BB8A3', '4603988011271', '-  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BC542D9-38B4-46A4-9396-C456C835D574', 'C115FB8E-56D7-4E10-9A7F-DB995A6BB8A3', '4604060081328', '-  10                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B75F68B-6DE6-4E2E-AF2B-DDB5A2493EE7', 'A0201406-4179-4C69-9361-5D68ABA47614', '9557955001015', ' eamination powder free                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7685D11D-D3CF-410E-B0A7-DD5E5B7F34E2', '9AE9B428-AF17-4892-802B-A1AE11DFAA0B', '3800712745810', ' 0,01 50  /                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91D80F99-56F9-4F7D-B070-F71F77EB78C0', '9AE9B428-AF17-4892-802B-A1AE11DFAA0B', '4607027762636', ' 0,01 50  /                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('687023EE-B606-4389-8609-11BD06CEC2F8', '9BCD6E6D-8D5E-4949-92E6-7ACB83B6EC76', '4602884000143', '  15 3%                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2545A752-9D34-4137-B9DB-F929FB221BF3', '9CA5B794-6CE5-457F-ABBB-1445F6764094', '4602233002569', '   5  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('525D9361-CFCE-4C00-821E-6270A5DFAA5A', 'B93E9EB7-060E-4EBF-B84F-25E0BB43CAA6', '8901148227903', ' 1%  50                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E895972-09E9-484F-831F-B9D178E4722D', '9DB65A7E-57D5-4A44-B2AC-45C8256ACE71', '4603905003235', '  1  25                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC33017C-6450-4813-A747-04ED1FA13B5F', '9DB65A7E-57D5-4A44-B2AC-45C8256ACE71', '4606683000632', '  1  25                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5C0272E-8818-45DB-A16D-9D269D1AA3C0', 'B188A58E-D191-4AD8-A370-5CDEC3D49FD5', '4603256004585', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DF5C484-F222-46F7-A943-24C33D5EC806', 'B188A58E-D191-4AD8-A370-5CDEC3D49FD5', '4603905002436', '  25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21383D6C-F546-40EA-AD6B-696FD9820497', '42EBFF43-9454-4DA0-A174-92684CC150C6', '4607131040286', ' 0,15  1                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8CB46AD-1481-42BE-A788-B00DA0B2C27E', 'E9884C67-0C47-4652-AB15-65F69D7B7A69', '4605077006946', ' 0,5  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB4FA6DE-01E4-47DE-84AE-F077C5A9D3C7', 'E9884C67-0C47-4652-AB15-65F69D7B7A69', '4607003244248', ' 0,5  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E867A10C-CA49-4B41-A597-C0572A96595B', 'E9884C67-0C47-4652-AB15-65F69D7B7A69', '4607027768096', ' 0,5  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12065751-31D8-4B36-BB49-8788008C9214', 'E9884C67-0C47-4652-AB15-65F69D7B7A69', '4607146760490', ' 0,5  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D4798C1-11FB-480C-B433-6C615F547059', 'C8F4567C-D818-42DC-9136-89CAD6847187', '4603933003023', '*  0,05% 100                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48DB0D11-E783-4F5B-8E79-71560FF69EC6', '86F915CF-5AAE-44B6-A227-E0D791CAC0F3', '5900004073121', ' 200  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B85A86D1-9E46-4A93-AE92-7A693DA946FB', '9FD34209-11E6-4E56-9697-9B250881331C', '4603679000713', ' 25  10%                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA98ED95-5382-4312-99A6-E2DD6114464D', '535AE536-DD37-4EB8-A0E9-3AD810D33589', '4603256000631', '   25 -                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CED103E9-2B65-4FE0-90C9-C4B0EF1056BB', '535AE536-DD37-4EB8-A0E9-3AD810D33589', '4603905002962', '   25 -                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6301A051-42D9-4E60-BC67-635A3DE0C5B5', 'A012691F-81C1-441D-913A-83B320CAC75B', '8901086040220', '    N20                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEE1DAA9-FC70-4F3F-9897-869934F800E7', 'D44BCDFE-2778-498B-AC5C-3862D1783D3A', '9557955001022', ' eamination powder free l                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81201F83-C7AD-4D0A-ABD3-C90FD551C878', 'ED86EBCB-ADAD-475B-9B2E-240844A3FF83', '9557955001008', ' eamination powder free s                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B628D46C-06F5-40BB-A937-04A809797F9D', 'DFB85DE6-F842-4CBB-9DB9-366D974D3D9C', '9120029750432', 'Manual rn709 .. m                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D7BABE6-0317-4060-825B-2539493D9A67', 'A4F4B3F8-E910-4DF8-A1DD-CB54A434ECDE', '4607101204441', ' 3-                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E5F67D6-D631-495E-ABF3-315ED2FF1814', 'A4F4B3F8-E910-4DF8-A1DD-CB54A434ECDE', '4779033720112', ' 3-                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC1B3F0D-404C-4C6D-ADE1-215D7DF9CF44', '16B9E783-AA4B-4B7E-B403-8DBCB79511B2', '4607050210036', '                                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E0664D6-E5B3-4A76-8266-CD3B0F332CB7', '16B9E783-AA4B-4B7E-B403-8DBCB79511B2', '4612734310056', '                                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('955CBB26-8542-4B17-8797-64A2960A60DF', '16B9E783-AA4B-4B7E-B403-8DBCB79511B2', '4620764310687', '                                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE0FB5AA-6331-45F2-8E79-6D2C5DDFAE87', '16B9E783-AA4B-4B7E-B403-8DBCB79511B2', '4629978990234', '                                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDDBD403-52D5-4AD4-A805-79950F68A379', '16B9E783-AA4B-4B7E-B403-8DBCB79511B2', '4640000904951', '                                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FD3BE0B-96C7-4C5F-946A-EC290C5829C7', '16B9E783-AA4B-4B7E-B403-8DBCB79511B2', '4680003692622', '                                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB5D6358-300F-4981-BCC1-3ED2D634553B', '16B9E783-AA4B-4B7E-B403-8DBCB79511B2', '4680003692868', '                                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DEB066C-0D28-4043-8FC9-2EB4539698B5', '16B9E783-AA4B-4B7E-B403-8DBCB79511B2', '6938807000524', '                                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44969CC0-0E72-4284-BF4A-5B664C24F8CD', 'A113661F-6DF7-44BE-8214-12B2118F166A', '3850114234016', ' 100  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B36AAAC8-1FB4-4E3A-BE35-01E355DE4522', 'A113661F-6DF7-44BE-8214-12B2118F166A', '4605077007806', ' 100  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('467D2713-1196-4ED8-8A29-CE6C21B9E58F', 'A113661F-6DF7-44BE-8214-12B2118F166A', '4607003669850', ' 100  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30098372-5154-43F6-A726-6C6D5E636296', 'A113661F-6DF7-44BE-8214-12B2118F166A', '4607027763879', ' 100  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F72F4A9-2489-48A9-9978-AF941D2E0416', '62C63EC8-9DB5-40D8-9834-AAA1AE176930', '4607098450227', ' 100   3                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB666C9F-E712-4D6A-B697-2DA99CB3671A', 'A2031272-0234-4B98-B327-D8F3EA788138', '3850114227988', '   12                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('393CDE81-5AD5-4711-8A4B-F275C3BCC383', 'A2031272-0234-4B98-B327-D8F3EA788138', '3850114237031', '   12                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FAA7CEC-4E6E-479B-91AA-1FE1FE456879', 'A2971134-E11F-4F6C-90D2-029AD393D6E7', '4600728005422', '   //  1 20                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B4660DD-020F-4EE4-B912-77F911172C58', '7B003FA3-F7F5-461D-B71D-625873F52638', '4600728005460', '    4-   / 1 20                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC28BC47-711B-47FA-802D-DBD02128C495', '7B003FA3-F7F5-461D-B71D-625873F52638', '4600728005910', '    4-   / 1 20                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06F6ACBD-D740-4A8E-9F87-88C45A057A6D', '52866090-7646-4352-83B3-83B541A6C374', '4600728005361', '      3- . / 1 20                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80008734-2460-49CD-B1BA-ABE313C684FF', '1D922234-B9EF-4AEF-A090-010D83EADDA8', '4600728005446', '   /  /  1 20                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDA18D67-BBCD-41FD-9885-E0B199C5A3B9', 'B2D4B23C-0E31-4B64-8990-BCB7BC5BC0FC', '4600728005385', '     1- .    / 1 20                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18EA9837-6877-4634-B5D5-CB3156769CF4', '8539EB27-1812-456E-A9CB-40BAD0836541', '4600728005408', ' / ,,  1 20                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D787D0C8-520E-4497-A9AB-C5E6E45A040A', '0A2D0542-8107-41DC-80C9-E0445607BBC1', '4600728005347', '      /  /  1 20                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C079A9E4-BB44-40EF-BCCC-887B30C827EC', 'A2C5A2A5-FA54-48B4-8714-A0D7A3A05561', '4602876004685', '  0,05   10                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C16921F0-DFCB-4BF3-8016-7BDDA2E4E44A', '56F4BDC0-B80D-4475-A532-EEC8DC2B1348', '4601026017018', '   10                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93FC927D-B7FA-4848-AB1A-C37948D8739C', 'A398968E-FB98-47A5-B3E7-DE583299829E', '4013054003329', ' 30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FB9C3B8-97DD-40E2-9C34-094D69D782BB', '0AB8C64E-3880-4B33-BC36-75530DB80448', '2400004703248', ' 5%  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0745817A-FA37-4074-B78A-7CA613F0E185', '0AB8C64E-3880-4B33-BC36-75530DB80448', '4250369506620', ' 5%  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A590E9B4-13F4-40C2-94BA-7453494B5B7C', '0AB8C64E-3880-4B33-BC36-75530DB80448', '4601907000078', ' 5%  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8DD205A-C768-4E8B-96B6-BED0563CB076', '058EE3FC-4D11-4070-95A4-C9CF62AAF3FC', '1800023823216', '  / / 100  10                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1D0E360-50BA-412B-A5E1-700E8230DD07', '058EE3FC-4D11-4070-95A4-C9CF62AAF3FC', '4602876003305', '  / / 100  10                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8278CC86-3ECE-4F87-82B4-86D0F23D755C', '058EE3FC-4D11-4070-95A4-C9CF62AAF3FC', '4602957000605', '  / / 100  10                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('327098D1-4CE2-4CDE-90D7-67167EFE64EA', '058EE3FC-4D11-4070-95A4-C9CF62AAF3FC', '4603679000430', '  / / 100  10                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00667B01-883C-4D80-BB72-C3DD20F6B6C8', '058EE3FC-4D11-4070-95A4-C9CF62AAF3FC', '4608816003305', '  / / 100  10                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('860CBA31-D782-411D-ABA0-30981CE5CEFB', 'E05E7558-7A3F-4EAF-A747-78D9D1C77F47', '4607004430473', ' 0,2  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E5F0A93-8843-4E04-909F-43854D2D8CD0', 'BD2C59E1-C0B3-4880-B26C-6B8642E04091', '4603679000126', '   50                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75441E84-62B2-49FC-AA19-8ADDA19B6EAD', 'A474A23E-C4E6-41D4-9EA6-671984C8DFB8', '8901083060139', '  40                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('493354FE-DE0F-4B62-91C7-7ACB08BE8D35', 'A4B4DD1E-B97E-4191-B021-9B9F59B5D275', '4601969002102', ' 2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1F583E3-E4DD-46F8-BB6B-2792BFED4A6A', 'A4B4DD1E-B97E-4191-B021-9B9F59B5D275', '4601969007183', ' 2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECD333F9-6E4F-4B0D-ABE8-FCECE5920697', 'A4B4DD1E-B97E-4191-B021-9B9F59B5D275', '4606252000643', ' 2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30F6FBBC-0B7A-4C2A-8910-AE088419E21D', 'A4B4DD1E-B97E-4191-B021-9B9F59B5D275', '4606252003316', ' 2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CEDCAE2-FDD8-47F0-9516-69102C90E402', 'A4B4DD1E-B97E-4191-B021-9B9F59B5D275', '4607005890856', ' 2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF8B23D8-34BD-4568-8E1F-345931AFEE6C', 'A4B4DD1E-B97E-4191-B021-9B9F59B5D275', '4607143560574', ' 2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51C78290-D5AB-40EF-87BE-F670FE598A2F', 'A4B4DD1E-B97E-4191-B021-9B9F59B5D275', '4610012020079', ' 2  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3CCD5D7-5B6D-4169-80BD-02CE91FF9626', '694A5962-92F2-420B-B58A-25C2B790BE13', '4607101201754', ' 1                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D233A978-BE28-43CA-AFD4-D4D94BAA5571', '694A5962-92F2-420B-B58A-25C2B790BE13', '4607101204472', ' 1                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E7DFF2E-AD38-4E98-B1EE-FCEE07312CCD', '694A5962-92F2-420B-B58A-25C2B790BE13', '4612747430284', ' 1                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA595822-D3CB-4601-B1F4-0DAE17CD9033', '694A5962-92F2-420B-B58A-25C2B790BE13', '4627082100013', ' 1                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1074392E-0047-437F-A6F6-B36542F30E27', '694A5962-92F2-420B-B58A-25C2B790BE13', '4680003690260', ' 1                                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3C7A769-3C74-4661-8755-4B79E3E4FAB2', '3EE6D1E1-1199-4F59-9F30-01D2CA3F4E00', '4620764310120', '   //                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8693AA2-85FF-40B6-9D3A-6999FC06627B', 'A54FC293-1F57-4C27-B658-56D24DE1ED96', '4602509002811', ' - 5% 2  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79EF251A-AD47-4EA5-9E6C-71C6C183D2F6', 'A54FC293-1F57-4C27-B658-56D24DE1ED96', '4602824014995', ' - 5% 2  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C30A1B5E-4477-4009-8BE0-6D3E90CB6E67', 'A54FC293-1F57-4C27-B658-56D24DE1ED96', '4602884000747', ' - 5% 2  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A64FA633-2236-4B16-8E6F-7AF3A65145AA', 'A54FC293-1F57-4C27-B658-56D24DE1ED96', '4602884014034', ' - 5% 2  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31D763C4-548D-47B3-BFE0-D8A12136DB20', 'A54FC293-1F57-4C27-B658-56D24DE1ED96', '4602884014058', ' - 5% 2  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7403A79C-9F06-4887-B76A-962A691A0829', 'A54FC293-1F57-4C27-B658-56D24DE1ED96', '4605453001374', ' - 5% 2  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61BEECF5-FDC2-4C6F-AF47-3A53B47523F3', 'A54FC293-1F57-4C27-B658-56D24DE1ED96', '4605894001063', ' - 5% 2  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9F78143-462D-4AF0-A2A6-207DD12F532F', 'A54FC293-1F57-4C27-B658-56D24DE1ED96', '4810201001494', ' - 5% 2  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA4FE86A-D1FD-4000-9F0F-04225749F6C8', 'A54FC293-1F57-4C27-B658-56D24DE1ED96', '6930169707516', ' - 5% 2  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BE0685A-1DF3-466B-B8FB-1C1E74278B8D', 'A54FC293-1F57-4C27-B658-56D24DE1ED96', '6930169717706', ' - 5% 2  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67D8676E-FD75-42B4-A576-A78A459EEC9D', 'A54FC293-1F57-4C27-B658-56D24DE1ED96', '6938588802232', ' - 5% 2  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF40639E-0B52-4D04-9F03-7C0E36DD23F2', '94C371BA-4644-47F8-BF80-E9177D116F21', '4600828001638', ' 0,04  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFB52099-041A-4115-BAFD-78DD253A0C0C', '94C371BA-4644-47F8-BF80-E9177D116F21', '4602196002156', ' 0,04  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('904B396A-B065-437A-A692-FD2F88B5EB81', '94C371BA-4644-47F8-BF80-E9177D116F21', '4602884005544', ' 0,04  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('886894FE-CAEF-4F99-9E48-9D21233A4984', '94C371BA-4644-47F8-BF80-E9177D116F21', '4602884010234', ' 0,04  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A4A6D26-B824-4289-A510-E053D5851E59', '94C371BA-4644-47F8-BF80-E9177D116F21', '4603276000864', ' 0,04  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FB52B04-8C36-457F-8344-1FBD78754F55', '94C371BA-4644-47F8-BF80-E9177D116F21', '4603276005975', ' 0,04  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('754F50EC-5A5F-4F45-AB01-5EEFB42ABB3E', 'A5E86ABA-EF33-4D89-9413-5B6C205BA2D4', '4605738000139', '  // . 30                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0B519CD-DBAF-40B1-BF3C-C523CDC133BD', '040DF9DA-29D4-4D2D-9EA3-2AAD84B2B327', '4607104131027', '  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D22A4C11-5503-488F-B5C2-0081390CA4AF', '040DF9DA-29D4-4D2D-9EA3-2AAD84B2B327', '4610010011451', '  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF1C2444-1B9A-4575-8C90-796781A9D203', '040DF9DA-29D4-4D2D-9EA3-2AAD84B2B327', '4620001090297', '  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('815905B5-CD55-4F6E-9328-822E96FF4DD5', '040DF9DA-29D4-4D2D-9EA3-2AAD84B2B327', '4630010960207', '  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E7BC048-0877-4339-80A2-111CC359B927', '020F2676-906C-4856-99F0-69466DA5E893', '4607118050413', '  25                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC480958-E0F0-48C3-AA3E-08B949DE1550', '020F2676-906C-4856-99F0-69466DA5E893', '4650001791184', '  25                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BC506ED-383E-49DB-BF07-13EAAA620DF2', '4F648269-EC05-49EA-A003-A9D07537D57F', '4607029291776', '  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA726FBD-3391-40E4-9B3E-BF2EC952E861', '4F648269-EC05-49EA-A003-A9D07537D57F', '4610010011529', '  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25DB777E-542B-448E-A24B-9728D7EFB318', 'A625DCE9-ABBF-4F67-9273-5610C41F4BA5', '4607045190213', '   0,1% 10                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EE4A473-ECCC-46A5-B10D-E75ABAD4C4CA', 'A7E1392C-7109-45E8-AB70-495FFF63F3F1', '4601669005762', ' 0,01  60                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F32FF925-8739-4CEC-8861-6F69A0F39260', 'B04BC5A2-854C-4006-94A3-CB580906EF57', '4650057490109', '  300/  25                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41B55AC8-DCD7-4B0A-A691-ACA66AEFE6AE', '71509469-98E5-4C4D-B9F4-ADD2E6B47DFA', '4650057490116', '  30% 50 -                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C92BFD4-F2A1-4E21-B670-7AB645A8FCA1', 'A7F864C5-7CD9-4B53-8D92-5A66252D7F65', '4603569721223', ' 0,004  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6080D19-7AA9-4FA0-9227-8DBEA6866711', 'A7F864C5-7CD9-4B53-8D92-5A66252D7F65', '4605964001207', ' 0,004  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('961F670B-FA2A-4D86-8A30-A5B0B9158F8F', 'A7F864C5-7CD9-4B53-8D92-5A66252D7F65', '6432100002761', ' 0,004  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('622B5DFF-50C5-404B-B004-4CD3F3D79337', 'ACCDC08A-F07E-4EC1-93B3-663449015DA1', '4605404000517', ' 10% 40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA1E84AC-3E58-4B9E-99FC-AC9DE77EA4D8', 'ACCDC08A-F07E-4EC1-93B3-663449015DA1', '4605404001132', ' 10% 40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27D80FD1-81ED-488D-B111-0FBC1565AE7C', 'ACCDC08A-F07E-4EC1-93B3-663449015DA1', '4607005390394', ' 10% 40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8E54343-A60A-4E01-9567-38907C8E452C', 'ACCDC08A-F07E-4EC1-93B3-663449015DA1', '4607007360609', ' 10% 40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FC17FC9-115A-4B3F-B82A-8980338E46E0', 'ACCDC08A-F07E-4EC1-93B3-663449015DA1', '4607007361507', ' 10% 40                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A6BAD96-8D98-45EE-BD11-7B77260E07C1', 'A864B505-4986-4F01-A29E-BBB4C7A665F9', '8901148023017', ' 0,0025  20                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7516CB4-A6E1-4487-BF21-DE0454E68E07', 'A8C42AB6-B29A-4FAC-928D-4F4446EB118B', '4030096114769', ' 2,5  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7392AEC-B323-4B57-92D2-30D745ED00A9', 'A8C42AB6-B29A-4FAC-928D-4F4446EB118B', '4607027764975', ' 2,5  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('928A755E-ED16-4494-9164-52EDB562A3A8', 'A8DB9067-A94F-46F4-AC8A-5B812D63F92B', '8600097300384', ' 500 //  16                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84939133-B492-45E3-98A5-EE4C0F25A920', 'A964FA36-F470-49D5-AB21-610963AF7F2F', '4603276003780', ' 0,05  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21D8B921-E3FD-458C-A05B-E680E35DB4A9', 'A964FA36-F470-49D5-AB21-610963AF7F2F', '4810201005096', ' 0,05  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAC927C2-48F3-4C7A-AA23-D1BD2B15D808', '33F1DAAE-2D02-466E-B2F9-038D22265766', '3838957090976', '5- 0,05  50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87C75F95-8508-4A01-86B5-1C09888A3BC4', 'A9B8C91A-EDF3-47F5-80F8-BE5E4403C330', '4602546002294', '   100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FE1397B-80B3-4D05-A084-5F87BD1AD75D', 'A9B8C91A-EDF3-47F5-80F8-BE5E4403C330', '4602546007909', '   100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CA12336-063A-46A4-A616-2AA946654CB5', 'A9B8C91A-EDF3-47F5-80F8-BE5E4403C330', '4603184003445', '   100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('689009BA-6256-43DF-832B-59B2F54A4A50', 'A9B8C91A-EDF3-47F5-80F8-BE5E4403C330', '4603256002635', '   100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FF0DC8E-4580-4584-AAEB-1B449DD217D1', 'A9B8C91A-EDF3-47F5-80F8-BE5E4403C330', '4603380000217', '   100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28548953-3570-446D-8E6C-C1F63B0FD46E', 'A9B8C91A-EDF3-47F5-80F8-BE5E4403C330', '4604060092010', '   100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D315717B-4837-46DD-AA57-E7375FA5FE1D', 'A9B8C91A-EDF3-47F5-80F8-BE5E4403C330', '4604060092027', '   100                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CA29E9D-8BB3-496E-ABE6-16C04962EE67', 'A31D51CF-4472-4A55-BFA1-40BA86C5ACAA', '4052199004143', '   .  7,57,5  /10/                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB9409A7-45BF-43FC-A190-EF0B4A4F90E9', '2D6445E4-0D21-40A4-AA79-4E1CA5FAF080', '4052199004105', '   .  55  /10/                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4569EACE-65DC-4BD7-B2A4-1B317CDD8C0D', 'AAA9FB28-A91F-4A5B-85B5-87ABAAC18A20', '4602565013851', ' 100  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('971D1131-6921-41E5-9EBB-B96B69DF1C47', 'AAA9FB28-A91F-4A5B-85B5-87ABAAC18A20', '4607027765101', ' 100  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F663CCB-5B3E-474A-9F37-13D15FD61408', 'AAA9FB28-A91F-4A5B-85B5-87ABAAC18A20', '4607047720586', ' 100  10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9D9C71E-B93F-442F-808A-852009E26D5E', '6E7DDAE5-E777-4042-881B-D720A84F5FB8', '4602196002408', ' 0,1  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8A40E88-4C1F-4D30-8FA7-D827D96EC149', 'F9600D12-4087-482B-9881-F9BE0D7482FA', '4602196002392', ' 0,1 20                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('184820AA-A6F4-45F0-AB44-39DF6BA6DEBF', 'AAABFE2A-8EE8-4365-BCEE-949A9C8DE386', '4601429000020', ' 15                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5179E6F7-45AE-4817-8D63-E721E04EE0D2', 'AAB95BBB-EACC-4E62-B99A-F69C0345F432', '4605469001689', ' 0,01  28                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BECA2D17-03FA-4E5B-9FC6-C4AD00496A52', 'AAB95BBB-EACC-4E62-B99A-F69C0345F432', '4605469002976', ' 0,01  28                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADFD27AC-ABFA-49A4-929E-2D9E9B4EDDBD', 'AAB95BBB-EACC-4E62-B99A-F69C0345F432', '5997001357811', ' 0,01  28                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55277D31-88BD-4EA2-9961-2B106D9F5340', 'AB144C9A-6EF6-454C-900E-76EAE820F697', '4620750540043', '     10 //                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97E30934-A30A-4512-81C9-2408690B8BF2', 'AB2C7BBF-76DC-4089-AE9C-4F554E416D29', '4601372001938', '-    N12                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4945197A-27D4-4BE4-A299-CB533FB4376E', 'ABDC1273-225B-48CA-911A-D64A80147902', '4602929000084', ' 0,01% 50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('339AD229-BFB4-4666-871E-DB1BB6E5021E', 'ABDC1273-225B-48CA-911A-D64A80147902', '4630008940013', ' 0,01% 50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C5BB409-1F24-47AB-9928-B59DC98E2D85', 'ABDC1273-225B-48CA-911A-D64A80147902', '4650068810019', ' 0,01% 50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AB93D16-9E20-4041-937A-9AB3256B2180', 'AC25CFE6-6851-4DA3-9E6A-B8B52485AB06', '4601669008695', '    50                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D93E88A1-B6EB-422C-B3BA-EAA288EF835B', 'AC29419B-459B-434B-A1E1-FB56E316F3B5', '4602505007483', '/    8                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBB49AF5-BE50-446B-A34F-E6C4E5A50633', 'ACBE5E3D-0318-4AA8-B856-49003D687A22', '9002260001118', ' 1% 10                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C8466A9-A87E-40E0-9068-5CC80C654D3C', 'ACBE5E3D-0318-4AA8-B856-49003D687A22', '9002260012091', ' 1% 10                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADDFE4BA-3230-4371-AF8D-6E4888E26D35', '575204A0-95FD-4F48-BB98-480D2287AE9A', '9002260025114', ' 1% 30 -                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBE273FC-1FB0-45E7-986F-C12ACDF8E65F', '0043180D-CACD-4903-BA88-7D4B613C8F09', '9002260012084', '  1% 15                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C22BDF3C-8A32-4248-B970-6362A85418AF', 'F273A2ED-A992-4385-B91C-657F762A2009', '4605370002621', '  / 150                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5AE346A-A97F-47F3-B8F9-9859FA8B6C7C', 'DA11B505-2090-47FF-BAF8-DCBB9211C41B', '4601026301810', '  1% 15                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8354D352-D710-4861-8747-C7F071A95237', '2953EA4C-68ED-48E9-9090-6D6A33E7865F', '9002260021475', '  1% 30                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21CAE4FA-B611-4A1A-B42C-D325DCC3996C', 'AE123B91-38FB-43A0-9781-730753F08A91', '4607006670013', ' /  120                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D4C1429-195C-4D08-AE6A-AEC4C276290E', 'AE123B91-38FB-43A0-9781-730753F08A91', '4607006671423', ' /  120                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2204F5A0-511A-49E0-BE2A-460AEE848753', 'AE123B91-38FB-43A0-9781-730753F08A91', '4607006672284', ' /  120                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('876860E7-3C61-4315-BFBC-2C47EF587261', 'AE19FF7E-6CAC-4D38-988A-FF669AAABF5C', '4601969001075', ' 0,025  28                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E44488A0-3591-4C80-8289-F4D4C68BB4C5', '647C9A5E-11F8-4009-A0C1-31AD9E98E5FC', '4660011212173', '  () 2,9  10                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A089D307-64F2-46B8-A501-39698A3564C0', 'F4BC0177-08C0-4977-8781-C978CF828A12', '4603713000709', '   1 25                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AFF0F23-AD12-4658-BCB4-CD3746182D2C', 'AFED5CBF-00A4-480F-9643-6117ECFC2109', '5000158105324', ' 200  / 20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37D0D8FD-9CE3-4D2E-A9DF-3E6E7C1434F7', 'B034E2F7-E182-45CA-923E-FB05F05CC030', '4601969000580', ' 0,025  40                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F4C8D3D-AA55-4305-A4D3-91EE9DF278AD', 'F1B344AE-40E4-44AE-9DDA-E2E271BD24A7', '4607098450050', '   500+12520                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E96C552D-E450-4524-BCD2-345E43340281', 'B10D87C6-3FA1-47EE-95FE-8F99DE288FA9', '4028352000024', '  5% 50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04009E08-8A28-40DD-9493-0FB510436764', 'B16946AE-480B-4CD6-9765-D68442ABA7B8', '4607109940624', ' 50                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C9EBA95-AAED-4E6A-8587-6454E7F7247A', 'B16946AE-480B-4CD6-9765-D68442ABA7B8', '4680005640034', ' 50                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6412F963-8902-492B-A627-3B98A89F02F5', 'B16946AE-480B-4CD6-9765-D68442ABA7B8', '4680005640119', ' 50                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B44CF250-4DCA-4708-97D6-B70F53E4F649', 'AE782D7A-E4A3-4C9B-87E7-55933A01CBDB', '4680381003355', ' 57 /.  /                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8526FD04-A9FA-45C0-9884-1A04F232B4B7', 'B16B2102-0268-4CE9-A287-5872D2B1456E', '4602565019143', ' 0,4  / 20                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('512815F7-99F2-4F70-A06E-526232D617B7', 'B20C872D-8C8B-4C6A-A0DF-B36CF91B5A87', '4602196002835', '   50                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3E3BD1A-950E-4DBA-ACC9-D02FA201B4B2', 'B2125695-8C44-44AA-97B4-5A996DF507A7', '4603988011875', '  0,25  30                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DBB8AB3-9B73-425A-A6A9-01B92733A591', 'B228150E-A65D-44D2-9DB7-52C478E84D6B', '4013054001387', ' 50  2,5%                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F1BFD8E-8808-4696-B5AB-7AD6AD602D4A', 'B38BA3BF-E31D-49EB-810D-30F6305980FE', '8904091116638', '  200                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B528C0B-AEB7-4278-BCF9-75E183CB3029', 'B391961A-85BF-4E46-BA37-AB7E1D42915E', '4602193011694', '  1,5+1  18                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D81F4CC9-B210-45A3-8C6F-618FA1B286BE', 'B3B2B4C9-7456-4371-BAE2-EC747AA5616C', '4028352000017', '  5% 20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFDB6B1F-C576-4B4B-B9AD-A7A1E0EE01CA', '4E21C6E1-BF96-4084-9414-4E8CF8A2FE03', '4601498000648', '  / 1,5 20                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD33FE1D-92A9-422E-91E7-EDD902EA1670', '4E21C6E1-BF96-4084-9414-4E8CF8A2FE03', '4605113001027', '  / 1,5 20                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19E04616-9FF9-480E-AC91-C1B0D0246BF4', 'B5284F8E-9C07-40CF-9B67-27DA538F38CB', '5000158100183', ' /    24                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A234EF5D-74C9-49F1-94C4-365BA9DB889F', 'B542F612-C1A2-4A36-859B-94C7109F0E40', '3594457800025', ' 2  150 1                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD439269-F0BE-4384-B3CC-E7BDE420E6DE', 'C3E27556-7F65-4576-A60B-CAAB568665CE', '4607027765262', ' 300  30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7848312-09EB-477F-AFB4-81E75382DA50', 'B60D089B-8EDD-472E-95F6-569334DF22E6', '8906000570524', '  -10 0,25%                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FB2E7C8-2378-4713-9009-5693DA79C2E2', 'B6116329-3DC9-487F-87AA-7EF627B04040', '4030031898204', ' 20                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12F4E1C6-018C-4B4E-88CC-2776463E5F8F', 'B6116329-3DC9-487F-87AA-7EF627B04040', '4030031898303', ' 20                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECE70920-4536-436F-8AA8-8B1A974B63CC', '056C2503-BB2B-457E-8C0E-D55EFB264ABD', '4601026302060', ' 400   5                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7638C116-C218-433A-B27B-EA31760AE067', 'A4DAB3B0-C7F6-48F5-9DA2-45E1250D4F3F', '4601669006899', ' 0,15  2                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D28C7DE9-059A-4A67-B5C3-9ECC50A28982', 'B6D90FBA-9ACF-4010-8110-48690DD2793F', '3800712440111', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41071E0C-52D6-4779-A139-97F504A5DE34', 'B6D90FBA-9ACF-4010-8110-48690DD2793F', '4607141998713', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3CFD049-EEDA-4A77-9454-212C6179635F', '0838FE89-CE14-4939-B03A-4F14F2C1FFFB', '4620011581686', ' 0,01  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34BC0C2C-CE5E-4343-9FE5-580FD84CA303', '60D0FCB2-F2D3-4AD6-A5F1-4F7F4A5EB727', '9088880575130', ' 0,0005  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C57C9B76-2DD8-4ED6-828A-9E940EFD8ED5', 'EE6B368E-93A0-4A23-A46C-F4E96BC1F877', '4607027768478', '  0,035 60+60   /                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E2A2994-5599-443D-A37D-59AD040A4D22', 'EE6B368E-93A0-4A23-A46C-F4E96BC1F877', '4607027768485', '  0,035 60+60   /                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ACBB86C-FA51-49F7-B08C-2AF3F80C108B', 'EE8E6333-34E7-45F4-84F4-F9EAEE27D08C', '4607027762476', ' 0,004 /1+1/  30                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65EDC71B-768C-4E9B-8721-BCC5C50D0DE3', '17B073FC-7070-48D3-9819-72569BBF5FAE', '4607083721905', ' 0,25 / / 4 -  5                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD3F1D6B-6D65-4AC2-8FDB-5090B62EAAFB', '37B225F8-0DAE-4856-8C6F-7437D6BEDBF2', '4814488001628', ' /        ..125                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B2A53DE-07C6-42C0-8B5E-4F946285E0BD', 'B0EFFEB2-CF67-448E-A35A-D6BFACFB2F70', '4627086700172', ' /    60                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4C8B74B-4F4A-4309-AFEA-990217FDCBB8', '07B2EB86-66D0-4734-80AC-9377D5977D95', '4607004855054', '- / / - / 60                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B714256E-E94F-45C7-968E-8E04A4BA3DA7', 'B7515781-AD73-468B-9003-24E1815DE84A', '5702589929172', ' - /  +- 2 30                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EB5E025-4BEA-4188-A0E6-97D283630592', 'B7E35FE5-C284-4DE5-8160-8101BC07077D', '4601669003935', ' 0,0005  40                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75EDDE5B-C344-47B5-BC80-2451D38D1346', 'B7E35FE5-C284-4DE5-8160-8101BC07077D', '4603182005199', ' 0,0005  40                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACEA20A6-2B23-40C8-9682-12D05DAA1BCC', 'B7E35FE5-C284-4DE5-8160-8101BC07077D', '4607027760076', ' 0,0005  40                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('501644AA-1E2B-4E6C-BC41-18273B9AB872', 'B7E35FE5-C284-4DE5-8160-8101BC07077D', '4607068360013', ' 0,0005  40                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9F4D521-A56F-4DCE-841C-B847134F0310', 'B7E35FE5-C284-4DE5-8160-8101BC07077D', '4820022240569', ' 0,0005  40                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8A5E349-92E3-4F9C-A84C-BD4E4DFAC23A', 'B8C40FF2-C350-4E11-B436-4456BD2506A0', '4601372001921', '-  20                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B0D2C3E-D8C9-415F-AB1F-CE8C4609C87A', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4602509017914', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A1EC527-9144-4E78-A307-3247C44B18F5', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4602784003640', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('765854FD-4465-4584-9F49-CC5ACE58D293', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4602789001771', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A2306CF-DB2A-4470-9AAA-75EB4F50647B', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4602824006044', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81D02366-218A-4417-A17F-10A4B5BFE15D', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4602824019419', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E3D3306-F2F0-4AED-9F33-BB069AC294A5', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4602884000396', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BA55D70-7987-4FDE-A863-27E05801A852', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4603988009001', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B78F443-BA32-4AB4-B12C-6FDE72EE49DB', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4605260002885', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EC92E59-229D-416E-A0EA-89FB3D10BEE2', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4605260003530', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BB62579-6C74-40D3-91D4-F1EF9980E524', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4605260003547', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C835A73-61F0-4742-AD24-59D8FD5D0E5B', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4605260003882', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D256C3C-C2A2-4FF9-A7BA-1AF3E3DD832F', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4605453003293', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DCDF5C3-E8D9-40B8-84CA-137D7E677CEB', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4605894003739', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF9457D3-7A0E-4358-A5C6-775AB30AEBBC', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4607005933676', '  0,9% 5  10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24D03340-6FEA-4C06-8B95-4871C8979868', '128E83EB-A1C1-4C21-AD92-620174026017', '5997001391518', ' 0,0452/+0,04  / 10 /  5                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8354B60E-EE84-43D4-9F24-2799C70832A2', '4A767789-599F-4285-B154-13282F3EC9D7', '8901079002327', ' 400 //  5                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E43737F9-FE86-494C-A40B-52556322D1C1', 'BA9B7FB4-5C8B-4CF9-A7E3-50864D155342', '4603179003115', '     5 10                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30663BCA-B052-434E-8F0D-FDFF49B3DAC0', 'BAAB83BA-DB80-4EFF-8EDD-9CA6099AB739', '4605342000020', '     /1000                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2210157C-0D0C-4BE5-8DF8-2C8FDA7C4140', '92AFFD60-AB03-4990-85B2-5784C4755A66', '4605342000211', ' /      700 1                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8E9406D-8DE3-4324-A65C-DA0959C15411', 'EF3343FD-FEDA-4A93-AACB-27986D2A6109', '4607039770117', ' -1                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('796CA436-822A-47B0-91BB-3D56A490D3AB', 'EF3343FD-FEDA-4A93-AACB-27986D2A6109', '4823060802058', ' -1                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E50F1A93-2BA1-4515-B537-D677C8BA2D9C', 'CF7C4A47-442E-4E7D-A4DD-5948019CB562', '4605342000303', '   - // 800                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AADF16C-6E9D-49BB-BAAD-95D4609AD4F7', '2EE6F624-16C4-415A-9DD6-3B3EC7451700', '4605342000297', '   - // 800                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('165A583E-EF38-4AED-9EB3-0EBE9E4636FC', '70E180BB-0DAE-41AA-A11A-893E7EB9AAAC', '4605342000310', '   -  800                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A690CF3-C0AD-4F02-BBDE-743447639D33', 'C6FD499D-81A0-415E-96BA-65C4F08A8D6A', '4605342000402', ' 500                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47CFA8C8-A5A9-4F2F-AF6E-9FE5A045B98D', '05E4F848-24EB-48CC-9864-68F5B9749B21', '4607098450036', ' 250+62,5 20                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('644454D3-CE92-43F3-9D5E-4A413CDF2E7B', '600CEFCE-F233-4434-A543-D138BC5B7A6C', '4607010244873', '911 - /   100                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F67F572E-8AEA-47F3-A397-2B08B35A1986', 'F78C00F5-D263-42BD-8CF5-706EBE0BD8CD', '4607010245177', '911  - / 100                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D587E61-5A2F-46D1-B825-F7EB19069C4F', 'BBECE2B0-185D-4EDE-9B0C-61B96D556751', '4740412002136', '   50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ABE0D51-1B62-47B0-8339-F005FADE5C93', 'BBECE2B0-185D-4EDE-9B0C-61B96D556751', '4750232007853', '   50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64B8ED87-63EF-4256-B853-366F323EE8E3', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4601969007206', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A03025E9-1855-4434-872B-4931F8405ECB', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4602456000014', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC887E0B-9239-428C-9A9F-613E865D266D', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4603276004244', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE36D982-03A2-44C7-B52F-9758AE0C8E4B', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4603988004891', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0A50528-F970-454F-9503-8E69FCA0A65C', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4605077011490', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A5EB7D5-D11C-43B8-AE51-C69E12D50118', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4605949000058', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C442D5CB-4D13-4F59-8D98-F7E94C631042', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4606486000044', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAF0FE4E-8102-45E0-A81B-5D878F9807C5', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4607005890467', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7158062-95AF-4EFE-879D-1FC73F7A24E6', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4607019010165', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D14F48C-ACBC-491C-B625-6EA7CFAA7741', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4607027766740', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4FC7073-324C-4134-B2B4-D7FAA32E451B', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4810201002439', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA27FE96-6CC0-4F9A-97D3-FD3678C57ADF', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '5997001358948', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFDBB4C3-B90F-4D20-AEC9-994618DACC6E', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '8901767221269', ' 5  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BADC8CB3-72E0-4A73-B8F8-C556D1F77B80', '192E0812-C522-49EC-BBF8-4BD0C9DB9856', '4030855001385', ' 80  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDF51412-B2F6-419E-A64B-77FAF31A7EF9', '782F966F-2C21-4734-B51F-362255F46659', '4602329000608', ' 0,025  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('178AFF5F-6D68-4B0E-8D69-4D3926F6EBBE', 'BF0CA5B7-544F-4577-9B10-6921C1762D03', '8906000570296', '  20                                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BD83475-FF84-4591-A2C5-EF52BBA5C77D', 'B2837874-CDC1-4A59-94F9-E3606FAA8A61', '5997001390993', ' 0,125 5 /                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A726F881-CB1F-4509-88B0-9A7BC55CF63F', '1D63B4F9-098B-4FEF-8043-BEB6673BBB41', '4607045192385', '  2 5                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('950A857D-447E-494C-9ECF-6E2D65D7A7C0', '59385D65-0141-4B0A-8EA6-F532E44634CD', '4607045190060', ' 0,001 2  5                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90AA6CEF-0519-4DCB-98AB-A2D5BAABA8D5', 'A0996495-6D67-47EB-BD02-21298AFFAEBE', '4680010561256', ' 100                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2093B1BD-CBA3-4726-A79B-F8DAEECF26E7', 'A0996495-6D67-47EB-BD02-21298AFFAEBE', '4680010561263', ' 100                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DA6DAC7-F649-4953-B444-345289D22BB7', 'C06AF0C9-3F36-49E8-B5F5-81F28C1744BE', '8901043000472', '   24                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('555D318C-2205-4AFC-945C-F54AFD904057', 'C2E9FC26-0197-443A-BB84-CEF47AD40D45', '8901043000465', ' /.-./   24                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34A41F31-2723-44C5-8B28-ABF180B8FD90', 'A98E9848-72AF-48D7-8B2C-8697BEC00AA7', '8901043000458', '  /.   24                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E2C6302-5200-418F-B6DF-23D9E76DCFE8', '7E705639-42D8-4C1C-B7A8-F2C9463693D7', '4607039971194', '  /   50                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2992C5BD-BD18-4880-9F42-33C3E0D83961', '7E705639-42D8-4C1C-B7A8-F2C9463693D7', '4660014120291', '  /   50                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54BD0324-9573-44FB-9AA9-2400C5A48436', '7E705639-42D8-4C1C-B7A8-F2C9463693D7', '7607449971194', '  /   50                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A25328BE-B048-4C09-9FE0-CD658414E07D', '43297C27-138B-45CF-A054-7EA0AFB871DC', '4602242002888', '  /  / 100                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FC88407-2469-4BF3-9C07-F553FA4EFD8D', '43297C27-138B-45CF-A054-7EA0AFB871DC', '4650001790262', '  /  / 100                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CDEB240-1DAC-42C7-BCA2-E0CB08EBFB37', 'E0F47013-93E3-4FA4-A12B-B766A8B39470', '4650001790309', '      100                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E282658-64DF-494C-A128-9BDD235391DA', 'A56532EC-462F-4ACD-90D9-7DD4ADF8D67E', '4607055560013', '  100                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80CC5A31-40D2-4529-9F57-6C5A07F47C5F', 'A56532EC-462F-4ACD-90D9-7DD4ADF8D67E', '4607118050017', '  100                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17CBE43A-3D90-4E3B-AFA5-050CAA1DB03C', 'A56532EC-462F-4ACD-90D9-7DD4ADF8D67E', '4650001790279', '  100                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C00B57B2-2788-4A5F-9CBA-520D8DC5D7A8', 'C2B82D3C-AE6B-4478-82F1-D7C132DA2E9C', '5702589912242', ' 100+30,39  / 100                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38924287-EECC-4E0A-AD09-3B0ED3C61414', 'C31F512B-917C-42B8-ACE3-F1C593C9DFAE', '4602196001906', '    20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F00DEA2-2971-4EF2-8530-6AC7C6208D92', 'C31F512B-917C-42B8-ACE3-F1C593C9DFAE', '4604060992211', '    20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D0CFA3A-8EA9-4A0A-84B1-9274673122FD', 'C35A7444-7E72-47A5-BA1F-35F59DC7CFA7', '4607027766191', ' 0,6 /1+1/  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69919FE2-4ED1-48B1-9A35-BFC1A4C880BA', 'C35A7444-7E72-47A5-BA1F-35F59DC7CFA7', '4607027766207', ' 0,6 /1+1/  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5493AC34-A9C1-4D61-A5A1-5A957627E6B6', '76F52844-E886-4B44-AE8C-664FEF01F1C9', '0070030990145', '   12                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EEB95F1-AB5C-4EAF-B769-FC8DB2FC549D', '76F52844-E886-4B44-AE8C-664FEF01F1C9', '4250369502905', '   12                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2335D683-60B7-4C70-BE18-794B508DDF4D', '76F52844-E886-4B44-AE8C-664FEF01F1C9', '8061841420534', '   12                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CA94467-7CFE-4A2A-86D1-8AB59C723159', 'C360B1A8-CBA8-455A-B201-D832C1B76016', '4602242001461', ' 40   60                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5267C187-E97B-40FB-BDAA-CF7368716B5B', 'F2C60FD1-75CA-4A53-8958-5D3602D604F9', '5903473001183', '  50                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('038D9058-6E8E-4708-86E8-EBEE2FDF0620', 'B92E2D76-6A7B-4FCE-9060-13068563C51F', '4010439201349', '   50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46F5490D-CDD9-472E-A661-450432012E4E', '1945F75F-700D-467E-904B-FFCB9A2B6AD3', '8030009500067', '   50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B173E72D-6BCF-4C01-9D25-3FBABC94D75D', 'ABD6C0E9-F51C-4E90-9F5A-07AA7D28DD5C', '4010439210037', '   75                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7454BAC-1982-4CEB-9349-7B9842409F15', 'C37B95AD-1452-40AA-986E-E5181C30D695', '5000158103627', '   200  / 8                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22EDAD54-5256-41FA-9564-A96C58EBFDF2', 'C229A70D-346E-4819-9D59-62DC01C4366D', '4602193009431', ' 0,5  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD971BDA-94B8-4F83-9297-D86271D51333', '0B2A98CF-34C3-40CD-A349-9B7567791DF3', '4607024941362', ' 0,25  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92C87304-6795-45A6-8CB0-73717DD31A64', '0B2A98CF-34C3-40CD-A349-9B7567791DF3', '4650057490017', ' 0,25  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5F21448-BD4F-4E1D-BD9F-0683AADDF57B', 'C624ED39-B3D6-4589-91D3-BAB5C31D8E05', '4607006670594', ' 1,97,2   20                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11DD1CFF-4AD3-4CC8-9737-FC7C85200A14', 'F92ECB1D-80BA-4317-8767-BAB4E331F1C5', '4600053020459', ' -6 //  10 -                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BA4AE08-8C66-4895-88A9-0843AC0BBD2D', 'C6F95BD7-4447-403C-9EE6-D7BDB3E5366C', '4602876003121', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FA12F6E-6079-4CCA-B02C-E18BF82CF2F9', 'C6F95BD7-4447-403C-9EE6-D7BDB3E5366C', '4602884008422', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B400BD78-6151-42A4-B359-88C367CFCF58', 'C6F95BD7-4447-403C-9EE6-D7BDB3E5366C', '4602884008453', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B25260F9-34B1-42EA-BE96-E8A49CC430B3', 'C6F95BD7-4447-403C-9EE6-D7BDB3E5366C', '4603276002110', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26C1E575-5849-4A68-93EF-AAAEB2B1465D', 'C6F95BD7-4447-403C-9EE6-D7BDB3E5366C', '4605077004904', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D7B0956-ED76-419F-AC6E-1C2C7EC908D2', 'C6F95BD7-4447-403C-9EE6-D7BDB3E5366C', '4605691000030', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E5BD52B-6677-415C-A334-AE499DFDE1EE', 'C6F95BD7-4447-403C-9EE6-D7BDB3E5366C', '4607027766153', ' 50  20                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ED20124-E483-4391-8FB1-A011AFFBB6D4', 'C7B7AE97-7884-4F67-8226-D5A114108E30', '4013054002643', '   / 80                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DD379B7-E161-4DBD-AD54-097965305DEC', 'C7B7AE97-7884-4F67-8226-D5A114108E30', '4630011650022', '   / 80                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E06D170-6E38-40B3-A607-1BE1F1FD9A74', 'C7C37CFA-E3D9-46D9-B2AD-845EABAF8BA6', '4602521004046', '  //,  /  1                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CE2BD22-C1F7-4E02-8B90-DC1D4A98A5A9', 'C7C37CFA-E3D9-46D9-B2AD-845EABAF8BA6', '4602884011729', '  //,  /  1                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5C60D61-EE6B-4406-8B5A-7B86DAD76326', 'C7C37CFA-E3D9-46D9-B2AD-845EABAF8BA6', '4607037190122', '  //,  /  1                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('767E46C0-D427-47A9-B2E6-1258F70A9FA8', 'C7C37CFA-E3D9-46D9-B2AD-845EABAF8BA6', '4660007810321', '  //,  /  1                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E03E74AD-8A51-4EBB-8ECF-BC27AF5ADEB4', 'C7C37CFA-E3D9-46D9-B2AD-845EABAF8BA6', '6936292100552', '  //,  /  1                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('123D508E-4199-4265-A9DE-4B6A2574FCBE', 'C8FBB502-626B-4D54-B2FA-AEC7A9C98786', '2860313510461', '     100                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BB2F67F-1BE5-4F27-8CED-53ADBD1B0F0B', 'C8FBB502-626B-4D54-B2FA-AEC7A9C98786', '4601669005830', '     100                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('340C407B-5983-459D-8D75-9D1138641B29', '86142255-7872-45CF-89A6-445FA12D943E', '8901148213760', '  0,5  10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('519594A1-14B5-42DA-AF0D-E6545498A3AA', 'DEF990BC-DC3E-4574-ABE6-721D26CDF777', '3592751842147', '   6                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDD44612-8102-4D01-A38B-7BE204E738F5', 'CDE5CE43-B3AB-4FC1-88F3-41C767E9E110', '4607003664589', ' 10000  //  20                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DC2C6A5-6D4E-4483-B91C-A8B136515570', 'C0B2F804-39FC-4A1B-83F5-1D93688EA265', '3760001040425', '   30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AE1EBAD-649E-4B49-9828-DF1FCBC732AD', 'FDC4C186-5EAC-42A3-9E53-F0BC243B6D55', '3582910043829', ' 400   20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E690E3D-5657-4318-94F3-BD2E5E90806F', 'FDC4C186-5EAC-42A3-9E53-F0BC243B6D55', '3582910072218', ' 400   20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('508F720B-D5D7-49FF-AAAD-1F0F26CED064', 'FDC4C186-5EAC-42A3-9E53-F0BC243B6D55', '3582910072232', ' 400   20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12B34476-3763-41CD-94DC-B1F527C5BD9B', 'FDC4C186-5EAC-42A3-9E53-F0BC243B6D55', '3587080002027', ' 400   20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E21692C-7B8F-4E9C-A416-25C82967C94B', 'CE7E79C7-CA8D-44C4-ABCE-E025D2209935', '4603365000164', '  0,05% 10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D4CE11C-ED1B-41B4-A5C1-F80C5DC875B3', 'CF047E59-EE83-46C6-ABF7-FE5E29BA24DA', '4030855000012', '  0,6   10                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B665E45-E398-4D63-97D3-2537B5BD8506', '656EDE61-C122-46F0-B638-3E4A1FCF393D', '9557955001404', 'DERMAGRIP HIGH RISK POWDER FREE S ..                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B20381E2-28F2-4931-B918-4873857AD001', '3860AEAA-686E-48DF-A09A-96242F7AFDDB', '9120029750449', ' /709 ../ l                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59322AB6-EBF5-424A-B02F-479E3C4BFF97', 'D02E0B10-2B2E-4406-966B-708072E359E8', '4602565016371', ' 0,025  40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95A97C71-3B31-487F-A5FB-75A271904B8F', 'D02E0B10-2B2E-4406-966B-708072E359E8', '4607020330269', ' 0,025  40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3D93B25-BDE0-4D41-8D4A-C24692ABDE38', 'D02E0B10-2B2E-4406-966B-708072E359E8', '4607027760038', ' 0,025  40                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('242720E8-1650-4FF0-AB87-6043BC38C031', '5F456564-608C-4528-9CE1-C91C4BF98B77', '4607068360075', ' /./ -  50                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21AAC8AF-D9C4-4889-B3D2-549F01007BF5', 'D250F020-F59B-4D25-A1A3-B0D98904F7D1', '4605180006598', ' 0,002  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69A07706-59B6-4D91-96D6-25BF884ACB7C', 'D250F020-F59B-4D25-A1A3-B0D98904F7D1', '4820044110888', ' 0,002  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('845CCD12-2163-4F2D-936E-4B4A1065A532', 'D089D440-DD83-4A54-80E8-D19895B70E12', '4602884003229', '  250  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F972922-1F8C-465C-9AF1-8333C233BCB0', 'D089D440-DD83-4A54-80E8-D19895B70E12', '4603988001043', '  250  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C74FAD7B-75BD-414F-B6A7-9CDC7D785E64', 'D089D440-DD83-4A54-80E8-D19895B70E12', '4810133000169', '  250  20                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A9CE24C-CD50-4920-817B-E16C8493876E', '3ADEBA2C-A523-490C-9E92-8590129C2F2F', '4605469000781', '  100   10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2713D6B6-0E0B-4077-8202-75241379A693', 'D0AC6385-9F2F-48CA-A241-9B35E80DD443', '4032128011343', ' 25 000 300 20 .                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FB286F9-AE66-468C-887C-2919E68DF750', 'D0AC6385-9F2F-48CA-A241-9B35E80DD443', '8002660019387', ' 25 000 300 20 .                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48AF2006-8F76-47E5-B693-9E0296E2D070', '0942ADE4-A2E4-49A1-9076-50CC322B6787', '4601214001812', '   / 1,5 20                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA22994F-8CE2-4CC7-8764-4FDCACC0131E', '0942ADE4-A2E4-49A1-9076-50CC322B6787', '4607066260674', '   / 1,5 20                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D57CF26-DAF2-45DF-9365-9E75158C1F79', 'D12F0A48-4B3D-4ED1-A228-88880975E642', '8594739055414', ' 0,01  10                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7E29468-68B7-4844-9C6D-987F97485A6E', '1006399C-03B2-4867-A390-56B0E2E40C39', '3838957090563', ' 0,25 2  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF2A78C0-8F02-4E09-853A-6DFC9B433A46', '98452B57-56F0-4D9C-B48D-8D1001130E13', '4602884004417', ' 15  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4D01AE8-E471-4488-BB58-E9C62E7E7316', '98452B57-56F0-4D9C-B48D-8D1001130E13', '4602884004424', ' 15  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1E41632-27F2-41A9-9FDC-222D1C3F43F8', '98452B57-56F0-4D9C-B48D-8D1001130E13', '4602884010395', ' 15  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E34E0CB-FEFF-4EC3-B486-0C1C789FA028', '98452B57-56F0-4D9C-B48D-8D1001130E13', '4603276003155', ' 15  30                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00761703-8C39-49E4-9DDC-B23799777923', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '4605949001505', ' 20  / 30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE29F896-D103-4B09-93D4-AA6AB9186F70', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '4606486002437', ' 20  / 30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C8530DD-92F9-46D8-BF80-4F5DABCF21B3', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '4607003247706', ' 20  / 30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8382622B-24A7-41D6-BEE8-69F738838F73', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '4607011631856', ' 20  / 30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F48D390-F976-4481-894F-85D5A3BFD0A7', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '4607126030537', ' 20  / 30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A49C66F-71E4-4C07-B2A5-21080426D57E', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '4660007702183', ' 20  / 30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EF29962-2420-4239-B494-825520DAECC1', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '4690655008436', ' 20  / 30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57671C04-FAB1-44D4-B424-F75B0B3A5706', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '7290102062263', ' 20  / 30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D9E381C-9E74-404A-B7EB-0D7AFF43C87E', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '7290102062270', ' 20  / 30                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2B8E533-8986-43BF-AF6F-D8B4123F3C63', 'D2F63978-E4FE-4796-A7BB-3ADAA6C6B4DA', '5995327122878', ' 0,125  400 20                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('039EEBB5-26E6-418C-8002-5445439FDD7A', '68C92A91-DFCF-4C76-B8F1-04C49A5DB76E', '4600053020367', ' 5%  5                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E1AF6D3-8815-4887-B035-D1B4EDA23A1C', '68C92A91-DFCF-4C76-B8F1-04C49A5DB76E', '4601026300868', ' 5%  5                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF0BD840-D347-42B3-9793-C335F85A3E7A', '68C92A91-DFCF-4C76-B8F1-04C49A5DB76E', '4601969000184', ' 5%  5                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73BE5444-F44A-4526-92DC-D595373FD989', '68C92A91-DFCF-4C76-B8F1-04C49A5DB76E', '4601969007268', ' 5%  5                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B892D149-2C6D-49B5-88BE-B77EF764D93D', '68C92A91-DFCF-4C76-B8F1-04C49A5DB76E', '4602565015657', ' 5%  5                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC5632F6-A0FF-4E47-ACB0-DDEAFF77D0A7', '68C92A91-DFCF-4C76-B8F1-04C49A5DB76E', '4607003240967', ' 5%  5                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F133102-3143-47A7-A11A-120B7C791C43', '68C92A91-DFCF-4C76-B8F1-04C49A5DB76E', '4607027764302', ' 5%  5                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C14347D-93C2-4D5D-B1E7-3CAF2D62838D', '68C92A91-DFCF-4C76-B8F1-04C49A5DB76E', '4810133005799', ' 5%  5                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E9DD63E-FC06-422A-AA4A-ADB1021D1A7B', 'D364D843-FF9F-454D-AFC7-C1C3AFBF21C8', '5060040300114', 'CONTEX 3 Lights                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63089E9F-CC04-4F2D-8B1E-835163D8D54B', 'D60D549A-D1AA-4CD5-AED8-67E64FEB09C3', '5060040300145', '   3                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E98DB23F-97A7-45D1-A794-6026DCBD09E1', 'B0B389E6-F8EE-4856-8057-809C6BCEA087', '5060040304518', 'Conte /lubr/  /50/ - 30                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB8FF720-3430-48B8-ACEF-5E905A431438', 'ABDCD6CD-9649-4FCB-81D6-8F0CABDD91F5', '5060040300152', 'CONTEX 3 Ribbed                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E43BEB4E-24D9-4D8A-92CB-8D9E9FB6C7C8', '43520C98-54AC-4D65-9D06-3021EAAA2E3F', '5060040304549', 'CONTEX (lubr) GREEN 30   (50) -                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('154442E6-93E2-462C-A2BD-F6EC82C23D9D', 'BA8F2BEA-6F8F-4B1C-A5B6-AE041F992307', '5060040304525', 'Conte /lubr/ strong /50/ - 30                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35F6678B-9D11-41CD-A599-57E3A7184621', 'C21A82E8-60B6-4CFA-96EB-7F0D40A1FBC1', '5060040304501', 'CONTEX (lubr) FLASH 30   (50) -                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE9DE97A-EBB0-4270-B709-9B0FB0C242FF', '65292F36-F9CC-48DC-ADEB-B2A7E57F3D23', '5060040304532', 'Conte /lubr/   - 30                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F125E206-24E2-4AF3-9780-23FB4C2517F6', 'D3AE09D1-0B37-4881-A492-FBE78475DDF7', '4607003663896', ' 0,4  50                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C267BEB-B1FB-4E6D-9C5D-CF77A99A7D43', 'D434C0ED-11F5-4452-80B9-D91E8F616D33', '5997001380239', ' 0,005  50                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85A23C93-C464-4A57-87C9-FD54209244EA', '025A4128-0CA1-4418-94FF-35532E0F00E3', '4607018264644', ' 0,024  30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97F7BAD8-DC75-4B72-A92B-6F81DD9C39EF', 'D50704F2-0667-47B1-9B8F-841BB69AAB01', '4601669005533', '   10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('276D98D5-8F25-4F3D-AC46-F189CC55E2A5', 'D50704F2-0667-47B1-9B8F-841BB69AAB01', '4601669006769', '   10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4251D4C-D7EA-4477-B7E4-EAC0B01F672A', 'D582EAF3-DDA3-42DB-8BD0-299B693A0C7E', '4602884005445', ' 0,025  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F206A698-10C3-4331-89AE-74421E00F144', 'D582EAF3-DDA3-42DB-8BD0-299B693A0C7E', '4607020330016', ' 0,025  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C83D362B-F49F-4A6C-AC2C-A09187B8F6CC', 'D582EAF3-DDA3-42DB-8BD0-299B693A0C7E', '4607027760151', ' 0,025  20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C71379C-9B52-4494-B3EE-6C19CD2273CD', 'A3839D23-389B-46EB-ACCF-D4C16227D8B3', '5060040300107', 'CONTEX 3 Long Love                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97716831-BE1B-4909-8E9D-D356D457EA6C', 'D6919DAB-A2A0-42F4-8E38-7C0F08618B49', '4601834003500', ' / .  2                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7FB21FC-62B4-4E6F-8EA9-6049163B62B5', 'E9157C2E-0BF8-49D4-B769-3976B68AF052', '4033033417046', 'Evitest /. /24*18/    2                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2E838B6-52DC-439A-8BAE-7000DB0CABC8', '6DBA36F3-49FC-4B27-A4B2-08BE4ABEDD26', '4015600372002', ' /    / 2                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C74D30A7-D422-4326-9EB2-F4F5FBE6655C', '6DBA36F3-49FC-4B27-A4B2-08BE4ABEDD26', '4084500097162', ' /    / 2                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C2796F3-C8DB-4725-968D-D9603C3FC8C4', 'DB6F279D-CF3E-4CB7-B543-09282CB5F5E6', '4013054003787', ' 0,02  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A09ECCF9-5F22-4E75-A448-5B88DE3DD04D', '0CF2AE72-18F2-42B3-8B76-8D73A9A9CB8B', '4030674000125', ' 2  25                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79C2E97B-405F-44B1-89F5-64D05070CDD3', '760BAD8B-FF01-4C92-A774-DA6780811B72', '4601969003574', '   15                                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3DAC24B-BAB9-42BE-8452-4600615724F9', 'D95B56EC-59D8-4B20-87E5-7F2A3E47B53F', '4640000902636', 'Evers life  /   44  10                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76E676C8-EF71-4931-9F12-70D578772E72', 'D9CEA715-6797-45AB-B515-6788DCA2299C', '4607045190343', '   1% 50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08B8CAE0-C083-47BC-8669-AB605D26C73A', '5902058C-A18A-4D45-AA86-42011E29EB7A', '4607035390050', ' 3000  / 10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D06C2801-7F8F-47FF-B328-0CF51E942888', '5902058C-A18A-4D45-AA86-42011E29EB7A', '4607035391781', ' 3000  / 10                                                                                                                                                                                                                        ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('169E5C0E-7D02-4BCC-86AA-D24641D0BE44', 'E1CEF89A-ED4A-41A4-9C7F-CA09DAE6D963', '3850114202480', ' 0,5  3                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4219DED5-926C-49B4-9150-9DE791BF1ED6', '4DD571DE-F9FE-42D7-B25F-9898500FF8C3', '4607028391361', ' 250.  10                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4068D63-7D3D-4DD9-AB2B-4B054C4F1A5F', 'DAF0A7AC-B964-413A-ABDE-6AF54775C0CC', '4606711702859', ' /     2,8                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDCB1142-8264-49C0-8239-C3F4CB3205FB', '11EB9FF6-42B7-4118-91F3-F7700D0CD60E', '4606711702866', ' /                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD769E83-66CD-43BD-A211-0EC4C57954AB', '96868780-0BEF-4F27-9B18-7107CF1D3EA4', '4606711700749', ' /     2,8                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DA5A6AF-F0F9-4A2C-ABCE-75995570F5D9', '1420FB82-ED79-4F4A-AFA0-7DE7600A966C', '4606711500325', ' /    2,8                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A0C9FFC-8C8F-4A3A-8A18-ED2858E71486', '1420FB82-ED79-4F4A-AFA0-7DE7600A966C', '4606711700725', ' /    2,8                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BB89FAE-178A-498A-82C7-6663EAC49D8F', '19E72D8A-FF5C-4573-93AB-4BDEB08EFCA5', '4606711100532', '      2,8                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BED2CCF8-A66C-4AE8-8EBA-CBD9DF8922EE', 'DB19AD57-6D2B-4451-8D89-6925A08C4217', '4607072020026', ' 225                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EF8578F-6B84-43C3-BD2C-F07651705D76', 'DB19AD57-6D2B-4451-8D89-6925A08C4217', '4607072020156', ' 225                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55976F46-3501-4235-8A18-F27CEC521707', 'DB387FF3-7785-4D7E-B241-7E0BDDAE1670', '4601969003437', ' 0,25  3                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6655DD6A-12A5-4902-8953-CC1B3047D759', 'DB387FF3-7785-4D7E-B241-7E0BDDAE1670', '4607027761943', ' 0,25  3                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('705CEF66-C993-4F73-8A84-84EF99AD1619', 'DB387FF3-7785-4D7E-B241-7E0BDDAE1670', '5903060001510', ' 0,25  3                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0A76A84-D9D3-4992-9CF1-8E76BE38671B', '2ABAF053-2CE6-45C8-9968-B191A13D0CEA', '8902034103011', ' 0,25/5-15                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EA38FB3-1715-48B6-B9C0-000146EE676A', '197CD061-205D-4852-9CAF-1B470136EA92', '5907529412121', ' 0,25/5 15                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('704C0D33-7F3E-4612-8825-0E33ED62900D', '3B9BEC98-4AF8-4028-9EC7-8667D06F8B60', '8901079004444', ' 0,4  1                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80BF2CB3-B2D9-4949-B139-AAC3A3E4B235', '18B962F2-FCCB-40B5-9279-10BC45658B80', '5997001380369', ' 0,15  1                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12DFD97A-D0A7-47CE-BBD5-5DF83E52B565', 'DB8FCB44-37E8-4486-9C4C-DA6CE0CAD8D7', '4607174650329', '   30*60 20                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87EB41E7-01F5-4472-A977-F0CD41E7BB1F', '6E7A13D5-6629-4EB1-AB7E-794CD7B1515F', '4600828000402', ' 6 ( \) 5% 1 10                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66B3BB6D-4719-4353-BD73-F46A80F6C6A8', 'B3D8B3C2-22BD-47BE-B774-D3C8575B6C76', '5010232954229', 'DUREX 12 ELITE (30*6)                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BF5B49E-5AB5-40AB-A072-16B1C97A497F', 'B3D8B3C2-22BD-47BE-B774-D3C8575B6C76', '9120029750234', 'DUREX 12 ELITE (30*6)                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58E663CC-5347-478C-85BA-8861BBBA46C1', '30D8209F-2C22-465D-9089-291201467167', '9120029750289', 'Manual av509 ..                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBF0BBC5-F551-46D4-BA55-0D8F467F0694', 'F7CF5314-AD98-4A54-9EF3-9D64934C9DC8', '5413895019180', ' 10                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D2D44F6-8DF9-4DB4-BC1B-6E5E499C81A1', 'DD167E53-E439-4AA2-B8CF-316173F7B370', '4600828002673', ' 30                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2746B513-1B85-40A4-82FC-8F63BC7BB357', 'DD167E53-E439-4AA2-B8CF-316173F7B370', '4601669003928', ' 30                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BD7A18D-E35D-4B87-859C-2DA75B8ED14E', 'DD167E53-E439-4AA2-B8CF-316173F7B370', '4603933003924', ' 30                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('702057B1-4D75-43A7-BA1F-B3184D498977', 'DD244F91-CF05-4BDF-AE3C-FBD3E9CD67F7', '4607055131336', ' 0,05  60                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DE469EC-0484-41C1-87D2-9FDAFDEF0E03', 'A3DDFD5B-B168-48D0-A17F-AE74F688A6C5', '8584005101204', ' 5  / 60                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41B87194-4B0A-4C9F-AC4B-1849659ED67D', 'DD8F2D48-4442-4A1D-BFB4-E32A8C9415FE', '4610008494716', '   250                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C0F6C76-9809-4938-BE2D-28B9B6EF0904', '60EF62F6-5E35-4AFD-98BE-ADF9062E3E48', '4602287000252', '  250                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('904FF6D6-58D5-4B1A-8725-AA293869885D', '60EF62F6-5E35-4AFD-98BE-ADF9062E3E48', '4605927000537', '  250                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84BD7E9D-0F53-4C8E-9151-58661C849016', 'F7C62457-C4E9-4CB3-A718-7D25021A6F20', '4602242006046', '  0,5  40                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('121C3580-21B8-4958-A59B-5C781D83ADBC', 'E015A344-0F79-42C7-BB22-61673FD9EFB4', '4605370000184', ' 30                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83966622-B331-4611-A216-077CBBDEB239', 'E047DC93-4D39-4F2C-B061-E164B0ED8788', '2400004706720', ' 170                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D20F65E8-4AAA-447D-B224-D7F71C7F2AA0', 'E047DC93-4D39-4F2C-B061-E164B0ED8788', '3800009121013', ' 170                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E65C765-1E5E-4191-B083-73AE85E228E0', 'FCBAE945-F02E-4285-B998-B63F4528D21D', '4606556002206', '- 120 //  112                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6A9737B-AEF3-4A4C-BA8F-A8C691EB35B0', '5AA68204-D88A-4079-831A-5F777D459F0F', '3582910066576', ' 0,4  20                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B36ADD3-5829-469E-AC86-98A0D77D5713', '5AA68204-D88A-4079-831A-5F777D459F0F', '8901083200221', ' 0,4  20                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1F24A1A-8AA4-4FBC-B5AA-D7750867E968', 'E067806D-345E-45BE-8DF3-45A34CCBD531', '4607040649648', '                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0255E883-0B91-4AFD-BD2E-913145FB0D42', 'E067806D-345E-45BE-8DF3-45A34CCBD531', '4690419001475', '                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6EDC945-3F22-4678-8DD3-0FFB66DDAC8F', 'E11A81FD-4DCE-483D-AE58-1B18DE61B888', '3838957882588', ' 25  16                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28AE7193-772B-42BC-A90C-C88F40F6B793', 'E11A81FD-4DCE-483D-AE58-1B18DE61B888', '3838957990733', ' 25  16                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C64DB66-8D76-4BDF-93B2-42DC44330440', 'E18929BC-C897-4BA0-BD1D-146209991BF3', '4601372001655', ' /   20                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4502EE7-F7B2-4433-B8E2-8294FF3A9F08', '1EBFCAF8-A759-43CD-AC05-379C4A3768CF', '3850114202497', ' 0,25  6                                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('274AC858-6EE1-4A4C-82B8-3BFFD1D72722', 'E2367E13-C2A2-4ABC-9D61-F0DCB0A22AE2', '4600702095791', '  45                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('032F7F67-3689-4AE9-9FFA-27A1908CF004', '993D24CC-8AA9-450C-9502-21BC77D0D9AE', '4606711700558', '     75                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9D149B1-0256-4EBB-A661-D1833925B328', 'E314DC4B-F446-4A39-BDE7-6E226EA824C6', '2400004762382', ' 1,5/  100                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9221482-5C32-4552-A78F-40F5E4D1E7D1', 'E314DC4B-F446-4A39-BDE7-6E226EA824C6', '4607045190091', ' 1,5/  100                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C88F65F1-E313-47AA-9F18-85173E93035F', '1E572C78-14A5-4CD8-8B74-119D53C01EC2', '4600728004784', ' /   4 100                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD9229DE-A513-4403-9021-26C6EA434C74', '6967E303-71E9-44DF-A63B-8FD4B61ECC09', '4600728004760', '      4  100                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E82706F9-E9B4-4524-AC3B-70CE22A1F308', 'D9065C1F-E1DF-499E-A8D8-0B39157CD6E7', '4600728002315', ' /    7  100                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FC8D12B-EF56-48C0-8A0D-32BFD64EF4C1', '116D198F-3633-427E-87E1-A2C60258F2C3', '4750258202164', ' 0,1  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88302534-3D43-49AD-8AB4-2A0DC3AEB837', 'C5013F4A-1D4B-4573-95F0-1242C5BBEF78', '4605964000064', ' 0,2  20                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE72176C-C6EB-481C-A57E-592A0EC027C6', 'E3DC6B64-2E86-446B-BDE4-224DC5A76F70', '4607136740020', '     1,42                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAB3B4FD-259C-4CA1-A054-3C6FD4E25D2E', 'EF838548-D867-4678-857E-7F73250E1955', '4607136740266', '  300  120                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF2155CD-0AE7-48E0-ABCE-E7B827812D11', 'E3F22AAA-8DC6-4FEA-BAD3-22004AC6C089', '4008500130407', '  0,1 //  28                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11A5ABAA-0D93-487D-93CF-8BA1A7567CEB', '0C0E9706-841E-4555-A261-D5688026483B', '2400006421591', ' /   / 36,4                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08230C50-4FA2-4627-BA73-216C94DD9856', '0C0E9706-841E-4555-A261-D5688026483B', '8717627100298', ' /   / 36,4                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41484875-DCBC-43D5-A215-A51652B13488', '0C0E9706-841E-4555-A261-D5688026483B', '8717627108454', ' /   / 36,4                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB246F2B-D443-4953-8F77-33454FEF7C9A', 'E5DABC9B-8E2A-431D-8D95-FB57E82630A3', '5904374000138', ' 0,48  28                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE30B1A7-B9C2-4F8D-BB65-639F9E226223', 'E6049B39-E7D5-4260-8CC0-A35BEB9A9BB5', '4602424005294', ' 0,005  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3037EDF4-D57E-4DC8-A3BE-5F4A4820D3F1', 'E6049B39-E7D5-4260-8CC0-A35BEB9A9BB5', '4607003244040', ' 0,005  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5E82940-3C39-443A-A358-AC3270A07614', 'E6049B39-E7D5-4260-8CC0-A35BEB9A9BB5', '4607005895721', ' 0,005  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('764AACA4-5C34-41FD-8216-9934788263B6', 'E6049B39-E7D5-4260-8CC0-A35BEB9A9BB5', '4607011631252', ' 0,005  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D56EDCD-F28F-4819-94A8-82E878CDE580', 'E6049B39-E7D5-4260-8CC0-A35BEB9A9BB5', '4607027763138', ' 0,005  30                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27B1C38A-2183-4B89-B87D-B35C668BD045', 'EDF842FD-8F70-4491-8F67-61F2F1C3AB9E', '4607003244095', ' 0,01  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4F80E71-4503-4D4E-9DED-40E10559E137', 'EDF842FD-8F70-4491-8F67-61F2F1C3AB9E', '4607003246143', ' 0,01  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12A56F29-D97D-446C-BDCA-01BB1DAABA44', 'EDF842FD-8F70-4491-8F67-61F2F1C3AB9E', '4607005895769', ' 0,01  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35C69E87-9E64-4D92-91DF-146F9F1FB88D', 'EDF842FD-8F70-4491-8F67-61F2F1C3AB9E', '4607005896001', ' 0,01  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1A2BAC1-F189-4325-B085-AB0129C8A4B4', 'EDF842FD-8F70-4491-8F67-61F2F1C3AB9E', '4607011631306', ' 0,01  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4A5BC3F-3109-4586-BF5C-8F870A3698BE', 'EDF842FD-8F70-4491-8F67-61F2F1C3AB9E', '4607027764517', ' 0,01  30                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6607A528-7028-46B0-908A-C8719AB69BD7', 'E7FEB896-A7C4-47CE-8CB5-3703F923B934', '4601669010636', ' . 250  30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('756020DE-83DA-435B-876E-81B073B6EDEF', 'E7FEB896-A7C4-47CE-8CB5-3703F923B934', '4603182002259', ' . 250  30                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C6A4545-9A8F-48B7-9A91-701C59D6386B', '46B7239E-798E-4579-AAB1-FF081320A7F8', '8906000570302', '   100                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('875500C9-C23F-47A1-918C-CFC8B9E3F036', 'E85117B8-A04F-4304-A542-2530A78B5A10', '5000158100305', ' 0,2  12                                                                                                                                                                                                                                      ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CF009B8-A645-4440-AC8E-9F503023900F', 'E97146FC-D900-4329-A0A2-D7CC9FEAC8B4', '5702589928182', ' 0,075  30                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B48AC10-C91C-4342-91F1-5A94746E11C6', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '4602565023737', ' 10  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1F744D6-229A-4E15-BAF6-501BCAA5D83F', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '4602884008521', ' 10  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6CB7CA8-421C-4C50-A2AF-1B7FA98E68F5', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '4604060201634', ' 10  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0D4484C-6B96-46EA-87BF-E88F3E8FB09B', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '4604060992983', ' 10  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('985AB860-A7C9-4935-8D34-260CB7CBFEA6', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '4607003241063', ' 10  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAE8E406-ADC6-4F48-8916-2AE1795B6C77', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '4607027761394', ' 10  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('539911EA-D704-4137-A5C8-8DEA348E8FBD', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '4607143560659', ' 10  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45C2B6F9-50A5-4BBA-8FA0-C5C3C7D11E88', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '4610011970283', ' 10  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B69016F-A5BE-4F71-AE0B-199060D32E04', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '5995377601484', ' 10  10                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C76489D2-96A7-4FC3-9D10-AE3962AE4A70', 'CA388BFA-D271-4891-AAB2-A3901755B614', '4607027760168', ' 0,25 10                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D390081B-5B04-4CC4-B5CC-0D592759EDFA', 'EB4A7635-0442-4356-B661-BF549F31EFF3', '2400006369848', '  /       50                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA8C0643-66E2-46F8-8358-A82D33098E21', 'EB4A7635-0442-4356-B661-BF549F31EFF3', '4601026308369', '  /       50                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26D9235C-1D59-4938-93A4-9097D18E48BA', 'AE3F0B2E-743A-453D-9021-B8EF326B395F', '4013054014660', ' 0,025 2 5                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDFAE3D7-3852-4956-AAA4-3FD49529D45B', '9C0C7D2C-5C98-4F19-8172-F667C02F6C4F', '2400006396493', '  50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23BA947E-B09D-4D0B-A3A9-03738F93144A', '9C0C7D2C-5C98-4F19-8172-F667C02F6C4F', '4601214000013', '  50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C673549-57EF-4ABD-939E-49BDA0ABC8CC', '9C0C7D2C-5C98-4F19-8172-F667C02F6C4F', '4601498001324', '  50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84DC64D8-580E-4500-AA16-10AA28D83A37', '9C0C7D2C-5C98-4F19-8172-F667C02F6C4F', '4601498006343', '  50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9FA21E9-A929-4481-85C7-17433B463E5A', '9C0C7D2C-5C98-4F19-8172-F667C02F6C4F', '4603717000484', '  50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E71F32BA-80DB-4520-967E-1A9251ACF6C5', '9C0C7D2C-5C98-4F19-8172-F667C02F6C4F', '4603762000811', '  50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E12924CD-CFCD-4CD2-999B-E96C14D563F2', '9C0C7D2C-5C98-4F19-8172-F667C02F6C4F', '4605113000112', '  50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BA7637B-1E30-41E8-9718-F30ED3E965B9', '9C0C7D2C-5C98-4F19-8172-F667C02F6C4F', '4680002553382', '  50                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E2EA237-B53F-437A-B94B-A56F4DFAAD2F', '2948D514-6D7F-44C0-90F8-DFE3ADA99780', '4370002552187', '   30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECEE1BFF-6120-48D6-96FF-48E9311BA11A', '2948D514-6D7F-44C0-90F8-DFE3ADA99780', '4601498000938', '   30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68616908-E370-4FB3-BFA4-8EF56254F699', '2948D514-6D7F-44C0-90F8-DFE3ADA99780', '4602439001809', '   30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CA9544F-DE1F-4BFD-9F69-83A630307FB3', '2948D514-6D7F-44C0-90F8-DFE3ADA99780', '4605113000020', '   30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5C2056A-30D8-4E1B-9F5C-03F26797829C', '2948D514-6D7F-44C0-90F8-DFE3ADA99780', '4607102610548', '   30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('814FDE8E-C572-4266-9AEE-2393B816044F', 'EDE0627F-6B6E-4829-AA44-D2FF0AA7532F', '8901083060115', '  100                                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5157E5F9-AD1E-4DFE-8C30-76D1D6293929', 'EDFA83D7-CE10-49A1-A433-3FFEE4597660', '4607004431456', ' 200 . 20                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('571E0E2E-00F7-4965-84D9-D7367D644BE8', '5730DEE4-06D7-4AA8-B95F-63F140305C86', '4607027760625', '  0,02 30 + 30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1130AB8C-CCEA-4669-894C-039A6378E035', 'EB49D2FA-43D9-45B1-9949-803AE1311CE2', '4607027763084', ' 0,005+0,00625 30+30  /                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5C95D66-BB3D-4C57-9A72-12B80A4ED9FC', 'EB49D2FA-43D9-45B1-9949-803AE1311CE2', '4607027764647', ' 0,005+0,00625 30+30  /                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C53F8991-634D-4E79-ACEC-86A335B25516', 'EE8C5451-0DF6-4CB9-9D64-76968B2CAB4A', '4607159860446', '  35  / 60                                                                                                                                                                                                                             ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBFCC216-FAF6-4087-A766-1C6606587F1F', 'EEA2C47C-2900-41D8-83D9-222594CB9805', '4601969001082', ' 0,025  56                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE6962A5-A743-4044-8F1C-E3D0C95A8726', 'A947F517-BF6C-485F-9AB8-CAED4A113D72', '8901079001276', ' // 10  30                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13F987CC-7A69-458F-829F-213595384938', 'EEF57942-C680-40BB-B81C-24509387BFA5', '8600097302579', '  5   30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0FA5672-54B6-42F3-BA59-F4A487E7EB43', '4659AF89-AD77-42E5-B19A-5E7EA1ABF518', '4013054007952', '- 0,075  100                                                                                                                                                                                                                              ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B579D725-ED51-4B57-9CEA-11E767E8B1DC', 'EF108150-9D80-4E8B-8F3C-1F225B076CE3', '4607136210073', ' - / 240                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('427D73C6-04AC-4E2E-B81A-4B19D4D6854B', '5653C9E1-7D72-427C-B2AD-EB435E0AA14B', '4607136210219', ' -  - / 240                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1F4FD33-FF21-4F2E-A90B-642B1219057F', '7B4EB9E1-D413-4643-B713-A89768654284', '4607136210059', '  /  120                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E329760-CF90-4FEA-9E5F-AA173E5BF284', 'EF3ABC1A-8BD5-4C3E-BE67-E7869E5BF507', '4602884005322', ' 0,01  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('943215B1-9407-45DE-B5FA-A03775B28D9E', 'EF3ABC1A-8BD5-4C3E-BE67-E7869E5BF507', '4603988001531', ' 0,01  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3C37D21-427F-4F8A-A74B-E8F8811D7619', 'EF3ABC1A-8BD5-4C3E-BE67-E7869E5BF507', '4607027764692', ' 0,01  50                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DFED1AF-824C-4F5B-8DE3-2B1F5E133740', 'BE05FC9F-233A-44A3-9A3F-8BDA58F1F707', '4601669004147', ' . 1% 10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E04966AE-7587-485A-AACC-43727645F144', '5E768262-7ED9-47C2-B65C-E53C9C42AF9E', '5995327237183', ' 180 10                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('489549F4-E6DE-4D01-8401-5049C3D28CB5', 'F307922B-B324-426D-9F7E-136CDBCBC5D2', '4603905012909', '  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB320B96-1F6C-45AF-8DA6-B1533B6854A7', 'F307922B-B324-426D-9F7E-136CDBCBC5D2', '4605059002058', '  50                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A224CDF-1A1E-48CC-B299-035BBB71EF8D', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4601429000327', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('464C5CB1-79B1-461F-AD25-60AC3A8E5B19', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4602822001737', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AC5F1D3-696A-41E9-8A6C-E63B42E0A8F3', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4602824013615', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FBD4E36-F20F-4D09-8B8D-453CAC1D7E12', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4603184000352', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16E959AE-6019-44FC-AA51-4B2B436729C1', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4603184004282', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69ED9F9A-CC6B-40F2-8B0E-B76D10BA9261', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4603256006213', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDCA9081-D454-4B9E-B16F-DB3E367F3AE3', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4603380002426', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19F3BBE4-3857-4B9A-AEFA-F56A37B4597D', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4603713000372', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE4A8941-2AE0-4C88-91CE-B8093DAFAED6', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4603905002993', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90E89D5C-E61F-476A-81A0-0F8BA15542AC', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4604060252070', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1536E5DD-3ABC-4793-A3FB-5A089D84976E', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4604060998091', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94EEE4B6-A494-4374-86CE-0C406545EA67', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4605180005102', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E9BCB9D-E01F-454B-95CB-700C34B295B0', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4606351003316', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCCAA982-09D0-45A0-9BFE-68A04273E211', 'FC74E644-45CE-48CF-BEFD-6CC8E0E2A60C', '4606683001493', '  50                                                                                                                                                                                                                               ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AA1DC23-1577-4D70-9DB5-3BAEF40D6BC2', 'F3B237C2-9818-48EC-A8EC-FB1CEA5BF0AB', '4602884006732', ' 0,2   20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A21B7EFE-61EA-4FEE-BFD7-3E8A1CBD7097', 'F41835F8-7E8F-4DAE-9B63-4942BB8C6AB0', '4607143560635', ' 24  30                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87E6A70F-9C1E-4544-8691-D5A4DF17D56B', 'F41835F8-7E8F-4DAE-9B63-4942BB8C6AB0', '4610011970399', ' 24  30                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A28D6822-025E-4C3C-9CAE-F5F4023C32CE', 'E7664DBE-060B-49E9-B41E-623F080D9ED1', '4607003661816', ' 0,1 10                                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55F1F181-256F-42E5-9B0F-2EB617ADBFEF', '40A81C2E-1EE5-45C7-93B0-978DA6D6E5EB', '4823002202946', ' 0,1  20                                                                                                                                                                                                                                    ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E57CE458-8566-4C6C-AB7A-FE90D2C6D9D3', 'F4B52302-0BF5-40BD-ABA5-B31F3F2649CC', '8901086040237', '    20                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B43B1F89-50A3-461A-8568-245C3B91C594', '3CA097F8-5580-4BE7-B98F-941850AA2656', '4601026039225', '  500  10                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('956D793A-61AE-4BA5-89E9-D8F2FBDF0952', '3CA097F8-5580-4BE7-B98F-941850AA2656', '4840456000126', '  500  10                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DF193DE-B859-4DF2-8F61-10524ED228DC', '3CA097F8-5580-4BE7-B98F-941850AA2656', '7840316000126', '  500  10                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97F6241F-F77E-405D-979C-B622E9B21E4F', '89507DF6-6C14-42AF-9D39-4D8DED520354', '4602884004165', '  25 10%                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE2B9220-769C-4368-B4D6-E90E1B790865', 'F64129EF-548B-4072-A3DC-CB66897BAE07', '8901086040206', '    N20                                                                                                                                                                                                                     ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E8F67DD-1342-4727-8B46-E81EA2C12CFB', 'F727608C-8449-403E-AFC0-D5DB4FC6DB92', '3352712001859', '  1  6                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09F8EA29-31E3-4EB2-952F-F862962B0F96', '39CA4075-F44E-456C-9B5F-35299CD57C9E', '4602233002118', '  // 10                                                                                                                                                                                                                            ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38996F7B-4ABE-4337-AD2A-07CBDE9C0DBB', 'F77164C6-B997-44D7-83EB-0F108D6CD1AA', '4602196000282', '  10                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0456EE3D-D063-4B1A-AA20-A5FC54BA203C', 'F77164C6-B997-44D7-83EB-0F108D6CD1AA', '4602671002268', '  10                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3367E0DD-97C7-434D-82EC-C158721751A6', 'F77164C6-B997-44D7-83EB-0F108D6CD1AA', '4602824000820', '  10                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0234860B-41E2-4637-A550-27F3F57AA9A3', 'F77164C6-B997-44D7-83EB-0F108D6CD1AA', '4603179000121', '  10                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('288A93E1-53EF-4835-9D83-64047868A1FA', 'F77164C6-B997-44D7-83EB-0F108D6CD1AA', '4603182000118', '  10                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78F1EF02-22D3-47B5-80CC-A34C9E854960', 'F77164C6-B997-44D7-83EB-0F108D6CD1AA', '4603276000277', '  10                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF390058-15F2-4140-863F-659E088E1497', 'F77164C6-B997-44D7-83EB-0F108D6CD1AA', '4603276006507', '  10                                                                                                                                                                                                                                           ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B432B56-3E5A-46C0-8A35-1B3D9FCF5FC7', '38B2744D-ECAD-4B88-9248-903E2052E869', '3760008320247', ' 0,0002  14                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEB1BF67-0538-499A-8BAC-1B5DE365A72E', '645374C0-B87D-4028-B766-4D8D86F5BE58', '4605964002754', ' 1% 1,5  3                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B91DA5D-2647-41F6-9135-87C43F591B93', 'FBBC94AA-EF5F-42BA-8673-3952816D2F0E', '4607022750508', ' 500  3                                                                                                                                                                                                                                 ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC01E216-C0D8-47C7-A41B-AF493539F3F4', 'FBCF8540-7ED7-4275-844D-2323A3541737', '4602809005925', ' 25   60                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0FD0BA4-0E5C-4F69-957D-F84F876EC55E', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4036534203019', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A0CF5DF-FB3C-4C04-BF13-C80C2E16C865', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4036534203088', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A680B0F0-6543-48FC-9AB3-3BD4B1F4C1C4', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4036534223079', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B33D2C0C-1B62-4182-A088-848499030B99', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4036534272022', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4404002E-F819-4E64-9F25-694E64012A1B', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4046963890421', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('584EB988-3F99-40DA-854E-3BF2D256F364', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4046964105500', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66368B10-506F-42E3-B5E7-3C9D578DE903', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4250431900356', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9E0C16B-CABB-43D4-B0A5-0B8787412517', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4250717500133', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E4C6D23-25E4-4A38-83FB-42C44690F479', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4250717500379', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA01DBE8-FB28-4557-88DC-548D27314F20', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4260090441183', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42D96D25-2D71-488E-9774-4FEB4165E541', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4260090442449', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D43B0B7B-AF5D-460C-8D80-F52AAAB5E413', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4260090442500', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76515EC0-B462-45E0-83FF-5D1C7E41CC98', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '8428235317830', ' 10                                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90C53DB1-D799-4073-AA53-3B8CBC73E9A6', 'FC0D82CE-F22A-4EDF-BE16-4A7518993FA4', '4601669002495', '   0,06  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51FD5655-C1EA-46D1-B536-A2CA692835A0', 'FC0D82CE-F22A-4EDF-BE16-4A7518993FA4', '4603276001502', '   0,06  10                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEA424C2-0E65-4F2C-9FFE-4771008FAF33', 'A452BBE5-D743-4EF6-BBC3-811801BEF976', '4603905002177', '  2%-25                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4640847A-FB57-4677-9983-73C70CFD6A46', '54CB3CC9-6869-4B1E-8935-D51313A72B32', '3838989500535', ' 20  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B75C6C43-EF23-4E04-BEDA-82239F08F8B5', '54CB3CC9-6869-4B1E-8935-D51313A72B32', '4605635000188', ' 20  20                                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F672A3B1-1F90-4F05-A31C-862E8DD6BBA7', 'FC3F39DB-6487-43B6-91F1-150DF4EFEF07', '3594452500104', '  30  60                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F999AD7-F7ED-4F47-9CBB-078FF17966EF', 'FC3F39DB-6487-43B6-91F1-150DF4EFEF07', '4607159860026', '  30  60                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA346935-D315-46BF-B0F7-C7C8AC70D185', 'FC3F39DB-6487-43B6-91F1-150DF4EFEF07', '4607159860514', '  30  60                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('209C41EA-26FE-4305-810E-51FD15D85278', 'FC3F39DB-6487-43B6-91F1-150DF4EFEF07', '4607159860538', '  30  60                                                                                                                                                                                                                                  ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF863A83-1820-4BE3-BFE3-C8F242D00426', 'B45CB9A8-D780-4C5A-9125-880FF1569F0F', '4606556001865', '- 120 //. 112 /r/                                                                                                                                                                                                                         ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86207E64-7E8D-4A3E-B43E-DAA3A7BCF34D', 'FCCEC1F9-DB9A-43D3-AB76-B157CD628DB1', '4603988013756', ' () 2% 10                                                                                                                                                                                                                                ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('115047C5-47AC-4A94-A6D4-360878427457', 'FD03F333-9336-4246-A0C8-00602F786DDA', '5000158100169', ' / 24/                                                                                                                                                                                                                          ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5779DAF-4FB3-4630-A30D-A91CDA6443D5', 'FDB9D3ED-5232-492A-B4C5-C83CAA042786', '8594737173615', '-    100                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1797A7A8-174F-417C-9A44-56EB6D3656E1', 'FDB9D3ED-5232-492A-B4C5-C83CAA042786', '8594737223914', '-    100                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C25CE85E-1C2F-4199-9C11-F55FE946FC9F', 'FDE6A1F7-0A9A-46D1-8E2D-5C1FC55EBC87', '5995327166261', ' 0,1  60                                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C30E20AA-8FC8-4E14-A2A4-3BAEF4658ECF', 'FE857C28-EF71-4D9C-B9EE-A222765DE70D', '4601969003703', ' 20  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F8EF2DC-684A-48BA-A558-91166497269D', 'FE857C28-EF71-4D9C-B9EE-A222765DE70D', '4601969007190', ' 20  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0E3FCF7-4E9C-4AA3-B79C-24989AE0B804', 'FE857C28-EF71-4D9C-B9EE-A222765DE70D', '4606486004202', ' 20  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF53336A-5334-49EA-A479-1D88498823CB', 'FE857C28-EF71-4D9C-B9EE-A222765DE70D', '4607003666057', ' 20  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ED528F3-169E-4211-BA8E-B4336CC1DBE1', 'FE857C28-EF71-4D9C-B9EE-A222765DE70D', '4607005890849', ' 20  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E42B505-6C97-49BB-831B-E5AB40FA89D1', 'FE857C28-EF71-4D9C-B9EE-A222765DE70D', '4607047720876', ' 20  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B548A17F-386D-476F-87FD-4BE9165B7530', 'FE857C28-EF71-4D9C-B9EE-A222765DE70D', '4607143560505', ' 20  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAB9CFDC-EFBC-4086-BAC0-E3469C068F0D', 'FE857C28-EF71-4D9C-B9EE-A222765DE70D', '4610012020338', ' 20  30                                                                                                                                                                                                                                   ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF569A4B-B8F3-451E-9091-2088A986D5DB', 'FFC5CAFC-16DB-44E8-A8DA-E1B734D7667D', '4602565015794', ' 0,2 //  50                                                                                                                                                                                                                       ', '2017-05-22 17:55:11');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8045DD3A-971D-4AE8-B356-4E592B63B7DA', 'D54E0678-93D1-4678-BD0F-93DAA01D0AA9', '0000046002747', ' 0,025%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEE7EDE2-CB2F-4F0E-81B7-C69BD8A7EDB7', '1E3BD214-6DD6-4757-BFF3-436ED1D747F3', '0000090266447', ' 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80CC0513-42C1-4FF4-9653-22CF45818157', '687C3EBF-7405-46DC-A7B2-D7107CD08C45', '0027917101156', '-  /    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21697341-46E9-4286-8578-B464A253805D', 'BB1C81BD-AA0D-460F-B96C-2E6CE4862515', '0027917101170', '-      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EF19939-8EE7-4B2F-8273-669732E43573', '9FC553AE-1762-46B3-B103-D6D6AF139430', '0027917101224', '-    30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DA99D87-96A0-4124-B777-151929CC34D9', '58D38D10-A720-4E7C-A0E2-4F5703DDFD86', '0027917101286', '-  30    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEE24532-9A37-4E61-AAC0-B695F25CD305', 'C0535E06-27B1-4B3D-979E-9332EAC09916', '0027917104027', '       30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EEDA37B-D185-48EC-8E19-3821B8ECBF6B', '81F52155-C556-4AF9-B8F2-7EC864C13CAB', '0027917104072', '-    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0189859-3C90-491E-8334-351A2D6119C8', '741CD940-6CB2-4BD0-9030-A52F9EB7F8B7', '0033674312209', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16A600C0-D665-4FC6-A25F-7CC824D560DB', '0EFFDA17-6770-4C3F-9093-711176C16505', '0033674312223', '   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FF752DD-02D7-4575-9046-73212B3F4C19', '8A3AA7B6-6FBF-40FD-8949-4700D4CF985D', '0033674312230', '   141,75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAAD4443-3C5C-4E23-A561-536DC12B2268', '8897B11E-EC16-4C25-84F7-B13CF6174FF8', '0033674313756', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('467896CF-47B7-4B01-B7E2-C0E3D607E4E5', 'C90FBB85-6AFD-419D-8D05-46F7A0270B8B', '0033984017887', ' -   -3  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF908F24-E555-4095-847B-0359983DDDD9', 'BAF79AEC-AA79-4EEF-8A70-F49DC4C4F8FB', '0061841015080', '   / - 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF5F7D54-C4CB-4201-B235-E351659293AE', 'D8601A27-93CB-4D64-934C-1414EB17262C', '0089859613036', '   -16 110', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37D498A5-0D1E-42B2-8570-3CED9EE05988', '4F556915-86A2-4B89-B847-484B1038FF97', '0130382903665', ' ( ) - 21g 1,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D738DA9-77D2-4E0D-83A0-55D45EEF5705', 'A360ADF1-CBBB-4E56-A3D2-842B617FB029', '0300093331020', '  1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A840F57-10AB-4A93-AAD1-29EEB73CA8CB', '28179E7B-BCA8-4591-92A2-C7B247136839', '0300093448049', '   2% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0ACD992-0AC2-41A4-98FA-6644B89858CD', '9FD6D21F-2C66-40C8-9630-12BFA063A751', '0300651356502', '-  / 300+ -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('735FAA79-455C-47DE-BE0E-1454ABED45F6', '473275A5-2948-4463-BFE1-38F049CE1DA6', '0300652144665', '-  / .  355 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C34A7801-4CE9-497D-A8D9-3BC6092504BF', '9222F87B-E094-4BC8-B96A-0E6BFA6E1BC4', '0300652144672', '-  / .  120 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A49CE1D-3463-444A-BD10-4D64BB5CDADF', 'AD6EEC01-C9CB-4B3D-90D8-6B1E67D0CEB8', '0300654013181', ' 0,5% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A1BCE8E-D8DA-4C45-9506-FB549D7EA8CB', '32148305-88C7-4DA5-814E-F67B1618775F', '0310119056202', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77143082-C88A-40D6-B57E-F094A1523720', '5BD3CB86-445A-4220-86EE-B36CF1AD182A', '0362487103088', '  / 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4AC23D9-CA2B-4209-B3A6-46250565F835', '82C15C86-1640-4FF6-96BA-BF9E733F262B', '0362487104085', ' 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CF3DD59-16FD-421A-B901-89AB372D5CAC', '43230F05-372E-438F-B6BF-D3708440F1D5', '0382903205196', '  /- 30g /0,38/ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D6C8EE2-5455-4412-8D94-20F86C25EEBC', 'D3DC7915-0450-4D91-B809-824CD7A0C548', '0389265678460', '  2- . -24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E3E5370-C1D0-4617-9FCF-3EBA957F2769', '201772C6-336D-4A59-9E6C-86660308B755', '0541007640559', '    0,05% 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9FD62BF-03F9-498D-A60E-F289865B2722', 'DAA55C97-9C24-47B2-B9AC-E5199D349E4E', '0643540737144', '      /3-6/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B038BA55-FBCB-48A5-9091-28F1E49E838E', 'ECB677C5-F919-4BC6-B187-248B12C4CD12', '0664942200104', '   amdt10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75559FA1-BD62-4D9F-98A9-727707213EA0', 'C072EFF1-76D4-4F60-92A0-FC3465E41EF6', '0664942201200', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10CD2CD0-B745-4F3D-980F-BF5AEBD79822', '6A339836-2216-4F14-971E-B827F6259E47', '0664942300255', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3702E882-5120-417D-9F16-24787C731861', 'DB3462AC-DDFD-4F51-A21A-EF3A368BD0EF', '1014300156410', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('165B813A-8BAF-4BC5-9E5F-EAEBE8EA277D', 'C17CFE54-C664-44D9-BD02-F58442A34EB1', '1044841006332', '- one touch select 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('461F44EC-DED2-46C2-92AC-BC95C1BA67E1', 'D5B6EC17-623F-42F5-9A92-36AA76569DAB', '1094922319677', '   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('003EBA8B-CFEC-4A7F-87F0-1F1FE6CE0C5F', 'FBCF8238-EB93-43DA-A31B-4ACD5B157465', '1230000020060', '  14 / 3 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FBBA0FF-9AEE-43B4-BA71-B38482480F4C', '1A49F97B-15FE-475F-99C1-ADBEF08C5E75', '1460183400193', '   7  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81B7F750-23E8-4993-95D0-E86C7BD2225C', 'A54861B3-D65E-4912-9876-DB183DDAE0AB', '1460701024498', '    //   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E818EDC-63EB-407E-9E21-A65D2F9AF593', '56C3EED1-F1CB-48AF-8BA0-08C46730E54D', '1464000326130', '       30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A93377E6-730D-4CE6-98AF-5FA682B8C034', 'C848E069-D72B-4971-A24A-D472E33D031B', '1628214001744', '  3 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24A9A74D-88E5-401D-9098-6F22051E95CC', 'B02B2E1B-B926-4DC1-B162-3C7400BAC859', '1628969007251', ' 2  0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BF4DEB7-BE08-4BA1-B86B-37A4253C8C3A', 'AABCE9D4-D677-4317-A33F-AB740A3886E2', '1644008940037', '  0,01% 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00A3147C-ECE2-43B0-A734-50849C83586B', 'EB7A24EC-500A-41C9-BAEC-1DAC5E85E83C', '1705770103898', '   50  3- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13DFB02B-563E-4C75-A478-9DCB616342CD', '9E2A3C07-08DA-4B86-A632-7C2634816C5B', '1705770151059', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72145779-FD32-4E77-AE34-FED06650F799', '02BE9C94-B861-49D0-8D33-DE4F8FB7C190', '1705770151110', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3840AA19-017E-4DDD-A824-A8472CF5D29E', '4593CCE0-0BEA-4384-B040-76556970E261', '1705770151196', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AA5CCDC-A6F7-4C31-BE4F-83D7973C1E47', 'EB17AB67-FEF1-4BF4-B660-0785D4769CDA', '1705770151202', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB7C9041-9E8E-44FA-A469-B76812F418B8', 'D31C9022-24F9-409D-9297-C4FA44A87135', '1705770201150', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D229FC75-A3EA-4764-8956-6566DC908674', 'A07A2091-65A2-47F3-B155-EFE28836B0A7', '1800031183630', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('687CC8E4-75EA-46F1-9D2C-D63AF168DDD0', '64E36032-F075-47F1-AF36-1240E63BBC80', '1916190463039', '     52-54 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('714BFCCD-EA15-4484-85C5-CA60D6006637', '811DB720-E5D5-43CC-BA9B-50B59D086E63', '1950112580046', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74C21094-B935-4AFA-954E-C1523E721BF4', '41275A87-DF39-455A-8680-FC6CFEB18CF0', '1950112580183', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1B4ADBF-1E34-4A51-835B-C20862751E1C', 'C0BBC053-E650-4130-99E0-419394DB6876', '1950112580190', '  () 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75D1C855-DDC1-489B-B800-38F80B8A1F84', 'C4F7DFD5-D072-49E0-9F99-B87EB6E1CA43', '1950112580305', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF016256-48C5-42DE-95BB-A0E6A99B2DBE', 'F2711808-10BA-41DA-B3C9-D59F80BA0096', '1950112580312', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('785BFA30-2DBC-48FB-919C-BE25EBD4536B', '90BC7DAB-A1FB-46E9-8F49-C6E1A36225D7', '1950112580336', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4201F726-B830-4213-A3F6-6762C3DF619E', 'C16C76CD-1BBE-4452-98C3-558783C40AD9', '1958090892007', '  3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D04A0CB-A23F-44A5-A1A3-699C4CA17B12', 'A6E4FE47-1E5B-47EA-B042-08B33250E668', '1977562567021', '+  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF1CF141-2AF2-4869-A236-FCE858CC2DF5', 'E7839F67-5E66-46E8-8AEE-007611FEEF4D', '1977585055147', '   sey life  10 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('457D0D6E-B619-42A2-8C17-1A869BF2ACF0', '9AF7D400-6D9E-4515-84CB-A40EA6533F5C', '1977722236002', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ADE5ABB-11DF-46A2-9D90-FAF0F746FEF5', '1A834594-D666-4EF5-A1E9-C4C02A7906B4', '1977793420065', '    . - L', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C62BAB7-C06B-4782-8545-B71C9E8F75F2', '186E66D6-99EB-410A-A2A0-DA8D961FCE7A', '1977793420072', '    /.  .s', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EF646BF-8878-47D8-81F1-FAB9D1F30567', '0255C798-D722-431D-8525-E7B39BBB0CD9', '1977813217002', ' /    10 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4088B65-89D4-4E3B-82AF-C84CC324C684', 'BDED7255-2606-4101-8887-B47CDBA584C0', '2000000013145', '  2- . -18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5C380FE-4383-47CC-B086-231A9A91B0EE', 'D3DC7915-0450-4D91-B809-824CD7A0C548', '2000000013381', '  2- . -24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45197282-81BB-4129-8B24-11FA28E9F506', '14872DA9-E6CA-495E-AB02-672CF920C40C', '2000001192252', ' / .  .m high risk 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('827AF84E-E034-411D-B2AF-546C2A4668C8', 'A3AF8179-6090-48C1-BF0F-7B8681A24A17', '2000016530018', ' - kineib pro    55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F47E2B37-8AFD-4924-B796-94F8E95DDB8D', '146DC8B5-26F1-4C1D-9961-DE5F2AFC233E', '2000021230019', '  -11 230 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ED7CFC7-D937-4C80-9A98-189CB4325205', '6FAF9ECC-CBD3-4F1A-8325-C8EB64229AF8', '2000028170011', ' - kineib pro    55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4664436-4C82-43F7-B91A-3EC7978EF6F8', '1BAD84D8-B5E2-4A41-9E4A-E29E92FA082C', '2000103609597', '-  9+/ 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFECF6CF-893D-40FF-8C7C-726882F8DD69', 'D7D2CB5D-81FC-49C1-B8FB-A6D5A2F9B743', '2000103610005', ' / 6+/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86FCA8D6-A57E-4B67-BA3B-0085D6E52E59', '716D41A7-5674-41C2-A0B3-BB95CBD3821F', '2000103610913', '-   18+/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A5D30C3-D0F0-413A-906C-CBD8FBEBC664', 'C4C7BEAC-CC21-463C-844F-C43469D5CBE7', '2000103610920', '    18+/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BF745CC-057E-4DF3-B837-E7A5A3B48AD1', '2E0E17CE-0E15-4168-8966-FABF5EA6D436', '2000103611071', '-   0-6   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('754988E0-28E8-40CA-8950-6860255D1A09', '9F638902-42ED-4748-BB93-6A2C78304AB4', '2000103611095', '   0-6  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D9278C2-FE64-48B7-8DF5-A754354174FA', '172A9968-22FC-4334-BCF1-153175913029', '2000103611224', '   6-18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67BD2173-1228-4F96-A172-C7538CEB6348', 'D42C25E1-9BDB-4AC4-9892-5F6F88A08A03', '2000103612511', ' 13/109/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35308599-3B9B-4586-A245-2B4CB205109F', '72DFE4D0-8919-4DE8-8C9F-C76099B3B23B', '2000103612542', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30FBC647-6EFE-4775-9B28-876CB7E6C0EE', '865751CB-CE91-4BC6-A68A-EE2C1C2A9D79', '2000103612931', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA6ECBCA-8D61-4F48-9415-62DF7616613B', 'F0A5EC5D-ED3A-44C1-AD24-D48B8E96A130', '2000103613310', ' 9/501/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE151F76-4BCA-4422-A09F-8E08443C56ED', 'A8BF7547-EB0A-451F-9C77-E20191A6374A', '2000103614379', ' 0+/ / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A4FC08C-346C-4960-9353-9AEDF902CF10', '94223502-0A72-48C3-A8C7-C65FD0347E91', '2000103614409', '  0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD0E12DB-E2E2-4AAF-B400-AF059C64E6B2', 'C072EFF1-76D4-4F60-92A0-FC3465E41EF6', '2000621432257', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8202581-6A53-4C83-A334-69C2BB2752F4', '8E9FAE6B-FF14-459F-BCC8-B69D2899D3B8', '2000621488773', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('938FE6BF-7709-445E-A1D1-96DF3F6BA57F', '6AE11E07-7ADA-4A4E-9F61-0846A2A0F22C', '2000621490998', '    0,1  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('660D1871-8B33-4628-BB97-9FDF155E8DD3', 'CE730B7E-A762-448B-9220-F8467F2B2300', '2000949711218', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28A9D30B-9288-4930-AF98-102F3A717358', 'D0CBE896-E983-4920-9BB0-992B7CD51A10', '2000949722511', '  14070 .42 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF15F406-F203-4B72-B55D-C56AA62909E3', '197A1ED9-6728-4ACC-B4ED-001240271DE5', '2000949743240', '  /    .L', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF509091-915A-4CBB-9A51-C80678281B23', 'DE1B3FCC-8DF7-4CD7-9532-1CA03B02F11A', '2000949766270', ' 310 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D53A3385-C6F5-412E-9869-6B9F01045BFC', 'D75A23D5-C663-4A6B-8B4E-8314EF0ABFEF', '2000949781075', '   . .0,75 / 35/ //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0374817-B857-43F8-9541-FC9A81BE9387', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '2000949788067', ' 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB18089E-BC71-4DDD-8D1B-A3998A117144', 'DD2ED64A-BDD6-491A-B1F9-314024624B62', '2000949804798', '  2- . 26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D282C3BC-6561-4428-9007-D883E0C49667', '24CF5C36-8522-4D3C-95D2-5E336FAA27F6', '2000949805054', '    1010  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD88C4A7-6ECF-411F-9B75-67F4A0DD1AD5', '11586C29-0E84-4EC3-96C4-2FC3AAF62943', '2000949821061', '    67', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6330E34F-AB3F-4AC3-880D-650DDDDC9B64', '1FDE4A60-4A27-41EC-91AC-D8827EF7DC00', '2000949828350', '  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DCDFE8C-BC96-473F-8479-83E273D83167', '1A512734-54D1-4127-B30B-FC9A7D29EB7A', '2000949831541', '  /    .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5227C7A9-CC8F-4F5A-99B0-30BBD348D2E9', '9601AD8C-1DE6-477A-9405-4FFD784F112C', '2000949837260', '  3-   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DD6EEB7-F148-4310-BB7A-6E03313F9A24', 'C5A1E3BF-B3A7-4D1B-A61C-93ED46760015', '2000949841045', '    7,57,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('036D32AB-DFC7-4F50-94D9-9C5824214854', '3B42E34A-00AB-4EF4-B56C-F14C6F7F531D', '2000949857794', '   ./,    / 1000 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB14A2FC-96AA-4A05-9EF3-9A21D19DEDCC', '72C5515C-644E-479E-821F-60578DF2E2D4', '2000949867069', '      3500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDCC3C0B-2677-4802-A491-41168318C9C1', 'FC33DE11-75C6-4EE4-A8BB-DA12CDACD85E', '2000949869612', '  21g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF1A4376-7282-4907-9070-54A0254132E9', 'F9C98B55-E9D6-4604-A54F-44B652620C9F', '2000949871912', '    5   10  (.30/2)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E79CB72-0D62-49BB-941B-C3CE70112696', 'FBB68759-28CF-48CE-970B-A7CDD114960A', '2000949875125', ' 2750  ""', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E2AA2C2-62AD-4D44-92B7-2A1EE1F48DA0', '57B2AA5D-2FF0-4082-9D6A-D8ADB8FDAFD5', '2000949877471', ' .  / . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('126D0502-1AA5-4630-B0CC-10F2A21E1E08', 'DCCB0285-9AEA-4108-8C6F-8EB06509008C', '2000949891415', '   108 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('759491A3-AAE4-4EAC-A4F9-4941627209B5', '5C6C07DD-0258-454E-B34C-E1153476D2D2', '2000949895482', '   /30  750 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D983252-E57B-42DB-9EE8-5E06026D161B', '9A1C0675-47A9-4F0D-9795-0FB12DD9C197', '2000949898902', ' /   /1 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A475DB21-1644-4265-891A-6A1C4574E525', 'AD8C60A0-03B2-433C-9AC7-B72D488F79B7', '2000949910338', '   75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('235B9821-4B0D-4FCC-813B-0770CF7C96BA', 'CFAB0A55-F705-4BD5-89FA-07046AA6FD75', '2000949910857', '  25g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DA38F91-FFAC-44A8-B9CC-9FC8A7DBAD6E', '59ED6FCE-8638-413D-9E37-4BB25AA8D35D', '2000949918518', '    "" ( )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAC6D123-F820-49B4-AF1E-86E6E47911B0', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '2000949919058', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9110B19F-74EB-4AB1-B265-4B2D200B4B0F', '2DF81138-F2F2-4CB0-A463-5B29E6249EB4', '2000949925639', '- " "   6 ., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C552A55-9024-45C5-B91A-A69BF9445925', '1629FEA0-9227-4EE5-98C9-A5108138FB6F', '2000949933221', ' . . 70200 . 42 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46385957-68CE-4709-B537-D8EC015A04CD', '8BAB70DE-3861-4B74-9CC5-524C65644085', '2000949934136', '-  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D4AA9D0-4E69-4242-866B-F9144333668A', 'FCA2F3ED-1D8F-48CF-A0E9-0FB64D35EC9F', '2000949959146', '-  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D39D3CBC-B019-4FCE-88CF-C49AB88BB371', '906BAAAA-29EE-43B2-9D1B-4BB4BAF8D770', '2012042000472', '  -6 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F8F12D0-A979-4510-A24C-00AC6A0002B0', '09FBBB3A-202C-45AC-8DCB-0FEF08764860', '2012042000601', '  2- . -16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F48A7C5F-C7F7-4FF5-9576-DAC783E87C2F', 'D3DC7915-0450-4D91-B809-824CD7A0C548', '2012042000649', '  2- . -24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA8482F5-8591-438D-88CF-EEE0FF8B8B78', '1FC8C8DF-C352-4311-8078-54BAA0ABA921', '2012042000656', '  2- . -26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6689582-D10D-4F81-99D6-1072D6970AAE', 'B126189F-88A6-44CD-846C-DB852AF7A860', '2015136122463', '   10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67E3ACBE-2069-43A6-8356-558EDE7A9845', 'EA8BFC9B-6214-4A54-877C-9BB2CEA6B1F9', '2027339504939', ' /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23EDDEE2-C755-470F-BC8C-DBD705C0C548', 'DEA5BFE4-12C2-4F62-BA0E-9C224208C6CB', '2120212644903', '  90  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C70216D2-0136-479F-BB8A-B717CCE1FE51', 'EEBD7971-7AC0-44EF-B0E4-A0FF75C2CF1E', '2184597400974', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07F0F8E2-0A2E-43B3-B965-658A712F90E4', '2667EBA7-B81D-4FAF-94B1-C6EA47385115', '2198846254331', ' 66,66 30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEEC2FD1-6B4F-4159-82D7-D9316C8834E8', '1DAE72C6-CD5C-4763-8F64-6F2EA06B64C8', '2200000002730', '  1671 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9EE6926-0C13-44C2-BF02-E75FF87F94DF', 'ECB26823-590D-4477-868B-85B2D59E9532', '2200000011015', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BDA9527-86F7-44E2-9478-2C1820E7F4EF', 'FA3F3BA8-7E76-4DC8-B6BA-AA3B3BA64A9C', '2207954450860', '- /.    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('594B9384-FBBD-45C0-9500-8350FFF3B60B', 'A5078BEA-4546-41DA-A0D7-1D3DABB5F8AE', '2212540667454', ' b6  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA9878D4-69BE-47F7-BF23-87B71E7C25AB', 'C18D0B18-CFF8-4F87-88C6-CC5F85728642', '2297807544525', ' /amrus/   tvy-120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('263E8756-8039-4D0A-8408-C5782AB68754', 'FF4DBB71-3304-405A-B041-82D7F2F39779', '2400004816122', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB2DB8BC-990D-40FC-BD8E-08334BF871C9', 'B8A39664-19BD-4186-AC4C-172DD1F30611', '2400005045484', ' bio+   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43093406-C53A-4DDB-B75E-66B4E8549BCD', 'A6FE9204-EE2F-45BE-84EA-8D21F147FEAF', '2400006369947', '  0,2  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73BD7F69-DC1D-43FD-B9A0-A0506EDC9A49', 'E6DD00EF-FD17-43F4-8498-C2FFE00E533F', '2400006370059', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F56E0A4-9813-4ABE-8FCA-8487954B5514', '8CB6AF8E-4490-4561-832F-41321972A7BD', '2400006370134', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DDD80F2-9CA7-4CAF-B738-439C2223637A', 'DF6A5AA4-AEB4-46A2-BAD4-51F96166835F', '2400006370387', ' /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B41E0BFD-DBBC-4D0C-AA4C-85E9ED241CEF', '79AE560E-7ED0-414F-AB10-69139471635D', '2400006370394', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE25D3FE-AABD-47DE-BD25-272A8F59A035', 'E61E2B5F-C35F-4B7D-849C-54B09509E1DB', '2400006370448', '     24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('481D2485-65B4-4BEB-80F9-9084F6B00A3A', '4F14FBCA-46CB-477F-8DEE-01CB2BC269B5', '2400006372244', '-   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E68E33A4-B2D5-4AA4-A433-A4E1CAD9BF76', '6D051CA1-F9E2-4C46-93C5-6321BEF80999', '2400006372268', '   / / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9684BA4-6971-48D8-846F-2C6519374034', 'E96A8E9E-8A57-4EB0-AC91-A826F94AB5CF', '2400006372275', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92097194-017A-49DB-A00B-C6EA5367A80B', 'ED9244ED-521C-4EFA-B613-B6D9D55E6F2D', '2400006372435', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98B86B5A-E4E4-41BF-B09D-8D9F9CC9B8C9', 'EE37757C-5DEC-4319-9279-CCE39FC712E9', '2400006373692', ' 180 //.  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FEA0368-98AC-4F3B-AD27-CC1264CA67E3', '7483C23D-4CE9-4ABA-AA90-9E4C930E789B', '2400006373739', ' peha-crepp  /. 124/ 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('016A1BB9-D61E-4F5C-B753-A075901B9120', 'D0D50DEB-3707-4762-885A-47838E3DA8CF', '2400006373746', '  -   4x4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63F6A73F-EEBD-4D89-8294-0B8DC3941535', 'CF8B20C3-37B1-4B7C-9D1A-357BD4862977', '2400006373753', '  -   4x6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0612DCE8-FC34-48F2-8FE0-DA8CB8F80465', '70EA7BA1-A674-468B-8EE8-E0B87CEE4C7E', '2400006374057', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BAA06AD-D80B-4488-85AF-954C8CD3FC33', '35AA61B3-480D-4CB3-BDBF-27066AA5AAA6', '2400006374521', '   0,5 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C192D21F-0AB9-46C9-9FE5-196075A7B211', '9688FA91-2EB9-4DEB-97A6-BDA4CAC0E765', '2400006375580', '   . 4, -800, .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF5BD59B-43AF-49DE-855A-A84264A0E202', '9A3749A7-220D-427F-B360-9BF20B9ADD6C', '2400006375672', '    /F-200/ - 4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('255E4FDD-06A8-470D-A90F-39A464C33E97', '5B8C04DD-CA29-4A6C-B42E-BDAF369BF585', '2400006376747', '-911 //   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B54065B1-D23B-4876-9DBA-BB1946117979', 'E7E874F9-AB7A-470E-B5E1-4F4044346861', '2400006379830', '  5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC47AAF6-B70F-4DE4-89EB-461090B316AB', 'B71E14BB-ACB3-44AA-8DCC-0F7429F9C46B', '2400006379854', '    0,1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDC14324-CAAD-423D-B0F2-4BFE0D56DDFE', 'A83426EA-473A-4441-9D49-9B2CC9F9DCC2', '2400006396356', '        6,25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF346016-9408-47A9-9268-9568E29A0559', '0CDBEAE1-4AE3-48A8-AAC5-086C1C48DB88', '2400006396363', '   /    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91B0CE78-87E9-45AC-B242-2D6EA2C09D70', '514A7616-2DF4-413B-9EE3-CB71958F06A2', '2400006396455', '   // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F9C9A65-DFE1-4561-A6D0-23675F27AC51', '6B837C0B-E639-4BB7-BAAF-D2FB642EA8DC', '2400006396479', '   // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD8F5ABA-082F-4554-9D94-108CBF371D94', '03D5AAD2-1CF1-49E4-A0FB-39B506725463', '2400006396523', '   neogalen 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AEB3D8F-632B-4BFE-941B-61163050BFB3', '5C68C98D-6FDA-433A-B226-D33033D69964', '2400006396608', '  /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E704AE3F-628A-4088-8E83-A89452DD1261', '0F3F3F2E-1249-4DF1-9164-321CB0AE1772', '2400006396615', '    100 0,3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A695DD4-B86D-432B-8EDF-59849F240929', 'B20D3040-A107-4886-AA1F-C346D994BB09', '2400006396639', ' //  /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('993C42C5-6B8E-4D3A-9A1F-D8CB3E6B0AB8', 'F3A0B5B8-45F9-40B6-A4A5-2DF78469A3BB', '2400006396684', '5    - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BDCFC5B-477B-48BB-AE48-AD8C0EBE87A4', '45FA24C0-4C74-44F6-9E79-31275AB1252D', '2447652345635', ' - kineib pro       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98139469-F253-414B-A6B9-59A2B8B678BD', '37AAF94D-43D1-451D-AC52-A8365D63BA45', '2448615346751', '  kineib pro     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9108885C-FA66-49DA-BD57-B53CC5A21164', '64517C06-A556-42C6-AADB-0006B0D6B20B', '2448695865883', 'Kinexib PRO    51', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51E11EC1-7895-40F4-97E5-D9549E31E859', '35DBC6A3-4BBF-4810-AE12-D5D5EF120BF0', '2448695865982', ' - kineib pro       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43277454-463B-49E0-BB55-C7F6F2720903', 'F78FCD9F-E404-4C44-BE19-3ECE5BE2CC0E', '2485152426386', ' 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D493654-0152-4F09-9049-7BB1C0D9B159', 'EBB11996-C068-476B-8294-BD23ABB3285B', '2487311865883', ' - kineib pro       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC52AA53-14AC-4ACD-81BD-371DC82236FC', 'E407FA43-F6D3-4133-B8F2-E658AFDC7B83', '2509591959646', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15F42D7B-9E56-499C-A024-4FFB8B57E280', 'AA09B117-B218-4E1A-BB27-D4174D028974', '2513754959343', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80DDE6CB-7FF1-4420-9D19-23E59E61FA43', 'F759FB14-5962-4472-8B0B-46CF4B9FAC48', '2549867084467', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A4CAEDE-E7A0-49CD-BDE1-02C55A1A979D', 'F78FCD9F-E404-4C44-BE19-3ECE5BE2CC0E', '2575684418871', ' 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A49B384-F5A1-4E24-979E-6FFE5BF17FF7', '90381B41-7A60-46C5-96BE-AE88DAC624CC', '2649712704240', '  500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F579F3E0-E7DC-4A4A-BDA6-A6CF3D3264AE', '72638CAB-04B8-488C-B73D-4768387249D4', '2744025650106', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6030A523-DF71-400B-ADF4-08E3697804BC', 'FA7CFA1E-D82F-4062-9CFD-08A1D51351DB', '2780001101033', '  3-   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE7B90EA-2DB2-46B8-93BA-EA4ED9D102C2', '6A47D8AF-A2FA-47D2-A138-B2652FF21B6C', '2804507047463', ' 0,2% 40  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEC3E3C6-08C9-4087-BE37-3599E6462096', 'E82F4C18-2FE4-4BAE-A539-D7E064811319', '2856228545346', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E65034B5-AA0D-4765-97B0-0C7F8808F267', '86D32CFB-CC62-4DAB-918B-65F01B16FA9B', '2876241340483', ' 2,5 400  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('991899DB-C4CC-47E6-88D5-0F6B38B2EFC9', '836E7C3B-DAE5-40A3-9D72-54E4AB33ADF2', '2906161394492', ' 50  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6589E9E5-E155-4C73-83DE-AE20F6975F8D', '6CED2FD2-B832-49CB-BC05-BA6FB7754AC8', '3000376211205', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82867638-3065-49F5-B2C7-F5143AB10254', 'DD39626A-E49C-4EB5-A9D5-C13DEEF87E48', '3000376211212', '     /  10+  1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE938CEB-CFB7-4A1B-8DCA-64602C1219EB', 'DEE1B966-B5E5-48AF-9039-A2F4E4D7FEDE', '3014260017156', '  -     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8909B4D3-83F5-4A07-8621-349FE100EE35', 'D78C6857-0F0D-441A-91D9-0E48F0E00527', '3014260022051', '  - pro-ep   / 40/+1  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15219821-A124-416E-BDC4-1AFE70B5BA70', '297362EF-87AD-4F20-8F5B-E53FF63E38F2', '3014260022525', 'ORAL_B      40  1+1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B50D077-4749-4ED9-967A-717637AFC843', 'B1D3FE14-B9CA-45B4-BEA5-4EB6A17913EF', '3014260022617', 'ORAL_B      40  1 + 1  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E69C0ECE-4663-4282-BC7B-4016383FCB73', 'A3623C5E-6B13-4D1A-923C-9A5D0C292F10', '3014260022709', '  - 3d   40/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18BFA1AA-150A-45D9-A3C7-34A652E73CFE', 'E9FDB266-4033-4FB8-9C5C-1A0004B2F287', '3014260022761', '  3D   1+1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39186940-48D2-4E58-8F29-0B57FE2AB1B5', 'B1E81A24-4343-41F5-875D-33B4BCFB8194', '3014260022808', '   40  1+1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01D71647-6B0F-4096-851A-E5614A8DC283', '527602A0-66B1-40BC-AC39-ABDF5474E426', '3014260094515', '   -  thin   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB614637-67E3-415C-A0AB-ABC3BDDD9F25', '6F961C6C-38C7-4A3B-BB7E-1F8B06C55F99', '3014260094539', '  -     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB9635A9-AE4E-4BF0-878B-15BE7AE46A76', '8B2AA03D-E6A6-4C70-B3B3-59BBF6DF7454', '3014260095925', '  -     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D34ECD7-BEF7-470B-AFD6-11974AEC8DA8', '92C88B46-C418-40E7-99BE-D9FD75709735', '3014260243548', '  / 3 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DC0E6C0-8C40-44CC-A9AE-0FFF0478B30F', 'EAF35F14-6734-40CB-BC6A-11DD69A82D0D', '3014260262709', '   / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45B3C1E6-FBD1-460D-8161-106A3014D28A', '61986589-1F36-4EA7-BCAA-CB818E005DDA', '3014260275921', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0BA8647-2B87-40A6-818C-1986296144F1', 'C67A4DA8-AB19-4F9E-8651-A49D180F567A', '3014260278311', '  -  pro-epert stages-1 /4-24./', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A073D4A-D351-4414-A347-73011878D99D', '1D8A720D-3E5E-4800-9BB3-0A7FF3324B9C', '3014260278328', '  -  /2-4 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAFB25F5-36D9-4575-8C12-AF83331A8A2A', 'A6FDB1C0-EAA2-4B39-8DD5-1C2C3FCBE84D', '3014260278335', '  -  5-7   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50AC565B-E4FE-4D53-B988-0A9D5AFD0BA2', '5D63850A-F636-4FF1-912B-9E27C5FBCCD8', '3014260278342', '  - stages4 / 8/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('439041C4-F33B-4440-8116-960A13CD19C5', '1F3D03B4-76D7-492F-BD43-979742B46453', '3014260280772', '  -   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE44CE85-EBE5-4B64-9336-002337D947D2', 'FB9F1EBD-A240-4A35-9229-A2C7331BF2B3', '3014260286279', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ED05EFD-7C57-4572-B0C2-4B2034703387', 'AE153678-9479-4A50-BA79-45E6EF839D58', '3014260286323', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A3404B2-2DAB-4AF4-BA78-4C0D19BDAED7', 'CE6FE137-C3DD-496C-B230-8AB053378858', '3014260289287', '   ii women  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8B5DCA8-0122-47B4-A488-39A2BC951504', 'B6A66CEC-3CFF-4FD7-BF8A-DABC27A4B3FB', '3014260318840', '  -  40/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10D8355A-0629-4B52-B01B-73DD1D329DF9', '920B69C8-631C-4779-9A0B-8428D3FF963B', '3014260318857', '       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E0A27A0-1BAB-49FB-878C-FE29707EA5CE', '9BD99F3E-44A6-489A-8BF0-D5285CAB729D', '3014260782849', ' -  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55C0F509-1089-4DFB-AEC3-A17D826C504C', '9E0F999F-C6AE-4C5F-8CD9-2715361F218E', '3014260795085', '  - 3d   40  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('552562B3-EBAC-41B5-9444-49CBBDD61FB0', 'D78C6857-0F0D-441A-91D9-0E48F0E00527', '3014260799663', '  - pro-ep   / 40/+1  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B632B6D5-FF6C-4196-8C63-2576972EC974', 'E87B469E-9FED-4D96-9D07-1A702FBF7D65', '3014260801786', '  - 3-effect   40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19DE3C7C-8FB7-4BD7-8AD8-45ECD15A166D', '828BFCE9-707E-4AA9-A0BA-2889F78E5162', '3014260806170', '  - 3d   40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09435CF7-50EB-4C4B-9872-63B9863140D5', '94DF2ACB-03DA-4E74-B450-CF0145ED9522', '3014260808105', '  1 2 3      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8AD7781-6386-4661-863C-0913D80E75AD', '774FD01F-82C8-4E94-8DD0-F7266FCBCB54', '3014260821470', '  -    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A893F802-9FA7-40D4-92B0-6613442DA973', '815E7675-636B-4003-833B-CDF9029C8A51', '3014260832834', '    3   40  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E7B040A-FDD5-439B-8B4E-856E07DB1B20', 'A485FF83-08A9-4065-85F6-E88FB9513D40', '3041094499469', '-1  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C4120E8-4D2F-4457-AF14-CB7F64253E5C', '0C2CFCD5-8E04-4E9B-9419-93DE7D4F176E', '3041094710557', '  -2  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D3E4370-4BB5-4581-8AC8-CD1CF047BBEF', 'EB090DEA-41B8-417A-B126-CE2690BC391D', '3059944022859', '  . /.  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7B7C439-2069-4642-A134-7B9771AA5B62', 'CF335E51-8EA2-4852-98CD-8C6872A91FDE', '3059944022866', '   /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F4A7F27-FE8F-447D-91D0-D095EFA7BDF5', '8558BD4F-ED50-4754-9059-051D8D290BE5', '3248140756709', ' /. . . /./ 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8976D19E-4F4B-4775-87E8-6919B7922691', '91EC7FBD-DF38-4D17-8DC1-B3C2F7724707', '3282770014105', '-    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03CCEF4B-11DD-4B9C-BB15-BF7E2293EF1D', 'D764161C-AFD8-4A79-9D1F-9C69EB46FF5F', '3282770014136', 'A-  dermalibor+  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5C8731D-DD63-495A-BF5F-85F16FE505AC', 'B88651DC-0071-4144-B69B-9555B7367EA5', '3282770073683', ' +  /     /c577 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1DF3FF4-73BC-4F6A-85C0-1D5815B6DF40', '3E115946-3623-44F4-B77F-585D6EA1C9E6', '3282779022569', '  -  d.e.f.i.  50+ /c73151/  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17217A50-3BAA-4B8C-84B4-4BDE33471063', 'D5B49109-3192-4F16-AD6A-D13CB3A6C7F0', '3282779051361', ' /avene/      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE6C10A7-FCC4-40A1-87E5-5895869FD3EB', '95EBA195-3610-4CA7-9E38-D118EB68BCA0', '3282779084772', '    spf50+ 200+ /  /c81035/ 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FD710DC-EB0D-4B3B-82A3-F727902C4994', 'B74807BA-9C90-4E2B-A08E-58C483043001', '3282779285230', ' a-   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16898EBE-2BAA-47E7-B667-FC8C811C5E99', '43CC5D51-E32A-48FB-A489-1576CE609B8C', '3282779363211', ' /avene/   / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D1484F0-2531-4A5E-BC30-A61D5BCCDC78', '58C5B493-AA33-4ED5-B890-4F3E5AD32002', '3282779365529', 'Avene    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C306A74-095E-448A-BC36-5A761DE26E99', '1AEE1652-EF20-4E82-A1F9-91ECED09F583', '3282779384704', ' a-  / /1+1/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8644A23E-E792-4A58-87A0-A8E45239862E', '5AF16C6B-1B35-4721-BC90-394258E774AA', '3282779416139', ' /avene/ cicalfate  /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('527DF75B-F53F-4442-84FA-FE7C72DFBC9E', 'A331291C-A6E3-422A-B545-7655BD12AC38', '3352710093412', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8832759E-8A53-4AD4-93AF-7FF11714BF9A', '196BAE5C-8F90-484B-AB45-18AD9C3A44E7', '3352712000142', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38950094-6ADC-4A8C-AAC2-BB681AE1E8AA', '53569D59-F591-4F19-9C4E-F61145AA76E6', '3352712000159', ' /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24F22AB8-10D1-42D4-90FB-4D308F01537D', '3EF0D5CC-EEEE-45BB-A2AE-F46CDA1E9CA2', '3352712000166', '   / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD9E56A1-9D9F-44C3-A0DE-C2FC3178CA21', '1D52B2E4-C13A-4335-8D35-BB08CBC9C012', '3352712000197', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('189CCDF9-CD44-4912-8514-BE017158E217', 'A9AC8C4A-5F5A-42C1-9FA5-0D3AF7790FFE', '3352712005918', '   1 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C33924F-D4B0-4421-A2B6-83229D1BCC36', 'C3DAEA23-1CE1-4B90-BAF5-666D6B850DA9', '3352712006106', '   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05253BC1-3221-4DCA-B141-276125B20D0B', 'C14BD19B-78E5-4F56-9776-AD1AAF345E0E', '3352712006205', '   /1 / 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E433455-ED00-4202-A068-7DAC00DBFEF7', '1EF41A0B-FC4F-4361-905B-E0A98F3A07DB', '3352712007028', '  1 1 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8B26A29-5AD6-4B7B-A62D-4BC79ED18A26', '95F110B9-B460-455F-AF92-BD108AEF5817', '3352712007202', '  1 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB66FEBB-6C46-43F4-9952-0CA5EFE9AB00', 'A6B28125-05AF-45B4-9C3B-DC9A92854544', '3400934195389', ' 0,1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D09F9BC8-C01F-40E6-9A63-47ADE1E6ABAA', 'C341DDF9-42F7-4A8F-AA4D-C3C8D582C65E', '3400935381316', ' 5%  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('524EFF0F-3EE0-445A-8C56-829690CAF5CF', 'C341DDF9-42F7-4A8F-AA4D-C3C8D582C65E', '3400935831316', ' 5%  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82C2D058-12BF-4B8F-B505-96F17FE1526D', '7D5CDB3B-5AEB-492A-B87C-8882D48B75D0', '3400970000685', ' 2%  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('748814F8-4590-4CDB-BB5B-A3A2B1C6285B', '71C7774D-BBE3-4D59-8DF9-61D599742515', '3400970000746', ' 0,25 //  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72FBA461-DC37-4EF4-9927-6E5F2710811F', 'D455A4EF-22BA-4CAB-B5B2-40D2BF401852', '3400970000753', ' 125  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95154155-4331-4DEB-A746-207507C0BAE6', '81335528-6591-4D9C-ABEB-D079A087CD7C', '3400970000982', ' /. .  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('792E7A39-9AAC-445E-BEE5-0F768C6601C7', 'EAEC0B51-33D5-4A9D-A002-FCA43B56AACF', '3400970000999', ' 10  -  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CA8E073-1565-4EE0-903D-C39BA4E8B7F2', 'A07556CE-2D41-4821-AAC6-607014DC291A', '3400970001026', ' 20   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ACC6FBD-5038-4AD5-9EB9-06256E55FFBD', '4031296D-8007-46C9-B6F1-4B44BF7411E7', '3400970001040', '   1,2% 72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6586FCC4-0D38-47F5-B4AD-AA17D106F1B0', 'A4660CF5-801C-4930-99FF-26B61CC5BCF1', '3400970001088', ' 18,9   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3316D01D-8FAE-4E18-A715-9B68CDA7FA6F', '5E7B2235-C481-4A7F-AD39-80E9B0DA49F5', '3400970002139', ' 600  / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5021708D-A9E6-4FE3-85C2-456C13CC1924', 'AE8C6257-ED34-4F60-A69D-0B94A3F6E9EC', '3400970002818', ' 145  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('937AAF95-F632-45A1-B9D7-15B2D225A239', 'D9FAB56F-3E40-4009-9C77-E40016CD51C2', '3401045444878', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF5A8641-1B37-4CB5-98F4-E2E7C308F565', '8F21A8C5-AAF8-463B-AF2C-2B4EB9E019CE', '3401347869546', ' cicabio    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E1B42A8-44AF-42C6-ABC8-637E0C5EEC1B', '3BF4EDBF-14F9-4969-A736-F94A6F3FF3DE', '3401381331436', 'Svr sebiaclear  - 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CC2EED0-6354-4DD3-B45C-0AF6A5B39089', '01168214-EE49-4A48-A6B0-07FD5D99A2A3', '3401575956261', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2AE853E-0A94-4E4C-91E3-BA6D8994BD72', 'BB55B859-67B4-41A4-96C4-2FE880CDB325', '3401598315304', 'Kelo-cote 6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('022A3CBB-97E1-42D0-950C-38A438B11C6B', '535E1F6B-DBED-44DF-9388-D647A0094EEA', '3401598315472', '-  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('906D7181-24CD-41FA-91DB-40A7F5C1D577', '7D243681-AD63-4FE3-811C-980A6874CE8B', '3499320002004', ' 5%  / 2,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('205509E8-4B96-4C09-8CA8-B38CF4E7A84D', 'F09B642E-10A3-4CF6-B1C8-43B0EB22B177', '3499320002073', '  0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD594242-5239-4EA1-BD3E-B4C6837F5214', 'E1D1C449-FE83-4230-AEA4-31149FB9D12C', '3499320002127', '  0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C76990E7-FC03-47FA-B0AE-676BA341F9F9', 'DEF9688E-013D-44C2-A7C7-268267227418', '3499320002196', '  5%  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04479318-8D6E-4549-8966-FC629FB55507', '63C5411E-935B-4E76-82F3-1D241734938A', '3499320004565', '  / 5% 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19FE7CBD-E287-4B43-AE12-C1AF9E2D8E28', 'F8EBB022-90FC-44F9-BB6B-779323732C98', '3499320004855', ' 0,75%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6D94426-A659-4D32-8CC2-4000A8A7DF23', '4E1BFB37-D7B6-4858-932F-9A8AA2273F5C', '3499320004978', ' 1+25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18CDDFD4-7732-433D-B1C8-6240D6679C7C', '584DA850-7B70-447C-8E50-E6CA6BC23D09', '3504105005344', ' - stelatopia 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B224573-6DD4-4E7A-83FA-B7C7BE1B2197', '8BF1489C-831A-40F4-9CC6-50E081A03EFA', '3504105019884', '  / stelatopia 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D9EBD3C-1F94-4824-B3EF-FDAA7AED9CAB', '0D448F61-FF27-41D0-B1AE-5C0874FFE839', '3504105024932', '    1 2 3 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E84BBC33-8AB7-4B59-8513-C5DBE3DC01EB', 'CC90D8B8-A50C-488C-AC86-28B78050A71F', '3504105026486', ' 300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE18087F-1AE8-49B8-8DF4-B8647753D924', '987E2497-110C-4583-8272-E2039EE6A247', '3504105028183', ' /mustela/  / 21 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB4746A9-0F78-4AC2-BB5F-A5014EAA8D9D', 'A46AB731-4DAF-41EE-ADCD-F115800ACDA5', '3504105028305', '   / hydra  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D54EE3F2-6FB4-4596-93A5-82DEE0A17BDB', '2F41582C-B9AE-4AC7-BC39-CE623620951D', '3504105028398', '   / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA82DF07-DE5C-46BE-BB90-660F58E87B64', '1B44C55E-3F08-4E65-8A2F-40190595ECA6', '3504105028947', '  stelatopia  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09EBF7A6-DBD8-467E-89C1-D6970FAC73A2', '2147D141-5E87-4E04-BE03-82A30A05EB6A', '3518646050138', '- 2 5 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEE6C089-ACBD-4CB8-A001-A09641FC94FB', '69FA37B0-5AC2-46B2-B6AA-B48A8B0B6F83', '3518646057342', '- 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C165C90F-E7E1-4739-A140-0F508E7D8B7E', '355ACD44-C474-498C-BD50-775AB351820D', '3518646057991', '-  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ECF0B94-841B-4B5F-85FE-F0A31A59E7C6', '52DC8EA1-DEBD-4CB1-9D0B-C331839080A2', '3518646081422', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F344BDD-7FBD-4079-8566-FBAE175477FD', '935A63C2-0E24-4B64-B136-B6A935C1CDBE', '3518646671074', ' 100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FC951D4-CA3A-438B-B3C1-3EF29C8887BB', '36FF5B4A-8EEC-4700-83D4-F8131A019576', '3518646671081', '  100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4BF8F8E-D91C-495C-BAEF-5A0478F7452A', '9F3272DE-E2D1-4A6A-9950-C9B67E4561A0', '3518646671586', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C5E02C2-819F-43F4-B640-15E3E6A85AFE', '5DC6FB74-F02F-420C-9AA6-0BCBB75C0882', '3534510000207', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F670491-4DB5-4C77-B3E7-888090B0DED0', 'EB76C305-20BB-4BB5-9162-6C47AF0CD8B2', '3534510000221', ' 80/680    24 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C4FC126-F0A7-43E3-AAE7-7E52F7AC47CF', 'EB76C305-20BB-4BB5-9162-6C47AF0CD8B2', '3534510000252', ' 80/680    24 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6893C06C-E518-4BAB-B47C-18BDB2A08FEE', '42BD08F2-5337-4692-999F-48AC5A88C2B9', '3534510000276', ' 80/680    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CA4263F-55AD-423F-BC3A-24726A790FBD', '9F0E7810-5FB7-4AC7-AB3F-22A005ED5585', '3534510000566', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('284E6BFF-D6FD-4CBB-9196-2E37B8806F0B', '984E70AC-E7EC-4F25-A8B1-E7AA94A5284C', '3534510003703', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('427DCABA-6A01-4763-BFCB-3AD3EC1CC83E', '868828CD-63B5-4408-A3A8-D6A908A81943', '3534510005707', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('698E9CEE-5483-4EE9-90B4-19ADB65C5524', '4F5294DE-8F28-4CD8-A354-8EA944227F3A', '3546895507141', 'Humer   150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE973707-8A68-4375-B506-DB90DA1CF38B', 'BB21013C-2600-4565-BBCB-5BB18605BF37', '3564300001022', '  . 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('659C6497-329B-4FD0-9C50-985716E26C57', '4EF803C0-D21A-491D-9D75-288382E7F135', '3564300002104', '  135 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BF93CCC-DB14-4D20-BC23-6B178242B850', '0E09847A-9F69-4682-959E-A7ECE9A8C738', '3564300031029', '     3  115', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('467E2B7B-BC56-463B-8E2E-48E4F2C320F7', '1AFC1553-A755-4D03-8EB4-0AC63E2A499E', '3564300031135', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E352909C-8512-4760-B96C-9F833EF4FDEE', 'BC1B2047-A78A-4C6B-90BE-E0D3BAF54097', '3573991495461', '  80  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('219F056F-3BA3-4A83-87D2-DC23F3CBB214', 'D0AFBD4C-EF80-4BC4-BB85-C194248EDB4D', '3573994000099', ' 750  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('590F819F-63D4-456F-A0FD-B7A36D20E74E', '90DF9DFF-61E8-48BB-BF96-4A64B1287729', '3573994000341', ' 830  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F9667BD-4DB9-4901-A27A-0FD23BAD5D5C', '90723C8B-8E4B-42A7-90F8-B487083CD731', '3573994001720', ' 750 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0CE453A-18EA-4B0C-86DD-6BCE5DAD7EC4', '9E87D85A-9486-4DE9-A1B8-E4FE7899F45F', '3574660026726', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A675071-F137-44C5-A06F-1AF755E626E3', '1BE56FB3-C351-4898-8007-95B632A0CA6D', '3574660030334', ' -     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('635A5C1B-05E8-44E4-9A50-7F8B1DAAFF8F', '9883484B-C9CD-4478-81A9-31BB19D1BEA0', '3574660051834', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E423685-8BDB-40F7-9777-99BD1F310EC4', '5993AFE1-7F1B-42A6-B598-4B32094D36B0', '3574660077049', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EC0FFA1-0FA3-4E72-BF71-9F03EEEC86FC', '4C1EB4DD-820C-4B66-A866-D2034D9196EE', '3574660085563', ' /  4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B341C514-18A7-4177-9CBD-DFA874DE7FBE', '10453B14-1E2F-4C52-B27D-CB5E786BA2AC', '3574660089202', '  /o.b./  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1FE2096-FF4E-4266-ABA2-6B197ABDC414', '507247BF-B601-49A0-8290-543C9753C586', '3574660089295', ' ..   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E68D23F7-5B1C-4583-9E88-8942C83A832B', 'B3A9E3CC-6C96-4BEC-AC59-97D2130CB81E', '3574660089318', '  /o.b./  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2747F57B-9404-4C35-A3E2-CC19B96FBB46', '9E17C629-AE18-43A9-959C-E25BF744DDA8', '3574660089332', '  /o.b./  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('673F2C93-43CB-4559-A261-6BE99328C2FE', 'C3890EF6-C2F9-42F1-9C01-EB992CAD42EE', '3574660089356', ' ..  + 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68535B39-169E-430C-BC86-E9BCBC608A75', 'CF368B89-1FC9-4C42-8E98-AF34EC65EDED', '3574660108293', '  -     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FC7FE0D-B2F3-4E73-8CC6-8BCE43231565', '481BF463-7D91-4922-8CFB-A72B25E84BF8', '3574660127362', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62C418F0-A775-476B-8EBA-D20171C55FDF', 'B739CFDD-AE7B-4571-A8E1-D34268D70111', '3574660142303', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A90D606-1E47-4628-8320-E4CD211F5EE5', '417F77A1-9E30-4B6B-AD49-F4CDD019FCA4', '3574660142792', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7BE0174-5E5B-452D-AFE0-4C409FFD9CF1', '64F91558-4D6D-400D-B979-5603BF643448', '3574660144703', '  /o.b./  32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3D1D0F6-C193-4A39-81FC-C2CF65EADA02', '764EAAB1-EBEE-4603-8678-19950B4457E4', '3574660146318', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C427335-5456-46F9-907F-59A6AC884C0D', '1F767031-9EFD-4E02-9986-D2D5D51B1AEE', '3574660146455', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58729D4A-87C4-4D0D-8B8F-A7CED9CF637D', '4DB91271-BE53-4ADC-A847-E7789DA81E45', '3574660170832', '-      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0917F44-1AFB-4F52-8545-80B9C4F2BA2F', '0FCD8FE5-4E51-4F70-BADC-ABA4FEC48527', '3574660192063', '  /o.b./   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5ED1F4C-598E-463D-96CD-9161F5DF4302', '7CEA7549-6BEC-4B2D-9EF6-4DBB8F064C81', '3574660195163', '   /   300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4F92E3E-B39D-4521-B69F-523FFF905A1F', 'A57CDA1A-3544-473A-928D-CA19FFCE1A58', '3574660215540', '     300+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CBCC0B5-FA25-4EEC-A7D1-FA41902B13E5', 'B9A669CF-2C14-45C3-BE45-78D3489DDD3C', '3574660226706', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8003BD15-A0D3-4AE3-A512-F033D563A016', '45C24F2E-471F-4519-88BE-50B5C5445A75', '3574660226720', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('968B928B-EAB9-49A6-81B0-CB49F767043A', '16C0BE30-351A-4A73-AF7D-7B0EFFB38606', '3574660234282', '  /o.b./   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DD6AED0-488B-4509-A0CF-A630CC10847E', 'BDA0652C-739D-4AD4-8A8A-D903F160D5D7', '3574660234305', '  /o.b./   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02B03CFC-1A92-4911-8969-E39EA6A27076', '4656F89F-A999-44AE-9827-78E91B3546D8', '3574660234329', '  /o.b./   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAB03D51-38C0-4A02-B4D2-1D658C19CE6F', 'B848947A-2B90-40F6-AC8F-E67657B6D1B5', '3574660234343', '  /o.b./   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADA221E2-3DF9-4D10-9D99-171193159A64', 'C6D62C29-9766-4E79-8840-26090B2B5B5B', '3574660249415', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F06EDC6-EB62-4839-949E-49389A399533', 'DDF2FD26-7790-4015-8997-7172D048C67D', '3574660256635', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('510C2305-5D0E-48BF-8CE3-53BB38D8AF96', '80784C14-44E5-4746-A774-0C92E495847D', '3574660262438', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('087E2731-DC7D-474F-A063-CCE16587BBFD', 'DDF7835F-D229-4111-A750-D90B3664FF16', '3574660277364', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DB5DA49-2E95-4A3C-AD78-F9C37B18741D', '7BE83108-56F3-47FA-895A-9981379113E5', '3574660329780', '  /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4DA7F3E-6AD6-4B49-9945-0ED18905E81D', '6598F1DE-9D53-4E26-A9D2-985A2208474B', '3574660383799', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0473142-6331-4A19-B792-454E91B2E8EA', 'E83F8694-5A8D-4155-A1A8-13CE5ACDDA53', '3574660385588', '      64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('842D75F2-C84F-48B1-B9F3-0BED1B23B8D7', 'FFAB553D-E45F-484A-A8FA-29335951F95F', '3574660387360', '      128', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F174C1C8-197C-4E25-8A0D-79CAFF42645C', '2D141A6C-0E9B-4D91-8545-2FC906BA8F49', '3574660388909', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAEB6945-1126-4F18-B947-92976592E222', 'AB0C4BB0-206D-4DCE-8F22-ACD01CA0F6B8', '3574660410525', ' - .  /.  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('277F14FF-D810-443E-888C-15145DF6D8CE', '6813EFD2-FC5F-4726-B759-AE22B4F4C036', '3574660436174', '  . / / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E29D20A6-F143-476F-B56B-20E5D657D861', '8D878A09-5B32-47C7-BAB2-C4CF0047B47F', '3574660436181', '     4 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDBFF2D3-9DE4-4070-A2C1-2E2D3AA5B551', '5051CCF6-484A-4C0D-A472-BC867541C60A', '3574660444339', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCC55897-1DBD-451F-970E-847ED28553B9', '06BE5654-6C7A-4743-A0A9-4DF973C366D5', '3574660468601', '     2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ABF4B53-061E-4EB2-AA9A-C368B677BC77', 'C3B75943-E84A-4815-9738-0318123BC70B', '3574660468618', '   4   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38CAAF7E-E217-4515-8A21-DE1EEDA78132', '2B68002C-158A-4792-9C76-375C638359DB', '3574660471489', ' . 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6164860E-9090-4A5F-9C34-F302B3BDB598', '3794435C-B05A-45DF-A82F-05990B30D8F0', '3574660476354', '   10/16  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3A241A6-53DB-4CD6-AA7A-7B23A2612CCD', '76D007D6-FE09-46D8-BD8C-E7EC4C6ED061', '3574660476477', '   15/16  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5628EAD-21A5-4BF9-B119-5E7741C9EA2C', '3C5C6AC4-FDE0-4E40-95D7-555B9BACE62F', '3574660476590', '  0,025/16  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C54062A-BD3F-4439-A893-001FA70A3081', '5AA8F6D7-7DFB-40CD-A109-83184320838A', '3574660482232', '  -   . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98893298-1598-4DE6-9E63-9809D7E70722', 'BB7391B2-5646-444C-8DDE-48827C51743D', '3574660482263', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14178E6A-CE46-4E82-B54F-11D1C857FE0C', '306E070F-FFF1-4039-AE22-CE4ADD9E268A', '3574660482676', '   access ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8551802A-429D-40E8-A134-07DBFF48A996', '58BAC124-F87A-4F29-991C-64C9BAB8D599', '3574660499001', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42ADE4B2-6EDA-447E-9B0B-652D5512C679', '91F615BE-B8B3-4EF0-ABD1-9E7AB647C496', '3574660500837', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59994A82-D4F4-44B0-B33C-C65451425A60', 'D1E688BB-2CF1-44F4-AF90-CE84CFFC4A8D', '3574660505818', '     24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F19D7B65-3B53-4F7A-923C-01A6DE9A9DF5', '8B0DEFF3-F5E2-4CEA-A3F7-30A8958090AE', '3574660505832', '      64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2F3966B-6677-4072-AF2C-BC6DB99DBFCB', 'B08F33CA-7667-4139-8616-F014C5D5429F', '3574660505856', '     128', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F0150E2-E242-459F-B66C-E3488ACA1B0E', '3EE43F57-FBFC-41C3-8D88-6264F9BEF18C', '3574660523225', '  57', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('462B5908-8A9F-4DAE-AB51-E64E0D654864', '86622071-5D7A-4D93-9FE8-62383FFCD67D', '3574660564495', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D74825B6-4916-4C2F-9543-707DFA3CFD06', '27C49CAE-DAD2-4B7C-9C4E-24AE162EE064', '3574660564518', '   10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56C3D058-F853-46D6-850B-DE7CDA599F30', 'A9F053F0-EB8F-40BE-BB20-09334867454F', '3574660575392', '    clean /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D722812-6307-41B5-A690-4A0B765242AC', '0AD31D50-8B6C-4327-A8C6-0484B133FB10', '3574660575422', '     / / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3468BB3-0FCF-4791-9F38-A509743A7710', '46DA7A47-8A88-42A3-9C3F-3C835DD9D5F6', '3574660588859', '  . / / 4 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0C1B550-459A-40F1-BEC9-B293034EBF2E', 'D0C4E31C-327E-4A44-96BA-3ABD48F8A683', '3574660589436', '     2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('448DC0DC-781B-43BD-AF43-F25337672DEF', '8F2AAB0C-DC17-4441-9676-1503FB109F86', '3574660598698', ' compeed      1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27EC707C-46E5-4EC3-886E-6A62A17B0304', 'BA58AB4B-E1C4-4921-B0FB-7D549AA8C018', '3574660610215', ' /.b./   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF5525FB-E440-4705-B6E2-59D30FA88D59', '9A445F80-9B56-4D9C-8E15-84569D8222BE', '3574660624106', '      200', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC869981-F333-45B2-9876-15060995C6DF', '6FC0E4E3-1A4F-4299-AF14-1C5C0EA1747D', '3574660639643', ' - /    250 /1+1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDA519E1-25D8-41FE-B0D1-E3D1B0C3FF52', '648DB1E0-62DF-4B02-8F4D-49627671CE8F', '3574660641639', ' /    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEAA8BAB-0F70-460F-9EBA-5968525F8A22', '46B96F6E-605F-4082-990D-64D46C9B6110', '3574660650822', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88006479-2640-4344-88F3-FA4B84031663', '7FD2D6A1-F814-4E1E-92F8-03E62C1158CC', '3574660651362', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79AF91FC-E9E4-4749-BB50-780FDDEF1B53', 'FBDE270D-8826-45EA-AB6B-0733321EE418', '3574660666564', '  - / 2  1   300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4BA229F-EA19-4838-B318-EFCE09963BA6', 'E78D3C29-8513-445D-8D95-3D8A026949E5', '3574660672077', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00066FE8-0AE7-4C95-A917-F2CD931B5C2F', '35DB03DF-B099-4576-9AE4-D68FF1F0FBDE', '3574660672107', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE1E6A10-10C7-41BC-AC96-471FEF5D2FE0', '5E756CB6-CD4C-4940-B22F-F4671EECEBC9', '3574660672169', '    300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7597138-F509-4D48-B5A4-F66F6065E5DA', 'DC495E1A-662E-4EF0-ABC2-3D970A7C0853', '3574660678772', '    300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BBA77BC-06F9-4BD0-8B21-3E9FE6B6AA7D', '09EF3D02-6470-4D0F-8DD8-F9C7960927CF', '3574660702606', '  100/5  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3878A79A-B45C-4B4C-90B1-C2A1A09B6582', 'D0C83841-BA98-4B58-9054-E769D34CFAA3', '3574660707977', '  0,05% 0,5    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAB2B49D-7007-4040-921C-AB104036E51D', '56FE7671-C6CC-490B-A404-35256D09C107', '3574660709315', '      5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25F93D70-5E80-4F82-9818-2546ABE8B07E', 'B74A7A29-E397-44BC-98FC-477F231467C3', '3574660709346', '      6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C3447E8-DEE8-42B9-ABC4-AF6CBFB522D7', '8D175F1B-4FC3-431F-ABC2-C1CD8B532E3D', '3574660709377', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFBF8656-D2B9-4C67-974E-99779E532107', '6DB2B79C-94D7-4F21-86CA-4AAD8CCADE36', '3574660709407', '        10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FA5CCAF-D128-40FE-8B52-B2CF61D36F14', '80E9BBCB-FD60-4318-BFAC-3C20FFF0A0B4', '3574661039190', ' 10  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77ECC154-28A0-460F-863C-F3E4A696D45A', '733E0FA5-D0D6-4DFA-AB9B-85AC26058F74', '3574661047355', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2F63ACA-3EF4-4FC8-A642-7A7CD6E1F3E1', '9371DE7B-45A6-456A-BA50-10953E6AE4BD', '3574661047379', ' 10   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D4AE4C2-7C50-4D34-899C-8CCEFC1285EB', '08CDE0E8-1010-46B6-AF16-2AA81CE1837E', '3574661048277', ' ..    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDA819F3-6F82-4774-B346-35E4E6FD2DA0', '8DCE7F37-D864-45CE-8E9C-98E2AF6F3750', '3574661048284', ' ..    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A64F927-7660-4F6B-AF15-67C41F1E0FB1', '89AB8FDB-D0BC-4DA5-A1D9-ACFD99DE62C0', '3574661048369', '       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C81E95B2-990E-4F27-99A7-9CE84E84A296', '171964E8-8A60-49F0-ABB1-B0050AFFD687', '3574661063782', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB26FC92-8F59-4DBA-A2BF-01D5680FCEF9', '91EC28DE-A3BE-4BF0-A32A-053F9793B385', '3574661064307', '    /cotton 34', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('414D58BD-C45A-4C24-A4EA-0FB291B90E16', 'E6ADA669-1A05-4527-B092-861AD3A359FF', '3574661064321', '     32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1F27CF1-7711-4E57-9F1E-C8827E7E3C19', 'C61B87E6-135F-4EB1-93E6-E1111224B24B', '3574661064352', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FA44062-EB4A-46D2-8471-9BF4BC564F65', 'D259789C-000C-40A5-BB15-D2543BE14979', '3574661098135', ' 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4AA5CC4-E187-4446-9BAC-E05FA8765A81', '2BA37053-EDAA-4851-8C76-032D84837F2D', '3574661102566', ' . 2  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C41566EF-F84B-4AA5-BC01-2E87AF4991A9', '1758D237-3E6B-4742-9A56-35F63C16A972', '3574661104522', ' /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C385200-7311-413E-8855-9BBAE392E9AD', '3EBF0742-E219-4DA2-ADEC-59FBAB726A66', '3574661130378', '    100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB2F750D-0B51-46E8-B301-C169F5056A55', '280E3BBF-FB59-4156-A9D9-E6797A86F46E', '3574661132211', '  50/ /100 / .10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDBC5650-875C-41C4-9907-E193408D6A6A', 'D20BF279-1DD3-48E9-8EB0-623856161CF4', '3574661133911', '  /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F336823-564D-46A6-82F3-FD2A366F4853', '06F565DA-C85D-43C0-889B-D3EA7CE7FF12', '3574661133928', '    /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE0A5FED-3132-4CCE-91EB-331AFCA67F31', '7FCE5C1E-EB1E-4EA7-9D35-C3ACC624FAB4', '3574661133935', '   - /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B5D9A0E-A383-40C6-B044-702C08313C2F', '77464129-FF7C-4AD1-B691-57C90B74F98E', '3574661133959', '   - /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F118967A-3E46-4190-B712-CD5128F5072B', '6DF91E54-8255-47FC-AD6C-48DF3C095597', '3574661136363', '     16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C608360-AC0F-4874-80BE-02AAC648B1BF', '22FB604D-6E6F-4760-979F-207522E76B6C', '3574661138442', '  57', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B9A10D1-3D7F-4F03-8B3A-E35684144C9B', '620095C7-CB77-4548-A79A-0699674ADDE5', '3574661154305', ' 2   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55C0E630-04FB-4155-AE93-7ADB81A5CBC6', '07B18CFC-FD81-4F3D-90F6-103D3E25CD5A', '3574661156750', '  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A282C3F6-A492-4563-AC7A-D96D9906443F', 'D48A1E48-2119-4025-B94D-A2FC198306BB', '3574661165738', '     25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E2ABBCB-4CF1-4079-BFF3-3ADA0D803ACE', 'EAE79AFA-C6B1-4D16-9550-E2E75D96558A', '3574661171883', '   31   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2A8C9B0-0073-44A5-BEFB-9947B612D6E7', 'D83D47CE-9986-4BE4-92CC-37A86A4E6956', '3574661172453', '  pure protect - / 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73787AD2-0EBB-44CA-A0EA-4A28CE34A4B8', '4EA91276-D6E0-4ED8-B6AB-38892B1C80A1', '3574661188317', ' 1  13,2  /.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64A85082-C705-49F3-8415-DEFAB9A5ABC8', '68707983-F9AF-4898-83FA-C261F015F95E', '3574661189482', '        5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A1D074E-2884-446D-81C3-6261B483D537', '876E0698-86BC-495D-B7DB-8A80404DB732', '3574661197005', '   / 31 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5304C6B3-4275-4841-9986-02CE30BCE721', 'F299087E-4219-4278-A7C8-565400CEE9EB', '3574661207896', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD7743A0-B106-4DC9-BB56-73D6DDAF4BCF', '96917897-FC02-404F-B79D-5688FE5229CC', '3574661215549', ' 0,2% 40   4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03215F2A-0AC6-43A5-AD37-CE17A7F388C4', '20230B54-7939-41AB-B392-1648287A7D7E', '3574661218915', ' / .  5 - 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F34D321F-CECD-41C7-A524-C76B2FEE7E9F', 'D64CCFAE-661B-4F6F-BE30-5A1BACE81F7A', '3574661253398', ' /    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22934A56-8F91-40B5-8A63-FCC531294980', '174A74F7-B5F9-4D1F-B143-D7785095EF65', '3574661287522', '    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAB52BFF-3E88-49E2-B5C0-801719C6C7BB', 'DDF90846-0FA8-4346-8C4E-93CFAB3DA85B', '3574661309712', '  / .   0  // 4 5 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9874ECFC-A1C1-49D4-8EAD-283F1338BB8F', 'AD6A2E6C-649E-4839-97EB-1ED225AC7CE8', '3574661343822', ' 0,25 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C394E45-5B5B-49FB-AFAC-33FFDC6DD9FF', 'D0D05F09-4F64-4E51-9D65-7E1C6AF7F4F0', '3574661343839', ' 0,25 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBB85FC9-B85B-431C-967B-8DCEFFA438E2', '916100DB-A486-4ACD-85A8-1AB8B603E50C', '3574661424057', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23784D95-7E74-4D8B-90FB-CF0E8CADDEBE', 'C9A3EFA2-4774-470E-9F05-6138D0BCC1F8', '3577057000781', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFDDEF8B-04BA-45C8-A726-6D4297129898', '5816331F-72A4-4767-90F1-758637906901', '3577057054678', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29D01291-2BB0-48AF-AFE5-36F596BBCBED', 'D5703407-4C8E-48B9-97BE-CC14E1ADEF55', '3582180535345', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03C5CA4D-CBEF-4169-932F-560F310E7E58', 'DBE76F94-0226-40ED-95A2-4DE0E07BA900', '3582181632401', ' 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DE49498-808C-4960-B327-6A4D5D655FBD', 'D9D761A6-9E15-4AA1-98FF-975A27B689F0', '3582182990401', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3116D5A-36AE-45BD-9AE8-649B6653E9AE', '48598E93-C602-4333-AB42-BB5B062E16F1', '3582182990630', ' 40  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EB2D751-DB6A-44C3-9D27-B8C49FCCF3C5', '62DA97DC-F4EC-4691-B43F-FB8061B10F6D', '3582183043212', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0EBBA90-35E0-42DB-B0E0-697670F7584E', '826AF566-CD81-4B75-BC17-205A3E20FAEB', '3582183899703', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('532F40B5-069A-4D07-BFC5-04C24B084B97', '0C23E80F-3627-40C6-9D54-01800C291374', '3582183899789', ' 10  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21C57A35-BB2A-4A31-9D82-3D483F35590C', '75371A22-CF34-481A-B47C-8958B40A90CF', '3582186001745', '  /-/  3  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('376D7030-DB0E-4DEC-976A-B43F9A502AA6', '0498EF18-336B-44AA-BE33-5C4BF9D68F3C', '3582186004500', ' 3 ///    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CACA08C-C0CB-43F7-829A-38F1968600B8', 'E9B120C9-3839-450C-8BBE-B16E96470A5B', '3582186052129', '     4 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('358F183B-229B-41C6-A126-7A6CD198D589', '18C6A259-AEE6-4BB2-90EF-B3DE06A9600C', '3582910000051', ' - / 50/ 3 .6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E18FFEA8-90D5-4E11-A325-43C5B242F581', 'C7129781-BDDC-4F1F-97FC-CF704F0A1881', '3582910000068', '  300  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('925A5E5A-0641-42C6-AC1A-C6D045ADCF39', 'D4C71F78-E921-48B9-AC7B-AD13119DE2C5', '3582910004301', '  0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C18BBC27-7D1C-4F3B-ACE4-FA1A3110389C', '57A79024-8F85-445F-83FF-61428C7ECC54', '3582910004318', '  300   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F64A54A-57AF-49BB-AAC2-8423CB80E82A', 'CE06624D-C4F5-41E1-B275-0EE2539ADE37', '3582910005292', ' 200  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('223FFD38-A44B-4680-963D-CD3FF64C8C36', '3883E4F0-EED5-4590-93A4-50E36296026D', '3582910005315', ' 200  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F96CA80F-CE0E-488D-B1F1-297DB128DFF5', '16BBB9AB-72F7-4FAA-93CE-435DB0D75E90', '3582910005322', ' 0,02  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C3B28D0-23A2-4DA2-9835-3BC72B8CB23A', '2CB37BD3-AE67-490B-9C32-58C559A2CED2', '3582910005346', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E44DD655-04E3-4FF0-A5D1-11E3FF7121F9', 'F7BFEBBB-9F90-49F3-98B5-4FF615A9AAC8', '3582910005636', '  210', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D2D3DC5-3D74-4C7F-81B8-1A3081882E71', '6BFD2577-2B8A-4A80-860F-A0E781BA0035', '3582910005643', '   135', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('707DAB32-AAD2-4C6D-978E-4DB4945C8CE2', '689A949D-42F5-4518-AAAB-53379E363AE6', '3582910005667', '    2-  115 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44FF1E7B-1276-42F5-8A7F-CC6336709CB6', 'D6251E79-DC3F-46B1-B03D-739F1F68E64C', '3582910014188', ' 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA4EFF7F-D4F4-49E8-98EE-433B23C0079D', '0A3E6521-73D7-4B9E-8AB7-4BD377299B20', '3582910020400', '  100    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4927EA09-0381-4EE1-B5BC-CFF912302C62', 'EEE70CFD-CF47-4763-890F-77B5FC459FEB', '3582910020417', '  250    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDBED9EC-E5A0-47D9-B5BA-C847FDA38273', 'A0AD5213-AA2C-4930-A723-F4D1FA221B59', '3582910020424', '  500   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FA76AE6-12F0-475D-90EB-ECB5BBAC4C17', '80B9C6F5-A764-4AE9-8C88-490D316BC550', '3582910020431', '  750    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85B81CDB-D57A-4FA6-A432-B7A3463B1CB3', 'BA07F474-8BB2-4B67-BE19-9CD9507A9421', '3582910020448', '  1000    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1284C7F3-42F9-4535-BA87-6274C8DC7D6C', '6950DF1B-6B49-4983-8973-527FC0F7C472', '3582910028956', ' 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('826D3A6B-D514-413D-8501-A377F8BD280A', '1454A714-9352-444D-890D-4CD3FC2C8AEC', '3582910033707', '  250/5 /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AE55C1C-B487-4731-B69B-6978931D64B1', '9A017253-D875-4FA6-B659-BE465094EA4A', '3582910037767', '   300  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4E21761-D6B1-464A-A8EC-E5209F12F9AF', '76CE8734-E40F-4923-A04A-D488C0CC271E', '3582910038566', '  2%  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93BC02E6-5EC4-4F8B-87DE-82ACD2C63368', '992D392E-F3E0-4602-BCCB-2DBCA23639A3', '3582910039570', '   2+500   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3D0FFA6-ECEE-4AF3-A93A-19E5E6C7C4FB', 'C0E7E964-99BA-4178-9D9E-151B37CF2ED3', '3582910040712', ' 100+75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('571A5781-7F58-4133-8332-94B25575CDC5', '3B148E1D-4611-4732-BD0E-F230A74825FB', '3582910043676', ' 6   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AFD800D-017F-4D6E-B2ED-0486D50A270A', '984DF39B-8F6A-4514-833C-BD2A4C0F8E66', '3582910044567', ' 500   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3BBE215-67B1-4314-ACDE-402487C5F543', 'E390EBE8-661C-44C3-B314-0BDA2700D32C', '3582910044796', '   4,3  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED5D5FE4-E326-459A-A800-023BD89087ED', 'CDE6CA5D-5D95-4FFE-B6C9-BB1753A7B087', '3582910046257', ' 200  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24637221-8C8D-4AAB-B272-D8011F78B67E', '5FF56547-2540-406B-A1A7-61774E6688DF', '3582910049487', '- 2% 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF9EE594-281C-4C4E-A50A-A245916490FA', '65E6DE5A-6CAE-48D6-8280-BE1BF491AA3E', '3582910054511', ' 4% - 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('682670BD-EDF5-4E02-8F95-F8DA297A84B3', '6D19AD70-29D7-4DF0-8A24-AEA9846DE6E6', '3582910056393', ' 150/12,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A71C9F8B-8220-41E2-8A47-D70A4D0377B2', '1CB4FE62-5488-4AFE-A9C2-42AC148C1EB3', '3582910056409', ' 300 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08E2B09F-89EC-48B0-8F8E-DBCD4FA45A4C', 'C638C5FD-B93C-4CCF-8133-EF1C648D4BBA', '3582910056539', ' 150  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4639597B-B440-4772-8069-941FC183B7C1', '55A9B7F5-1896-4BDE-8322-E21FE7B73F6A', '3582910059400', ' 10+150 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15B57530-E37A-483B-BD69-E2FC3E396B57', 'CB562DC8-A928-42A1-A17E-7E2C39BD7BD5', '3582910059417', ' 10+300  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F76B3F31-0F72-4E19-8024-C2DBBE2364B4', '228BB76A-C77B-41D5-9204-A5BDC76725F9', '3582910059424', ' 5+300  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7809E1E4-DD96-493E-9BCB-A2B80B46026F', '024C3E94-9BE4-4355-905D-E479850B8BDA', '3582910059431', ' 5+150 /  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28A24A39-85E9-4888-998A-11B93D98A6F1', '82EF0472-1107-4753-BC5F-785757FCF2B6', '3582910059745', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09E708FF-7568-44E9-9C4F-37E530A33798', '9606A84F-9CFD-443C-82ED-B21EB1B30C37', '3582910059752', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38F36993-657A-4B84-ABD6-306F7F52C961', 'E304B44B-D427-466F-89BC-34C4C5F8FD8B', '3582910061069', ' 2  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43187023-562B-47C7-86A8-744B29BE8751', 'DF256381-D00D-471E-9BEB-04EDE2087FB8', '3582910061083', ' 4  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('534D40D1-58F6-44BC-98CE-8B3005AD1F88', '1989E2A6-BBDC-485B-9DEC-3F06215F6A18', '3582910061694', '  100   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A29F3210-F160-4B3D-A0E3-5CB1FD5FFF4C', 'BA7C2BA7-A118-4AAA-8F57-6A061861E7AE', '3582910062172', '-  80  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53D0ABCE-012E-4B9D-8AF9-1DDF98449046', 'ECFE7217-82D6-40F0-99CC-F1E9E8024F5C', '3582910066484', ' 0,1+0,075  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F42BF9A1-2976-4EED-A79A-4F8D4B26B358', '3C9423DD-C9E5-4E5D-A4F5-65812E175BC0', '3582910066491', ' 1%  2 - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41963D25-2BDA-4FB6-8638-8048B5FC0F20', '393F164D-3D70-4738-8C09-B178445977D7', '3582910066507', ' 40  45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1B7449B-0DDF-4C7E-A283-9DEF52861BA8', 'A683F77A-3713-4797-879F-DDBEB9DC43EE', '3582910066583', ' 400 0,4  //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB2A7191-E443-45CF-BAF7-F50EC3E8A019', '96595276-C2E1-473D-85A6-FFCBA46A8524', '3582910067061', ' 120 //.  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A674649A-166B-4ABA-B820-7456B4B7C175', 'EE37757C-5DEC-4319-9279-CCE39FC712E9', '3582910067078', ' 180 //.  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2353CB96-438A-4C54-B232-E2A8DF44BBF2', '958A30DC-4C32-4654-88C9-8A70F21651B1', '3582910067337', ' 2% 100/5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B831437-82DE-422D-BE7E-A263B0D57601', '03D4CE29-C150-4868-A35E-185C3237FACE', '3582910067542', '  5,7% 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87707AE4-3E67-40F5-BFA7-C9FD9DD45394', 'FC5899AF-E589-46F2-B262-6CEC9A424DD8', '3582910067986', ' 2000   /0,2  - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E00E15B-D158-4028-BDD0-0C72D43D8CAF', '0AB95FF4-93C3-46BB-A74A-64F32C8A8722', '3582910068280', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0EFB280-592F-452E-A3F9-40E50C330872', '6F78D8B4-58C1-4C18-A6B3-9F5C2C9416EE', '3582910068440', ' 20  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11377D13-3206-4C60-8453-5D4F2D86FA1F', 'B0C785F2-3E69-459B-BC1C-F0CB6092C3CD', '3582910068457', ' - 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B367C25-501F-4C1D-AF78-A469FD54DA14', '07D0C307-A56E-4F45-998E-685DAD11C4D5', '3582910068464', ' -  2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('543CF741-5EAB-4186-A06E-62D7662B7A53', 'F92D7508-0BE0-4F4D-8619-56ABD980D5E6', '3582910068518', '  0,005  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B90A388-963F-4404-96B8-32F47897EFD9', '9F9C4EA1-9D7E-44A2-8E52-CB63BAC42EA4', '3582910068525', '  5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9186E568-C132-4B1B-8A66-491BBF070A6A', '7B70D457-34D8-4F97-AC51-BAFD8D7B8179', '3582910069317', '   130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('969A46AB-5FBA-474E-9811-70DF9FFA0F10', 'B4A9E766-9E91-47E5-9E72-839DB6C7A304', '3582910069324', '    2% 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B8E72D3-DE13-4EB8-A56C-6E68879A0777', '03581F11-1353-417D-A841-AB596CA2BB1E', '3582910069331', '  5%  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9200724-AA0B-4B3C-B08E-DC2897D26B02', '1B6A923B-048C-475E-BE76-77014032B348', '3582910069706', ' 120  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43238EE3-948F-4D6F-9256-EFDB639A9961', 'BD01004F-BEE6-4153-8149-52EAFA9DCDCC', '3582910070252', ' B6  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25131D89-C490-48D2-B9D7-B5B8675878A7', '3B148E1D-4611-4732-BD0E-F230A74825FB', '3582910071259', ' 6   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8505A075-3376-4AAB-A44E-BA2890B4BDCE', 'C7129781-BDDC-4F1F-97FC-CF704F0A1881', '3582910072058', '  300  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6DB1643-84A1-4B2A-AADC-54DD229FC62F', 'E390EBE8-661C-44C3-B314-0BDA2700D32C', '3582910072089', '   4,3  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C747CC2A-706B-4C22-AB54-1DE679FA27BF', '6A395394-9829-44AB-8BE4-319FD930BBE7', '3582910072294', ' 200  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EBDD973-59AE-4902-9E54-8DC230443621', 'AE4F7D97-4EF3-441C-AD4D-555D4E5F5E92', '3582910073482', ' 75  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10320550-D83B-472F-B343-4467BA651CF0', '9243601F-79EE-4A56-8B9D-CC2BB8EBCCCE', '3582910074588', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B03E23E-2A99-4F68-AE92-0C106AC52372', 'ACE48B83-AC25-40D5-9098-93C3CCE1D646', '3582910074694', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67EFE35C-8E88-4F71-B933-5596CD283918', 'D9A0F773-8C78-4D7C-911F-DD4831559279', '3582910074922', ' 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('541F59D4-7002-4A91-92FC-82DB0DCB73D2', '35BCFBA3-CC2E-4BFB-BC8B-D12229657BF0', '3582910075004', '- 40  64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A0C1B9A-1865-4245-8440-11EA0C5C7806', '5593F70C-5A9A-44E1-8BBF-5337A7917776', '3582910075660', '  //    4,3  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FA3E2DF-64E6-40A3-A648-4F36EC4375CF', '7A0B6778-4EDD-45D0-A233-FA39CAE7E7CB', '3582910076773', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88FB619B-A459-4D2C-B44F-13413B346A46', 'C1564465-EBBC-4DBF-B797-486AAC5D4B56', '3582910077305', '   300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ACD10F7-BE61-4706-BB66-D76449D94D9A', '9A017253-D875-4FA6-B659-BE465094EA4A', '3582910077312', '   300  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33CF73ED-C617-429E-95DE-D15854076420', '691809EC-5D85-413F-A54A-3866F2452B28', '3582910078531', ' 40  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D798A9D3-0B1A-49DB-8FF6-BA028F669FE1', 'F470B34B-6494-4CA0-B081-3607370D0323', '3582910078555', ' 80  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43CFC117-CFA1-4019-8CA2-FAA98C28E398', 'DF662CDB-F1CC-4B57-9FBA-F09DED0CDC9B', '3582910078562', ' 80  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8424A6D-C4AA-412E-A387-39D623CC702B', 'DC93CBCF-6245-4AF8-AB6F-20CECDD51E32', '3582910078913', '   300  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EE4E539-76AF-4AD0-A41C-DE1C20A52F1B', '7B70D457-34D8-4F97-AC51-BAFD8D7B8179', '3582910081203', '   130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8620BD02-9360-463B-91CA-36998B708CF5', '8BDD65C9-7539-453A-9C65-D660D110B1B5', '3582910082453', ' 180  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB8EABE1-6DB2-4E38-8F1D-801C01810B3E', '7BCE881A-3AA8-4C08-83C4-A6B918498559', '3582910082484', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82F7168D-6845-4C4F-B44C-857D32158362', 'A2C31DF4-9E1E-45B0-A84C-F2868DB7F5E1', '3582910082491', ' 10  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A27FAA2B-D1A0-4F05-BEEF-ACE97793F46F', 'EF7C4319-D299-4F12-AD41-F47505D2740C', '3582910082538', ' /. 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EDF0882-36D4-48B7-93EF-5D17B7A6EC54', '98879FE5-DE03-4CB9-9DC6-9BD5CAE1DAC6', '3582910082552', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4832A8E7-6B5D-4069-A6E7-D384D9C0BA60', '96258F33-9484-4B46-9006-E914DE734474', '3582910082569', ' 5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1DE40A7-B84C-4928-840B-5AD4D772021B', '81755F9E-477E-45DA-AAE0-FE950B222829', '3582910082576', ' 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D08855C0-4260-4656-8930-42594D8F236C', '1DA28608-8459-4ADC-A71A-585366777DC6', '3582910082583', ' 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E7B35FB-B740-4F07-A134-A8269196F99D', '71EE9BB6-A3E0-4835-933B-FF295159B99A', '3582910082637', ' 30  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9880FE4A-9866-4436-B93A-75994A54D3CD', 'CED8E7CA-24A6-4896-862E-A6F8D7FAF40F', '3582910082644', ' 30  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B805F4C0-A1FA-496A-9013-BD27C893BE8D', '3604D527-3678-46A8-B452-69654C4B60CC', '3582910082682', '  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('651A46E8-9C2A-499C-9BC1-181795E8AD19', 'BA87829B-5EDF-4FFF-A5B4-1E7939E8EC4A', '3582910083344', '  5+100 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13AE63F3-AE74-4B2B-83BD-568E9D5D02DF', '49FB7F64-AC81-4499-8AD6-4C6B922964D7', '3582910083351', '  5+50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60CAC5DD-423A-4E5F-B61F-A1AC2942D7A5', '9FFAC800-07FE-4B89-B497-718A8B514BCA', '3582910090694', ' 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77C29F37-F46C-48DB-B0B1-83354818149A', '037309DA-B1E1-4874-86D8-0B6C5EDD0163', '3582910090724', ' 50  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5430DDD-F4AC-4401-B119-F2DC267CBC0D', '46684BB6-DFBD-4D0F-ABCE-0CC2D9357F8E', '3582910090731', ' 12,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCB58B7E-A43C-40CB-9C54-C1C780842948', 'F2F48A43-E347-43E2-B927-0F0B29017C6D', '3582910090748', ' 50 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D53B816-E22A-4AFD-BD1D-2725991A69DD', 'D70560F1-0A80-4149-8CB9-7F69A988C823', '3582910090755', ' 50  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C452CA15-3A32-4C7C-B52D-92CABB5524A3', 'A3BB1987-2140-4592-854D-446F3206AB9A', '3582910090830', ' 75+20  / 63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14ABD3C3-4F75-4586-A0B5-3FA0991C5B75', 'FA59A66F-3DCD-446D-8189-62DC924870DC', '3582910090854', ' 2+0,3  63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9802CCD0-2849-41F5-A9A1-1D510A5CF6AD', '250E9C40-590B-4037-846C-1381B5042CEC', '3582910091042', ' 5  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4915D6AF-05D5-42C4-8F99-1FF8322C513E', 'A4D0DA46-ED91-4F10-A6EA-96F96AA9EC3C', '3582910091059', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A20387F-8EFB-47EA-BCFD-E1FBF3133411', 'A3DDFD5B-B168-48D0-A17F-AE74F688A6C5', '3582910091080', ' 5  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBDC7404-6BA1-4B56-8DE3-97CDA59EB118', '5665B302-FBD4-4F66-86C3-085BA4C14CC8', '3582910091097', '   0,4  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D96C7FD-6F67-4C70-80D5-6BE341AA004B', '78FADA68-B478-4BC9-A76D-D6E3AFA443C2', '3582910091103', '   0,4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('923F1E0C-2D88-4F4F-BAD2-91D9EE7136C5', 'F470B34B-6494-4CA0-B081-3607370D0323', '3582910091158', ' 80  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A51A6554-62BF-4A6C-9279-81522BFD08EE', 'CC88B98B-1263-4487-876F-F1CAC6ED7086', '3582910091233', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69797EA6-6E0C-4092-9009-2B22FF870908', '6267DA05-7AC3-4A06-9E37-2406CB4A8F5E', '3582910094968', ' 6  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('716AF315-EEC6-42EF-9E14-715C83F845C2', 'BD01004F-BEE6-4153-8149-52EAFA9DCDCC', '3582910094975', ' B6  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8CD03DE-CC6E-4838-8929-2D5D94CF0475', 'CF7650E1-BD6B-4262-B694-B81E79253923', '3582910130031', '   125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B25084DB-A320-432E-BBCE-A5C9BBC9DF7F', '571070D7-EC14-471B-92A5-CFDA6A2D2454', '3582910130178', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33738159-8E52-4FD9-A289-6E7D0D10475A', 'C677B6D3-BF5E-4EE3-B7AD-4C5B48859411', '3583313228578', ' 50  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82A19E17-0FB6-4E81-9883-4820C3C90FD4', 'E301F9E3-07FE-46E2-B06F-3B91CBA3E93E', '3583313228585', ' 50  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D45EE053-7883-4EDE-93E6-8F10408460FF', 'C5645ACD-6D9E-4FEA-82BB-7C4439541436', '3583313345190', ' 100/ 10  - 18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D5F6A85-4DCC-4675-890F-896955D66EA0', '94A9547F-388F-4281-9754-C11D9D92336A', '3583313437949', '  .100   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('083C99FE-07A1-4ADC-8D1D-D98ACC9B05CF', 'AE0DE1A9-BCCD-451A-B081-85FABB509B80', '3583315558079', ' 250 / /     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('239A7B70-14A3-4420-89AF-359211A1F279', '2F49ACBE-5124-46FA-9103-5574EE92B16B', '3583315558093', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6BC6C02-8DFF-470A-8E81-DEC944C7BE3C', 'B0CDF5D6-9712-409F-B2B5-F52DAF589EBD', '3583316669187', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCF34A26-143B-40EF-A9A7-7FC70027D08F', 'C8DE80B3-0536-4CF2-90B7-EAED5A3A967A', '3583316669217', ' 250  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43C9C5BB-7A55-4E39-999A-E429295E112F', '78798D3A-8E85-4DBF-A941-ADE2E4ABCC14', '3583316669231', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDA4CF4A-0F3D-45DB-AF4F-3A5993168A02', '9C05CD3A-806A-41CC-B35E-FA45334EAD3F', '3583316669309', ' 250   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('800F2106-6DEB-4ED3-9A2E-80133CC4A855', 'E059AD98-C4ED-48A8-BE94-F035FA273351', '3585550017373', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28434599-1D10-43A7-9401-5665A364E212', '518E4D16-B598-458B-864E-F32BF93DD6E9', '3585550017564', ' / -  /  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E2A20E9-2701-4BB3-A6E0-D917C695C0B3', 'E9AF890F-0BF6-4F41-A902-F0AFD45103EF', '3587080000504', ' 250   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AD80428-4668-4501-BB86-771335410568', 'F0EFC439-FCC4-4810-8096-96263D875B10', '3587080000511', '   15  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB451100-4EE1-4F77-ACCD-2089C3C5743D', '7452F10D-1068-4F06-AAD6-51DCC772A146', '3587080001532', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90172F4A-0E44-4989-BDE2-F448C3B52237', '5A93A71C-8242-4C81-9673-4902FD9D28D8', '3587080002171', ' 4000 - /0,4   .  10 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47DB1A7D-5147-4A4A-B0D4-CD5CEB6CD32E', '0493725C-CC6D-4AD1-9DB4-E73BDB7B79F1', '3587080003031', ' 8000 - /0,8  - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9A58F3E-93B7-4B41-8D0B-4BF4520B6AC4', '2D443BDE-2994-4B46-A7A9-19070A7CF7F8', '3587080646764', ' 3  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('723CE664-E7E1-4C5C-8890-A74C533D39B0', '5833E77F-A4C2-4188-8AB3-9DE10770F20E', '3592751325299', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F790DE2-91EF-4DC4-9202-11073D90E761', '346151F0-86BD-4175-80AC-871F5DB16994', '3592751533427', ' 10,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3583845-E0C2-4297-A81F-F7544F0B71D8', '0908ECF4-DF2C-433F-9DD8-7B264E14E924', '3592752805202', ' 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E1FE1FD-631B-4454-A3FC-CCAF7B1A5D39', 'C51733A3-533C-4211-A365-2C2F69EAFF24', '3592753528926', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC132BB0-B5D9-4FB3-911A-E1A76130DE57', 'BC87C55A-88CE-4242-8B2B-2715781B4C14', '3593140000100', ' 25/ 10 - /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED53A937-3E3C-4408-AE9A-34F8DEE40CD0', '61E17A9B-79E3-49BB-9C2F-57D9F3750D6E', '3593140136298', ' 150  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB63C2FE-59B3-4FBB-9982-3567DF577F47', 'B30A7C94-4148-4896-BAA3-59847DD0E8BE', '3594450170026', ' 1,0/10 10  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('985371AC-A08D-4AC2-86D7-97AEAEF4F324', '5BCAB673-9182-418F-B3C9-0C66206B3660', '3594451900073', ' 2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9344470-DB99-47DE-91BD-72B018CFDCA7', '8F0B0905-D8AE-400C-9485-E26D40EF1B72', '3594455600023', ' 1 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE09CD5E-B0C2-4DDB-80BF-7306D38A3780', '9F4E0D9E-2CD9-4D61-BFC5-E014018F1F31', '3594455600030', ' 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B4A8D83-54FD-43E2-AF55-12924B356927', '6F0ECB23-0976-4577-A578-0154B47DFB16', '3594456500087', '  /  2 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9C3E72E-9ACE-49E1-9EBF-DECE26323587', 'FC345022-B7EE-47EA-B227-FE0C7D5A2AE5', '3594458800222', ' 5+1,5     / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAE890D7-AD15-4410-A845-7A7BCD6FC798', '984BB3A1-471B-41C9-90BC-334E59DEC96A', '3595890048241', ' 152 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69440E11-3B2D-434E-8E7B-99433E24A8AE', 'F0B187C3-C64D-4746-BBC4-93B4FE6BA266', '3595894002638', '  116 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA40D62C-65BD-4D7A-B535-15ACF962FB81', '3E95B5A2-DCF0-4840-BAA3-BFA5CBA86A1D', '3595897976318', '-  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C645C23F-604E-4E6A-B746-3C572909CE5C', 'CA21280A-241D-45C3-ACF1-EA431A8098B2', '3596540010021', ' 850  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4B372AD-B7B7-49DA-A0C9-2102F2EEB55F', '5F466CFA-9275-449D-A7E3-8152CC319D86', '3596540010076', ' 850   /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4CDA44B-0274-4F58-9CB3-9461A556CF5B', '472A955C-321B-4C47-B36F-CE67E62AE1E4', '3596540040035', ' 0,5 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C116CDE-860A-4555-9462-89F1CDCEE83A', '999FA262-E962-4FF7-9EF1-8E04AFC6CDC0', '3596540060118', ' 2,5+500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FED887A-785D-4D86-AFB8-5839ABE97176', '632F996C-0CCE-48D0-991C-AD08B3A4CCC5', '3596540070056', '  500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F60FBB3-B271-44B0-A7A7-1B393A28E979', 'BDCBC570-5A5C-476C-9AE0-F9641E939234', '3596540070117', '  500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('137ED4F7-59A6-4293-B0CA-5C1C2B23EA86', 'B09F78C1-4E73-46F6-9DB7-A80DF2CBAC04', '3596540130088', '  750  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A88413B-6BDB-43FE-BB7A-37496E19F21B', '74C12A84-6CB3-43B2-9B9D-91EAF6E7577D', '3596540130095', '  750  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C0E7CC9-0CFC-4877-87F7-C3B9C8488D33', 'C526170D-977D-4357-BAE0-CAFDED9E077B', '3596540150123', '  1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1160F516-1E0B-4C88-9D29-0DAC8331D0CE', 'E3D4973A-48F6-4432-9EE9-CB8708D59C8D', '3596540150130', '  1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51517193-FFE7-4103-8E52-A33A55251674', 'D191D712-B3DF-4224-AD9A-4AF94F0785BB', '3600540873279', '        15 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86C7DAA6-00B8-45EA-B5C7-EA1DB4FB4A22', 'E8AE49A2-23BC-4E7B-99D3-110A68BCB2DC', '3600541436275', '        50+50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB3A2375-8C88-4047-989F-B83F292AAD32', 'CCCDFA7B-3E49-4EB5-8268-378E25C45FBC', '3600541595194', '     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E20EFCA-4812-4D75-9E4D-B754B06BF62B', '5BBE0991-BF43-4A82-BF22-CA89B878563B', '3600542045490', ' /garnier/ sn - //   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93F3427D-0A63-4236-B558-8AE75CDEFCF4', '900771B2-328B-4730-84C7-4D1DC2B473B0', '3614250000009', '  600 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4C52B51-3187-4775-8968-651FDE013B3F', 'D32DC6E7-AAE3-4442-8051-14B7E61B4CD8', '3614250000030', ' 600  / 18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E39BF45-7685-493D-9344-23B6868E215C', '15160682-8B0D-4260-A3F5-64EF9F13C2FA', '3629001109061', '   400  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EA48B31-4C32-4D99-BF94-FE18C28F3382', '558BCA1A-B69B-420B-8D4B-3F4DF50F21FB', '3629001624120', ' 3  / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EFE2AD4-580A-4828-ABFB-FF1EB548C9C4', 'DE94514A-4AE6-4481-8ED6-C0186987B3BC', '3629001624243', ' 0,003  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA1B2451-3656-438B-BF0B-3B0F5B3286E0', '4134D2F3-311D-4F0E-91CF-56F699C218C4', '3629002716039', ' + 3  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F81E1E3-E599-4D72-B21C-5897532146F1', '2835560A-7C38-49BF-9797-D3245F46ACDE', '3629002748030', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('782A9030-B8CF-407A-BCF8-C8686230C956', 'EA801FCA-20D2-4292-9500-BF81CB0CC4A6', '3629002748061', '  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D54F846-ECB5-4664-823C-51B4A518BAE4', 'BC2749A8-6723-4C87-A46A-5A7C65DB2FC4', '3629002748108', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BBB868B-73FC-4A1E-B541-09FFA816A56F', 'B89634F5-B0E8-4316-8D4E-E7577384FEAE', '3629002748139', '  / 130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EA590F4-B516-4EFF-B661-0BB4544BD282', '8EA0B997-DD6C-476C-8AA2-FF4F6AA9F9C8', '3629002754031', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAB1B7A0-E416-4C9E-B765-6846E9F47EA7', 'CC7116D4-B7BD-4691-8687-23093E62838A', '3629002772035', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A029689-D147-46DB-85ED-EA82B868E4C5', '94F83618-6BFE-4826-925A-1E37BCE59433', '3629002772103', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C052765-F030-4EB1-A82B-FA62AB6D309F', 'EAF829E5-5728-4BD0-A19D-F8AA1E06AFE3', '3629002774039', '    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49590389-AF11-4DD3-980F-A9432F81C613', 'A61F1DB7-390C-4727-BD21-7E9CF8F870CE', '3629002774107', '    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('852FB33B-0D16-4525-A1BA-BFCB8CACFB20', '5C9FA9EE-F4F4-424B-B5DE-1FE5BEDE8D43', '3629002790039', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59B6857E-AF99-4A83-B898-ADF66FBC8EAF', '6F75B5E5-8074-40D5-9DF0-124D3841632E', '3629002792033', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('547A143A-4B63-4ADC-9C2E-025B526ECD81', '39AE0D1B-6B0C-462C-AB56-246564EE8441', '3629002795034', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13897B60-0DEA-4277-8AE6-8C25B3DC7351', '26C207F3-549F-4663-B776-2AEE17D99D4C', '3629003101032', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5387680E-3BC4-49FE-9A97-6E57569C4834', 'C7A581CB-E9D6-4C10-A6C7-89DF67C19718', '3629003126035', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D020D96-E35E-46C4-8EE5-DFAB80146FF9', '39A7575F-5C35-4758-9BC6-7B60445A8438', '3629003126103', '  //  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8E06263-F886-4F7B-AA56-0950ECA8D7CB', '4EC18271-34E3-4CF0-ADCF-E28FB145AB76', '3629004135609', '    / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EA43AE9-BEA1-4108-A3A3-07ABB001131E', 'B077AF28-37C1-4D27-B3F9-475785B5694F', '3629004240037', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0031FBD7-F5B0-462C-9E4A-1347818A810C', '4E48AA39-4A7E-4170-9781-A49B5FDC0142', '3629005115068', '  -3  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB7EC72D-F782-4B39-B11B-AF38D65941F2', '013D2B11-4812-4B45-9419-1A6C01C35148', '3629006016609', '  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69373355-799D-4287-A990-EDA5D5F9533D', 'AF4F1DD0-9386-41E6-98CC-B540015DC2FC', '3629006470609', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BF43AC2-2119-4FFF-A119-B8117A839122', 'C40DDD5C-0B95-4511-B072-60184FCCE1E4', '3629007015038', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('428BCBB1-CE39-4B8A-BD7C-327CAFCD2747', 'F738F940-AE04-4302-8959-3AF100D98258', '3629007015069', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98CD6504-DA48-4193-9848-8517626BE084', '97268382-7488-4A10-A0BD-4EE807D41D94', '3629008051066', '    / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4ACEC08-A840-48BD-9E20-06E21BBD0339', '49772D60-3E3E-4158-ABCB-84A107CEE7EA', '3629008055033', ' 500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42B1ED0E-6977-472E-A6D7-8EAF89EDE968', '4C1E63DD-7A04-4A75-8C6E-2FFBC074A5F8', '3629008055064', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23D3E10F-27E8-437A-B765-AC1E23EF21B4', 'FBDEA140-2702-439D-910A-7A321E7DE241', '3629008055101', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84A5C419-0200-4549-BB2D-C0CB72AC9CE3', '6D5855F4-56CC-43F8-A6C7-51565425E063', '3629008055125', ' 500  / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('859CFAFA-4034-47BE-A2D4-BA9EB576A1AD', '6324CA2E-3B32-4863-9817-C8DAF7D4F64D', '3662042002656', ' 15 0,25    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA1FDEDC-1C84-419F-9D07-B295CF3F35D3', 'A457BB52-A93F-4986-8FC2-80FAFC06BD76', '3700003365010', ' /  -  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41D99A60-F414-4ED4-A456-44ED6CCDBE78', '8FB3D103-81ED-4461-B0F8-121EAB82A0C0', '3700022400013', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B365591-B0CD-4D24-BF5A-81A3CA07933A', '7C32C46C-9CC1-4B48-9A83-3599666C76F2', '3700028501769', '    0,7   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FBBE450-AFDE-4007-B0F0-BE1AA05EC046', '64914BBB-D42A-4480-9C01-9C37CAFBF429', '3700244200415', '   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29D30791-DEC4-41CC-A585-A2FB6B0F0684', '0DDCAF12-9611-4148-B377-E67B67378E3E', '3700244200422', '   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A461494A-DB2D-4F98-9097-11DC399C4BDD', '14167CAD-8612-4B4D-A285-8A7EAA7D2527', '3760001040258', '  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B06BBB3-EAE1-4CAA-9203-6250F5B5CE52', '8DEAB951-03EC-4E93-90DF-1AD536FE36F3', '3760001040395', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5017E30C-20F7-4045-9F6E-A0805F6B1536', '8DEAB951-03EC-4E93-90DF-1AD536FE36F3', '3760001040777', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F2BE727-7AA5-4215-8CB9-5DD7A81FC255', '847A292D-F3B8-4E19-8155-30D3DB908797', '3760001041088', '  227  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F099F9EF-4EDF-43F5-A2C5-3CEFCF22E8BE', '5752C138-6154-44CE-81A5-65148180B14C', '3760001050028', ' 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('097B2D1D-B69A-4C3E-AF05-D1E0B260E2E8', 'AC2DDC0C-90F8-43CB-8A92-353650321EE6', '3760001050103', '-  //  10 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6E970ED-2C7E-4052-9196-842BFE9DC2BC', '7DE40691-E1FC-4C9D-BB8A-A26A8D2913BD', '3760001050110', '-  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('471688D1-2246-4C92-B98A-E3A7E1FEC543', 'F6BEB7E2-477F-4CEE-B403-3D6431AF96FB', '3760001050158', '  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC94FA8E-E1A9-449C-B1A6-8E0D46E82AD0', '90ABDDA0-E8C8-42AA-9571-7850D1373B98', '3760001050165', '  / 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D0B6362-C7D9-4FFC-AD69-44F0EB2D4F57', '04AE3EAA-6711-4409-8AA7-245E00256B4D', '3760008320018', ' 50  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F76F1BAB-96BB-4574-802E-CEA3F5B95E63', '96348209-C2EB-406C-B13B-9B1CF7733C68', '3760008320193', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85814BF4-308F-447B-AE70-DE957FFC6B58', 'A9627CAC-A1DE-4DF7-86B2-C82A8C909C1F', '3760008320223', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B41560A2-E38D-4E59-9499-F74F64471C4E', '2A4050A0-060E-4B18-AFC4-E429882CDA9B', '3760008320254', ' 0,4  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B88DD736-365F-43CF-A74F-C34DB531B74F', '77630CE4-8B6D-4B2A-9850-3C868720A4E7', '3760008320667', ' 50  / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED35F4A9-48E1-4112-8101-EB0F27C5CBF2', 'FBB846A8-5920-45C2-AD72-4EB207DCB30C', '3760008320995', ' 24  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C8313C1-DE88-4A03-B77B-B45883CB1CED', '75A5061E-AF7C-466A-908D-55B78B00BB55', '3760008321756', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('245D135A-1767-468A-B8AA-95F7E2591F2B', '46E8B7EF-0FCE-44A0-8E3F-A3585F528A9C', '3760008322142', '  600  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC399E34-2700-4C95-8069-5E631F0214B9', '89197D2C-2B7F-4D0E-95C7-120025D69307', '3760102850374', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A654611-C9AE-4B86-89E0-E2A43028CF48', '56A2E461-619B-43FA-9866-AE7377718BE7', '3760102850947', '  /     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C03AEB9D-7E5E-4FEB-92AC-316935894F59', '8C22B665-AEE7-4D0F-B20A-1E4E4105FB99', '3760102851104', '  /      -  /a/twa01/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FD00B17-D706-4BFC-9678-7C90A7617EBC', '83F02A94-B6C4-4631-892E-F0A1376CA336', '3760102852002', '  /     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD7C7894-D766-45C1-B255-767AC80EDB9A', '5D41EF6F-8AAC-4C17-BD1D-47DCC471A618', '3794675386244', ' - / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('316412EB-693D-4F3C-A5A3-1FAEAE790A9A', 'D2CC3DEE-6516-47CF-B1DA-8E3D3E734363', '3800002300040', '  /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A5570B8-4E6D-4F50-B2A4-F8B0083C3998', '70F723C4-9784-4877-8215-6BB445734217', '3800002300064', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0471C3B8-A54E-4B4E-AE21-7EF842AAD766', 'FD8997FB-DE8E-45BE-B14B-F833A01E6258', '3800002301092', ' bebble // shampoo&body wash 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('222F7714-3C07-41A2-8241-14C2EB6D7A5C', '4356393E-182D-4DBA-A796-9732DBDC88EE', '3800002301214', 'Bebble -soap -  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E74B1B2-52FE-42A1-A9BB-BC9EA51363CE', '9F870C30-6CA2-4943-BCAB-4A087A631867', '3800002302037', ' /footprim/ /   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55DF8097-54D3-4AB2-8AC6-2C197ACFBE18', '5B3658B0-E398-486D-9D0D-009ACE059B11', '3800002303331', ' my  of bulgaria /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC86BECF-A0A0-4C0A-A351-ED3D978230AF', '5072B08B-54FB-402C-A249-54D4807DEF40', '3800003303620', ' -    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('517AC9D8-BEFD-4FDF-9DF1-A1F86014C876', '08E879AC-AEC4-428F-B06D-486E82222862', '3800003304016', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9F890FF-B266-4E31-8285-2E5CC6A154C8', '98A59231-A93E-4685-B7DC-DFD911B3A90C', '3800003304030', '   550   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('821BB41F-EF44-4075-9419-42F26CD47BF3', 'F2EEADA5-40E3-47C6-A915-37C7DC5B38D4', '3800003304054', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('078926AA-C131-4E8F-AF09-B28703199C0F', '4D907B70-43C8-4B9C-AA4A-0EDC481A4C46', '3800003304405', ' +  20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('738E24E1-9D53-4074-94D8-CF53C1162A76', '7388EEEB-18DD-4339-BC41-989DFA3AC2AB', '3800003304580', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C6A2179-870F-4D33-A703-EF47FB1B9BD8', '5AAC1E48-F8C1-45B1-868D-82046AFF3641', '3800003318594', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D646295A-F5C2-4A41-843F-907582B5AE06', '964304E9-94C3-4F23-BB5C-4D6105449ABF', '3800003318891', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80FAA263-F728-4910-B435-3D34B6845472', '9FA225C8-DA9B-4E8E-BF6E-8803491FBB5A', '3800009121112', '  170 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D75FFBFE-B73F-411C-A3E5-BD5850E17907', '0208F6E8-606A-4DFF-BD28-90A65D79DA4B', '3800009121150', '    10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B521B4D-30C7-4AF3-BB6E-40BFC544EC3E', 'DE0AA056-C854-457F-BBFD-B7B1B2D1D8D9', '3800009121198', '    10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92B0D008-33E0-4691-B7A4-91CABA97670A', 'E4177EAE-96FE-448C-A112-A074BADA1232', '3800010612708', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56D25A06-4576-4FE8-BEA7-474019DB9562', 'CAB0BF50-E92A-4211-A9E0-B2ADF657C69F', '3800010613781', ' 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24991946-1998-4F0C-99A7-131D2E60B919', '61C6BE0B-6296-4CF6-89D5-6120FC574911', '3800010629348', '  45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E39E6B6C-2295-405F-A348-23BD8E742DDE', 'D6E24193-53CD-497A-B604-F6AC969A7679', '3800010629409', ' 0,04  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED1E0351-A46A-40E2-B91D-444FBD356863', 'BF2C0017-AC70-47CA-B87C-42B1081F1D40', '3800010629744', ' 15/5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D758B535-4E9C-41F4-BDA9-B3716E40358E', 'AF13899C-3B7A-488B-8017-A9066497AAE4', '3800010629768', ' 0,0002  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75F58FE8-84B8-4C86-8D6B-2CB5D72C9199', 'B4E2FDBA-4D05-4E25-A4DF-E7AFC57B037C', '3800010630191', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65312563-4BF5-4771-95CF-B4E5A7534690', 'B3CABA34-C35B-43A8-91D8-FD2BCB97E5A9', '3800010641524', ' 1,5  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A9BD0DC-B2FE-49C1-A0BB-001D41F05EF2', '8F930F35-B9C1-41DB-8110-BC606DAD4A62', '3800010643191', ' 0,025  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5ABED35-1FC0-4895-BC55-ADBC2D4C484F', '2C4B0809-9868-439D-9B88-4F5A9DE5A961', '3800010643474', '-  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('680F6F5A-9853-4F30-A842-2CD61E6C7287', 'DEA5BFE4-12C2-4F62-BA0E-9C224208C6CB', '3800010643764', '  90  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('169F4BA3-6970-4986-AC3F-1F641B57D818', 'F7259257-DD48-4570-A3EC-17EB06153CA6', '3800010646246', ' 0,035  180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B92F1685-AC5A-4418-847B-3A788BEC3EE2', '6DFDB1CF-A51F-4610-A180-F28976606A53', '3800010650090', '  1 5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0A35BB4-DC73-4D03-85C0-999D75FB3FE3', '2A00A326-12CC-4964-BBC3-FB43827A9A0C', '3800010650175', '  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA023215-70A1-4C31-9CAB-678239515C86', '69E4DB4A-69D6-4E39-AA53-66179B683531', '3800010650380', '* 50  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6DC59C8-32B7-4F46-BE8E-D4DCAD9B5F7C', 'BC5B46C5-EC7E-4F16-B5DE-3567FAF340DA', '3800010650397', ' 100  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C5808B8-108F-488D-983E-F97E94E7062E', '9B9AC868-3DA1-4AD2-A61B-3490C8E4CECF', '3800010650700', ' 10%  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7E2BDC3-1A84-4A54-A0E7-5A77D0AE6F11', '0B0F7000-47BF-4D16-866F-9BD2703956CF', '3800021100591', '  125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86F74A5F-5A9E-4FD6-86F4-5EF87A622267', '5A75DA7E-8217-4B33-9C7A-44E40FD5058A', '3800021100676', ' 2,5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40C753C3-D20B-499A-8FB4-0F0F1EC552FB', 'DD79CC3C-DC29-44D1-A0FF-5991C8BC1ABA', '3800021100768', ' 0,05 / / 2 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0CDF808-0B45-48C0-8A4E-1A822A30CC4A', '0F3A0DB7-59E5-43A4-8425-1E6ABC09C843', '3800021100782', ' 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B705E36-D0C4-41C6-9F79-017A62994426', '1C92401D-034C-4BEC-A7AD-33780934533D', '3800021100812', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6656A29-D8C7-4FCC-97D8-22E3DA90B44B', '9B9AC868-3DA1-4AD2-A61B-3490C8E4CECF', '3800021100836', ' 10%  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96A3A0FC-00CF-4B68-AB0E-48F85BFD86F5', 'AC0AD049-E74C-48F4-BEDC-3036846DFDC7', '3800021100935', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F268F7B-CA7D-4AF2-AADC-688416C32693', '3043282B-F553-4EB0-8091-8B058BA6A2BA', '3800021100942', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B389B195-876B-44A9-B113-57DD6D87D6FE', '348D4841-7EEE-4E55-9027-25123F2197C3', '3800021100959', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BAE8B60-9C75-4A3C-B764-D145F9DF985A', '4AF4122E-0A68-47CF-8C4C-F4048398BBF4', '3800033700512', '  / / 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDD59477-20AE-4035-B30E-C2220B99B925', 'C0423A3E-0FAB-4414-A281-4DB20D5A8519', '3800033701014', ' 200  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('128CD4C7-D56C-48EF-B7AF-D33CF608C5A1', '96EE9D28-F22C-432D-89FF-B0182144EA2B', '3800041903295', ' 50  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2480AC56-0DD8-4D94-9717-53F435162CA1', 'D3A05217-B6B7-4689-A19B-14B592D4F854', '3800043700519', '  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B9489B9-B1D8-4956-99B6-4B3681F3EE98', 'E7E6EFCC-C4A0-48D7-8D24-0C03FE8398C3', '3800043700526', '  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52A3996E-9B45-40B9-B06C-09EA9D9267E8', '60EC45F7-29B6-4DD9-A7B1-45342EFAC19A', '3800089810029', '- 40  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8661DBB7-D90D-4E69-A621-B55786DF8347', '480A3BB6-40B8-49A9-8E2F-9AD41BD51246', '3800089810043', '- 40  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('875F8446-E942-4F1A-9D3F-5B17CB06202E', '2FDC6CC1-5B63-47E8-9AEC-81876A1E2F10', '3800089811255', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78E9B98C-F130-40A4-9FD1-3CEBBE455605', '36348872-7FD8-4911-B4E3-BE1BEDDE243E', '3800089811279', ' 400+25  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DF9CF6B-C393-46C4-AA7B-35C54A54AD80', '7E480A07-76F8-4688-8E65-3EDD00BA6C9D', '3800089813525', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C93852F-01A8-4473-AB35-9A257A3871AD', 'F6C52C57-B665-44D0-AD62-1C823429B48E', '3800089813938', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('427F18A8-2A03-4F5A-B5CF-B5F402B0CE5F', '79BA7283-B40D-4F52-97B9-4417877F82D4', '3800089830256', '- 0,01  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2588854-F9FD-4983-9F4C-389FA5574AE3', '080CEFFD-A0D8-46D5-8E90-D84CE7D9B927', '3800089830263', '- 0,02  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('551D7DE3-A7FD-447A-BAE2-041313002C07', '1AD2A1A2-6597-4112-AD3C-B7DD5B472965', '3800089830270', '- 0,005  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D18DE5FB-9D2F-4AF1-8DFD-2A2C32987731', '83AE9D3A-4544-47CE-90E8-0D6EF3B97B6E', '3800200961135', '   / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDA07E3B-537D-4F74-B5DA-CD5D23CB0574', 'F766E0EE-4C81-4874-8DC3-A36B00985A48', '3800200962583', '   / 330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8175D000-FBAF-4265-A26E-514EC5F2BFAD', '1FD3B16E-8A4B-4721-818A-BD0E48942D55', '3800200962606', '   / 330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61B11648-BC54-4A95-9C0C-EDDFCFCB1C6B', '544C91B3-D18E-480F-885A-421ADBBEDEAC', '3800200962613', '   / 330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('425E7340-C8DE-4080-ADCA-94AC87DEDB29', '9091E6A8-688D-485D-86C0-33E10AB4167B', '3800200962651', '   /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54798A50-D53B-49C2-B89E-3DC1C677A095', '303D96E0-DDE8-46AA-82C6-8BCDE396A061', '3800200962668', '  of bulgaria / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59224D33-3B00-416A-9B75-4242FDD801C2', '2BD5032D-955B-470B-9ADB-A6F75E671524', '3800200962675', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EACFC09-727C-4750-B390-2E6880161805', '02FCC720-8714-42FB-98A9-703372B190F6', '3800200963375', '   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D1A33EF-2028-4C93-B4C8-F6B8935734CC', '0BD5286D-B1FA-4DD9-A9B7-2972EA07ED38', '3800200964341', ' of bulgaria     230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('150783B8-AB4E-4C2C-98DB-A626A35C3696', '73B72EE2-C1D9-49FB-A27B-1FF9A588DB2B', '3800200965713', '    230 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('310900A4-7946-4F2D-9566-5E87A6E087CC', '92C9CFE2-34F7-4A12-A05D-BD0C015A13F0', '3800200968615', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3585D6C-BE01-4873-A168-5AC20AE0A887', 'B1F36011-FB4A-4D9F-B995-6E6BEC858BDD', '3800200969292', ' .  / ++ //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76E2CB1D-4086-41A9-9D64-CEACF1D70A95', 'E13D9DAA-EF99-4BE2-8260-A82C6EF92EA6', '3800212712565', ' / /  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D0F0EE6-590F-48E4-A9D1-F84253DCAA1A', 'ABC9F55C-1884-4C96-8F29-80F594D737D1', '3800212712626', '  / /  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01452A4E-9E16-4FBF-BF87-2F66B17C2EAA', '0A2D6E15-6121-494E-92C6-83CA0B76B5EC', '3800212712749', '    1,3 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BF05828-B44F-4063-B166-2D1F0EC15CF3', '643F3B6D-80DE-4756-B020-C94E6D753ED3', '3800229340126', '  45 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D317A30D-E6C6-4291-B51A-E3B166839E72', '0F3D7BF5-1DDA-4525-B7F0-810A3720BDEE', '3800712041721', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('366883BF-3EB8-4477-812A-9319737F5AB2', 'DD498090-D7AA-4559-908E-25CD3D8A9A83', '3800712840119', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F35AD64-4B94-4DB3-A64A-436F4920016C', '39577DE6-4018-45F0-A811-04A63F194702', '3800714477108', ' 2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C40A6BCC-0684-4DD4-9EFD-6E55BA03BC74', '13DBAB09-C2CE-473A-BF8A-D6CFD232AA1E', '3800728850072', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C83FDCD1-B93D-4293-BE86-CF486BD09FD0', 'F1532D05-9D85-4DC9-8F9D-0692744AFC76', '3830029291687', '       /6+/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('254E02C2-DB58-4A12-915F-5B540802B347', '67878941-CC54-4B4F-A4DB-C1EC55B02A91', '3830029292189', '       50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE06BEB2-9071-4BFF-A1C8-B404530958DC', 'BD0CA0F0-1B74-4977-B7F6-1D1D0EF712B2', '3830029294251', ' /      70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEF33C95-54D5-4EAF-AF3F-5C85B52F5F02', '36E71BBB-D889-41CA-A7A3-04F29A2EAA86', '3830029294589', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0D7638F-5B34-4A83-87D2-C33506DF2933', 'AC873729-03F7-4225-9260-7676234CB4BF', '3830029295524', '  /   150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DFFBB9A-4A3B-4D3C-BB29-3794441153DD', '589AC9A2-FA4E-4339-A8FB-8C95F4909266', '3830029295548', '  cr ai 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4E29DE8-D216-4F71-A88B-90C61BB217D2', '1AE5A119-C597-423B-A00D-3FD558F7EBC8', '3830029296422', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A60E93D-49DE-47B6-B502-15DBF01F2F11', 'A3A20E03-179A-4CC9-9661-43132A95ADD1', '3838600041157', '    1 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('965648EE-1B42-451D-8DD3-B4C8CF188ECB', '49EFEBC8-3025-4CEF-BC56-FE2AEDC6C278', '3838600041188', '    0,5 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12315D69-C43B-4003-BD23-7D6A2F1E9820', '84F167D2-5449-48BD-BD98-46ED1CE8E7EC', '3838957000302', ' 0,4+0,057/5   35 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB854819-F137-4879-8059-04A7CAA829D3', '8A4E3685-CDD2-41A1-8E3E-70C7FC9F10EC', '3838957004904', ' 8  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEE55D01-C78A-4522-BCE1-4713DA8D1768', '5DBC03A0-4CCF-4783-B97E-F852DA1C1E79', '3838957005185', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40BA37A9-256A-4738-9DE8-F3E38F513EAB', 'BDA63DC2-DB09-4B71-9875-F0C058D8AC23', '3838957006373', ' / 400+57/5 17,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB42BB9-A9A1-4CF9-A682-580860E9C8C0', 'F7168845-B76E-4FF9-AC02-FD8E1D05AA09', '3838957007240', '    / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34F55A88-5806-47EC-B415-5D0C4F026B58', 'F16E2F04-A69C-453D-A3D3-7F94BE6B1377', '3838957007318', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFB24039-856B-4A5B-88FF-4843A96075C6', 'E26E6AC1-F6F3-4CDA-9C11-4DF851C73647', '3838957007370', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41C0B44B-7684-420D-93F0-933428478494', '8A178F48-49DF-4351-BBB5-450D946B9188', '3838957007400', '- 7  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4673E53E-C690-448B-902F-A337B618F988', '7FD91483-E1DC-41A1-AD45-2EEAB81DB7E0', '3838957007417', '-   3,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4214B9EB-7EEC-42BA-8B41-F4E628601CA2', '910ADF73-80C0-4575-B7F2-801D5F243A09', '3838957007462', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9443AA33-F901-4AD2-9D83-1BDE692764FE', 'F3B362CD-C438-48C0-834E-7A2EEC7E924D', '3838957008902', '   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2768C16A-A436-409D-96E5-7D7DF37185C3', 'AF986125-A68B-4399-9BEE-3FEB36EAF8B0', '3838957010011', '- 7  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77E1A2F5-DEDA-4292-A8C3-F7183DC8BC1C', 'E5628EE0-3BD8-43EC-B198-6BDBDBC12F8B', '3838957010028', '-  3,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AF6861F-59D5-4C49-8CE1-293E60C3D980', '081EDE8F-4C7C-4611-82BE-10CEB6074A76', '3838957010073', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD518DE3-E36D-4711-B228-9C79EF47B005', 'F3E14955-55A5-476E-8D95-CF6C7335FBBC', '3838957011018', ' 1000  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FEDD864-B4CD-44DC-9B9E-60BBED082245', '15A5C7A6-9EC3-4DF1-9F34-95F55B95D692', '3838957014705', ' 100  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('277276E7-377C-4D9D-9D3C-29867CFE39DB', '66B5CEDA-36ED-4C4A-925F-8424A2FC9202', '3838957016174', ' 70  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37470B0A-99D3-4835-939F-8ED7CAED1450', '435829DE-B472-4EAA-A085-E5F9818DC7A4', '3838957016181', ' 70  / 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DD026D7-66DD-491A-B536-0827DF52AC0A', 'EB4F6700-BF52-48C5-8349-D2261411BB3A', '3838957016419', '  150  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5E603B8-BFF4-4462-B6D1-65490C304983', '6925D241-BDD1-43CD-A09D-08963D5413FD', '3838957017379', ' 250+62,5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E780BED-20ED-4381-817C-3034D671C050', '806FBBBC-C84E-4AF7-A5E5-71B4BCF0DE90', '3838957017386', ' 125+31,25/5 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDE72233-A752-4FE1-B17A-F16E6F00F954', 'A85E6CE8-7395-4BFE-85FD-2889ED540A55', '3838957029006', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('935389B2-A1B2-4A26-BEEB-CE6F793972BF', '9756F9A7-1DB2-49CC-B1AA-0EEEA3F493D8', '3838957034765', ' 50/ 2 / / - /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6040429-A1BD-4940-BFD2-AE40AE8EAEBE', '65EE6368-9DFB-468A-AC3C-32C19FAD64A2', '3838957035007', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34157ADE-E315-4D1E-82B6-9C3859B02B1D', '0C52F6C1-2261-40AE-B077-85985C0C4495', '3838957038428', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDEF68FC-91E9-4361-AE96-DEB3587BEE03', 'F34CEE64-74B2-49E1-A9E2-6AA21F2261B2', '3838957040971', ' 70  / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89FDFE88-8D9B-439B-885C-5192283DCADC', '070FEED1-008B-44D3-B747-0765E5C9EC39', '3838957051434', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9F64602-48D3-42FF-B7E2-AFDA5A6CB2CC', '0F82A0E2-0EA0-4C50-A944-752A0DD3AC26', '3838957051441', ' /   1,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0EAF82B-8CA0-4645-B1BB-39A14EB6B139', '42D4EBEE-4E91-44F4-8095-5412EAF371FA', '3838957051465', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F36AAFA-0682-403A-9A2D-E050A1F1AED0', '6C1B9E5A-982E-4711-B962-6ECA930A81E0', '3838957054275', '  / 5% 2,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7184C22-2AB2-4916-A0D0-8A97548086CC', 'C119FB17-AEF2-4182-962F-BE4C33C4B3C6', '3838957057115', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54E507F9-9319-4809-8587-AE55B2D873CF', 'F4910B6C-CE28-4BB0-96A7-2B69AAACC6A7', '3838957057122', ' 10  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAA09360-A419-4C48-A14B-752B3AB2092D', '3FA18926-1D43-46F5-9626-BD52A18C2ABF', '3838957057139', ' 20  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('038CA625-52A4-45B4-AF70-A979F51FAF0F', '59A398A5-41A1-4B63-B561-A4703A3EC7CD', '3838957057146', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48F6568E-27AA-426C-9297-34B6A518B95D', '00D81946-8B09-454B-934F-EEDB41A13837', '3838957057153', ' 40  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F95F8FD6-AD40-4FD2-B45A-2DC90EBAC130', '186A6C18-DD9F-4DC9-9D8A-3EFECA3DC8D4', '3838957058259', '  0,25+0,0625   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('013B891B-A8DC-4BCD-87E9-5021357891E4', '174FD27B-576F-46A8-9668-E36579F25392', '3838957061709', '  25+100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('587D38B5-AA8E-45BC-9512-3B53D786FE2B', '090949D1-D97F-4807-928F-BEF941442975', '3838957061716', '  50+12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5DF5E14-B864-424D-AE0E-BE95AFD038FF', '7AD72D84-C19D-4EC4-8822-2F3B5D13A471', '3838957068050', '   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E556B3A6-41EF-4178-9DC3-FDEAF400FE02', '0BB8CE22-4FE3-43D7-9BA3-659EC513DED8', '3838957069583', '      5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('598603C2-9F78-4988-AD23-0392EC3DE624', '03D46454-DDDE-4685-B2D0-711015BA4278', '3838957072903', '  1,5   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C43D07A-DEE7-4E6C-8DB7-367BD25529EA', 'D3D1D722-7102-4751-A556-8B1D181AF7D4', '3838957072910', '   100  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A8A629D-2A58-4C08-8412-C9E0077EE92C', '836AA09F-1355-462E-9E68-3EE0A28095E1', '3838957073856', ' 250+125  / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('179D0ED5-A83B-41E6-97FC-46E7ED969A94', 'D14E250E-E945-43EB-8D57-CF5A8088CB27', '3838957075720', ' 500+125  / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFE92F14-35C0-465A-955B-C83650820EFA', '34A02167-C7F8-4304-B6BD-CDA714E49E22', '3838957075867', '  0,1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81656E9B-412B-4AAF-B39B-F14EB0830716', '6AD18808-DCE3-4B05-8530-EF90FEB9A297', '3838957075874', '  100   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51E6CBD9-5954-4870-B19F-BC7C1ACAA5F8', 'F16E2F04-A69C-453D-A3D3-7F94BE6B1377', '3838957076734', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD29C828-CC46-47A4-9C07-70F4686BB9A6', '910ADF73-80C0-4575-B7F2-801D5F243A09', '3838957076758', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8880B733-EEF6-4786-8EF2-D0E29A308828', '596C22AE-CD54-43F5-A8A9-175067C3C6FC', '3838957078158', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FDD4469-37E6-413E-A28E-83A2C7A270BB', '8DE6674D-F0F4-4232-8680-62F5046A3756', '3838957078165', ' 0,02 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55A473BC-31EE-4272-BEB0-158F1B540D94', 'AF986125-A68B-4399-9BEE-3FEB36EAF8B0', '3838957088072', '- 7  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0234269-0DB0-4E74-AF51-5BE859A29155', 'E5628EE0-3BD8-43EC-B198-6BDBDBC12F8B', '3838957088089', '-  3,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F4548E0-0F89-4297-9539-BB9322B83CD4', '8A178F48-49DF-4351-BBB5-450D946B9188', '3838957088096', '- 7  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D241FDD-FA38-40A8-BE74-0914CCE78A5B', '69BE4CB3-6DEC-4514-AAB9-69A6CE8FA0CF', '3838957088102', '-  3,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C8A3255-4A00-48BF-B7B3-39F257474407', '321BF0C6-3D87-4EAE-9BBF-739A9D39218F', '3838957095292', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63215CE6-0F06-4A15-9134-A7569A5E7657', 'D5C87040-CF4B-4FA6-9623-F463E5FA854D', '3838957294633', '  60    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0085A5D6-E827-4B1F-AB47-C8F8ADADC0B0', '53577C35-7F11-4122-918D-795B228037C2', '3838957393497', '  30    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('979C5A03-B1BB-4F3B-9C23-55D8FAE1820F', 'FDF6FD25-79D1-4D7D-BE5D-62194846AB10', '3838957398843', ' 1000  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('018C670E-DA15-4655-9B37-CE3A220ECB45', '741E79D9-A69B-4483-AF35-583FE49A52D2', '3838957492800', ' 400  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70F09FC9-AAD1-430B-A5A7-2E8C7B1EA7AF', 'B1AF496F-26C0-4835-A7F0-5221821613BD', '3838957499793', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C832491-D50F-4A1D-AC92-F47624FA0B14', '568BC798-C141-41C5-94B3-36ADAE2B1A9E', '3838957499809', ' 150   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5051F8B4-7934-486A-83FE-E2205BF91C2D', '9F73F5FB-6F29-4B61-AF92-A56C84DA3779', '3838957499816', ' 50  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6C9AE06-9041-4D47-8C5D-DD2260F49525', '8ADB1EE6-DB38-4133-A920-8BAC198F5143', '3838957499847', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BD7B062-4EC3-41B7-86CB-A0FDF4BC1540', '836AA09F-1355-462E-9E68-3EE0A28095E1', '3838957699902', ' 250+125  / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38396F7F-2063-4E6D-8E4B-2150067C3DBB', '677EC153-E4D3-4293-94A5-C44148D18740', '3838957871018', ' 2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F4CB4C3-7F59-4F10-8DE2-15DC7456F42F', '4E3F6CD6-E3A4-449A-B180-2A1487444BD6', '3838957871629', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('268F3926-DAB5-4FD7-8968-BE951FC96992', '190351AD-C4C8-4A66-9C3C-CF54C3F0666A', '3838957872039', ' 250/25  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B914FAF-77D7-48C1-BAD9-D8998E2D80E1', 'B3F84B9E-FDB2-4517-A8E0-BE77956D4583', '3838957872305', '  50/ 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E259299-2FD9-482D-BC7C-A34F41912230', '80232233-9DCA-466A-9655-50A7694ADA04', '3838957873296', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBBE5122-60C3-42CF-A074-AB0E6F6940C6', '9779B43D-B0B6-4D0F-B3B9-D32C256EA75B', '3838957873906', '  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1515408-FFDD-4491-86BB-BA5941D5F9E5', '28530C25-153B-4110-98E5-4E60EA13746D', '3838957873913', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD60BCC1-FC01-46A4-9912-1B049179FF0B', '08B8A4ED-6956-4E22-93E1-4DBD9AE08880', '3838957873999', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF522275-7308-4D52-B4F0-8F04C3EAB1BD', '061B9195-95F6-486B-BB2A-6CEDE68960F4', '3838957885442', ' 50/200   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E02FE425-3084-4592-B633-4BD88AA0E5A9', '097E6374-980B-44B0-BE7F-5F2D6690DCB0', '3838957886609', ' 0,01 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('940FC946-4C4A-4D58-B4CE-456B55B8E555', 'E3F0B559-4B67-4173-AE8E-A1FB424FE8B2', '3838957895885', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5772CAA-3DD2-4455-8F9D-05609ECB5F2D', '9779B43D-B0B6-4D0F-B3B9-D32C256EA75B', '3838957896318', '  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02509448-D87D-4C3F-A80C-B0F2144BB130', '0C61100C-E4BD-479A-8694-E5C16C3736D8', '3838989500115', ' XL 40 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('034AB223-3A53-4659-A1DA-72475233A21C', 'CA902CE9-0891-476E-8E57-256ADB33AE91', '3838989500139', '  550  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7E2F186-B17D-4C23-A7B2-93D0F326208B', 'BD43F7CE-729A-4E55-B767-EB33E2C6385B', '3838989500719', '    / 100 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E2E89AE-7F46-4CBC-94B0-FADCFE108AA9', 'C7E8EF75-0A92-4B88-934B-5824762C5609', '3838989500993', ' //   75  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('454102B5-E8AF-4F74-89FE-E99F29B9437D', 'A32FEE28-AB47-4011-8B62-1E481D34A39A', '3838989501013', '  20 //.   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35916F08-8E77-4E84-826E-3253E220A0AD', '393B1DA4-7660-4B60-A733-EDA00B513FBF', '3838989501228', ' 0,0005  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F23C7454-B286-455F-8545-BE4D05A1449D', '44A5C8EA-B02E-40D7-B8E0-3B6B2CA4A271', '3838989501693', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F4B011E-D30A-4DF7-9D70-1B43C4963D51', 'D89437E8-6291-47ED-8CD2-70B51CCF09C4', '3838989502652', ' HL 20/12,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA6F0AAF-C58F-45C0-89D5-5BC72ECBAEC6', '2E9B8692-0CCA-41A9-B313-6D5FA17227D6', '3838989502751', '  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95F92D4F-BFC2-42CA-AFFF-03C5F7F35A6A', 'BBF4A0E9-1CC4-48FE-B2F6-680C80224830', '3838989503123', ' 0,4  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F13D86E6-1928-435E-9F3E-C439881A693D', '266DD834-A8AD-4809-9711-37743B899A61', '3838989503130', ' 175/5  / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D8CAAB5-843B-4060-BD7D-36E66DFDB601', 'A3137FCB-AA17-47D2-BAF0-B58F73A5B63E', '3838989505226', '  27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('309CFFA4-4832-44D4-B3B7-12C8D7009FE1', 'A44DA078-A28B-4D5B-AA0E-69CC996B3C5C', '3838989505523', ' H 10/25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC0E0AE0-6087-4D76-AFB7-A5EE02AE5D2E', 'BBB130E6-BAE6-4C0F-BBBB-AA4842EFB7F4', '3838989505530', ' HL 10/12,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B63A500-434B-42C8-A012-DD42D44354AB', 'D478A0BA-8A47-4855-A3F2-77357A3E8B35', '3838989505950', ' 1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB6A7C6D-BC51-46F6-910D-A546A03C14B9', 'C4E453EB-7805-440B-967D-D01EFC8E86BD', '3838989511630', ' 250  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34BE5379-0695-4283-ACCD-DED1DB518189', 'AAFD6016-3955-4966-9119-A978AC858563', '3838989511647', ' 500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9483100-7913-403F-A833-1877A8BBCBF8', '1FDF1730-8199-4329-8F0F-00CFF0263059', '3838989515218', ' 2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('277FFDB4-5528-45B5-9C81-CE9697D34F44', '9082745A-BADB-44E2-8A2D-44F609F4700A', '3838989515249', ' 0,005  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F338373-02F8-4E91-A46D-576AA4CD60F5', '016F5BF3-1D5E-4626-A6C7-4F26A70CDF15', '3838989515270', ' 0,01  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D91900A9-6AE2-46A4-BF36-95149A6D2C4D', 'EC653882-1B05-44E2-944E-87466073626E', '3838989516802', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C82E36C-A69D-4330-B141-26265F2C6B14', '4B38C413-8B94-4DC3-83E7-91083D1AA639', '3838989517205', ' 150  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8346530E-9CA1-4B5B-AC1A-9F7ECB0A5A83', '39D60172-4F89-4730-88B5-881349E3D7CE', '3838989529611', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E7D4F0C-89E0-43F6-9FDD-AA45519AC3A0', 'B35872C8-F92D-44C5-90DE-2BEFD718BF27', '3838989530273', '    1,2 18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80282351-E824-474B-B3DD-E69FC71A34BC', 'E9C0B95E-0083-4CDB-8671-647A42958586', '3838989530280', 'C     18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB56214F-22B0-4894-8B8F-3811479E75E2', '16E5F0E0-417E-409D-9AF4-DC4C0D3F4E82', '3838989530297', '    1,2 18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A60E6DC2-5752-45B8-83C8-0C29C00F6FFF', '4EF98616-F6DD-4123-9E0D-DA121A84FD53', '3838989531461', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E50A0F1-BBA1-462B-9AEF-9EC4D36AF3DF', 'F175A321-E893-4049-8D38-42DDE9E67392', '3838989539610', ' 500   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8564191-DD34-4B8F-88AB-B0EE4D60B7CA', '3AA72BCF-F557-4D90-B34E-17FECFF9FE05', '3838989539627', ' 500   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C835AE1-2AAD-4FD9-8975-C510DBA02AB2', 'B4D1B4D2-7236-400E-A081-6532DC570666', '3838989539887', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6837B830-D3DF-4BFC-AA47-E5756C19A47B', '51E2BEFC-C64A-4F9D-9E2C-81B308D4E884', '3838989540340', ' 20  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9198762-7252-41B1-B522-8E4CE02DC592', '449156B1-C459-4C45-9C0A-03CF2A1A780A', '3838989540357', '  0,05 //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF0747B8-CDE2-4373-B63B-ED042ADA7321', '921BBFC7-2B40-4609-A4E1-7E887627BD45', '3838989540371', '  0,0075/5 200 + ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F90CD859-2339-4C72-940D-FE32A20AC1A6', '75F85D29-4A2A-4C67-9E9B-6103CD211E11', '3838989541095', '  2,5+12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B58DC1B-67FC-412C-912B-90B840DDB00A', 'D91CE413-9B0C-4505-B720-C019A02469FA', '3838989541187', '  5+25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70B35924-1287-428A-8C81-FB8DF14438BC', '05DB9661-0E87-4F60-AAFE-5483BF29E725', '3838989541286', '  50+12,5 //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FC80D89-C4C9-4538-B5AC-4BC21B3238F4', 'BC0BD6A1-95F5-46C4-A633-54EF82ED3902', '3838989541361', '  100+25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30E9E4E2-A6A3-43DB-9AA5-CF22ABF577A3', 'A451CE65-1FC5-4760-AC09-31896462BB34', '3838989541385', '  100+25  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E03E9274-7EDD-440F-8BF3-01D3C831BFB8', '9AF687E3-A880-450E-ADF6-1B346B5714ED', '3838989543945', ' 40 1 /   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('652AC8DB-2A3D-434C-8D01-E78B94D3E3BE', '05097BC5-9980-4F8C-9D87-2781B7EEF5F7', '3838989547264', '   / / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BA4A053-3342-4633-80C2-C121A5E39912', '927C4D96-3A1B-444C-9F8C-F9B6A0E4808B', '3838989549817', '  1400   27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E08525A-DAAB-4A5A-9AE2-28EE78269799', 'F6FA7BF2-7588-4F04-A2D0-B614DAE41160', '3838989550127', '  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D52A57D0-7949-4A1E-99BB-DA550499F746', 'A632E842-0512-4047-9A83-2252CB53FA7C', '3838989550240', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('896A1AC0-10C9-48D2-88D3-56DCC9F9769B', 'FE43E2D5-9B8F-431D-8A09-1E814F01FAAF', '3838989552039', '  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('261787A6-FAFC-4341-876A-5BEDBB68D6A5', 'D855A3C8-8F31-44D2-97D0-B95803F2FC95', '3838989553555', '    4+ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45D9DA81-019F-4999-830C-AA1DF0FD39B0', '9B70A6B0-852C-49F5-82D7-5E8C01C18185', '3838989553562', '  7+  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('314BEB0B-951E-4B23-9635-18ECC7896AFC', 'C4765C07-44A9-48C6-AAA5-16B105E859D7', '3838989553579', ' 4+  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A99AF40-FE81-4D51-9F75-51C41FC43AE1', 'E113574D-3FFC-4368-AD50-A2AA8C84A42C', '3838989553586', '  4-   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7199194E-70B0-4331-A42A-0D1B47936E53', '1A1D323A-9CE4-47B4-869E-0BA2193CE01F', '3838989556860', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DBB6D91-62ED-4B6B-8D24-B83D1B3E7BBE', '930EBB15-DE0A-48C4-A32B-9B8974331EB2', '3838989556976', ' 20  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC1F7418-F613-4FB0-BE4F-798607DB55BE', 'F1FEAB07-F101-4669-8D4A-81AB7D35EA94', '3838989556990', ' 40  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19733B17-0396-48BF-BC78-CC1572CFD62E', 'B59D34DC-3939-421C-9A2B-0F354771074D', '3838989557003', ' 40  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5669D02D-3371-417F-BC34-2BA540B89268', '39AD1E3C-23DA-4FBE-B2C5-B25AA5C510E8', '3838989560522', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA307E92-5F30-4ED4-B06C-7F2F7200D896', '8D23D856-5386-4D3A-9EB3-7B67CE2F4287', '3838989562502', ' 10  28', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B75E1FC-50AD-4A9C-8489-ED5FAAAD3C71', 'D60C2944-7B67-4A1A-A8C3-AF7BF778664D', '3838989572389', ' 275  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC06D1AB-3B03-4E2F-B7B3-A072B0D67A4D', '6D9A1CB5-C5E5-48B6-A5B1-31514E267F16', '3838989578565', '  80  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52B27295-9B5B-4004-B102-469EB4522BB7', '332BB50A-90B8-4B1A-99D3-968BEADD3417', '3838989578572', '  80  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA61613C-83C7-48B6-A594-7FC0F75E63C4', 'D84A0DD7-332A-4CA9-94B9-0C123CC4E0AB', '3838989580896', ' /  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9856FDC-4B6F-49D3-B956-F4F9BAC5FD2D', '8B07709C-1EB5-4868-9154-7D2BB0120ECF', '3838989582142', ' 0,01  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B6D4672-B600-42C5-BA19-99509CC884DA', 'FC3C5ED3-2F49-478A-86C2-86F251A1B2BA', '3838989582166', ' 0,01  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAF62140-24C4-472D-A389-B17840839638', '7908357A-7CC0-4648-A33E-0FEAE0B4AEC8', '3838989582203', ' 20  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BCD405A-7721-4393-8C75-21A12A9B1518', '33657550-4DCD-48AF-AC1F-F3FE03FA9D7B', '3838989582227', ' 0,02  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40E4DE55-41E1-42E0-90BB-92F0693816DE', '475159AB-3879-4C22-91B6-7060CC094ECC', '3838989582296', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A214D5C8-8B91-425B-8581-946EAA90FC0E', '8977616B-BAD8-4368-9B83-539BC325A5DD', '3838989582425', '  5  30 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CADAD49F-B711-427B-98C2-7028D8868DD6', '035F5398-9A1B-4039-9642-BDBEE6DD4CF5', '3838989582449', ' // 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFE820C3-89E3-4CE3-A444-0CF0CA300E3A', 'BEFE4942-AF48-4265-B28C-DE6A3E9766F6', '3838989582463', ' 15 //.  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2148E42F-F503-43E5-9F7A-47704EC08410', '536F47FA-6340-4F87-807A-970E2E4FAE4F', '3838989582470', ' 20 //.  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EBB3628-D04A-4863-B107-33EC5BD75EB1', '00A5F625-6C16-4D05-9D0A-5B9C8BA66830', '3838989582647', ' 5 /.  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC52E837-86EC-4B6F-92D0-047DD2167A57', '612A783D-7468-47AC-868B-721B9ACF7440', '3838989582661', ' 0,01  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2D395A1-DE36-4CDB-A915-EFFA3F0DB0B8', 'B65734D5-90BB-4C0B-8495-454C1E63DEE7', '3838989582708', ' 20  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87CD982E-BF18-4CEF-853E-C261A73120AE', '3C23FF4A-44B3-43F4-9A56-B2E76C10BDE1', '3838989583927', ' 0,01  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DC95682-9B87-411E-9A4E-EE20CC18DA86', '20ABE1AB-E72D-4676-9EA7-FDAAC80D1931', '3838989595821', '  350  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92FD7344-1A0D-49EC-805F-42995CC486D0', 'EF12E665-0D0F-430C-B00E-DB414CE2E38A', '3838989596446', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CBE6D35-597A-4572-976D-C4439277943F', '5BEC001E-A19B-4DE9-8A09-40641E116CF5', '3838989596453', ' 0,01 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DD862CF-588B-49E1-A05B-B542FC1E8471', 'BACED20C-12C4-4B66-B702-820DC4BDFCA4', '3838989596477', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA56C102-B675-47F2-BB7E-4D64D4205D96', 'E8B2A473-F9D1-4EAB-ABFF-8E70D604F3D9', '3838989596484', ' 20  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABE2E779-09FB-4F20-B4FC-7F65FE2CE26E', '6D795C72-04DA-4B08-887F-AC5959142606', '3838989597764', '  / .  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D146B8FF-0FF6-4D3A-B394-2CF57AEB0BE6', 'C6F86664-6A76-4212-8363-05053536E89A', '3838989608200', ' 30  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B667816E-8A61-40F8-93E5-1E6AF96DA4D8', '64B21813-DB3B-46BC-94B0-34225FF3FEEE', '3838989618834', ' / 1,71  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A595D1F4-7FB2-449D-87D7-2EB6CE63CC25', '64B21813-DB3B-46BC-94B0-34225FF3FEEE', '3838989618841', ' / 1,71  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('018F5966-AFB0-4A6E-82C1-E7B29F484A74', 'A216ECEA-8DBA-4979-B49E-9445CEA2ECDB', '3838989622718', '  500 /   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A725B78A-6B28-4822-9DBC-EBD763C42307', 'F35757CD-AA29-4CE4-AF64-2E89FBE07971', '3838989622725', '  500 /   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B668D46-11F0-4B1A-AEDA-0E9BC10B181B', '4C128EC6-6B25-47AA-98EB-EE5DF13BBAB4', '3838989622732', '  500 /   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D079063-41A8-4FBF-9F9A-F87C3A7ADD92', '248C2AE8-0C57-42CE-9DE2-C0A982E5D4CB', '3838989625603', ' 20  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62E0A446-74D7-49C6-B2C8-2D70DE02E418', '71AEFFEA-7B35-4388-B2CB-D4DCB92852CB', '3838989625610', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9092BF2D-85E3-49BF-B4F0-A9E81DE4BAE9', '0C16D411-FB1B-4F46-A89A-0E2BECEBD32D', '3838989625627', ' 40  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1281A0C1-F827-44BB-82BE-4046D7CAEFA7', '6A27C67A-6961-47D0-972A-71C96F3DE63F', '3838989625634', ' 40  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F85CFCF3-DAE8-4AE4-BC2E-2CC7076F28BB', 'EEBEF66B-9D0E-4AD7-BB1D-EA63A8FF84E0', '3838989630034', '  120 120 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38A512BA-5CC4-4F10-9F69-863A55BBA979', '0EC4925D-4020-465F-A03D-7A2E347A08A8', '3838989630041', '  120  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4D667C0-9669-41F8-A407-44FDCFD3A294', '8F491F6D-1FA3-4364-8D0F-965CAC0B54E9', '3838989633912', ' 0,025  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('759FC0E2-4AAC-47F0-A65E-189D90EA2DBD', 'B976AB18-09C3-4145-B5BF-14331F32C35B', '3838989633929', ' 0,05  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7748923-53C9-4C3A-8BB4-F674CDD93D2B', '230BE6FE-64A1-4DAA-9502-9C4B5F31F890', '3838989633936', ' 0,05  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD42C88E-4352-4791-9AEB-172810858964', '7AB5BE5D-EC89-4CC0-B4C7-61D90857C9CA', '3838989633943', ' 0,1 //  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D207E5F-E0C1-4041-A28C-0381CF33A8E0', 'BB331A26-6D86-40AF-B45A-302303FA8B35', '3838989633950', ' 0,1  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CF8B5EC-5792-42D2-8819-ADEAF9DFB382', 'C69922BD-2745-4F23-B965-D0A2C33C8A77', '3838989634964', '  100 100+12,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD295D3C-E915-4A72-946E-09457B75615B', 'EDF5D573-8D28-4E37-8B8E-65548CCC5F88', '3838989634971', '  100 +12,5 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EEFE071-62AF-4061-93B6-07502D717720', 'D466EFA5-509D-4C65-8923-F3ADE5405D63', '3838989637101', '  50  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3F52FE4-B92B-4331-A5A7-E06C1FBEF1BB', '1BEAEAFF-C18E-4B51-A09E-27933E087D67', '3838989637118', ' -  50  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('502EBF98-EF0B-48D1-B0C1-39B0309DD87F', 'C506F5D8-6AFB-4C2A-9253-939D4AAE3BC8', '3838989637125', '  100  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8C5CA2C-C2EF-4CA9-B41E-50771BBAEE91', '77871890-1504-4CDC-8FE3-992FE33BAC6E', '3838989637149', '  100  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DBF1017-263A-4924-BB42-F8008AEFE468', '54454E2D-05A3-4214-B198-F39440A9CF70', '3838989639280', '    27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D592963C-191C-43C8-9979-6E01DEBA6540', 'EF3321C3-0C33-449B-9D9F-283C4BA8C6B7', '3838989639297', '    54', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30E1F2A1-753A-4B17-91AF-414B3C92AB48', '85934AF2-C588-46DC-96BB-8D8A64415AC8', '3838989639327', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CB4017C-8560-459C-AD94-A7432081ADBF', '01D65E2F-1310-42F4-9071-2FA27A9F631E', '3838989644239', '   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8CA6DA5-CBE6-4410-A6DC-5500F8E5A24B', 'F1E90E14-1D88-4AA9-AFEB-F8322416B796', '3838989644253', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C30EBC9-017D-4130-9CE1-9FF00244A155', '92E15F30-0634-4492-A95F-AC939F66B81F', '3838989644468', '  160 160+25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA39CE48-9CAE-41D1-A252-7BE2FD13196E', '7EDDEA14-E3B1-47CA-91D1-CE4CB3CC23BD', '3838989644499', '  160 .. 160+12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE4C0F26-7DD7-4234-B3AA-1182C87B3C80', '5736B799-4773-4160-BB39-FE3507D4E90F', '3838989644505', '  160 +12,5  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('712913FD-193C-44FE-AAB3-4EBF41105892', '37E83006-C924-407D-8F6D-B0F6F2C0E804', '3838989644550', '  80 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C17141CA-E6E9-4870-942A-6945A4120A9D', 'D9465AA0-797C-4B98-85DC-8D189976B1A9', '3838989644567', ' 80 //.  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('665BE2FA-5ECE-492E-AC61-F7238439C6B5', '828F0521-E566-4BD1-AA3E-1FF569EABC42', '3838989644574', ' 0,16 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0388A342-E0E6-42BF-932A-2E6C64A7A349', 'DF0E1E0B-5E21-4199-B80F-108221841097', '3838989644598', ' 160   / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('856B1E87-2FA2-4619-8D7C-5F65DC325768', 'BE73D23C-151B-4CAC-9E86-5799394E60E3', '3838989644703', '  80  80+12,5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FB63057-2105-457E-AF06-297DC241CD72', '04DE5166-C779-4295-9FD0-D00A5D853A31', '3838989644727', '  80 0,08+0,0125 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDB9860F-F5F0-4758-BC99-9F872710097A', '0029D5CD-3EDF-4FE2-90A3-140549AA0AC0', '3838989647032', ' 20 //  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2311C852-D62F-4B8F-BE6F-FDE1F46618BB', '9E6F105F-98E1-40AC-A20A-E0EFDD93F263', '3838989647049', ' 40  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C928843E-7B38-421A-8551-83DC0D187A56', '55FFB1C3-B967-4896-A5DC-413D95DE2E77', '3838989649715', ' 0,1+0,005 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C63717D6-440C-4FCD-8D51-C57A19497DF9', 'E7A5BD21-07B5-4B30-AF6B-B0DDB9BBB971', '3838989649722', ' 0,05+5/  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3D7040D-AB84-46C5-B71F-87CE2D9BB946', '77823B77-D11F-472F-BA07-2336586D8837', '3838989650674', ' 320 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F249B5EB-C4D9-4E97-A18E-8539CFBFDBEB', 'A198937F-7559-44DB-ABEB-E4122D4DEBB9', '3838989652784', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6EBDD9E-4B96-4F8D-8222-5577AAEDFB24', '6EDACA02-7F1D-4DCE-9EC7-B9FF9CB16737', '3838989656263', ' 120 //  112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3148C5C1-9FEE-437B-93EE-8541F56F3448', '3C8F16DF-3793-4CA7-B350-12E90368CB8F', '3838989656270', ' 120 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A29C287-8CA2-4DFC-AF55-11C0E45B2B39', '0F5FA5D0-093D-45A2-AC16-618A10912536', '3838989656287', ' 120   56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BDE60B7-C4C8-43B8-A8CE-89FD186BFA08', '2984BE6D-B016-4D5F-BF52-BF05E495D021', '3838989656560', ' 0,1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99078F17-5BA7-4201-B785-A78FB5200145', '04310790-E735-4DE8-BF30-7945CA29C2AC', '3838989656577', ' 0,2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('193B7161-72BF-4091-84BC-AC9DC91C018E', '1C353244-A757-473C-8A01-7B71CEF06FB4', '3838989656591', ' 0,2   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52277FA7-C3CD-4925-A356-AF6C70000DD3', '8C277678-B99F-481C-B998-58A062F4A0A2', '3838989664497', ' 400  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1548F0B-594E-47DE-8751-F1E46C915226', '40BBD74D-BDEB-4924-93F4-A91A987BAD57', '3838989665029', ' 400  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('919B73F0-6FB0-470C-89EC-E13CA42D7137', '2D56D0CC-2ABE-4A8E-8331-9547A4B427EF', '3838989665883', '  0,55  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBC40ED9-C4AC-4E75-9A75-DE6C1CBC716A', 'EFB23CEE-9768-4EDE-A3E9-2FA9D922D21A', '3838989668235', ' 0,04  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28CE3078-4E9C-4A8E-B099-E39A3317122D', '62228677-093E-428F-B893-D46419E4558E', '3838989668242', ' 80  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E035536C-6709-44F2-9794-F4F1AE724FAC', '4B3D313D-8C87-424C-88CE-26BEDB1B5C1A', '3838989669126', '  0,00015+0,0005/  /  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('325A90D9-1901-4243-A181-6F98FECB6B36', '2A5DB455-2FBC-4118-AEEB-AB2F817D654A', '3838989673451', ' 2  - 7,1 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC281EAF-A475-40FF-B8E2-35CC9C407EFB', '24409679-CF99-4226-A990-E10D79B59D31', '3838989680862', '  /  /   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F035F0B-882D-468A-9221-0A436F7D4F1D', 'DD7139FA-10CD-4550-B186-77051032F97E', '3838989682354', ' 0,08  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EC728AD-BD4E-4BC5-934C-BE97C22AA130', 'ED7C2290-4C09-4EA3-BBC8-CC9AE86F17FF', '3838989685393', '  /.   3 +1  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CEBD98D-7670-4643-9289-119B956ECB9C', '94322DC9-E4F0-4351-8011-54F8ECA20252', '3838989735227', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BEA1946-A664-4052-A1E0-ABAA5F9FFBD6', '84896422-D3C6-4A31-B3B1-D4C15932512A', '3838989748388', ' 40  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72217B14-D4F4-4199-8609-8D0BAA0D90C2', 'B2822F6B-692F-4478-95D6-F71A06813BAB', '3838989750732', ' 40  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD0850D1-228B-495A-8DAC-C190F5C68ED2', 'D9453E78-F43D-4941-893B-CD3DD617F58A', '3838989798000', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('766895F3-4124-40D6-9B10-64D14F5D304B', 'C53DA762-2516-4E49-96E0-C59C5EB90A35', '3838989798055', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D210163-948A-45CD-98EB-0FF3AA1A18B2', '467E0386-2BD0-453E-AD75-46C2094526D5', '3850114202473', ' 125  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F1680F9-3BA9-462D-9316-A1697B4E69AA', '481AC2B6-3743-4B0D-BD0B-C5E6D091E70C', '3850114203562', '  100/5 20  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55D52169-FED9-479B-BBC0-E682CF4EF45C', 'A15D9597-1339-412A-88F4-54B5FBA9686A', '3850114213202', ' 5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCADBDF2-393D-4F7B-B960-689B132351E6', '85FBC9A7-A29F-4E1C-9AF7-92ECC5B3C337', '3850114213219', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC1149CC-8496-435B-AFA1-269A41D0BCE9', '77148B8F-15EC-42D0-ADDB-832E7E3284B2', '3850114216210', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7094E7C5-8C1A-4436-97E7-749D2915475D', '68F8121D-5500-4680-8C40-27286045A7CE', '3850114216227', ' // 48  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('200D4CC3-3177-4FAA-B119-54CD05AC18D4', '3B4D6688-C884-45C7-8E4E-7D64E28E0E90', '3850114216234', ' //  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3FE430D-33FC-4ECF-8F5D-C5B6B9550D8F', 'DD9C4497-CA3C-4039-AF11-01CD89042C88', '3850114216241', '   48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38473ABC-473D-4B5A-AED0-FE4D1C8D2957', '6BECC82C-8071-48DE-99A7-E912ED6ACE6E', '3850114216432', '  200 5  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('439BFA9F-6344-4A18-B1CA-3849B90049B8', '18C8A3F8-7834-453B-8D0F-B7A853565B32', '3850114216449', '  200 5 29,3  / 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D06EB045-70CA-4BEC-8311-663D2FFED698', 'D5BD8B6B-8BDA-4049-A592-E64C6060C099', '3850114216456', '  0,2/5 37,5 /// ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('431DFC7E-B5FC-4F05-A91C-BA5118AA8A08', 'D3C3AC48-5F4F-4B1B-B34F-7F3094BD27DE', '3850114216814', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D78FC91D-07CC-4B35-8DA4-04625F7C8C4F', 'A2E11C79-2980-45D1-8058-016F87E8C4B5', '3850114221245', '  0,002+0,035  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9D18BFB-8EFF-4256-A997-02DA1172ED49', '9D3BAD65-5951-4FFA-BCB0-92BF41F9CA9C', '3850114221252', '  0,002+0,000035  / 63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B974B708-B649-4A54-96F3-9F2B9F2B7EA7', 'F1C6D34D-FC37-4638-AF00-367FC055D3C7', '3850114222341', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('389710AC-4832-49D5-91E1-BF12EC48AA93', 'A7286499-1A98-40A3-885E-91030F323439', '3850114225878', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87BC268D-B1E2-4DDE-8A0D-243E96B2C1BA', '9C9BB25A-3B79-4312-9C84-5426E69AAE24', '3850114225885', ' 500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1278408-7247-43ED-835D-AA6816BFA88C', 'C46324FF-1665-4E0E-9DF9-D8E3BE8450B7', '3850114226776', ' 50  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D41CA109-0153-428E-B106-8E0AAAB1847A', 'E6722E0C-8014-41AD-A77D-B688F7BE7BF5', '3850114226783', ' 50  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C06EAC1-7FF8-41D3-84D8-0718E81A429B', 'F8B1FF31-DEFC-4D07-BD75-F22BAEBFC0E7', '3850114226790', ' 100   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEB26FD5-81E3-4200-8C20-6163E0151957', 'BE02006E-4A9F-45AC-9851-2ED0B351A9E6', '3850114226806', ' 100  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AAC3360-2FC0-476F-928B-9816FF248BB8', 'E7593465-06B8-4E84-868F-64692A0FB9C7', '3850114228039', ' 6,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9252554A-1D56-4FB7-8B20-A9FEF5184037', 'FE0999A5-2DA3-4AF0-8B4C-7EFBCAEC1968', '3850114228053', ' 12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7DE7ADD-BCC6-4AE4-834C-373B25B5101A', 'E6ADB4FE-F7CE-4BCC-91EF-EDA0E6A6FABA', '3850114228077', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4ED7D95D-1105-42D3-864F-DD30099F69A6', '830266C4-E76E-481F-8D2C-253946A4E05E', '3850114229067', '- 2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF756BD8-02A2-4DA2-A768-D3485DD3B758', 'B61170F3-ABC9-4F45-ABE9-31C505FDEE99', '3850114229807', '  200 12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F51F954F-C88B-4016-BECB-1B4B86BF7C56', 'CDBACCEE-AC98-4453-9975-D3609BAEB8C0', '3850114229838', ' 5 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A89C116-1873-4F63-8F61-BD536F0CAD00', '34DA6ED6-471C-4741-83FE-E63BD5A7360F', '3850114230148', '  20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2B9720D-9147-42B3-B97A-472958C6B815', '648D2AAE-4C3B-4173-B0CB-B596E00F42B3', '3850114230537', ' 60 60  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('524FC619-FE8D-47A6-97D5-79E1E8EA520B', '24E64E50-FD89-4538-B8DA-9EBC8D26421B', '3850114230841', ' 0,01   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4435C8B4-C153-477D-AF94-6D4E7715B6A5', '6653EBA6-8583-4AB1-A5FA-FFF2F5550B11', '3850114230865', '- 20  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB0FF1A1-6399-4166-B9EA-E76922943AF9', '4F205DBA-8A2A-441F-A294-73163B6A62EA', '3850114230872', ' 0,02   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FE2A937-ED78-467A-9C6A-6F1FC64B3E36', 'EEA40E64-D7B1-43AC-BE4A-BAB7ED680784', '3850114230902', '- 40  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D7DA8FA-9420-4AD6-8FA8-895854C9E3FB', '9D5BF7B9-7F93-468D-842B-25CAB030F9A6', '3850114233941', '  0,075  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F364EE4-4213-43A3-AD91-60D7BA5C8EB1', 'CAABB659-5BEA-467F-A760-45DC3C24B693', '3850114234023', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E397C7F-749B-4DB6-A167-7B50E549B1A3', '9064EAD4-C96F-4662-988A-1F00DD4EDE59', '3850114235037', '  0,003+0,0003 //  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1656D62-3193-4F08-ADDD-E25F61551873', '8F2C710C-5E57-44D4-8C63-0134F08211C6', '3850114235068', '   / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58D2B273-B177-4222-B729-1324D3135F36', 'C8A7820C-11F9-47C0-A239-E399D097079C', '3850114235075', '  3+0,02 //  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A984DA81-B3CB-4F7D-9DF5-A388056A3CEB', 'EE7849AC-692D-448B-9CE9-D7D6610B09F0', '3850114235907', ' 1000   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B71725B-3EE3-4030-8D3B-3893411652DB', '2D648A20-5B13-44AD-B68D-DE2F64C85D80', '3850114235914', '  1000  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D454265-247E-49BB-9479-149E65845A5D', '0C72D4BA-406F-47AD-A890-953493849881', '3850114236232', ' 250   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04E9C8C7-DC29-476C-B170-DCFBD035ACC2', 'AEAB9B7D-1EE3-48DD-B8B7-E508DEEA31CB', '3850114236249', ' 0,5   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C840CFB-A980-497B-84F2-1A4B335C542F', 'A7814840-CF35-4DC8-98C5-DA811C19AC2B', '3850114236904', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33D56A66-7C65-496A-9AC9-7B9D7AEAD545', '982398F7-E863-4766-966C-C556D5AA5FED', '3850114237024', ' // 12  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97BE24C8-3463-4BAF-BE84-B6CCB6610376', '79F61F0A-88C7-41F9-A4E4-F61B71CEB5F3', '3850114237048', ' 30  /  2,5%', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFFEA737-6F2D-48A5-84C5-980BFE12841C', 'AF7221B0-A8C5-4335-BAAB-9A3175B99BFD', '3850114237406', ' //   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81AEA4E8-9BD4-4F8A-8B26-9A2A1410AF64', '5785C9AB-D7D6-4165-A5B6-D1C33AB9E23E', '3850343001144', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F288977-CB87-4F74-A2B1-013B0CEB15F3', '2E42C2CA-3B9E-4C7E-9B63-C81164CA3BF2', '3850343001380', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2389286E-375B-42FE-8A62-11CBB119AE0B', 'A6F56595-4AD5-48D5-ACFD-095920BF0074', '3850343001410', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D65E606B-EC79-46A8-BD31-2025AD05BED8', '3994FEA3-9E57-46DC-BA8C-641CC4F6855E', '3850343001472', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C9485FC-BE6B-4EC9-AE18-9FF739C458D2', '712E7906-795C-45C3-A946-B3BAAC3B2278', '3850343012003', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('251FB90B-744C-4DC9-B052-7351CB2EEB22', '1E128816-AD05-4A55-9778-1258A54859BC', '3850343012119', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20C626A6-2CFD-4BD1-9763-DB3CAEC58DE2', '2E2208CE-CC34-4A20-BA8E-E79B58E00E11', '3850343012218', ' 16  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67321555-573C-4840-91E4-CB8F1823ED2D', '42DE812C-4E25-43F4-969B-1BF758B0EF17', '3850343013253', ' 24  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA6A3A7F-637C-4F79-8DDE-6C5CB04C53C1', 'D1DC9FF8-D999-4243-8E7B-87F6B4812C26', '3850343013598', ' 300  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BF0FE8E-6EE3-40B9-8C4B-E9B3BBF8F533', '575B6C51-7C94-4277-888D-CD4036F28A2C', '3850343013796', ' 30  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2D64972-673B-4905-AFC0-0E22A9730255', 'C3FE397E-9FDE-45C2-87FF-30F1F0E6567B', '3850343018210', ' 5  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('995CA564-3C99-4D07-8A5B-56A90C281A81', '72203DE1-F53D-42DE-AF17-0C2CA0B73A7B', '3850343018562', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADF8F755-4F83-44F5-B57C-2697A81C4648', '3270086E-AF61-43CA-8034-70CBD7562B57', '3850343018753', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75000EAF-8F58-468F-8020-EB7DE4BEFA1D', '372E5D3D-7527-40B2-A856-E12AA68012B2', '3850343019606', ' 24  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7E584B6-7E4D-4941-A291-08A409E6213D', '1686F4AD-B7F2-4A0A-8AAA-8858C7CCA20A', '3850343021357', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67194B48-836A-490C-B943-EC69C8FFA57F', '9C8250B8-6D18-47D3-9728-0F2A8A7DB5DE', '3850343021364', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DD5B8DC-9763-448F-BDEA-5C3ED0ACDB83', '9A103176-CA22-4E37-AD97-06857E0E1CE8', '3850343021647', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4780F35F-CBE2-4BC5-90E6-55AFA8B302AA', 'BA267CE6-CC02-429E-BBD1-6DAB876E24E9', '3850343021685', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('481EB8EB-DF0C-4532-96F7-FA39E45AE216', '33A4AB5B-D4B6-4CEB-9A0C-D58D150EC9F6', '3850343022071', '  66,7% 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80E0180C-ED13-4339-9CE3-E5D516877284', 'DC22830B-82DB-4A15-B25B-60C4ABF67719', '3850343022507', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B9D875D-64BF-4EF8-9977-5E84486AD502', 'A6C9ADE7-1EE5-4C07-AD52-A8E544632315', '3850343022798', '     1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('752ADCBE-1179-45EB-B448-948ACDAA9A25', '37AA01B0-942B-40E2-863A-B37B9CD05745', '3850343022804', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBC2227D-48A2-472D-99B6-53A473C0587C', '4B25D7EE-A2C5-44E6-9E54-E39305CE945A', '3850343025294', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B11F9C54-A793-42FD-9F2B-458E84931CF3', 'CF016D24-66B3-4866-A4EE-D40CB977B9E6', '3850343026949', '-3 0,5 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70BF5E96-18F2-441B-8780-8BE3B51EB713', 'FAA50C9C-DB4A-4FB4-908E-2E781E4829DD', '3850343026963', '-3 5 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('040D9E6D-1F00-43F1-A7BD-D816E5510F7E', '389730DA-2389-4132-98DF-E751BC7E5A81', '3850343026970', ' 5%  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE05D04B-A60A-4870-83CD-090B908890B5', '5DE72197-337D-4EDB-85D5-F44351672EA5', '3850343026994', '-3  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5D7E240-4AD3-40DB-88D2-12F64CAB12A8', '223849BE-F11C-483B-AD4B-094719246B2F', '3850343027236', ' 5%  / 2,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05D6A910-06CC-4E87-862C-6CF7CD8E03B5', 'E979EC18-0DF3-4F48-9CCF-1D510AEE6B98', '3850343027274', '-3 5   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7321C21-6558-4708-8D15-E1B7ACEA8233', 'C2750C60-25E6-4BB6-81EC-0D162695791F', '3850343027878', ' 400  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('158E45D2-8988-4C9C-9A98-7A3C3856EB76', 'D44E8A9E-6179-4754-B45D-CFD04FE345A9', '3850343027946', '  /. . 2% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21441126-A606-40C2-AF25-321715478402', 'A38179EB-D284-4A07-B1B4-5ADFBAE5BA61', '3850343028950', '  2% 60 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D9F4E9C-A316-4EC7-8780-F2C42D9952F8', 'BBFD2DF7-EEBC-4DFB-AC55-17D058F15C5D', '3850343028974', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0845F53A-9B0C-4CCD-B6B4-D25A6523CF3A', '5BA0EFE8-0BA7-4169-A852-4DB432AE3073', '3850343028998', ' 400  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A73E8CC9-7B12-41CB-BF2D-73BA7A50F6FD', 'CA345113-1EF6-4D4D-AFC4-FC12A9EADE18', '3850343032124', ' 0,075  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9654CB61-826F-46C2-AE3A-80AAA03A9E3A', 'ED3A77F1-7C8F-412B-AF66-9E6E6B896184', '3850343032278', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F9FA794-8DEE-403E-A3E5-A0BEBCC36AAE', 'F5AE9D97-48B3-4EEF-B34A-95C54E7CF33E', '3850343032285', '  100   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E696E99-EB65-4DC5-9A5B-D3CFE38D4DFD', '694AA55D-A1E6-4056-8D6B-73B5598741D7', '3850343032315', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A3A6017-2B12-4913-BBDE-BC8C8A9DBDD4', 'F87E6CA6-C864-4013-8EC4-C9A69B514594', '3850343032339', '  / 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7121C048-230B-451F-BD88-18911286DB60', 'F5806738-08DF-487E-A510-521AA3C671BF', '3850343032551', ' 25 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECACAA71-B031-4A73-B152-6E24283FFC8E', 'D3C3AC48-5F4F-4B1B-B34F-7F3094BD27DE', '3850343032568', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B9D66C4-F9E9-4CEE-858D-96F93F9F4F40', '764DA1FD-C6D9-4702-86AD-92BB2C4B345C', '3850343032803', '  0,05%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4759B85-8884-4C1B-80C0-FE453BFB0244', 'C678BA5D-0DA0-4998-BB98-311DA6716527', '3850343032810', '    0,05% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E809D7B-7434-4F46-B529-587110121B21', '68E209EB-9B21-4386-BEE7-543CC269DC8C', '3850343034777', ' 400   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C3960CB-714F-4408-9D9F-BD6FD6F7B015', 'ECE06A5B-C6D4-4352-BB72-9D975A2C854F', '3850343035408', ' 5%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E67248E-C81B-4F26-A300-853A23549204', 'B2670E6F-F4FD-4048-9855-CBD8853364A3', '3850343035415', ' 0,05%  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04DCCA7A-FFC0-44DF-ACA5-59A8CD3D5173', '16AE88A1-62B8-46FF-9C0C-03BDB5475418', '3850343035422', '  0,05% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DD1DF21-512B-4ED6-A15A-30C89F2FDA6B', 'A432BD24-D450-4F78-8045-9DB978C5CE94', '3850343035453', ' 0,05%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3E45602-A267-4A7C-ABD8-DF56EB5D4355', 'AF31DBB2-3DA6-485F-A9F5-2418F8C67690', '3850343035460', ' 0,05%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0730C0AB-7B67-48D8-8AEE-16208EB6558A', 'ADE9C123-903A-4CD2-A22E-CC45D089C900', '3850343035507', '  0,05% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDFD9EC8-C442-4838-82CD-2BC093204723', '440C2079-9F0E-48F8-8FC0-439822ED1720', '3850343040433', ' 20+12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE295808-33F7-4049-9200-4FBD90568522', '15F77293-B9B9-46D1-85F4-D80A9AAFEF7C', '3850343040440', ' 10+12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AA7A8C2-04D0-421E-991A-4F5A7DED1DC4', '78951AE7-7F22-4B05-91F7-95672B7000F6', '3850343042482', '  667 500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B20739D-54BA-461E-B898-F669E25E6374', '0A1C90DB-1F07-4E64-B40F-16F49C4D916A', '3850343051002', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D523FAFC-ADD9-4617-8E45-A647A1D7A37E', 'E5C66036-6E1A-47CA-BA33-BACF04AF57E3', '3850343051019', ' 5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAF859C5-8AB8-45BE-928D-EFF060B9CE2A', 'AACAFE17-1E0D-4BBF-A346-DEEB35378655', '3850343053280', ' 0,05%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87C3F0FD-0CE2-4240-9753-2B6C9295C663', '74A2757F-1A96-4A73-AC09-6B85E1095367', '3850343053297', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1B3B3F4-CB5A-4E09-96F3-794B173DCF5C', 'CCFC6A97-2ED9-48D6-B176-76D79D37A665', '3850343053594', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2576168-63CA-4175-AC7A-2E0CEF7C4B50', 'D93B369E-11E5-48EC-A3BA-3DB9D19AF43E', '3850343053600', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43D381FF-98A7-4BEE-BB70-E94E340B0AE4', 'CC149E81-0275-45A3-8F80-B79FD96E6E9A', '3850343053617', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58E4D341-2315-463B-8B37-681F4B684533', '0786F8AF-26E5-444C-9372-9D794E7CCC50', '3850343060271', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEE1E249-B75F-4C1D-AE27-8D3F73718A5E', 'F62B3659-76C2-4B56-8458-EBBD443AD9BD', '3850343060288', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39B29299-5C0A-4E67-BED0-B5BBD3EA54B8', 'D44E8A9E-6179-4754-B45D-CFD04FE345A9', '3850343061681', '  /. . 2% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30F40C55-7FD6-4359-9ABB-45F2CF44788B', '2DDF3099-2B42-4A55-A64B-F23DC274A3A7', '3850343065931', ' 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C742AB33-3115-480A-AE41-F104126CF381', 'A1288CB5-9D74-479E-8D7B-FF81062BF080', '3850343065948', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B722E62D-A7C6-4DEA-AE94-CFB8783002AB', '72FD2300-37AE-4004-BAF3-A1505B8FC285', '3850343066129', '  /. . 5% 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00312321-8DBB-4C36-B371-3BBD54D2E286', '70B8FB4C-5E7E-4E13-83DF-ADFC905E8C39', '3850343066136', ' 2%  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F4E09E6-D867-4A4B-9C90-95591633AE26', '90DFF5D8-2447-4EE3-BDB6-5D24913A8193', '3850343085144', ' 200  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85F3B052-5C28-439B-ACD0-F44CB9AD7BA4', 'D077AA6D-8B33-4E5D-B7D1-F4506826ED3A', '3850343086127', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('009D63F9-AD7F-4D2F-88D4-2570D83DE919', 'FCBCA843-BBF3-4C0C-872D-BC1DD318685F', '3856013204853', ' 10 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('949195F6-CBD6-4898-B43F-434D2886B19E', 'F9AB57ED-B6A2-4838-97BE-D105BD152A2F', '3856013204938', ' 180  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ADA1F3C-A2D5-4EF7-84DB-AF64E54018DF', '90406AA7-AF19-4FD5-B834-496431BA3245', '3856013205300', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CD11910-5F4C-426E-B3F1-D2F26E7B2EC6', '1BC3ADCE-184C-4F9A-BA20-7191720A07E1', '3856013205317', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D65D1A29-3C3F-413D-8103-E592A5C8AE10', '84754F41-37DA-4983-8782-157EBF9F1444', '3856013205379', '-  5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86BCF878-D1E4-45C5-9972-74BD75AE9888', '2437CF25-43B2-4F41-9C1F-584D2DBAB205', '3856013205386', '-  5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F5DF09A-A828-472B-9110-39B232059A68', 'BDFEA175-7712-4860-940A-2007E99E7AD1', '3856013205744', ' 0,005% 2,5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85BDBC1C-1DB5-4CF7-A39E-17912942D379', '0A6D04D7-D889-4D84-9DA9-D6A3BE50A259', '3856013206550', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F52277BD-98C3-4782-B898-9526A658355E', '898E43AB-68A9-4994-99F9-A11CFE760863', '3856013206604', '   0,05% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3A0E146-EE00-430B-9C32-28407115320A', 'FAA872BB-0E4A-46C2-9BB6-BBD8EECA9AC4', '3856013206611', '   0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7F8DC8D-5F37-40A6-AD68-B091A5027963', 'BB2B7891-79A4-4895-96FA-75F90C33C7B2', '3856013207014', '  - /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC65D1AB-0DF1-4B0C-AED4-412148DB0E8E', 'F8B1D47B-DF24-405E-954E-5E7D85459974', '3856013208578', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8650632-1927-4819-8D0C-CFD59F43C494', '01C02276-B612-43AC-866F-CE4306498AE8', '3856013209339', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32AFEAD6-30CB-4CEA-8934-2822EE4FEA9E', '06A6F24E-750B-4C50-BFB8-A68B9A07A4D4', '3856013209346', '   //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48F72AE6-670E-47C3-83D5-A52333BAFFE4', '059D884C-3685-4CC2-9661-9A52B8667139', '3856013209391', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D38EDFF-D7EF-4F8A-9AD3-BC5ADE074D6F', '4042218B-8CD6-43D6-9C82-803472534DAB', '3856013211219', '  /. 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CE3B39A-7D5E-45EF-88FD-ADA1008D3CF3', '6355519E-211D-48DE-8352-986746DAC7B9', '3856013211226', '   /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA500A3D-C3B0-4E56-95CA-820C73B9DBCE', 'F344796B-0919-4A07-BFD2-BAF73DF797E3', '3856013213626', '-  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E3A71BA-902C-4925-AA15-C8602E67885C', '3C1C0486-7C4D-4261-9680-84FB7E8BF1E5', '3856013214104', '    150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11E2A440-0A1F-4AE3-8FC1-2B59CE74C32E', '231C1092-4C54-427D-9F93-EFC1EADFB71E', '3856013214852', '   c 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF530A21-54F7-44C9-BEF1-F0BF7DB5212A', '898E43AB-68A9-4994-99F9-A11CFE760863', '3856013217624', '   0,05% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5E933F9-2E90-406D-9751-DED0AF4F1795', 'FAA872BB-0E4A-46C2-9BB6-BBD8EECA9AC4', '3856013217631', '   0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05B7DB95-FA25-4995-8BF1-839A3948B177', '6216A1E5-AE8A-431A-B6EF-66205DEF5D71', '3856013217716', '   /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C344ABB9-D3FE-4446-A4E3-9C86C838A538', 'E698D4BD-1BA4-43D3-91F3-340C11907B90', '3856013217723', '   c 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81ED3E3A-E906-4CD0-AF99-5B6A9BE243D5', 'A036FB61-B914-427A-BD23-B76CCEB04D8D', '3856013219000', '   // +2 150 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72CF30FC-ABD2-42C7-A9F2-CCBACBFFE891', '7130BB88-B576-45D9-ACD4-F046DF7B6BCD', '3856013219017', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('786F7BF5-1EE9-4E8F-BB0C-E80A428742B2', '01C02276-B612-43AC-866F-CE4306498AE8', '3856013219031', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68B9748C-5269-4046-AF04-A3E4C38FF1F2', '40C8D400-51A0-4B00-89E2-A03ED548F74E', '3856013219680', '  /.  - 8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('548F9FAF-AB7F-4BCD-B84A-CAA246D91CDF', 'BB2B7891-79A4-4895-96FA-75F90C33C7B2', '3856013219833', '  - /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27F70786-8E90-4D9C-8A49-5D14E0C55DDA', '645C3E54-1BDD-492C-9D74-C8A2017F989C', '3856013219840', '   - / +  30-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C30444A-4641-47D7-B288-8DDF42E798E3', 'D9A70F66-1BCE-4C14-A8C1-2CA865802ACE', '3856013219963', '   4,3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4040230E-1606-4DE7-AA38-1DDD7F201AF0', 'F413B9D8-9D71-4414-899F-48D84E92ED64', '3856013221805', '  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE89D00A-D4C9-4437-9F3D-FD9C9E3AE4EB', '55D3651C-6A30-40F3-95F2-1940C2726318', '3856016806078', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF9EF8EE-4174-4452-BD8A-B3F694E498AF', '2CC690E6-706C-463B-A8BA-31ACAC3B8F5E', '3856016806092', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69F5287E-1D51-4E1F-8D80-CF536F2584C1', 'F20B6E1A-383B-48ED-8A7B-E4908FFB3252', '3858881051843', '  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E339DDC5-D082-49D7-98BE-115B7C84DCAB', 'AC530FF1-D6EE-4831-AC1A-9B4EA786900E', '3858881052185', ' 50 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20F4CBAE-B0A5-46B6-978D-95E48BE9722C', 'FD718ED7-1484-454A-A266-5F2DD4FE1C23', '3858881052260', ' 0,05  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16D15944-C2F5-43F7-A6F2-C7797E3EA54F', 'BFEDBDE8-60CB-404A-BC25-0C06CAABF9CC', '3858881052772', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03625A29-9633-4B9C-82B0-18F0DC1ADA82', '92E7A62E-6C98-454B-BBF1-A5CD1D9351D3', '3858881053120', ' 1%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0881EDD4-3900-46FA-9A48-934E630B4C6B', 'D7009BCC-FBC6-4A42-ACE1-7ACC3DD36DB6', '3858881053137', '- 5%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AC381F1-4726-4BF4-8E3B-15832D9AB949', 'F9ED6D7A-D9ED-4D23-8FFE-EDDA400F83C0', '3858881053175', ' -   5% 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23F40E18-01D7-4046-AC55-FD21339CAE2E', 'D2825642-3C0B-43F6-8835-2C105B8D8532', '3858881054868', '  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBF95FE5-AD06-413B-AE11-750DFB733ECB', '7DF33B25-DB4C-429D-8485-14856557F661', '3858881059283', ' 160  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96F7B2B4-E2D0-47DE-8202-782417846D43', '2D9911EB-F2B3-424E-9356-EACEA92B7AF7', '3870010000638', '  5% 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99D730D9-190A-4DD5-9524-70792E2EEA71', '556CF49B-2A5F-467C-96BB-93A077B24679', '3870010000645', '  2,5% 125/5 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2B4EDA6-FDC6-4F79-B89C-7390CFB761B8', 'E5628EE0-3BD8-43EC-B198-6BDBDBC12F8B', '3870010000652', '-  3,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A94773E-3D72-4743-9921-D3ED80964FC2', '58B63898-2B02-4DF7-8D3B-7AAC9A3CF1E8', '3870010002700', ' 100   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E725B1B2-CD04-463D-BE41-ED414A869CE9', 'CDF1F692-2C19-4206-9B41-3680547AEEB7', '3870010005091', '  /  2% 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E038E96D-7D15-4B2B-A96F-0FD1EE4E88CD', '9645DC55-A028-41DF-ADB6-F147DD603993', '3870010006456', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44159F65-95B1-4F4D-A6C8-5DB0E42C9BEF', 'A3F1F791-9308-4C6D-AC51-2FCDA338AEFA', '3975213923019', '     1200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3E9744F-9FFF-4CE2-8088-6F60A26149EF', '12AD523F-9D3F-4959-9455-78803AC56D3B', '4000000050155', ' / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BE0489A-4290-4D08-A77E-21EFC7CB2115', 'F80A30D1-729F-4E57-B12E-5534EBCED517', '4000196911469', '  /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EC28EA2-8F4E-4230-9DCC-79532A53E861', '511DDDBC-FF2D-494E-9F35-98F82DBFF129', '4000196911483', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07905853-1E17-44DD-B3E7-0CBAA6712258', '85EB4B6A-6E32-4773-90AD-1AF103E3B0B0', '4001895874802', '  /  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5768EB8D-F714-4AAB-96E8-F929D133CE51', '2B502FF3-1B06-4A7C-AE66-FA6E158A1792', '4002857002752', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72984B2A-FB7C-4019-892C-072B4E7D6EB3', '6B77B0CF-8275-45B6-A8D4-239126ADF247', '4002857002769', '  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC9D6E76-BECB-41CE-9E31-7ED577CF82AC', '659C1FA1-9B78-4ED0-86D5-67323A210688', '4002857005326', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FA045B4-F21B-43BD-926E-ACD74910AFDB', '5A58C1E3-ED10-4FB7-BE0C-95B30CE6E25F', '4002857007658', '   /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F836F54-7331-419D-9153-3FA0E031B0C0', 'F43F14C0-1ED8-4FFE-883E-A9AF75EB8508', '4002857007665', '   /  n30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('930BAA12-AB56-4E7D-ACF9-9BAE20FB4909', 'FA3AC85B-8AE2-41D9-9327-6E23FAEDC559', '4002857007696', '    /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1460BE24-333E-4802-909E-2B0C3DE78839', '3E78840E-E4FA-4C96-A287-A36983A246AC', '4003583063314', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94041722-7755-4057-8929-867E9026149F', 'FA31E9D4-46A9-4639-990D-537F9102D2E8', '4003583063390', '      .  .150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45082D8D-2B1F-40C4-8F05-E814059F5150', 'BBE76CDB-0A6D-4C50-AC8B-079E5114FB89', '4003583063451', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3D8AD5C-D978-462F-9723-BCFA3DCA31B6', '3CEC94C6-9D2E-4D55-983A-B4BEB2AFB3C8', '4003583063499', '      . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F5C712B-BF15-4024-9C34-0372549B29CC', 'F16ED3D0-045C-4B4A-9BBE-6F13B23E4438', '4003583075591', '   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76989870-F0AA-4AF8-B070-E3FFEDF3BAAF', '6FD94950-6E54-4A42-AC9D-8FF793A71052', '4003583075751', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81054EB8-0E6B-4CAF-8F0B-59E8B7DFF38D', '0CEA0233-B462-42BA-A4FD-767AE9F1D9C3', '4003583109654', '  -      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9010EB3A-58C8-4D92-B9BF-0D12D32F567B', '6F423C29-384D-4290-9D89-F14FCC887588', '4003583118052', '  / /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70B61D91-B116-4289-814A-BD89FF763953', '8ED84CBA-1738-4D13-8603-03D40038CA54', '4003583121182', ' - /  .  .  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D170917-C39E-44E2-A720-0543C7FA2719', '2D8E244E-8918-41A2-8EFD-6D3EFC9375E4', '4003583190973', '   /  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99B4252C-29A5-4C2A-8C90-4494F4673CE7', '3E78840E-E4FA-4C96-A287-A36983A246AC', '4003583191079', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0572F9D-ABE4-4087-976D-8E25F0A95D79', '3CEC94C6-9D2E-4D55-983A-B4BEB2AFB3C8', '4003583191192', '      . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B785AAF-ED1A-445A-AF45-CD79C4988317', '8F24E320-0DC2-4470-B888-5900EEA6511C', '4004696503841', ' bio+   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAC7A499-A419-4309-A690-9A9596AC4DCD', '154F0BB9-8713-4C9C-BCD0-086F792FE056', '4004696503858', '  +  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31367126-FC16-4C8E-8403-A4B4651A504A', 'BD1AA168-3935-4AC8-BDE1-414220FA6388', '4004696503865', ' focus+   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC635CB8-3F3E-4582-A455-4A2B8188AEAA', '059B92A2-F0B3-4A69-B387-2DDD886C9FAA', '4004696503872', ' immuno+   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F74A205-E2DA-4FC2-AC91-755F5910E19D', '99D1D83D-452C-49D4-AA4D-F58012049483', '4004696503889', ' multi++  // 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('317D949B-9AF2-4D00-AA0B-525692C2F366', 'B8A39664-19BD-4186-AC4C-172DD1F30611', '4004696503940', ' bio+   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11B0EA2F-EBA9-497D-B569-FB0C64CD300F', '07C300EE-F9F9-4542-AD9D-ADB62992AFA5', '4004696503957', ' +     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('695501CD-3F8C-45E0-BF56-E8FB6D76DAE4', 'F3197770-D2A9-4449-82BC-B1A7177FD32A', '4004696503964', ' focus+   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('169DB3D8-92AE-40A4-800A-52921912686E', '14F7FF5F-4B33-4F94-8400-6B30458038C0', '4004696503971', '        2,5 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AC6895B-9A64-493E-9669-F9B4E1FD7921', '3C831476-EFBF-4C28-8896-09F459C77541', '4004696503995', ' multi++   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28B367D8-6CD3-4B72-A1EE-1C0C63DE3C60', '8E775EB1-B7D1-4387-82B8-FBA51F60F294', '4005800195822', '  /   4,8+   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEFC4A57-CB4F-4983-ABC9-7C08EF8CCCEA', 'E53D8459-B21B-4005-BD4E-8DE07BD9D650', '4005808369553', '    / 4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C84218AF-A73D-44F3-A56E-670364A5CFB6', 'C94B5E6A-DF89-4F30-8E8E-CD74FF2F3B44', '4005808369676', '  / / 4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F7EA2B7-80CD-4B14-A3CE-D90D0E47011E', 'AF597C17-5AD2-4D38-83CE-86F0AF225EEB', '4005808369812', '  /    4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DDA6C33-CF8A-41BC-9FED-C1203DD397BD', '16EBCA79-AD74-4FF8-81DD-7A8BC39DECD9', '4005808369904', '  /    4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3861D4C2-FDF5-494D-B7DA-BFE39EBF5E56', 'DE48EA5F-3FC8-47AD-836B-2C9454015C7C', '4005808369980', ' /    4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BACBACC4-F63D-4F2A-AB32-ECAF2C9F612B', 'D071450F-C5FB-4A4E-80C1-F8793D07F960', '4005808370085', '  /   4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5C00F44-9C04-47DB-BD5A-86CD47801CAE', 'B57F9BE8-6E10-4D2C-88EF-ECE414EDD0DB', '4005808556571', '  /  /85225/ 4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B851D706-690C-45F5-BCF2-8DC5F6C575D4', '65681224-E3B1-4A66-ADA3-9B0EBAE873AD', '4005808734559', '-   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CBF77CE-3905-4413-B790-0E234220A329', '387D330F-A3B4-4B47-BE7F-1965D10C7585', '4005808829958', '-   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('491257E2-39FF-4EC2-BE99-77FD22D33BAD', '4C9CCABC-49C1-4A0C-9178-11B1832D4408', '4005900431752', '  /   4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A0DFA69-B81C-4211-8B7D-27A635315712', 'FF7FFCB4-E60C-46D4-865D-4F16DF58BEF9', '4007965580000', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA37FF6D-6AF6-4AE8-9B6C-6CF377BC1D1A', '031EF49C-3BCF-4453-B95D-9362EF90FD12', '4007965582004', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CD5EA5E-BA32-4235-8919-FD7F5095C057', '04595324-D678-4489-A8AC-E4FB52EA3A6B', '4008102003260', ' suss   1200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00C7549B-B882-4617-B6E3-4A8EC7383409', 'F19665B9-7531-413A-B5F7-B3C30A8F5070', '4008233032603', 'Kneipp - / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94F5DC5F-1A3C-437C-80D5-B8696F32901B', 'E79112E3-8B71-410A-9763-6804726EFC2B', '4008233106595', 'Kneipp    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37628B04-F9DC-43A8-BAA1-C408E213D00E', 'C70A702A-1820-4660-AD20-38DD54939BF2', '4008233109428', 'Kneipp    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEDA7FC2-C162-4315-876B-236CEFB89EB0', 'FD755A6B-AF97-45EB-B12B-1280BA9CBBD3', '4008233117379', 'Kneipp / /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C94B9EDE-730B-4755-90E5-C534BC0B6ACC', 'DA1DAF63-E08A-40C9-8B8C-B3BF4FB12960', '4008491201285', '- 0,4 500 - / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90105F87-A94A-4421-9836-F1745497BE55', '6544F878-B950-4958-A5F0-B38B98A838FC', '4008491226011', '   3 5 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14D97436-8EB3-4926-A272-E0E5F6EACCCF', '2B0AD17E-4063-4C75-87E6-53E5C17C34A9', '4008491301022', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A8C9B5E-B17E-4494-8F7B-11FD7A09233A', '5A85E01B-34BD-4F2B-97ED-3735BA2324F0', '4008491301039', '   75   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD8F6EED-861D-446C-A2D0-B6B4CA58D91F', 'E5CF7FC1-650F-470F-973C-369B012C5E8E', '4008491301060', '   75   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('855549F5-BBD0-42FD-B928-CA91B2203FDC', '69B7BC6E-5615-4337-B150-274C22915C64', '4008491309790', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75FD1BDA-5B06-4DAA-A89C-EF62E59A49C6', 'E46A436B-D790-4134-AB3C-39B80B816F52', '4008491313568', '- 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E27BCD5-D65D-426E-AB4F-F9377C5E8DBA', '3EA0239C-40CA-419F-8B3E-C790A889FDD7', '4008491750257', '  10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CCF42E3-D2B3-474D-AA19-5F77BB02F7AA', 'FDF9773B-6498-45A9-B5FA-3196185ADEDB', '4008491750264', '  10  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8467E7D6-CE62-43F8-A076-95832D2A218F', '297AAEB8-FFEE-4A2F-AC49-02CBB6BAB23E', '4008500015971', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB4065B3-EEE4-4B56-B673-BF5B8F1583D1', '4693F851-0A9D-4470-AF2D-123A269C0520', '4008500017500', ' 15  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('718D906A-5353-45D9-B866-F1548CBFE7C5', 'B36D2176-262A-46F3-B2DD-40C5C848F46A', '4008500017517', ' 0,015 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFBF3084-8F69-4AA3-AC8A-322DBCE8EEFF', '8A524C8C-69EF-4DD3-955A-639C4C4C1014', '4008500017531', ' 15  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1F2D7B7-7CA9-4BF2-AE2C-C9DF5B467625', 'AFF81C20-E194-406A-BFAE-F663DB614AEA', '4008500017548', ' 20  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59B71149-3A65-47F0-831A-DE74553B41B8', 'E204F197-0603-4E9E-83B0-39B3275EDD73', '4008500017555', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35ED47A9-0D90-4594-A6C5-9860F500F473', '54F6A927-7058-45E9-A4A4-0B9C024367B0', '4008500017562', ' 20  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D503235-0E89-4DDC-B3C0-49D4A220FE15', 'E8545E95-C1EC-4553-8058-C1991E2AE920', '4008500120033', '  400   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('698A03E8-C82F-4443-95CF-801D6FCEA038', 'CC816477-9800-47DD-B8ED-48D3F76A5560', '4008500127155', '  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C8925CE-E064-4E36-8D27-019F8554F9A4', '0CBD8D29-DED8-4EC5-ACF5-C2CCBF5144C8', '4008500127261', '  300  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65A70D22-819A-43D8-A70B-13FD75EFFA86', '5C94196C-0F99-447D-BA18-CB8A01B3EB7C', '4008500127391', ' 1% 15 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('884CBF69-206A-48D4-B362-23A98096679A', '6F50F540-0D8D-497E-982D-EA98EF9D5220', '4008500128275', ' 400   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('307763D0-E055-4BF8-9D0D-3CD250C985DC', '2048A163-ACE5-4087-8B95-08144DFB9BAC', '4008500128466', ' 20  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E8CA8CE-6D84-49C2-A797-6A9CD29E8515', '435CC1A0-6A8C-4A33-AA68-B0F6524C275D', '4008500128473', ' 20  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66AFAC10-E577-479F-BC5D-FAD897D6D099', '658A9CCC-F9D8-4CD4-9946-F14A998BF9ED', '4008500129142', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D369F0BC-51D1-4EDE-A236-7E8BBB6DA04E', '3825011C-E285-4505-8AE7-8D9394B9D107', '4008600047490', '     /   0-6 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20F6D908-4CFB-4351-9D4B-71A35C244AC1', 'F18C3C5A-E5BE-4A9A-B187-3CE0F18B1E29', '4008600047513', 'C   / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFD1384B-0DCF-4C26-B859-3EAAB2D52060', '21E997E0-55E8-4F1A-BAA9-28745A163081', '4008600047520', '     /   6-18 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43AD1E33-7A7F-4E4E-8C16-DAFE42E30DE3', '33CD65CA-EA79-4E4B-A430-9914C94C2CF8', '4008600047544', '   / M 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('953182AF-1BCE-458B-B5E0-C17D0C11E532', 'A7B2F0D9-B7F4-4DBC-B64F-E92FAA976AB8', '4008600047612', ' -  heppy    0-6  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C35F954-48D0-4505-9A54-F3BADE02F208', 'ACD59CFC-156D-4BF1-92DF-BCDF61AB5AEE', '4008600047650', ' Classic Soft    0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('046AEBF9-813C-43A1-A1B3-FA4E589150FD', '531B6ABB-2FF4-4E89-A77C-CFCC3D84F6C4', '4008600047698', ' Classic Happy Kids    6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75E76311-6881-4A0E-B509-46D84D100985', '96F71F05-196E-4305-AA56-5004A9FB12CD', '4008600047735', ' Classic Soft    6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39E25A59-C67C-4194-9CA0-B74A10231C00', '55C46DDB-8F86-4119-B7B5-92E498DC8705', '4008600047773', '       18-36  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0B0E42A-08E7-4F55-9C11-4D710DD54E0C', '781823AC-95BB-46F9-B1A7-35BB6FDF4ABA', '4008600047810', '       18-36 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80FD4286-CD64-48A7-BB00-A3DBD1953C45', 'E12D11AC-4D1D-4835-8E49-93A9F5AB98F7', '4008600047834', '       0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39E3D5E1-2696-447C-81A9-43631A4A1141', '187658A2-ABA4-449D-BCD2-1F06310A13ED', '4008600047872', '-   heppy days   6-18  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2F8CC13-A2D6-474F-9266-7FC57E9D9936', '381DB527-EFCA-4D20-803F-A814E775D015', '4008600083825', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1744E781-97C5-4EB1-84BC-5ED332E31555', '573BA08F-F38B-4208-9942-9949E970E95C', '4008600094760', '   -   0-6  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFAC658E-02B6-4E97-A0D5-FC46A4948630', '6B01D1D6-7F81-4A61-A4C9-2A9CFE3626F9', '4008600094821', '   -   6-18  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C565A0A1-1F26-4E9F-BAEA-9AF12A9058D3', 'DBD32F66-772A-456F-8B11-B1A37EB0A8B6', '4008600094883', '   -   6-18  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEFE9A01-3032-48EF-A72D-60EF3BCA649F', '6B01D1D6-7F81-4A61-A4C9-2A9CFE3626F9', '4008600094944', '   -   6-18  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F997B442-CCD7-46AB-8445-1D578F54703C', '87C654C1-E9EF-4F72-B861-0F68CBEEB030', '4008600096740', '   -   0-6  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24DC59EA-1957-4E70-882D-F43E50697DE4', 'F887DE91-6A9C-4B12-B063-E0A9BF6A7DAD', '4008600096764', '   -   0-6  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7704E149-1530-441A-ABDE-EDA0AFC36297', '80F0F776-EC62-4499-8A8E-51E197CA14CC', '4008600096788', '   -   6-18  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F6A275B-C763-4357-B8D6-6AE3A5337CC1', '7D11DA3F-E0EE-409D-8604-90347F987668', '4008600096801', '      6-18  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDC5ECA0-AFE8-47A4-9CC8-82FCE9B1B9EF', '17011CEA-0D91-4D13-BF37-C6E76879F8CC', '4008600100461', '  / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94C28294-0B23-40A3-A49B-0E3B4D377C61', '5FC99F5F-657D-4F2E-BC15-BB2A56A3D18D', '4008600100676', '-     6-18   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C42030B-1AC4-4930-A61B-0A2E237839B0', 'DF260DEB-73BD-4B33-9AAF-932697DB0DA0', '4008600122715', '     6-18   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA09843E-D2FE-4E50-B80B-5D39EA7876BC', '9E8C81CF-1E33-40BF-93C9-A4E75D083BD2', '4008600129929', '  0-6 /   240 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('912E994E-DB82-4BF4-B207-37C438F8FF9C', '89F478C2-C49E-42E0-8D37-050A5E40380E', '4008600129943', '  0-6   240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28822BDA-5FD1-4D28-AD0D-77017ED7F63C', 'AD2DDDC5-F922-41F2-802D-A54073905B2F', '4008600132622', '     L 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DED98D65-4616-4EF6-A777-C4D8D82ACAC0', 'BE504F40-5C53-4D30-AA99-4E5BF144A9CA', '4008600132745', '     M 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54818B80-1A72-415C-89E1-36CDCE9480F1', '14BF48C1-70A1-48D2-A7F5-38761071944F', '4008600149491', '   days -   18-36   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55A3A7F8-89CF-454D-A5FE-822938BA313B', 'C5CF793C-E833-489B-9227-877E9DD469F6', '4008600162391', 'Adore  -    0-6   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A723603-215A-45D6-A7AE-76944889E8EC', '3555B886-FE9F-478F-A143-8B1FEA98CC71', '4008600163114', ' adore -    0-6 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FA45D44-D4E0-42D1-96EC-476506CB5852', '20368BE1-7410-48A6-8278-25E1507783F4', '4008600186748', '   / 36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('113F69C0-8911-4FEA-9F97-87ED1A9C5DF9', 'A0BA8F16-8332-498D-9C5C-044E387DEAA1', '4008600248606', '     6-18   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D498768-6162-4505-8293-19EE4A90C42E', '8AAB0BA1-5B29-464A-9F7C-2F31A7399F06', '4008617148890', '- / //   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('901A10CD-C736-489B-AA96-1A596C559DC5', '6A07C6EA-4E3E-421B-B431-F44290705C8F', '4008617149774', '- /  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F908936-79FA-4180-B55D-A2DAB0A6DB49', 'C5765077-DA76-4624-92D6-265144189A81', '4008617149873', '- / /  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEE272B2-DA82-4278-B734-31AF9477C922', 'D7C0C0C2-7786-4BE4-B3FD-48D4D43DDAE7', '4008617165071', '- 15 /   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA7F68AE-F17C-4A59-A40B-BA729A3C0FB4', '57515380-CDFC-46D9-A1E3-72A28CC66F1B', '4008617226185', ' 0,05% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA87C664-26F0-4968-A4ED-F3AF03709451', '76230814-FA8A-4C6F-9389-381092D5EC8C', '4008617227243', ' 0,1+5  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75ABF137-E9C4-40E9-912B-438D11194A51', '57515380-CDFC-46D9-A1E3-72A28CC66F1B', '4008617227250', ' 0,05% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EA7B415-9FAE-4ECF-85E0-183F82DEE234', '038AFB60-B10D-4A8A-9774-C649D5071F37', '4008976680178', '    322 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D822B85F-FBB7-46E6-9E07-6F9A9DA5B931', '443A46AD-199C-4FE8-B01D-0526A5FED8C3', '4009137941404', ' suss   650', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3287B7A4-1E91-4D2C-82E9-6B48FA5F45DA', '18A69203-DB18-46C9-ACA3-48315A45EDCD', '4009283000116', ' 8  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE63294F-438D-4885-91C5-5FC19093E54F', 'D7BB3A2E-BECC-40BC-BE8E-B88FA0BCF464', '4009283000130', ' 8  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DFBB9D9-3305-4884-AFE8-53675D57F5DC', 'EE62EA9B-9A2A-4115-B43E-6DF5627D8EA2', '4009800001008', '- 0,04 60  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E56C646F-7221-44E5-A48C-CA6EFB4A7314', '18E4E460-796C-46F4-8E82-14BBDBA7399B', '4009932004007', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D4595BD-7A14-463D-A883-22A9A8769463', '6C86A8D4-434E-4D3E-B694-41276D35D284', '4009932004243', '  250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('181DF668-C99C-4E23-8332-1035E53551EC', 'C600B6DE-D607-4DF7-854F-407A4FA708F1', '4009932004274', '  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D33989CB-92EF-4BD7-AE96-C2168AE3567E', '9414A051-3D6D-4706-B94D-6ED416639A03', '4009932551525', '  /   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37F38F99-FC6E-4D74-BDB1-9F1A2B1D5791', '870D6FEF-0B4D-43F8-A2E4-501DA80C9983', '4009932551624', '    - 47', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F81D794C-AAD2-4A49-AB24-67E76E30DCAD', '6AEE5439-4E16-4C06-A158-62BFA879CAE7', '4009932552089', '   -   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA72EDCA-09DC-4F72-BAF6-A4D5AC90E02E', '066DDDA5-674E-4C94-A6C9-FA7E4DC8D96B', '4009932552140', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92EDC988-9940-4DF7-BDE8-27B43A3F404E', '5A849EC0-ECFE-426E-9D57-A3A517F47B64', '4009932552164', '    - 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F1A5CDF-E6FD-458B-BCFE-218F99529DBC', 'A593B4C0-7722-4ED2-B7C2-F6DA68A8066B', '4009932552171', '       40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51BD9DE4-7C85-4AF3-9392-B7B69A57E027', '0BF3CA0A-CF28-4078-B3B1-E21A1FFAE27C', '4009932552188', '  / - 40,0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B9452D9-8EC7-436B-959C-EDE119ACA982', '7480AAB0-ADA5-4818-9F69-909A1AF5EED0', '4009932552201', '  /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DF509DF-E365-478B-B91C-C9C271A2251F', '27C8F086-C72D-45CD-A336-8BCD14074254', '4009932552218', '  /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDCF8B90-F9C4-437A-ACEC-87ED769E00DC', 'F35E42B7-1AE2-4D04-96A6-0BC762CDC9D9', '4009932552270', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('331E3EEB-FFD2-440C-8D4D-06873D42A427', 'D1482C1B-4529-4AA3-9868-472ACF7FB124', '4009932552324', '  /     66', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEF6634F-32E4-4F1D-82B4-61775F496C6D', '63CFA8A1-BF8B-4038-8A6C-FB999E284BE0', '4009932552331', '  /    32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87F0F375-9C54-4463-8EF0-C496FCF18963', '30917F5E-BD8B-42A5-AB79-F972E4600015', '4009932553529', '  /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D19470C8-6C58-404B-984B-A51DA211B3C2', 'CBC0FD62-7EFA-4267-8DD6-F3FD114B18E3', '4009932553901', '  250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0646E351-B5C1-4983-9E16-EB156590749D', '722934ED-9FC2-4B29-85D4-59135653D8DF', '4009932554045', '  180  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43405143-A8B8-4D41-AE08-029A3B9DDFB4', '41C4C5B2-89A7-46F1-B31C-3C8F7E9B916E', '4009932554526', '    +  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3D6020D-5B34-4B44-9DC9-B0C637EDD334', 'EF8E9941-27CB-4E58-9008-3F89C095AA82', '4009932554663', '   1,15 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1E0EEFD-4622-4C68-B986-62AAD5AB5237', '842D4767-1D5C-44DE-99E6-9B1B8E704146', '4009932554700', '  - 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB0C7D3B-AF9F-46DE-897B-02777A58665D', 'A81F0089-C345-4A84-8654-B3D10A2DC5EC', '4009932554731', '  +    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A948BF7C-3275-4929-AECB-0590297F703D', '77645FAF-8439-4B04-A650-A9AA9B50EFBB', '4009932554762', '   1,15 /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6340EC55-DD72-4739-B8A2-67A8F8EC07CE', 'A340178B-B24F-44B4-A8D3-907E69BD1B50', '4009932554793', '  l-+  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A19978F7-4A82-47A7-BB9A-84841354A336', '51358F4B-8762-4327-BAE4-DE7E9E27FDCD', '4009932554854', '   1,69  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D9DEF86-5408-4171-92AB-A309BDA08575', '93BF09D5-4C27-4006-A59F-D2C10A7A2AC6', '4009932555455', '  -3 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA4FB76D-7898-4ED1-9FC0-8CC83162EA3F', '5207C22A-AAC6-45A3-9A12-50970471BE79', '4009932555844', '   /   800  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC2E631F-0F80-4C4D-929F-CCE37C7B9AA1', 'D67A7A18-5FA1-4570-99FF-9356A824AA53', '4009932556179', ' vip  -++q10+ +  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C6208D6-3E73-48B5-9556-A626C5D0698C', '2EEEA7D4-61AB-4455-9CC9-48DF51B98E70', '4009932556285', '      1,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28E4BB81-EAF7-4E98-9AF6-7AC77E2C7B0B', 'C386DE6C-BA28-4A7F-B725-E7F968E1FC9C', '4009932556292', '  +  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB632C12-B294-404D-AFB0-A410BA694072', '04A770FD-C22D-41F6-AFA1-C2D396AA11EF', '4009932556469', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1C0EA02-48DE-47D1-8C70-E587BF7BF1C8', '92289BE8-C546-424E-8A47-16205FB0886E', '4009932556681', '  -3 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3814542A-5824-4E5D-A69C-FF0F2E338B85', 'BFB714D1-CC9C-432A-8825-7A1E26AEC090', '4009932557022', '   +1+2+6  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A7C990C-9C18-450E-8729-36C123E02219', '8BC439E3-FE02-417B-84FE-438B3A89FFF7', '4009932557091', '   q10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45CCE264-6E20-4586-B675-8DCC32543A5F', '8B474E5F-9A25-4D7B-86F5-F574FEE3F6C1', '4009932557121', '  +  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('055899FF-8FD5-441B-87CA-4FBF9B4D8543', 'EB6D55B4-959B-4C7E-BC4D-1B063C387AED', '4009932557190', '   //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66F2F3A8-D691-4BE3-A52D-100D54C573EB', 'A2C24F93-BC5F-422C-9748-EB97B3FD8693', '4009932557343', '  + 2-  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('707AABED-6DA5-472B-B428-F0CF072304BD', 'F60F8C83-F855-4264-9B75-CBC741B110E2', '4009932557428', '  -     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19A0B239-55DA-4EB9-BFF4-C0CC4A2ED294', '06415A55-9B3E-4757-B8A6-4703339B99B4', '4009932557459', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEAF98B6-6832-47C2-9336-A5CF363164F5', '92379853-6774-4832-A5CE-7CFB0E5443BA', '4009932557565', '  ++3     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90EFFB98-EB83-45E1-A961-10D0C36C6807', 'B8DF8210-3AA5-4B60-9F70-922222C06259', '4009932557619', '  +-  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B88264A-D02D-4A27-A633-5302E05EAF0B', '353351C0-2780-44B5-9FFD-605AC45981E8', '4009932557657', '    1200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77FC24CB-B965-4885-849E-A755820A6E5E', 'BAA8E1E7-4729-4230-BAF4-365F21241524', '4009932557763', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8D1E34C-A0B6-4E33-8FB2-DD8536F7F73C', '00833AD9-F3A7-417A-A0A5-74A58BCAC575', '4009932557855', '   3-6-9  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C36D05C-3814-48C6-91CD-3A6729790EE4', '0A88ECB1-4B2D-436B-A3C3-D3FF8FB36409', '4009932557916', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('329205E3-E85A-4719-8DFE-64E2268A39F8', 'EA76DF31-4556-4339-847C-729B8549D294', '4009932557923', '  vip  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C4F6741-58BA-48A3-8F93-12BB0F19F3D0', '97BEC7E8-1C76-4B3C-A2FE-2FC52CB18F2D', '4009932558548', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2BE9267-9351-4042-A08E-4321344EFA2F', '4E04D96F-1B15-4083-8C8D-9FEBA63CB0A7', '4009932558920', '   /  15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FD4DD28-9EAF-4463-8BF5-407675F5767F', 'C5B6D713-CF92-4474-8AF3-303F3EF1D02B', '4009932558937', '  + /  / 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B822A0A6-8487-4E24-988A-B3CC493555C2', '4EF5FF7F-7502-4E6B-9C40-7E64E55DF9F9', '4009932559019', ' vip /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B548D8E-FA92-4E63-9FA4-9B1BA824F61E', '0FB7AE87-4877-4208-AAFD-54B5C003BAE6', '4009932559026', '         30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('207A3207-9A87-42F5-B4EF-A253B0A39296', '82C90586-4CEE-485B-97AC-E6DF6DECA62F', '4009932559088', '  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('967D7EA6-98E2-4AE3-A141-5BD1E5E00C82', 'A01779A7-B297-4231-8155-A1137A9D03AA', '4009932559132', '   +   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48917E84-4758-4DE4-B4DA-BB34BEBF70F0', '7C3BB6B5-6821-4E96-8B98-1891415143AC', '4009932559163', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1C15464-A694-49E3-8707-BAA4BD6ED433', '0E3AD7AA-F669-4827-9D28-531831D83F30', '4009932559187', '  -  50+  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73786B4C-C65B-4085-8AB1-D0F77D25A351', '049ED9BB-172F-49E5-9AE1-695FBBDC2A85', '4009932559484', '  -3   7   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F470BD13-80FD-4EA7-8F34-B4D572702F35', '3FA1C4D9-7559-4EB1-AC43-E324AC572F45', '4009932559781', '  /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0F3A258-E665-4430-9BCE-B64BE2ED8614', '9CAA9C03-9A3B-4D2C-8C07-D3597A891D62', '4009932559958', '   d 400  45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C0E4BE0-DEF3-4C50-98DC-3E3DD7305CC9', '7585D6F8-A20B-42FC-A680-9A13BD66234E', '4010439201226', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74205D4C-208D-4156-B0D7-E4B618EB5A32', '1FA7FA4E-6431-4663-A78B-56F4967D6188', '4010439201363', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99FA739E-5307-4E94-9E86-B8AB7F92A08A', '02F99713-778A-4B31-8115-9F44673CEE40', '4010439201370', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA403EC6-BF6A-47BF-B5CE-45253E56962B', '48E45EC2-A6B2-438A-AFB3-0762995C0968', '4010439210020', '     /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5EE408D-E1F4-477A-9CF9-54C9C1C2DDAD', '604CA00D-3D28-4D80-80D3-117A8A28F8FC', '4010439210051', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1C28E00-2E11-4A42-A477-E6F5E3DF1194', '8BD2AB11-494A-49DE-8FEA-53BE94630268', '4010439210068', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCCE7AB7-B0E4-4480-BCB2-D654C883B873', 'B4C1C222-50A2-4B5D-9B5A-B3BA01E0484E', '4011548000021', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38E1A490-9649-4875-B428-62CBA5D64361', '8C1A197C-228F-4777-A8F6-7599F7B3BE78', '4011548000076', '  / 12 / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17E48DE8-0524-4B20-A91F-F3FDDC39184E', '4B606C3D-CFF0-4272-B892-6B85EC8A77D5', '4011548001684', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CC5A85D-FB1A-476C-B80C-146A20698915', '917A5670-7517-44D8-9A98-D88D0BF34A53', '4011548002803', ' /-    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AF209E1-9495-4DAA-9937-3DCFC73CE360', 'B93D6284-0218-4102-B334-79CAA287784C', '4011548016022', '  spf25 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14AACB19-F8D1-48BC-AC4E-CB244563DE4C', '35D101E8-4B42-4F63-979F-483109EBC4CD', '4011548016312', '    - 1% 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7518717-3D7E-42A8-AEE4-B646089A49F6', 'A9E8019C-657D-4F6B-8B87-FBAB7A6CAA62', '4011548023419', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D91A4D0F-2BB3-4579-B20F-69365B26B269', '28A648D4-F5D5-4F99-9E1D-580EEA9BFB1C', '4011548025765', '   0,05% 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24097770-F256-4E53-B82B-20F2D11BA838', 'C8DBB443-E065-4F6F-982D-0A3E8815BFA4', '4011548025772', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('908B6577-B556-4A59-B5EB-24644CB1C6FB', '34CFEB2F-E574-42D8-82F4-1FA9EC66F005', '4013006092111', '-  eroticgel // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61ABEDAB-75D0-4036-BB02-33314C66F60B', '479BF7A3-0C8A-45A6-8921-530E9CA9E959', '4013006092210', '-  eroticgel // 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1D8AF52-8C7F-4C10-BC70-F2CFDF0DDFB4', 'C9310047-45E6-4FE7-86ED-C9E13EF83438', '4013006092265', '-    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('708ECF90-307B-407F-9022-01EC86BD8A09', '992BACA8-3AF2-462C-87DF-8ABEA6ADEB3F', '4013006101028', '  safety  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBAE1CC6-DD54-45E5-8055-1B7141F69F98', 'D1CA5B56-9C17-438C-A344-119A52BD7D60', '4013006102025', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF2FFE5A-67BE-4AA1-ABF8-8EF4EA668428', 'D1CA5B56-9C17-438C-A344-119A52BD7D60', '4013006105026', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62C9F223-EDCE-4751-8048-AE4A6FE0CCB7', '3D0C8669-5DEF-4EB6-8A8E-732975EFC9F0', '4013006110150', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1308A22-0495-455E-BDA6-2C71B346E0F7', '4611483D-FE9A-478C-8A66-B1CAB0410B87', '4013054000724', ' 100-- 100   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A5BA53F-41FF-4405-9D45-DE43297EEE32', '73E73E7C-B520-4AA8-8994-2A2F6ADFB3A5', '4013054000922', '  5 120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90DD8B07-2163-4457-8F9A-91063E3EC8C0', '9C368616-43F4-43AE-8498-C5FB1A750ACD', '4013054001189', ' 1,75  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E404DCED-F89D-4173-A676-62FB75B42209', '4C548D9E-3E30-41FF-8BB3-C50A065982BE', '4013054001196', ' 3,5  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00FC11DC-EFCD-4734-A870-A37939FA6B2D', 'DCB8B58A-DE2F-4382-A731-CE1395DD90F1', '4013054001448', '  50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('054B6FB2-9EB7-494A-BDF0-2EBF6F93B48B', '8B840FB5-F2C2-41E0-A35A-02C2BF343CAB', '4013054001516', ' 75  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEA131DD-0AC8-44A4-9734-9163984135F0', '0BA8A73E-E74F-4F60-965F-7414B5160906', '4013054001523', ' 4  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AE61A46-92B1-4B0E-9E36-6E6EE21A1488', 'AA1B6760-190F-4F18-BD10-2BC4446E10D0', '4013054001790', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D42F2C83-FFB6-4450-B7AA-7561BABE03AC', '51B8E197-C78B-4442-A26F-346F6AC29284', '4013054001806', ' 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C31C80B9-A9DB-40FE-B4F2-CE1B89B52F12', '1BE72109-4B84-4357-B78F-8855965622CA', '4013054002001', ' 40  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F045836-2486-44C9-9135-16A5F1A6B628', 'D648740A-FA3E-44D1-AA95-A969D66969FF', '4013054002155', ' 5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D3964B8-4EF7-46D1-BC36-2FCFE3475A2C', '3F1F07B4-E708-41F1-9154-55212E93AE4F', '4013054002162', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3196E44-187F-45F3-9CA0-B7F06F9404BB', 'BF89EEE2-289B-4320-BD21-D0CBA3242A46', '4013054002346', '  320  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2A23984-E319-4929-A6B0-784675344549', '45C4A759-5886-474E-98FC-D131B49A0C81', '4013054002681', ' 30  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B433167-A672-44FD-AF5E-035122A3D70C', 'B472EBC6-2415-4D04-8475-173CEA3B3540', '4013054003305', ' 100  / /.    9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02F43403-2730-4FBF-ACF6-6340EF59B6FC', '5A23CE0B-ABB9-4A1B-B9FE-2DCB39AC6C28', '4013054003442', '  10000  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6D9797F-6D06-4191-AD30-27CD5C760EF8', 'D801FF8D-F95E-47D4-83C7-3AB864561E1B', '4013054003916', ' 1000  1000/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA21A45F-1766-42DE-8D21-D7CF15736D11', 'C4F2848C-7B47-4380-A444-5F7C98D828D1', '4013054005309', ' 100  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D292C91-2647-4CD7-99E4-BEFF7B719136', 'D79B994F-98EF-4B30-A8D4-4368EC72BE00', '4013054007365', ' 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3617AD1B-D17E-45A7-AD93-CE137A1A29A9', 'B2306973-A403-4A96-B7F6-3BAD31589A6B', '4013054007815', '- 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A87CECD-5981-437F-90F0-BBCA265A2BB6', '1074B07B-F919-45FC-9F6C-426652D39F86', '4013054007976', '- 150  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21E945D7-B2FD-43C0-AF96-87DDCF4625BF', '3E7F01FA-D99B-4E16-BF63-AB5D8829FA51', '4013054007990', '- 125 125  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A72B235-BBBD-4D62-A75C-22184069C7B4', 'B75C249B-C197-430A-BB89-0F455BEE31FD', '4013054008652', ' 300 0,3 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1DF7089-0035-4FC3-81FD-8895E27EE8D9', '7811DEAF-6E08-4B0F-A564-0D4BDC71BF49', '4013054008669', ' 300 25/ 12  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34747F50-EE23-4BBF-9B8C-CF0CCD1C03C4', '4033FCC6-F165-48C5-879A-3CF847046EB8', '4013054008782', '  20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF08692F-231C-4936-B38E-1D4A6B9B59CF', 'FC2E8FE0-7D9F-4DCA-8D97-F8FD05417194', '4013054009383', '  2,5% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6B5250A-7737-4E55-B1A7-ACB7D7424426', '707ABABA-F08D-4D3E-9284-218976BC95A4', '4013054010006', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03644B99-40A7-44B8-AEBB-128654B3E1E1', 'A9DBCC6D-05B2-4F3A-9A96-B959B21E0F01', '4013054010044', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('521F37CC-BF21-486B-BF21-3E0F162FDFEA', '373C65BC-B67D-4CFF-A1B0-4BC6EF480EE4', '4013054010082', ' 40  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2DB695D-A7BF-4B81-B1C2-E7D0018F0525', '668F310C-365D-4FAC-889E-6A9E0BD1E9C5', '4013054010389', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9ACDD90-BF14-4563-B15B-A604B4B8FBEA', 'B8E355A8-8CA3-4122-8205-84457715B23E', '4013054010570', ' 30  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('941635AB-9C7C-4440-ABD1-75C9CFA473FC', '48C092EA-9AA8-4572-9B6C-E6A20F8CBDCD', '4013054010600', ' 7,5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('481BF8C1-4E4E-4E59-B22F-F4EFED4EF297', '15815731-7678-4703-8F34-A23B16EFB53F', '4013054013526', '  25+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4D0FB6E-E386-49F9-9DB7-3626F24707F0', '52461434-26FE-410C-8858-03891EA7982B', '4013054013557', ' 10000   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A840C3F-0110-4015-809D-340F4E6F2CD7', '1316D2E9-7430-45E4-BB64-52DB5C1CFB59', '4013054013564', ' 10000  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFD8E0FC-C795-4ED8-BAC0-20DD9FC35943', '09C79E89-827D-45A4-BD19-240F3D9BF619', '4013054013588', ' 25000  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11A81182-F852-43E9-BEDA-52BBEE61EB23', 'DC571B13-07BC-4C85-A143-85E878BFDD9B', '4013054013595', ' 25000  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49E40362-A5CE-401A-92B8-86B5664EC0A5', '6B28ED2F-54FF-47FE-81F4-51EB1438DE5C', '4013054013953', '  0,0125+0,02 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5378667E-6F6C-415A-B609-1E58A5EC7340', 'C212B997-7652-4A8F-AE2A-E247A7A8EA80', '4013054014295', ' 1000  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C4146F5-1434-4747-BA96-A7F958AF071A', '75BE066F-CB40-4A2B-B33D-D738686EB7D8', '4013054014639', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DB9B8D6-EE74-45C2-AB5B-508D9EC74E99', '1B074A36-F4E0-4B4B-88F0-8C5C3F1CDD2A', '4013054014677', '  2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAF3625F-7580-493B-8095-BE92D8939262', 'C6BF8ADC-40B8-42E5-86D5-E052ACD076E4', '4013054014936', ' 15 5 100  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB85757E-9DE5-436C-AEC3-BD988F4C5F68', 'BD7AF4F4-37C1-41DD-9DD0-7EB77FF8F286', '4013054015223', '  300  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03843012-8647-4147-B380-35339BDA48F6', '0F3627C5-0E84-4104-A05D-C54F2693AB85', '4013054015469', '  30/5 - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F87ACC9-21D2-4D22-8CAA-2FF8671B6567', '3077FEB3-CAA4-4E8C-BC9E-68603B60185C', '4013054017463', ' // 4   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFE6370D-FA51-493F-8582-E4D14D9E4B1E', 'E8263C75-65FB-4607-9906-12FAE5FCB010', '4013054017470', ' //0,4  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8086785B-1943-47BF-B141-CCE1CE7E3A37', 'EC139B4E-8725-4736-AF4D-000D8F5F8CB6', '4013054017487', '  100 30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E439DA5B-A89E-4BFB-B9BF-9618D8E41B43', '1D885B10-ABA8-4C82-8A3D-E91E09A54824', '4013054017494', '  100 50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('514D00C4-0D79-44A9-BBB8-AFE1657C220A', '22AF9E7B-AC12-4977-A91C-1054F8EA828E', '4013054017500', '   30', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7C4301A-C8F3-41EA-90C0-83055ADEC1B5', '263EC304-D903-436C-8965-E0EB391F912E', '4013054019085', ' 600 0,025  /- 24  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4201F17C-1A2C-4F5A-9683-DB4013FE70AA', 'EE526DE5-A254-47A2-B064-1D5F36655222', '4013054019511', '  125   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6136621A-A624-426A-A80D-2FD0478FB346', '5225D395-D442-42FA-B778-5C4BDD61DF04', '4013054019634', ' 0,01  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAF935A5-F6B3-48D2-80AD-FFD2CE98078C', 'D88F5564-44E7-4CC7-8968-3A8819074669', '4013054019658', ' 20 20  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9979E82-FF66-42B8-9BDC-309D3C2B6428', 'ADF563B5-BFC7-4707-8388-ED0C6D92BC7C', '4013054019832', ' 20000 20.   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15678F40-ED97-4999-BC5A-EC77D365567A', '65B15191-7DFD-492A-A68D-D5EF7533125F', '4013054020630', ' 500 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C74FE34-5AE0-4CB1-90EC-2BBD8B9C3D62', 'AA1B6760-190F-4F18-BD10-2BC4446E10D0', '4013054021859', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D04CBA54-9CEF-4735-B22D-7DE0C49B4235', '51B8E197-C78B-4442-A26F-346F6AC29284', '4013054021880', ' 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34516067-9581-4E75-97A1-C4E0C422B5CC', 'D79B994F-98EF-4B30-A8D4-4368EC72BE00', '4013054021910', ' 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2691C382-A33C-4648-9D34-BCADD05C8356', 'E68A57C4-7006-406D-AB19-4BC4E3845BBC', '4013054022887', ' 20  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C00081D-AD24-4C5B-AFDD-22D198FCE433', '5447FD60-C812-4F33-B7C5-61BECAD32A0A', '4013054022894', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5180186C-0C36-4B17-8317-BAB99D62BF0E', '709C8E2C-D357-4493-97CB-BDF1588A4B27', '4013054023419', '   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD9EB043-FEB8-4DF4-8BB4-3593155C192B', '91BD9A23-A83E-4252-9026-3A0ADE496417', '4013054023600', '   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('428C4812-4563-498C-9FB8-3C56C66A53AD', '380C53A7-8FB4-48E1-B103-2E571451E946', '4013054023884', '  60   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE56B801-B60C-42A8-B5B4-261E11059315', '50011260-942C-4DC8-ABAD-1FC7A576826C', '4013054024478', '  320  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEDBADDF-7056-4162-8FA5-B11D621FF90E', 'AE1B1D55-5AA8-416F-938D-3EBA9D6738EC', '4013054024935', '  / 10+40 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('385996FB-6FBA-4287-8334-9480BE816708', '0AC5582F-B611-4688-91A1-214D3BC7561B', '4013054024966', ' 5+40  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EF81AB0-C71C-4330-A38D-4BAA02A56EC4', 'ADFD272D-DD14-43D8-97E7-22797920FA49', '4013054025079', ' 25  // 25 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D84B048-8134-4C9F-8A8B-9E2C78A4FA7E', '087D5405-D745-466C-A593-26F17FA2FEEB', '4013443492277', ' -   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC586634-C061-4C8D-B214-793B39BF4162', '6DF3689A-61E8-436F-BF24-94D6E5731DEC', '4013742004423', ' 20  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6860F326-80EA-48E5-BF1C-E606ED221BF9', '9134ED0B-7609-42F2-A0AD-512477D872DB', '4013742021420', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36D2FA8B-4D7A-425B-B643-D665B65E558B', 'DE6E1164-1FCF-4C30-8ADA-6B835DED5CB6', '4013742022427', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFC7FB75-2A75-4FA7-A2ED-64403FCB1CF2', '45ABA6BA-05BC-47F4-A252-04970D145875', '4013742025428', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31790EB4-B2BE-4575-8DD4-4614BE377820', '00472A96-5C69-482A-92D9-0CD508A8959F', '4015400006770', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD1CB964-FE47-4CDB-8219-5D4FDE71A6EC', '4B2E34A1-4664-4463-947F-FC5DE8A712B3', '4015400032328', '    14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D14657D-0321-44FD-B518-5FDB6BC0A0D1', 'BAD04637-7150-43C7-BA98-9B51AFDBBB95', '4015400041603', 'ALWAYS Ultra     Night Single 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C3C6211-3A2E-476D-B162-C6C2499A8D5C', '11561502-7EE4-46A5-A0D3-34594DC2873D', '4015400041627', 'ALWAYS Ultra     Normal Duo 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B174D40-330A-4A09-A5DA-7E1D851864D6', '1791784E-FDFE-4C78-A25D-20E6E37BB394', '4015400041641', 'ALWAYS Ultra     Normal Single 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7EC081A-EA22-401E-A376-F90BDDC9A6B5', '5DD1BB41-946C-4B70-BCE2-B73DAFC3E270', '4015400041665', '  .  .   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D62CD47E-8005-4D5A-9D1A-6B7B577F5443', '3212FCE6-F5B8-4536-9F86-9231D975C35A', '4015400041788', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B404596-578A-42CE-973F-D38CDA9CBFB7', '27EC4AAE-C71A-41D5-90C1-6DE6D55FFFEF', '4015400041801', '   /686/   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B12652CB-5A9D-45C3-A78D-0C6E56E3C505', '18B9C641-E7CF-4F68-BCFB-636190945EE8', '4015400069881', 'ALWAYS Ultra Sensitive    Normal Plus Single 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40EA8C27-B05B-4E87-8419-0F5E34E53A38', '75DC21CF-9B10-4BE9-A5BD-9DDCA1EF0B51', '4015400069928', '   duo    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78C757E0-FDD7-4546-A14C-DF5D93070E6D', '256BE4AF-4600-4BEF-BDA9-62A012239B6C', '4015400069966', 'ALWAYS Ultra Sensitive    Super Plus Single 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29017B27-A095-42B4-B19C-FC768257812F', '7EFE175E-C935-4ABD-B6F3-EC1734C031DD', '4015400069980', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E60F858-B0C4-40ED-B53E-BB0EFF1349AE', '028C56E2-6724-4AEA-8133-0BA3574FEE43', '4015400075097', '      16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('970F9AEA-372A-403A-A4B9-210270C37D0C', 'E3CDFA35-0437-402D-AEDA-A2DA29EE1EFB', '4015400075110', '     c  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('617C8108-D854-4ADF-A641-E07218235D81', '63B9BA50-A7C4-43D8-894C-C63C6A8DB2B8', '4015400080800', '    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4153BB36-C16A-4A1F-9C2B-02AA85D9FC6C', 'ED925519-2C19-4183-A176-731C2E782DF1', '4015400080909', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE714228-B496-45D9-BC49-84B8B0863ADF', '770DB080-B733-455C-9DC5-2F4C722E427E', '4015400107774', 'DISCREET       Air Multiform Single 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A1336E2-8409-4526-B229-C07974E723C4', '7EF0FB56-FE4C-4247-9D6E-21C507EA47F1', '4015400107835', 'DISCREET       Deo Water Lily Multiform', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07359BC7-98CD-4776-B74F-2ECCBB34B727', 'DC378E98-5F81-4E52-8C4E-65F305089D93', '4015400107965', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67429750-8E89-4F5C-882F-BCA428B6C298', '9B81C151-9461-4A47-9E4B-4E4BE6767D3A', '4015400108023', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0728695-9CFE-40FE-B2A1-5AF72845987D', 'EF1CF6D5-5B07-4BCE-9017-AA2B4FA76A87', '4015400122807', 'PAMPERS  Sleep & Play Mini (3-6 )  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D6F7821-F241-4338-9E98-D688CD483833', '5612D036-25C4-4C73-A710-DC36C7757831', '4015400122838', '    /4-9/ 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D3F2122-ABE6-4DC3-8615-70A3F9B4E277', 'FB12A72A-6FF7-4B4C-9EDC-5240215488AB', '4015400124719', '    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10D2B801-0A51-48A8-A3E0-ABD31A231E7D', 'F507CDF1-009E-4C89-8FFB-0EADD1A6C706', '4015400124740', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5ACCCD4-E3EE-43A5-A9D5-589C1EFC7984', '8F9CB0E4-0D26-4FDE-9F3A-54C421DEF016', '4015400125013', 'NATURELLA Ultra     Camomile Maxi', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79583A9E-FE2E-4445-8688-6C85FB1A6935', '1E363DE9-06E2-40BA-B836-3FA65A68EEB3', '4015400125020', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FF59430-2493-4A27-9473-95463BDA9789', '81E80ED9-7AFE-43BE-A564-E857DD6D2A37', '4015400125037', 'NATURELLA Ultra     Camomile Normal Single 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('633336AA-3B1A-41A4-ADFA-2622775F89AE', 'F481C866-5E02-4E27-AD3D-29E7DA9E828C', '4015400125068', 'NATURELLA Ultra       Camomile Normal Duo 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9FD48C3-6225-4A52-8A81-926CD9B1FB2E', '1A62C540-324B-40F6-96C8-A30FF1ED3A5C', '4015400125099', 'NATURELLA Ultra     Camomile Maxi Single 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1761FB18-EEB5-4FEE-B78E-CDF07AF3AE19', 'CAADCFB0-308A-48EF-BA86-64264ACDACC2', '4015400147749', '     11-18  11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A10A2F4-4003-40D8-8974-5CC519DE9D71', '764FBDCF-E91A-4B60-804A-AE99D897FD91', '4015400165804', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AD60337-F88E-4A0D-A6F3-C2AA5F8FB0C6', '973B28BC-2B4E-452A-853A-E0C5F2466177', '4015400166658', '      8-14   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE738DE8-C817-4371-8CA3-3AA4B269D23F', '99313A88-3282-47FD-8CE0-168901619167', '4015400175575', '      9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AA01ABF-F911-4406-A708-AE1BDCE80548', 'CB79114C-7518-4B02-B32F-C6ADC95E3C94', '4015400179634', 'DISCREET       Deo Spring Breeze Multiform Single 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F979AEC-E7A2-4A05-BC2B-64ED3E1D2C48', 'FCE6A02B-0A84-4107-A3A5-B1DEDB6FAA08', '4015400198246', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F598051-D6D7-4D07-A6E7-707E98FF1CBD', '568EDB50-B289-4E85-94F1-06A24286B129', '4015400198277', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CD29014-57DB-4ACD-9642-6480088F3FB6', '5E49A146-91B2-48A3-B3C0-044A21795E92', '4015400203407', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AA19F7D-FF27-4A63-BF6B-83262958E5FC', 'B4112E3F-B5CB-4AF2-9536-A4A82B5AF1C4', '4015400219446', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08FF85E1-0A61-4BDE-964A-38240C14AF29', 'E3CDFA35-0437-402D-AEDA-A2DA29EE1EFB', '4015400219620', '     c  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('653A81D9-A2D0-4F6B-9A6F-2B74AEBB1854', '379D1A40-81DA-4F71-B360-FA77C835049B', '4015400219651', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCE71130-6F10-4B72-972B-9E36C1FF8445', '470D4ADB-E717-49C7-B3AA-B5853137A096', '4015400219712', '     16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8E60596-98D2-423D-8D88-DB6188CD0F8E', '22C4DFA0-1B02-4FD8-BF47-187353CD591C', '4015400224242', '         4 /7-14/  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8902BBDF-6072-4306-A3AA-3080C0D5B54B', '74FFF31F-57CB-4B40-8521-6F5950776AFB', '4015400236061', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1A044AE-4DA2-4D43-9167-62B27AA01549', '7BC406D8-DAD0-47F5-A29F-847E93D04E53', '4015400240310', '  // /079/   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C43B6F52-9EC8-4661-886C-52DD2A302901', '814A7BAE-D9B3-49D6-BD82-A72745EEBB95', '4015400240341', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4942CD0A-6E76-4C5C-B4EA-44C93880BE9C', 'F67597C5-6CC9-4271-ADEF-BA6C6AB088D2', '4015400240372', 'NATURELLA       Camomile Normal Trio 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E87E3F95-515F-47DD-9541-05C2FB0774E2', 'C1253959-AE51-45FA-9B1B-CB876C85D89F', '4015400259275', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B1DC77C-58EC-42B7-BC1C-51F7F409FB61', '41197644-68A7-44BD-93E9-EE03FA2806E6', '4015400259367', '    .   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7C9DFB7-37BE-41B9-AD9F-E5F1445C84A4', '85C465AE-B372-434F-B50B-7B967614FE45', '4015400259459', 'ALWAYS Classic    Maxi Single 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D9C6476-8BB9-4530-827F-737221CF1660', '54EB8E12-6A4D-40C1-B7BF-9635539B845C', '4015400264453', '    2-5 27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0292CE70-E435-45CD-A489-9DB6AC95F51D', '8A417902-EE75-4E9B-8640-5A469E0C3FBF', '4015400274698', '   3-6 32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6314645-D4D6-4C8D-91C1-66700B4A9C71', '86507212-C185-4C0F-8347-9F4880304CA0', '4015400317876', 'NATURELLA Classic      Camomile Normal S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F405B51-D191-431E-A12D-C112CB7CEC00', '285D885F-EE45-4EC0-9B66-FE2D275083CB', '4015400317906', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1B1F587-9BED-4A61-950B-50EFED66B093', '6C8F0E70-B722-4DA8-9ECA-AB4351414803', '4015400317968', 'NATURELLA Classic      Camomile Normal S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACE57E16-E1F0-480A-9B18-AE2C50508151', '1F98EC66-672F-4693-BE89-D40F20A54870', '4015400317999', 'NATURELLA Classic       Camomile Maxi Single 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BBEE75C-04E6-4E5A-873B-089A26AA20AD', 'E73D7E41-ACCF-4E67-B157-848ABA4BCE4B', '4015400318026', 'NATURELLA Classic       Camomi', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('607310B3-9852-439A-9BB9-A650615E21B3', '21C85736-ABEF-4E99-9646-60131CD1C0AF', '4015400341505', '  summer multiform /998/    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71611B78-45B3-43D4-8FA3-BD2605FE048A', '727B47C4-E4A9-4997-BE6D-A9996DF934DB', '4015400403845', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1B65BDE-F178-4373-8A83-73F0E988F56C', 'F3C7AC69-C08D-4AB1-B340-269D94734678', '4015400435846', 'NATURELLA Ultra     Camomile Night Single 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9323BDDE-F782-4B00-ACB5-4EDEFA6FAEE4', '8F5C8001-DA25-4EEA-9330-ADBF672E0A15', '4015400436058', 'NATURELLA Ultra     Camomile Night', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F551969-25C4-49A5-8738-367EA48F74E9', '4A27017B-034C-4D41-A126-2BC24E9135EC', '4015400437543', 'NATURELLA Classic      Camomile Night Si', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('455CB87C-D87F-4595-A16C-28D93F9F48C9', '87BB9D48-8BF2-47DB-8C2B-26F075C48EE6', '4015400437932', '    14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AEB502C-9822-4520-9637-4A712CD5739B', '310746CC-7CB9-498D-906E-46BF21AB02B8', '4015400439110', '  pampers   clean 64 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('521D86E8-8CBF-47C1-9C63-B3F114131AF7', '8F118677-F0A4-4F2C-8AE0-2B00A7E2E4B9', '4015400439424', '      64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE4C55E8-5FE2-411D-8907-ACAC3AEBE7DC', '3D63AECB-53F0-4F14-9E58-FD295FE75D4D', '4015400453185', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5C58E81-95C8-4AE4-AFBB-E705FEC0DB4D', '6A69161E-B4F4-4E98-8A1F-4FF8D8858FC4', '4015400453215', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAF573D0-BCF0-4CBF-9081-8C515853B734', 'ABB22278-4599-47F2-AF82-995613D67A13', '4015400453246', '     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C3CBABC-3C91-4DDD-A244-26CB7A356F10', '2D1A3702-F492-4D87-AE74-B6F101EE7E76', '4015400453307', '  platinum   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BA3EED8-93F0-4533-AE69-2BD9DF1CB186', 'F06527A4-EFDB-4ECB-B1C6-CE4775B9B80C', '4015400453338', '  platinum   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AA4247C-AE84-400A-82F3-38242D7DBF28', 'E1AD6C0B-37F5-4E2C-9C8E-DC0F824077B7', '4015400481072', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B951158C-5A73-4567-889A-CD4BDA91A4FD', '8EAB03FD-5CC3-49B8-9C00-8F2348B76883', '4015400481836', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5569D95D-11A7-424F-B012-0D0CB53AA825', 'E05DD713-FCDF-4876-988F-094B5737A13B', '4015400481867', '   tea magik   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CD64B08-377E-4DCA-BE2B-175694246CAF', 'B5515A8C-BC85-49CC-8144-6D013D72D2CE', '4015400481898', '  .. 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34C032F1-7269-4A60-AE30-B2A2F6BEE2A8', '9E0C977A-7E77-4B9A-93BD-9B3CE7D5550B', '4015400481928', '  calendula tenderness   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A70CB30A-D7CD-499D-BFC7-83FAC6C64810', 'AFC9745C-F544-49FF-A46B-DB28B8F3663D', '4015400515593', '       16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF75B9C0-1D00-4EF6-9F90-47839A9282D8', 'A51E5F4A-29DC-4FE6-8470-18DB486D8CBA', '4015400515685', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4A9163D-421B-4AAB-844B-743539665E26', 'A4CF8D96-6C5E-4419-B2D9-8CD6254B5E48', '4015400536857', '   1-2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6C02FB9-61E0-4072-825A-283E07EDBC72', '83CB97C9-12B9-4AA3-B26B-E91F0ED6FCF6', '4015400537397', '    3-6  27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09F530C0-54F3-40AC-966A-BE6CA90CA9E6', 'DA51C179-F300-4E2E-92DD-BC95BB232041', '4015400542476', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B5157E9-4BE1-46D4-8284-184DCBED3A18', 'DC378E98-5F81-4E52-8C4E-65F305089D93', '4015400542506', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19F13F82-FB1E-4E22-95F3-F66FC551563A', '9A119B75-0942-469F-B686-25DA127E66F8', '4015400552000', '     7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAD04D67-7F86-4E27-86E4-40968A5C14EA', 'F96F818B-6D71-4432-A139-801F018F9F9C', '4015400552031', '     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64E23822-2AA1-437A-8816-AF18C1352145', '4B019BEE-0F65-41E5-8ECA-176564781943', '4015400557845', '      21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37F278D8-26F6-45F2-BAB3-77A9A478CFA7', 'A18CD317-D80B-4C78-B127-70F898FED7DB', '4015400581369', 'NATURELLA Ultra      Normal Deo Single 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C8E8ED3-2C54-4601-A614-5D788C3D0CB7', '2F9607B8-7D84-4E03-8AB0-0AFAD12EF557', '4015400581581', '  calendula   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A60DAD6-526C-409A-96EB-52C3C7D037C1', '2759B3E4-C067-4B23-9442-18CD15B9F62A', '4015400612346', '        7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A0A231F-88CD-41BB-8D5A-1C681A58C960', '355352A4-CA98-40D8-89F9-D7701F022B47', '4015400612377', '        12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6F14EDA-6A3B-4297-B61F-6645D4C6C25B', 'B8C1E698-A5B5-4A99-A7AD-2EE77F1578E9', '4015400624363', '    28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48F579D0-2250-4EEC-BE1E-F1D856D4B7C6', 'AF9F36FD-7D1B-4EC3-8E02-42F0EAB92B09', '4015400636649', '       56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC21B77B-7C89-4584-BEA7-D9B1C7DE2B7E', 'F4CC0DCF-A220-475B-8EA2-C1F8431B7104', '4015400636670', '     56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D88420E-8E5C-49EC-8DEA-C80A65E0CA47', '2151D596-2068-4F1D-BAE7-5CC423946582', '4015400636779', '    12.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BA3A3B7-00EA-4BEC-B223-2C6DC5C95424', '9E038DFE-ACA9-44C1-9726-244416AFBCF3', '4015400636830', '       64 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B68D9769-13D4-409F-B95D-B4CEEA780E60', '9C3F09E9-5CFE-4D28-99F0-3F8B88C87658', '4015400647515', '   baby-dry  /- 2/ 3-6   17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90E77305-86B6-4192-B8FD-671A62A27293', '8D61537A-186E-4EB4-B61D-D98134544DDD', '4015400659785', '    . 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69B47FBA-57FA-45BC-B9A0-2273821411CE', 'C91044F7-8DEA-47B9-9F30-685F36A54776', '4015400659792', '     6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65234F46-8161-4345-A8DD-EE9BF7C72485', '25C8A270-34FB-4CFA-9227-1BAF95170207', '4015400686101', '       54', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('948C3FF6-64D8-49AF-8522-F28EDF9C0BE4', '3C7B5E21-D064-41EB-B4A0-48E7B253C916', '4015400687696', '    /- 1/ 2-5 22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61BA30EC-AC57-45BE-A727-D8DFBE28B82B', 'E742A1A8-C1A4-4C5F-8F2E-F508669021A9', '4015400687733', '    2  22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93DF1D6A-39C9-47FE-84E8-D3BEF57587DE', 'E650AA9F-B1A2-4F49-ADA8-5CB2260E18C0', '4015400687818', '     5-9 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCB0B04E-EB01-42EB-BF6D-36C78BDFB123', 'F75D0A61-B817-4F6B-97DB-F7AA7B321C24', '4015400703983', '   /- 3/ 6-11 26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1FD9C21-19C9-4F56-B91B-B8D6A85BB446', '6F11FEF2-707C-4C3B-A429-AFE79A7F7120', '4015400713647', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E9EE2CD-6A02-4F62-9D8F-2E631052BFF8', '774F7530-FCF2-4848-9032-0C68BAD0F05C', '4015400715092', 'NATURELLA     Calendula Tenderness Plus (  ) Single 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32B8EA55-73B7-4C20-B63F-211C5850E942', '5C9128D8-4695-4697-BD42-EF5D33026E8B', '4015400715160', '  calendula tenderness   58', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE9AD61D-F13F-44F2-AC4C-D48FAE76F311', '90A1A4AF-3292-404B-9752-C11C20C0E7CB', '4015400726999', '   9-14  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFE9BB3A-E246-4510-89BB-CB8F7F65D59C', '3B965F2F-044A-439C-A35A-E41DA15ED6FC', '4015400727026', '   12-18  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D5366F0-4A33-4669-BF3E-0402922CA744', '6EB4E1B4-8EAB-4EBC-9B38-A72182A08D25', '4015400815228', '     /4-9/ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50CAB003-1C96-4C66-8128-FCA9EEEA8D70', '081CE53D-5A5E-41F4-AEAF-AA572E658166', '4015400815341', '  active  8-14 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76998B4B-49A6-4AC7-9636-306C832885C5', '99712CA4-3308-4337-9493-7F64E23DF9FB', '4015400815464', '     /- 5/ 11-18   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68A2BBBC-B15D-433D-ABAF-9E61F06D5369', '1501C3F1-603D-4033-8D97-782AB83FD6B4', '4015400985143', ' head&shoulders    130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4CE6C30-1CE0-4433-A611-63BC3A2606AB', 'B98BDECD-386F-4511-9D85-FD5E724E5321', '4015400985273', ' head&shoulders /   130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6F4B6F9-3566-46B8-9A7B-B443B29CD019', '9108C386-3F25-4D49-9CF5-9F291A2B8669', '4015600001674', '   /4-9/ 22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F6E6CCC-CEEC-4AA1-A17B-3B0BEE929310', '94E8F793-9B3D-4355-9839-E811C747CDA8', '4015600003043', '   baby-dry  11-18 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1842CF8C-4FCD-412E-A820-0592A33FB12A', '89BCEAAB-4ACD-44F9-84E2-C9F5D269B7C5', '4015630006779', ' -  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B72CA00-3CC8-4BA3-8E11-476DE9376C40', '85B9C742-223F-4267-B278-855658D0F89E', '4015630018239', ' /  -  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCC000C4-32D4-4D4E-AD64-22BCB69BAEDA', '7DF803FB-917D-4D45-91B5-11599BC98E30', '4015630018277', ' -  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF815F2C-137D-45D6-8A99-22F17916288F', '99F54B6C-A9AA-4D92-B4EF-6F23AC7CF9B3', '4015630063598', ' -  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6DC2952-3123-4F33-A271-2F87C88DCE9B', 'EAF606D5-7493-431F-BC16-E3F159F8FC2C', '4015630063918', ' - active ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BA073DB-8F61-44FD-B18F-F7DEBD813767', '5C7EB111-1934-4EAD-A16C-3C9AD3C6897D', '4015630064137', '- accucheck  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1142FCF8-F409-4427-920E-24C95791B9D2', '6220DC75-8486-4D77-88E6-0597BC725A54', '4015630064236', '- accucheck  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9FCB3D3-0BA0-4C63-8AF0-9B074364E8DF', '0FD21D5C-62A0-4394-BBD0-05CD4AB6D630', '4015630064564', '- - active 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA0A7AE3-E2EE-49E4-B509-D1A859359A07', 'EAF606D5-7493-431F-BC16-E3F159F8FC2C', '4015630065073', ' - active ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6DC5190-7B24-4BBE-B165-1078BDA08848', 'C5303341-28B7-4C34-AC0F-27C433B2DBC0', '4015630065288', '- -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1580BE2A-FFE0-48C6-A41B-6E856DB4AC5E', 'BBFE167F-9C1B-4CE9-B66B-E3F2503F62D5', '4015630065370', '-    //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('796C94FA-707D-4D7A-85AF-25F90011B731', 'E6126F07-3FF9-458F-82AD-495F17466A07', '4015630067152', '- -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D222F34-1C24-4EC9-82C6-5A0F2CFD47D3', 'E6126F07-3FF9-458F-82AD-495F17466A07', '4015630981991', '- -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('327469CF-C90B-4C4C-9939-DBFA8969010E', 'CDCFF52E-AA24-4026-9C07-D6C77B1E8613', '4015630982615', '- -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1383201C-1281-4073-8933-5E30787C197D', 'E73EE621-3258-4223-9414-2CB7733473CD', '4015672103771', ' omron m1  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A96AFA96-CC95-4267-94FE-5BF5C4343CCE', '8A86C0BF-E8FC-4719-9C40-56B5F8BF8158', '4015672104679', ' omron m2 classic', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F083DF6-C2C7-4572-84AD-D6B81D99F147', '02BA19C7-6E4A-4C04-8056-1321DFC071D4', '4015672104716', '   2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('508BD24B-B9D0-41A0-B12C-DB97DF121CE1', '2C24F82C-34BD-472C-BB4D-6934135F8046', '4015672104730', '  S1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B92276B8-F168-453B-8C3F-F98FD548B2D3', '8E5BAE25-947A-47CF-B0CA-E74D3E0849D1', '4015672104839', '       OMRON R2 (HEM-6113-RU)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A907C48B-C702-4B32-8DF3-56F75B2A4910', '2AB7372D-E353-49C6-85F1-D34A97FC9B5F', '4015672104860', ' omron r 1 .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D7E7259-DDB3-4100-80B9-11AB20D18586', '55139C3B-0A08-4BCA-8506-AF7FE614D3DF', '4015672104884', ' omron eco temp basic', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B85599BA-667C-4967-AE67-445FE9DC29EB', '99EAA097-3778-453E-9783-2D151F896B62', '4015672104907', ' omron eco temp smart', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BEFB65A-28D8-4380-B925-CB5ECC40C5E6', 'B68F177C-C658-4B8E-894D-30EC837DD0FA', '4015672104921', '   OMRON Flex Temp Smart (MC-343F-RU)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('152E7015-B464-4865-B243-415914ADBB67', '72D82490-CD96-4807-B3F9-FFBEC8729C0E', '4015672105041', ' OMRON M2 Basic  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF16AB4D-5E59-423A-8A8F-241C012EECA6', '5C4D8051-2D3F-47AF-B5F5-186D68B790AF', '4015672105430', ' OMRON AC ADAPTER-S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DF7C5C9-DF1B-40F3-89B2-FB1D1986C3BB', '57FE9444-1004-471A-8585-E6F5A6FD1F4B', '4015672105584', ' .  CW (22-32 c)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95638E48-77CC-4AEE-97A3-82850E718E31', '33795448-5346-44B2-A93A-29A85742DB0C', '4015672105638', ' OMRON NE-C24 Kids', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6813B843-21A7-4333-910D-544A2ED4442D', '74D9F4CF-B72E-4822-AD1C-70AB7FAFD9A7', '4015672105652', '  omron ne-c24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('950DC42B-303F-4E83-8FFD-405C7991BCD0', 'E712A12B-B31B-40F5-9522-FFE36FBF67B2', '4015672106093', ' omron m2   .  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B0EC450-BDA9-442A-9377-3F8583D4D61C', 'D565F34C-7D91-41AF-85FB-1E0281ABD8FF', '4015672106963', '        OMRON CW Wide Range Cuff (HEM-RML30)  (22-42)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59AD97C9-652D-4A7D-8853-FEBA9D9959A3', '1526805C-93FA-435D-AB3A-11A2D492166E', '4015672107113', ' omron ne-c20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C2EC336-ED55-4308-AC1F-F9281526A98D', 'C743DC33-1640-494E-BF4D-3FC619672077', '4015672108394', ' OMRON M2 Basic   +.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AF07A3C-4297-4B5F-B166-8AF3BCABD7A6', '72D82490-CD96-4807-B3F9-FFBEC8729C0E', '4015672108462', ' OMRON M2 Basic  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBD596F9-6192-41F2-BAB0-6CCA7750E3EC', '8E3666FF-9EBA-4B01-A314-508CB794F72D', '4015672108523', '  O M2 Basic /  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FE8E048-4FB6-42B5-B95E-EBE11960DC6A', '8FBFF64D-C0E4-4FF1-A742-7EACC71A2402', '4016242001008', '   120 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B3E8456-EC98-4CBF-BB36-F2195FEAD6E5', 'D13E4E6E-DDE3-49D3-A65E-92CD7E32AE23', '4016369355237', '  hyaluron /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82FEC225-53C3-44D8-87DE-FC0173175640', '749E7D65-7420-4EB3-95D8-7A1646FBB2C4', '4016369355282', 'Eyelash booster  /    2,7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD2E01DB-ECF7-45FA-8714-FA7408E4879D', 'CFD377CE-A72B-4C2D-B1A7-4DCF183CE3B9', '4016369660362', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8277D49-EA4C-4FA8-B85D-901DBE6F26B2', 'C5A55122-1C51-4830-A4F6-B9A2795502E5', '4016369660690', '  // /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDFCD2F0-275C-48F3-8DAF-B9D92EA0B38C', '85BCC202-59BD-454F-B225-73FB53AE86F7', '4016369661130', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6395D4AA-3F26-49B8-AA18-299EB7E660ED', '616E0CE8-1207-4C11-B9A2-7250A469B501', '4016369661147', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B765D0D-823A-4EFF-9D8E-473270EC5E5C', '889278A4-7812-45F9-A276-4C7D1A4F6703', '4016369661178', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81B4ED8B-B85D-4113-BE6A-0D74D7C023FB', '43D34B80-9A16-43C8-AF40-B118D310BDF9', '4016369661222', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88220336-509B-482C-8305-5AA07AEF4AC3', 'AC9AF909-E559-4EB7-8223-724BE3493F9E', '4016369661239', '      60 /+   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58FAD0F9-5A12-4B9C-BBE9-D5ACDB8411E6', 'F03B4CDB-810B-416D-86AF-EFFA577197F6', '4016369661246', '     24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8FF018F-700E-428F-9B57-BCED82AB143A', 'D9FD93F0-9CE9-403C-85EC-F4118DCE4CA1', '4016369661307', '      100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80934F4D-4450-4294-AFE4-FBE245B4BDC0', '66919321-F5F0-431C-A819-8C4B840A5F3E', '4016369661314', '    200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD2961AE-7973-45B9-A2A6-468782D6848F', 'F60B719E-1032-4FB3-B4BC-39343A51E094', '4016369661321', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73C2E45B-B418-49A4-B86B-97E9E3C08322', 'BE12EFA4-297F-4178-A50C-9BF199A8459D', '4016369661338', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B894EDC-A42E-463B-850A-D1B6DB866099', '23CE7FB1-76CF-40F9-860B-FF6BC519D14F', '4016369661345', '    /repair 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F5F073C-DA96-4F0C-9898-4E5FC7300B54', '31B59ECF-3405-4AE4-83EC-3A181F59741C', '4016369661604', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DB24255-260E-4891-AE4F-D7421E82E7BD', 'AA6A3D9F-3527-4809-B1AF-0142EF9BE4ED', '4016369661703', '         7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E63B73E1-196C-4AE7-AED3-F67E65F01F02', 'A5C45C58-8845-4445-8835-FA75C72720D2', '4016369661772', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A46C9AAF-CC60-44CC-8146-418B3B377D13', '490FC09F-B48D-4E30-AE6C-27ADE40BD4F3', '4016369661802', '   /     7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F68AFFAD-CD73-4B84-8EAF-8B36FF323882', 'DD0F2CBC-13C6-4559-AFC6-06C2BB0A30C6', '4016369661888', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB913861-D5CD-49A4-80A4-61986F5ABD07', 'DB6D48FF-2300-4CE9-8630-7FF39A3FAEE3', '4016369661963', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('533C092D-1945-4DB6-B764-F9A27BC3AE96', '3C5E74FB-5009-45B2-8D3A-A6F817716CA7', '4016369661970', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5528A8D5-4123-4037-A293-AB43C24B4246', 'A7474006-4353-4AA5-B95D-7603D182486F', '4016369662236', '   multi-effekt 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAC6D220-50BB-4B25-8D99-10BB415270A8', '6CD5D047-4784-4A33-A4CD-2463CE407341', '4016369662311', '     / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02ED1B6B-4209-45E7-8286-C2BD4B4667B4', '65366A1E-56BC-406A-B9D0-4BCDD04B9499', '4016369662366', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF8EB95A-231C-48C3-9B0E-8542353F75DB', 'F1D6DBB4-0965-415D-BB40-96300B9B23FD', '4016369662533', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01D1CFEE-5792-46AF-9064-962113EC6C10', '1A2858A5-646A-4B06-84AD-F0AEC8489082', '4016369663417', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('519B7FDF-08D8-48C6-91BD-71F0EE926AAD', '527C927C-C952-4644-A465-1BB1BAFEEDF6', '4016369664155', '   / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('443FE8D4-0660-429C-9F8A-71207A66299E', '1E92E548-7041-4727-8EF1-0D17344D0CCB', '4016369664162', '   / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('700299B6-3C15-452C-80DF-850DBFB09772', 'B620ED3B-6971-48AB-A587-92C0BA1E47C2', '4016369664179', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8695BC1F-8F62-4689-B309-1C57425F857C', '99812B43-BA9A-486B-BAB3-B19E8A7324DE', '4016369664230', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F416C7CF-BE9B-4B8D-A0B5-DFBC824AAD59', 'BD7ABCCA-D343-41C1-B798-2521C00052BD', '4016369664766', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49A55DF8-024B-41FF-9996-3F9FE929D121', 'B8995F42-3037-4C3D-9DF0-E46F18998905', '4016369664865', '    q10   / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F09A15CC-20CA-470D-9511-DD385F22C8B1', 'B9803350-A64B-4CAB-807D-8B76CD1FAEF9', '4016369665022', '  /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39FBB3E6-5663-4942-98A9-7690E96886C6', '074142AA-7846-4089-9128-0B73EA42123E', '4016369665046', '  / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BC2E0D7-B2F1-457B-8641-D95635BE25C4', 'AD5B8BFA-4B75-4185-A901-64FF329FAEDC', '4016369665572', ' . / . 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C387A2DB-F329-4D24-A109-61C85D7A02BA', '0D87D2B8-6BCE-4900-87B4-2CFFF618DB27', '4016369665763', '  /    - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C0562B7-3E61-481E-A539-961142045A0C', 'C0747E95-1D9E-4E82-ACA3-BCD7649F8805', '4016369666159', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D74D5630-BEBE-4374-97FC-E9676059267F', 'C9F9C9ED-870A-4CD9-AB79-1243979278C8', '4016369666289', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B68690F6-B2F4-4244-AC55-502A76557F5F', '97ABBACC-D11A-4429-A3E1-7AFC723C70B5', '4016369666562', '  / 2 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('170626A2-DEDF-4263-A31C-E0D826833FD0', 'C1B3EFDB-EAEF-4145-AF73-688786129F8C', '4016369666579', ' /  - s d2,4  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D05BBDE-071A-4375-B3B3-E9CBD2CCAD55', '4B2E1349-F50D-424F-8F04-EA3456BC6A58', '4016369666586', '  .m  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE7CBBE8-9DD1-45F7-8EF7-C0C7727C5E52', '7A189D42-50D6-4D25-89A6-968ADC2BB4CF', '4016369666593', '   / L 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8767CA33-5F61-4685-B80D-96FBB4F28306', 'BF1C44F0-7BCE-4DBB-8961-77C49712CAC1', '4016369666647', '     4- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('328A8BAB-4666-4904-8010-359ADE158316', 'D616BA8E-9019-48A0-B546-CBB4C549E83A', '4016369666654', '    4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B277453D-71C0-4769-B1F9-34278A169508', '6F02B0CF-1DC8-4704-A4A7-D996FBBDF636', '4016369666661', '      4 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CA6E327-370D-4E09-9EDE-363A8E12054D', '1FC850A3-1A52-4986-9C29-FDF195CDC3C7', '4016369666678', '    4-8/+/  4+// 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A64F1E4D-9F5E-47FB-8DAF-45F69F54BC48', 'A0D9A5E4-0AA8-41DF-9C16-FA1BD898B2A7', '4016369666722', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A6F8EC6-26AC-4ABC-82CE-4E446BC721D2', '86BB584D-AD37-4445-A931-015B084E4B2C', '4016369666807', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4634C302-22E5-49EC-834B-86A99CB48A4A', 'DCF47C22-5411-49FD-93EB-E8CEC123BFCC', '4016369666814', '   300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C6793A0-18D4-41CF-B40B-33E24E81F253', '66EA3CA5-7B48-481B-9DDC-8208010086DA', '4016369666845', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93E78143-3962-42D5-B907-77D21FE1D065', 'C0326C1E-7158-4C30-A2A3-49CE59347D12', '4016369669242', ' /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F38DCD66-A54B-4997-B6A4-3D8EECFF4A6E', 'B09364FC-36C4-4B4D-A628-042947F868BC', '4016369669259', '   /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4310ED78-43DB-4BDA-8002-A13806022925', 'B29E13D4-C43F-4A80-A0F4-C278DC5CB733', '4016369669273', '      24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1812961A-481F-4579-9AA8-D9B5EA0ADA9F', 'DBF087D0-5DF0-467D-A488-82E1A7529A5F', '4016369669280', '      2,5 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CD986F7-C75A-498D-B492-22C16D5FE602', '9C8357BD-0D32-4AAD-B27B-D1765F1269E4', '4016369669327', '     /   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25BB3A22-0E43-41C7-8444-C1933E47FCA5', '94AA576A-33A5-4442-9829-C580E1680697', '4016369669334', '  /   1+1  48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('007D38B2-61AC-496D-9C5B-9B97D36A0C92', '6AA1179A-56F7-4918-B7AF-F2DD461C90FA', '4016369669358', '      24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D71C9996-62C8-458C-AF91-4A6B23912991', '2976E131-A0C1-4047-BD27-C146A1861166', '4016369669723', '     200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('212A8CD9-68FB-4A0E-8BF8-56F31F5F333F', '2EA86557-939E-442A-818C-D42273E716D3', '4016369669884', '   /. +  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40B65E99-6C00-4F2E-936F-7BEBA01CC5BA', 'C38E4B31-BDF9-4AE0-ACA4-503E6F5A50CB', '4019338199030', ' 0,05% 6  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B1FD9E2-D2E7-4713-A4F3-09A819C721CA', '622B4F95-F560-4001-9BCD-3C739385EBBB', '4019338600192', ' 140/ 10  p', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE1E698D-4DAF-49B6-A207-BA01793F20AE', '9606FA0D-1A03-4746-955F-BE358EF1CF75', '4019338600208', ' 600 600/ 24  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3EF2C74-C9A6-41F8-AD87-A0646E5861AB', '107B625B-944B-491B-97AE-F71E47BCA26C', '4019338600215', '  0,6 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E8D332B-5B4A-41EA-AEEC-D4498EBB43E3', '88AF82FA-4505-4B8F-805A-4A2B45F36417', '4019338600543', '  600  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57BA2423-3FEB-4AB0-B7A2-394F4B65A4E2', '2CE689A5-5D81-44CF-86DF-04D196A13433', '4019338601533', ' 2  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D357AEC-FE86-44AB-A70A-04A8BB47C890', 'D99BB2C9-0B0B-4006-974C-BD2A85E96E97', '4019338601557', '  /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C80BE283-BCCD-4922-A4B2-204E95862DDF', 'C15D8286-DB60-4DDF-8FF3-B1F3E188CEFB', '4019338602561', ' 0,2  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AC42E26-A7A7-4115-B788-7968DC92B838', '6E01BF2D-6552-4C48-9E1F-2B4E7B12C1A1', '4019338602585', ' 1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52BCEAD5-4922-4101-84DF-FF783419A632', 'BF4D7ACB-EFE4-4C8C-ACC2-09C5241AB828', '4019338604350', '    413  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCA8DE1F-EA2D-481C-8C85-F42E0DBFF09C', 'B1C2148E-0FA0-464B-B970-C1774581DBBC', '4019338605012', ' 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1A846E9-4DAC-4457-8CC7-428A752BC94E', '6BD0A9AD-13B5-45AC-AAE0-F7E742BFA25F', '4019338605197', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62175C4E-4716-4C7B-9163-2BFAB84258B8', '874DD0CC-8412-4B0B-8F91-7F1624DBC9D6', '4019338605265', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BA21EF5-9939-4F14-8245-559329DC7871', 'A6C08AC4-605B-4776-A418-6B13B10C9B3D', '4019338605272', ' 250  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28E47ACD-7854-4D24-A866-ADAB4012CB11', '408D18A3-09F0-4BA0-A9F0-4B9B925794E3', '4019338605302', ' 2  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F624EAF-A179-4F7D-B68E-0995300CD022', '63DD1C97-367B-45DA-B673-C5CD8637699D', '4019338607368', ' 70  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83B51C64-AFD5-49B5-9641-E70B2A14F31F', 'D639B28C-DC81-491A-AF9C-45B50C679A4E', '4019338607375', ' 140  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('855D1873-F0C9-4F14-9453-2DDD9FBB7095', 'E0DB59E4-A4BF-42CD-8BEC-B3401D3C4244', '4019338608143', ' 0,75  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC32FD1C-81DC-4C3E-B8B4-C22709BEFC81', '6AEEC6E2-A6EF-4189-AD0B-92D80B63C6DF', '4019444003351', ' spark plugs   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3013008A-A83C-458F-90FF-27D29C84CD6C', '77D8A077-A6DC-4D36-A5D2-B4E754610517', '4019444003689', ' moldex pocketpak 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('064E3457-5C1D-48B3-A74B-50560E883777', '91522F9D-DB8C-4DCC-A55C-9981FDB9A38D', '4019444006659', ' spark plugs   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('149DF78B-9139-4736-A785-963D94B4FD1A', '20E37A8B-3692-425C-B59F-A9195A235752', '4022536645544', ' 200  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D795A59-CB3F-4C95-BA73-BABB9ECD4022', 'A955A4E8-C2F8-41C0-B88A-91390863BAAC', '4022536645773', ' 100  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D0C47C2-278B-449F-B0B9-958F39608BC3', 'FAD12F88-A710-4259-B40E-41A795BE6BE1', '4022536645902', ' 0,01  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2AF61E2-8EAF-4271-8E1F-C7D60E9CC8C3', 'E6C7499F-FC56-43D9-AEB4-B4ED59793B59', '4022536645919', ' 10  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED13FF2A-2B57-4D7D-BA6D-D6EE9A92F8B0', '1E3B4275-0797-4A83-97FC-032B9C02D0BC', '4022536645940', ' 0,005 //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7141CF08-3549-44D2-B914-9391B17F1E59', '3D33795E-B4B9-40F9-8094-CA85D85B378F', '4022536645971', ' 0,5 10 /   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38DAE36F-344D-4AD9-96B9-1EF5335F9C59', '95AFB976-47F5-4582-8DF8-ED3F107B544E', '4022536733562', ' 0,01 //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('469B9123-7562-44C7-A344-9EF053065ED1', '8A9DA2A2-7D96-44FA-A715-1599B6E61A39', '4022536876818', ' 25  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42888446-E37C-415D-9E4D-0008CD5548F2', '8251C51F-2E3D-41E5-9796-C1931AAB0FB5', '4022536876825', ' 50  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8231D6DB-011E-4399-B677-8063F9FDCB85', '59D1DCA0-3D60-4E10-883E-85B789F71AB7', '4022536876832', ' 75  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D17E0378-ADC6-4B45-866E-A2322A5D755D', 'FF32CA38-399C-40E6-A267-53A1C52BE4AE', '4022536876849', ' 100  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B19CC124-D9BC-4DA4-8FAE-F855E50EAF43', 'E3CDA5C6-D0E8-4488-8F29-26A9D01C01ED', '4022536876856', ' 125  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8C84E5E-BCC3-4595-BE89-57F2133C9136', '56276315-3607-45E4-9C81-44D48B1CACEE', '4022536876863', ' 150  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95F2F52D-7511-41C2-A872-4A8B11B0C836', '57D9CE43-815A-4AB7-A0D1-B220801F9720', '4022551309711', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB8C35EF-A851-4B04-ADB7-785292BFF945', '8E14D106-DB30-49D5-A50F-ADEE847BE835', '4025612664514', '  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55F7C3F1-F0F8-4E36-AB73-585814EFC48E', '9AAD14AC-1A99-4F91-BF79-F690FA911B6C', '4026600682541', '  // .    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8CE5F58-1CB6-4323-BF85-B9E82C6751E6', 'FDAFCF0B-E2BD-4C1D-A9F9-5AF440BA1BBE', '4027269042653', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A85CC4D9-0FFB-4C89-9A29-2C916913912E', '1E6146FB-DA99-42A1-9234-16D2E2284123', '4027269052683', ' 3  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('285C487F-C5AF-4CC5-B9B1-EA2164652E28', '6AD850AC-EC77-4694-B752-91DAC052E414', '4027269055707', ' 3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F58CB669-2BD2-47EA-A60A-30AC510AFEEA', '3F86DB5F-6007-404D-A697-3C72B8ED9296', '4027269231781', '   2 / ++/ 30+ 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AC93A38-3461-4C18-812F-42598B660052', '69778BFB-9BDA-42EF-BB23-32378CF033D1', '4027269231798', '  1 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95896553-3DA3-4FFB-8902-6A49EB155C88', 'B527AE68-04FE-447F-B730-F40EAC90B25F', '4027269242312', ' 0,01% 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B15BE26B-7D2D-4BD4-8891-06FB936AD741', '90B9406B-28FE-46AA-B1F6-4EAFC87BE81F', '4027269242329', '  11,25/10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('745127BA-8E84-407C-85EA-9FF006923FDC', 'E9D60315-5CC1-4D43-ADDC-17D8B5D12741', '4027269242336', '  22,5/  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD82DC6A-CD9C-4B66-83E1-C0D8DD5A30A9', 'E235510C-8172-4F98-AC30-5C915E35388B', '4027269284671', ' 88  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC46264C-12CE-438F-ABF2-C38D40BD64DB', '7356535F-C57D-421A-9D6C-23DCA591FED6', '4027269284688', ' 112  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69E2EE3A-C293-44C4-9FDC-6682AF6FA3DE', 'B27DE4A9-9F29-4779-8A3A-E40B1D4E3596', '4027269284695', ' 137  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('116C7C7F-DB2B-457F-8C4E-899B09C585C6', '576C8EFB-8A21-485C-978F-0030F3EAC6D1', '4027269303167', '  0,005+0,005  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AF85F24-DB49-4F01-8766-CABF0D67824E', 'C8922578-41DA-4D90-B1BD-5808C4BF294B', '4027269303174', '  10+5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC1C4A2B-E863-419A-8122-EC43671ED0A0', '98908B7B-1E1B-4C9F-9BB6-B4BF6624CAE8', '4027269303181', '  5+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0131EDE5-CA9C-4BBD-9B4C-FE05A0C622F8', '35C84616-9485-4245-8775-2EDC887D47D6', '4027269303198', '  10+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A51650F0-97CA-4E73-8814-4B7BACFAE419', '7CBF2866-6579-4576-A7A6-3F14FF206F2D', '4027269847661', ' 2,5+6,25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6C664C2-A6F2-4D23-964B-469AA0E760E3', '72F3DF74-E028-4ECF-AEC0-F3F78F4A8132', '4027269847678', ' 5+6,25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A009FC7D-F3B4-4507-BC60-C1296D32377C', 'E7F58F61-CC33-4DA9-88C7-4A019DCBD14F', '4027269982652', ' 3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42F1E073-90E6-43D0-8E3A-D67459003350', 'CEA1FC93-7BD2-4BC9-8838-02D54315445F', '4028305000064', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4120B68-B927-4638-BDA8-303E57064B68', '511A483B-B1CA-451B-938B-6D1092BA1986', '4028305000095', ' 15  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('261079C1-66D9-4212-A403-7A292AE7FCFD', '78BC7F10-AF25-46F7-A626-0FB22FCC1419', '4028305000125', ' 30  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41208F4A-668B-4E56-B7E5-C285C9C55093', 'B10D87C6-3FA1-47EE-95FE-8F99DE288FA9', '4028352000093', '  5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3D11127-F093-4FFC-8619-53977E776F77', 'E4993F91-88E1-40E3-8C28-F8EF9FA8682E', '4028352000109', '  5% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63B2724A-983D-472C-A9E5-99DC5200635C', 'F0BA9BB3-8D1C-453E-A593-01531D9FF897', '4028685009602', '  2,5/2,5 - / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C408414D-0316-4508-8879-300832CD2053', 'D011AE89-4DC9-4758-8046-5A4B3B06B89A', '4028685013944', ' 120/5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30104811-F0C9-4D89-A108-7B0C8C9E8E62', '5CDEDC4A-A577-4356-806F-2146F09E5B67', '4029125000029', '  300  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C28E506E-ECF8-46D1-8C83-18773E914BA4', '08CA71AE-C66E-4FBE-BCC1-294845B8D87E', '4029125000036', ' 0,12  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3036941B-2194-461F-B5B0-86DB6650C4B5', 'D07DC15C-FFE5-4A98-8270-040AD2C32407', '4029125060993', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C4E25B1-0493-4519-9E3C-A665408172DC', 'B59CDD74-EBA3-41D6-A78C-7714304EC3B2', '4029438000129', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29F33613-268A-4C94-B292-C81F9D1C169B', 'ABE4EE34-5678-48AC-96B3-9387F888D359', '4029438000310', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72F92960-0C8B-413D-A048-610FD271D6BD', 'ABE4EE34-5678-48AC-96B3-9387F888D359', '4029438005117', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EF5081E-838D-46FE-9BFB-729CB2314194', 'ABE4EE34-5678-48AC-96B3-9387F888D359', '4029438020172', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3E32D3D-7124-4F74-99A5-B6BAE2FA332E', 'ED3640C7-5B32-4642-948A-5F0A91FD1FE6', '4029668000081', '-  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACC5854C-C137-4C00-9D65-8C151DA2BC64', '199578D0-FB94-4A78-A10D-E1D5F62028C1', '4029668000982', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1535B7EB-3C85-4CEB-9D63-6C79F1ECCFA3', 'AFC9135B-F0C0-4615-A302-9E32B3D43CF8', '4029668000999', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('814300A5-68FE-4C72-845E-AA1A2CACB895', 'E57508AF-CC64-4598-B738-C1502547CC61', '4029668001057', ' 2  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CF8A912-A412-466E-857D-223037E98BCA', '9A492031-022B-44B9-9B40-ECED9CB2D9D2', '4029668001071', '  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C78328A1-BBC8-4241-AA60-96CD17B467B7', '5005BEBE-CCE7-4061-8CFB-2DC530BF5AEF', '4029668001101', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A5FCAC0-B535-466A-92F1-AF3B24283939', '4D36544F-6485-4689-9A51-BB548CD16EE0', '4029668001316', '  213', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCCBB7EF-7314-492C-9E8D-84BFC2BE0160', 'A33A71EC-3C94-45C5-9725-29D985E8364F', '4029668001323', '   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2A6C36F-837F-4E34-A839-05E7B79FD038', '5CA96E78-A7F7-4A3B-8E69-A8906BD0364E', '4029668001354', '  213', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('380ECDF8-A90A-40F2-A0F3-78AF2559939A', '6852A504-8295-4A32-BE08-A798CE00727E', '4029668001361', '  21*3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AF15C22-BCD7-448A-A9A4-FADDD8707CA7', '2CB81647-D388-47C5-8F16-4B8E78CE7562', '4029668001439', ' 50  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A707A959-514D-4998-AF7E-36E9783E3092', 'DB4E0E35-97A8-4C11-AC2A-A1FDE827A769', '4029668001446', '   / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4307CF7E-653E-4662-86FA-77E2A7C0CA61', '3FD92A8D-20E7-4511-9C52-4A1606E86AE1', '4029668001460', ' 2  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E8B5358-722F-4748-904B-4D9847A8C56F', 'A7E16ACD-4D25-4083-9436-F37D36E9D1BD', '4029668001507', '  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71C4A09B-C4FC-486E-89E5-5153593898BF', 'F588D89F-E25E-4B39-87F5-3CDD6BD1DFB6', '4029668001514', ' 2  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D20D555-00FD-4FC2-8C3D-F34F1658D3C7', '490EEAC4-F710-4DAD-BE13-83068D407993', '4029668001545', '   / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E580870-D944-429B-9DA4-5A53E018A33C', 'DB4E0E35-97A8-4C11-AC2A-A1FDE827A769', '4029668001668', '   / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDF4E62C-0142-4A6D-92DE-B8FBC4221C33', '016B56BE-FB07-49DA-AF94-1982DA00383A', '4029668001712', '   / 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('830149DA-9FE5-48AA-885F-25B0B8938FDE', 'F718EA01-8573-4D3C-82E3-E8B1B07883E8', '4029668001835', ' /. . 283 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93324B92-4BF4-4AD6-B76D-2F638F855147', '26E64836-7C67-4C5B-98F6-736AF528B4BD', '4029668001842', '-35  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('092E90F1-4C52-470A-AC34-09C6B1B3D523', '8529BB84-491E-4E09-9B63-EBDA0BAD9710', '4029668001941', '  25+0,5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED804010-2ACE-434E-A724-7F248B4112CF', '5BFE9AB0-1EC6-48B6-B4E1-4171D0C76C45', '4029668001989', ' -  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9B378D4-38F5-4EEF-9FCD-635D4CD3B041', '407D4779-CDDA-4EC3-8860-D0D8027A9B25', '4029799116200', ' 100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('291ABC41-0D3E-40FF-AFA2-83921E1898B0', 'D1358A1C-82C0-42AB-A4EA-0EDB8EEDC798', '4029799117047', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8198BFCF-3C59-48F8-A479-E4863BF16312', '9B5C3C59-66D6-4D11-9031-D8106856CD0E', '4029799119706', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31555E62-C080-4EE2-89E0-0B777845451A', 'B346FD3F-1766-4818-A8A0-3F0EC030FC5B', '4029799125578', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E21299C-DEA5-4E14-9FCD-DFB0544626A3', 'CFA14454-0E4C-4212-B53E-312A86C0AE8E', '4029799127565', '   /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21AA8F5A-675C-428D-A4D9-53750DF35A39', 'A465BC1D-232B-44B8-8790-E6E9B61343DC', '4029799129934', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE457BAF-CB57-4D30-A775-390554B31FDE', 'DCA62918-2450-46F4-8146-7E0761367943', '4029799131753', '   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8C0D267-F840-4B19-9A8C-D3D672DB4B40', '618E0307-8978-4E90-BEDE-4CCF3EEB4630', '4029799131814', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EF8DF92-F212-4FF5-BDAB-7B8E308AA2EC', 'FF519380-61B5-4427-BE83-8BA3385680AE', '4029799131838', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0CB72E3-1556-48FD-9713-AF049B3124A9', '141BF3BD-F61D-4426-9F68-C28B12C06384', '4029799134716', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('021FBA49-C0A0-4CD7-9084-328075DCEA1D', 'D71FAA79-81ED-4BFC-A6D3-35E1D2F64F28', '4029799138875', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95B06168-5086-4413-8AFB-AD94C7F05EA3', 'DA51E249-DBC1-4C1B-88B4-15D2986CC4D8', '4029799139735', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54F73F3B-1A56-4623-81B3-7DC5640FB90D', '62F6996D-0C52-4E17-B893-E639EE99205F', '4029799139742', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('779F5E47-E54F-4C20-85F4-2EAACFAEC058', 'C3B23554-DA37-49D8-A4F7-A200E06CEE5B', '4029835000074', ' 0,25% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7B11A42-C5C3-436D-822A-7B9E81A50A0D', '328630FE-0280-458A-881A-02BBCFF09726', '4029835000098', ' 0,5% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F03FC3C5-28E9-4839-8EAA-25EC5DD4C0D0', '1C77D12E-E1DB-4E23-92BB-DCA11F94AAF5', '4029835000159', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBB80001-250C-47AA-B0E7-61923C9B9E9C', 'CEAC48CA-EA84-4684-A790-ADAAFFD24771', '4029835000180', '   .  0,5 -  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6731616-32F0-49DD-942F-52DA00AB667C', '3AC569C0-960B-4BE6-8DF7-9243D9F7C21C', '4029916000108', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81599CBB-0D8C-4FCA-A102-3D5B9F7558F4', 'F756BC00-BAAE-4EE7-9EA3-941F0D8B7BC9', '4029916001167', ' 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('204E6DBE-850F-467E-BAC9-97E426AC5D47', 'A65B1BD5-C90E-49CE-99B8-4AE4BC38DAC0', '4029916001211', ' 80  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC44C571-E848-41AC-8733-49626853FE82', '51CE89E3-BFE9-4D96-8AAC-1482343EBD5E', '4029916001228', ' 120  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64E9AFDC-3F7E-4B2B-A83F-B92922ECC3CF', '470BC10D-220E-4479-A370-8A38C928666E', '4029917000237', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95361C5D-A178-4032-BC39-4B5783CD215D', '24B1BF90-E28A-4946-8A76-3F5BFB331BD3', '4029917000244', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D2EE1CE-1A87-46A1-A6C2-A1C207093FEB', '1A3ABA9F-C288-4A23-9D7D-BC3563F91D95', '4029917001920', ' /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B20DA31C-997B-48EC-8B2A-123F7E7E5D4D', '5D6A79A0-8DEB-4276-843E-52234C1F251A', '4030031891458', ' 8 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA72B4AF-36E4-49D4-BD9C-738F0B652B2B', '46E6E400-7722-4B8E-A68E-6FD184DCE806', '4030031893308', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34D735C6-8B57-4152-BBFF-97E47E541E95', '7A9F2AB2-406F-4C82-BE27-D5C5E84965C4', '4030031894268', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA832552-A798-4AEF-A542-B1966FAC173C', 'DB0E9CC1-535B-4A4D-A6A9-E1497DE69E05', '4030031895852', ' 7,5/ 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F69447A-D398-4C68-BFF1-9BAC6AFA444A', '7C75AB69-D39F-4AAF-A19B-A21B0DBB5B86', '4030041001021', '-   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22D488EA-527E-47D1-931E-184AE347916E', '7E6B5EAC-2FB5-41D2-ADA5-F81D5E33D9E0', '4030041001120', ' 70  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89CF0DF3-2D7E-496B-BCCB-4FF6E72F83A6', '63DD1C97-367B-45DA-B673-C5CD8637699D', '4030041001137', ' 70  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61FAB366-E076-4C1B-8BBC-D6186FD2E62E', 'D639B28C-DC81-491A-AF9C-45B50C679A4E', '4030041001144', ' 140  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04027E1A-F6A5-4D06-AA7D-85DE9F7746DE', 'BE38F585-CC68-4311-AA6A-6C59E190F457', '4030041001151', ' 140  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('853BF3CF-C56E-4FCC-984F-71EF76DE880A', '62E45EBD-69D3-443C-8727-D7F904F34651', '4030096111508', '- 0,1% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADAF7E95-B446-490B-A31F-A287556DD174', '420F5F7F-F225-4472-A83A-67B497F05FD8', '4030096111515', '- // 0,05% 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3900DFEB-60F7-4019-B021-07E1BD4EAF04', 'DFF3C25A-81B7-4BBA-9C65-7250D45453D6', '4030096112130', ' 35  / 5%', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('854AD4FE-14D5-4E50-B7C3-6CB00CDD1BE7', 'E701C687-1973-492D-881D-728B8B507E30', '4030096112536', '  75/2 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BBAEBDD-A12B-4FF2-92E5-4369447238C3', '144FB332-298D-4BF8-94C2-9CB01F28E82D', '4030096112789', '- 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25DD26A6-33E7-4FA6-8B71-B6B20FC211E9', 'C10469F1-1A17-461C-B2D0-7CF5AA0FC885', '4030096112796', '- 20  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24624FF9-2C70-4364-91A5-FA04B7E32C1C', 'AAE79EEE-90D9-48F4-B693-3916CAF7CC5F', '4030096113991', ' - 1,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77FA8E30-DE96-4DC9-B0BD-BDE660BE41C5', '1620F44E-6B93-4273-9288-3CB3DDBF3F6C', '4030096117104', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D270322D-8704-45E8-8EC4-541CE830EBEF', '2ECD3E98-1AB5-41E5-99E7-1092BC39E9D0', '4030096117111', '-  1% 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75909A7F-0730-4885-A650-AC3F7A2F615F', '1CFF8253-B458-4870-A2E5-1700A4A742E6', '4030096117418', '  35  / 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C417776-8315-43EC-8732-997AA4E1717B', 'B59E6867-C44A-4FDD-B14D-5161D5737FFE', '4030096117470', '- 0,3  //  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F1DD09D-75AD-418A-AB32-1292A0C170B0', 'A4BB15B5-82D1-41F1-86FC-F632A2F8E991', '4030096117487', '   /. . 500  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E1BDAD6-33AB-4BD7-AADA-EF32561C912B', 'F5E87E51-838E-4AD8-9743-46E174EB7067', '4030096117555', '   1,1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B11716E-916E-4CD1-AA7A-5F04B40A62A9', '16B4AB56-B9CD-4DB9-A57B-337357CB1134', '4030096117562', '    2,2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BC0423D-AE3D-423E-B464-65E117083033', '14B7DBA9-CD42-4080-B3D0-A8CC6FD888F7', '4030096118309', '-  1% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11065570-BF25-4A07-BA03-0029F480CAE4', '07890736-15CB-46E0-A2C2-2408546D9AE4', '4030096118415', ' 0,01 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8E310D2-7E6C-4098-97FF-3B9CAF1AD6E5', '0118D0A4-7CD6-47A4-A8D8-4B04D9350A2C', '4030096119344', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9F7290F-738D-446D-979E-A25661DE3DB9', '2BA56B86-E376-4511-8ADE-062FE67741B8', '4030096119405', ' 0,1%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C204C8D0-A2A8-4192-92F6-9B5AA589E84C', '2E6C9E8A-B426-4333-B4BC-6F24CAACE7C6', '4030096119412', ' 0,05%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7729352C-495E-4FB5-A1A6-40FF6F896AB5', '094995DA-2811-4887-BF75-77A5821C2CAD', '4030096119641', '  100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0FF4DE8-46E5-4F43-8A31-12E69EF9D0BF', 'E6E8F2EE-297C-450E-9295-A6F402E01C56', '4030096119658', '      30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A8958CC-4B1F-43A1-834B-BBBA3A923091', 'A1E009D8-324D-4F37-8F59-A19689F8EAB4', '4030096245067', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A12F8834-A2AC-4289-9375-407C9D069320', '207E4424-4E53-4766-B658-49F5D16390D7', '4030096245074', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A14D2F5-2F4B-444E-8256-6555ECE4FE98', 'FBEB9559-D152-4771-9F18-1FBBAB4E5FE6', '4030096245081', '  75  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F6D773B-DE85-4AD1-BD2F-E9E2F3B7B338', 'A263F3A3-5C67-4696-9391-8CB59F3C627B', '4030096245098', ' .  75  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EB22CE5-3879-43BA-8262-7CB6D30D3299', 'C868C7E7-1964-4A8E-8AA5-99B41B929723', '4030096245173', '  /2+1/ 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D849806-8908-4A9B-81D6-18D69654ED4F', '6B38DD87-BFD9-4757-A0C2-9939BB0692C8', '4030096254618', ' 15 2 - / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8059DE75-B3B6-4CC1-80E9-FF1E89C5DE88', 'CFD3B9C9-1E6F-4EB1-8134-7E4B6DBE3FE1', '4030096254625', ' 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DC64CB1-B97E-4732-866A-3A24CF186C1C', '2E3CD904-314C-4E4D-AA28-E89DF887C3B6', '4030096255967', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('602FDD60-A3D8-47A0-8A4D-CB9B18B7CEED', '1A9E8D11-BFDB-486D-871C-DA43AAC28BEE', '4030096288453', ' 9/100    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7262D109-541B-4C08-87AD-B8E778CC9150', 'C463CFCE-CA7C-413D-A8DE-A1FF28BD1591', '4030096304672', '  1% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E621A43-9A72-42B8-8165-FA8E04A9DB9E', '96AD9E92-6A09-4DB3-BB1C-5C0E25D97301', '4030096425360', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('631BE598-4230-4043-BE2A-37D17D6D2CBA', '3FFD5F5A-2FA5-433C-9D04-5FD38214DA2B', '4030096425384', ' 50 /2+1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77741174-BE54-403E-BD13-457DAEF75E0B', '6BB6794D-41F7-404D-8458-956F2E301FFE', '4030096501354', ' 2/  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('292874B9-0290-4366-80E5-9CAB90A773C5', 'EAABE21B-C9EB-4C05-AC33-1C4555D07091', '4030096506366', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2A81408-48C4-4D3C-B2D9-447A268DE289', 'AE5BD1C6-FBB1-4BE0-B83A-607DD4440BBC', '4030096506397', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82FFA3A0-1EBD-4D33-AD67-76B93A2BFCBB', 'A39AC0EA-7EF0-4C6C-AFB9-3A4B783C7CB6', '4030113647133', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1363845-E084-411D-B8EC-DA224B8CE3EE', 'CC3CB8FA-E01B-4A7D-BB48-263C4B5C0258', '4030142016405', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F06DF83D-CCF0-41BA-BB8F-167FE5BD761C', 'CC3CB8FA-E01B-4A7D-BB48-263C4B5C0258', '4030142118130', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42177B58-BCA1-400E-9D2A-20519806F237', '431AF71D-E335-4518-8230-68B052722707', '4030142128139', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('049D71AA-686B-4C08-99CF-30CCB9D03F02', '0932F01D-AF96-432B-AA91-85574AAF037C', '4030142140131', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBDDD759-3C63-45AC-87E6-8182C7C92D4E', '3C28D683-55A2-4EE2-9FA1-109F0AE376F0', '4030145020010', ' 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('243B1830-2C3A-4533-9E6A-D22E638E26FF', '49A83B22-FE09-4463-818A-F008BB2C7885', '4030539060677', '  0,9% 100 - /  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5D73E74-8AE7-4C4E-80E9-4B28030B1E25', '6829AB3F-98E7-4230-A393-7869FD2667A3', '4030539060691', '  0,9% 500 - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92043BBB-C369-4FA3-B877-D599C8A03D81', 'CDDED6DE-3218-4255-89EE-E2A290D54597', '4030539061490', ' 5% - / 250 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A68D51B-42F1-4EC1-B8B0-E3D2D10E65B2', '4A8AEECC-96B6-43EC-81E3-40D33CCE1EBC', '4030539061506', '  0,9% 250 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBA28C1C-064F-42FE-B13E-9C8980038E5F', 'BDEE8ECD-4AD3-4B31-A68E-609575F04495', '4030539062398', '  5% 250 / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF71775F-1851-4FAD-971C-10BA1EA4B5D4', 'A3A5D17E-AE32-41A7-93B4-4B906CB1E31C', '4030539090544', '  10% 500 - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B95D3F95-C476-4960-AF0A-61D59D280D4F', '1AA5960D-5466-41AD-B669-26E0A0C846B7', '4030539103725', '   / / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAADD9BC-324D-4AC4-B298-41307C045EDE', 'BE5B9D51-7CA8-4FDB-95D0-EB8B78277C1C', '4030539103732', '   / / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95E73D9F-1D2B-40F5-A1DF-4B1C7F22541C', '798C9313-FCE8-4A9D-BA56-EB08D9160B49', '4030539113496', '  10% 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FDDE83D-CF56-42AA-8E84-AD4B10D8ECB2', 'DA745643-173E-4CAA-915F-8C04E990F38A', '4030539129381', '   /./ 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4C9FB2B-8505-460A-9640-5DF899B47DED', 'E5F18FFE-B790-4737-B840-C864C09F1BD3', '4030539137386', '    / / 1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2DE0D1A-B7AC-4AA2-9258-469CE7F7FFAD', 'E35FE70B-81DC-45E6-AC75-D63E05574972', '4030539146401', '   0,9% 5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00852D30-E1A4-42F0-985F-607F5CC47BF1', 'F72BBDC5-C643-4332-AF3B-0E0A7ABA382F', '4030571000013', ' 0,3% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59F78CDE-DD66-409D-8897-B42658F0EC5A', '8E4E01F4-3E18-4B17-AAAC-F3FFB30A68F7', '4030571000020', ' 0,3% 3  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2992D4A8-50A3-4D63-9913-1E70FD7E4567', '9EA8833F-4D43-4ECC-A66C-EE90D9B99B64', '4030571000082', ' 5% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EC8DF06-B332-4E0B-8B1D-3CAE039C4D11', '5D961E06-5885-4F4D-8284-0FE0609577D7', '4030571000105', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E61D9457-49BB-4DEB-B6C7-FA477F182044', 'C617D7A1-C9E6-4EB1-A8AB-3C65C2123564', '4030571003083', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57403788-133F-4658-80F7-BFAA43B9CCE9', '3826F380-AD8D-416B-88F8-317DA89620E4', '4030571003410', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AE814F1-06FF-42A8-90DF-C15EC18D32DB', '511ABCD5-0D02-4E82-BA90-75F14E56B7E5', '4030674000354', '-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71E30D11-241A-405E-88D6-3932A8ACDBB1', '2049CC66-28A4-4445-BF39-98FE0CD316D7', '4030674000361', '-  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('956BB8DA-EAEE-4CA6-8C2C-BC3EF80480D2', '48753FE6-0F8C-4117-91FC-95B744265849', '4030674000491', ' 150  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('319B7D46-BD8D-4D07-A621-15D9598ADB81', 'ADC21683-4196-46C7-B5D7-98DB74D8132F', '4030674000507', ' 150 150  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85441488-60B4-4B71-9492-D1B1C57033AD', 'D390312F-BEF4-4126-BB06-5C1C1FEB81B1', '4030674001146', ' 10   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC2113B9-EE58-4D3C-93B0-79C2DE9ACA88', 'BC4B6E2C-DB73-4EBD-9533-29DF86AA245A', '4030674001177', ' /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1701869-CF18-4C15-9C02-478C3257CFC9', '8E838EDF-B630-41FE-939B-C73C7DDB4EF4', '4030674001269', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67E8DEEE-F889-4640-A2C3-C8B878F897B6', '9C9CCD9A-6215-4C1B-82F4-F2F08402709F', '4030674001283', ' 1,2% 50 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFD494DC-E044-4C44-A521-4C56D7031E1F', '5FA04857-7DBC-4240-8C4D-7BB8B72CBD1C', '4030674001290', ' 1,2% 50 - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D49C0412-B346-436C-AB43-86CDEE7050DD', 'FAE1086F-6F75-49B2-BEB0-BD68BD8C89A3', '4030674001603', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC9CD6E8-69F9-4588-AC4B-D324AD785701', 'BD563AD4-F32C-4B6E-BCD8-FCCEB4537604', '4030674002105', ' 300  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCF79C70-8A12-409B-982E-FF75D75B61F0', '00CC9657-BE8A-48FB-989C-8B18531868DD', '4030674002150', ' 400  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72D10F62-F2CB-42CC-BEDE-C8680AE6F0B7', '4E5E6501-7B8B-4B77-85C7-E24256E02641', '4030674002655', ' 1000  / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FA50732-6D19-4125-A55F-84046EF0ACC7', 'A375CDFB-602B-405A-97C4-3B34D17142F5', '4030674003188', '  100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AC259F7-1EC8-46E8-B4F7-F96A289F67BF', 'DAD492BA-E4F5-4E6A-B288-892CEDCBEEAF', '4030674003195', '  100  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E51B7831-AAA4-4FBD-8882-DA843856B4AD', '42334CA7-AE46-4BF3-8479-5BCFD4117756', '4030674004604', '     90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56086E10-7029-45FC-8BC0-28840F4046DF', 'AA76E559-C8F2-4C5E-A320-00A8F82E3873', '4030674013033', ' 600   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('130F844E-D83B-4461-8429-74CD366E71F7', '26E686A0-6821-46BA-A8DF-B8C9106FBEE6', '4030674013040', ' 600  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09B75D10-FC6B-44D2-8023-E5726DA3338F', '366BE628-264D-4E3D-997B-30A7C2BCE351', '4030674013064', ' 850  / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FE09C03-05CF-426B-AAA2-FCB6CDE2279B', '3BCEB26D-0771-49C9-A1FF-0BEAB3A6B463', '4030674014191', ' 0,01  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA07526E-8094-4C7C-8AB6-B5B36685C609', '435200C2-38B0-4696-87A0-5955E8585BD8', '4030674014481', ' 10+,   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9365AE6-55AA-4585-98DB-00C0138529B9', 'F16A66FF-ED38-4428-AFB2-9597291A65DF', '4030674014535', ' 1 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13CCE619-5735-4DF0-9697-C3BF8313A406', '3C6195D6-49C7-430E-8B68-061015BBB81F', '4030674015211', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D0716D4-F7C6-4B40-B03A-809B52C17FCA', '21DA39B4-E8F2-4CDD-AB20-F2B0FC8282C1', '4030685282558', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BE530C6-BD04-41FE-8098-ED1B028EB756', '4EB00FE4-9494-4F02-8117-FC17B15BD62B', '4030685404110', ' 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E4BB474-416D-4B89-A109-AC6641A4A55A', '6C2F77B7-624A-4600-AEFB-8DD9C9EC6E73', '4030685404189', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A628FC9-F8D0-43B2-9A4E-D63C63256C8D', '5B228CAC-40DD-44E0-8144-5A1E754674CA', '4030685404226', ' 3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8CEAB30-7F22-4B8F-ADA1-35013B67047C', '244530BC-E855-4780-8AAD-739D6CD36003', '4030685404295', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB1D526C-3047-4F3B-8FB9-8F182DD9512F', '6234EFC6-1F5A-4DF2-8DCE-B59C2548D837', '4030685452012', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E0038EB-15A9-47D3-AB05-3280134F8604', '4EB00FE4-9494-4F02-8117-FC17B15BD62B', '4030685551623', ' 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0F7DBBA-607C-43AE-AC64-030147B3B6A5', '4EA4D375-4E29-48F6-8190-FB003FAEBC30', '4030685560137', '  / 8% 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82DD1ABA-8C25-4447-97A5-AE7B13B9C01A', 'C65BF5B5-A951-482E-A990-EE5E5418C1D7', '4030729001558', '  20  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EA8C3E0-D2B6-4B0A-B72B-5530EAC583C0', '5F8F92DF-A4CD-4420-9BB0-A4FED67A959D', '4030729002937', ' 1,25  /300/ 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF65F1BF-B304-45C2-9D5C-6562CBD9E4E9', '07825E2A-AB26-4D9C-B727-38F053F7462F', '4030729002951', '  20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFD85C1B-0F02-4603-B175-B18BF0E9A3A9', 'AA71A3CE-319A-48EE-B899-DAAED8502B9C', '4030729003019', '  0,02  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9BC7B2F-5C6D-4E13-89CD-13BC62876A15', '1B2E1778-9D15-4899-A316-2534C0C2902B', '4030729003026', '  40  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DAF6AB6-044E-4135-8CA7-5C83E9592D07', '529BE461-8CC7-4662-99A7-067BA5B14351', '4030729003033', '  40  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04F249C1-D766-47AC-A010-53CBE7D23A01', 'AEDE7CE7-0E22-43E6-8D20-57657938647E', '4030729003347', '  50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32B258BB-9603-45B1-9743-20379DD32CE6', '7D2A0E9A-AC26-4E32-9992-AF8B38200ADB', '4030729003354', '   50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68597F84-E9B5-4F7F-8075-18A2265D6ECF', 'D1FC27C3-D900-46E4-AB41-3068BEE70F7C', '4030729003361', ' 20  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('507AABAA-D771-489C-AAF6-C438AAF2FE9B', 'CFA33FE8-F664-46AC-947E-ED67CA8B5F0F', '4030729003866', ' 0,1% 10 - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70B59E1F-C93D-4703-88B7-377B6934530D', 'A7D7B3D0-C451-49B3-AD34-8D7232C694B7', '4030810080462', '- one touch select 100 +   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F18095D-72D3-4B9C-B875-9BC2920CCC6A', '22D365A2-3AB1-4961-B4E3-2A5C3707EE1C', '4030841001825', ' one touch select simple', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8547D85-9C60-4F27-A6EC-AFB7B8CD52FD', '53DE6DD6-CA70-483C-9D9A-5DF0C553B578', '4030841003805', ' one touch delica 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F34559D-37F1-4067-B681-64E6172C7E61', '1C1C18D0-8816-4104-83C1-9690CE6EEDC3', '4030841005335', ' one touch select ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E70F533-B509-42D0-9C53-5969D9141BB0', '8BAB8EF4-364F-4F2E-821F-FDFC17A9B70D', '4030841006233', '- one touch verio 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE41B931-46DE-42C1-8587-2F660D574629', 'E713A789-E47E-444D-B5A2-6AA56F2BA1F1', '4030841006318', '- one touch select 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF61BD3C-DB5A-48B3-9609-E2E36368BE64', '4F013952-D6EC-46B8-9A0F-6BB43A2BD0E9', '4030841006325', '- one touch select 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('769A717F-6F38-40B0-81AE-A33197ADDDD2', 'C17CFE54-C664-44D9-BD02-F58442A34EB1', '4030841006332', '- one touch select 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4E5D104-09DF-4ECE-9920-1C60E3BFE3FC', '5CA3FB58-B2A8-4BC5-B32D-00B2915E6EE4', '4030841006349', '- one touch  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BD2B200-CF99-48FC-9649-8FCFDAF24772', 'FCC8D31E-F1E3-4439-88C6-28F59A2F5574', '4030841006356', '- one touch  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('217AFB67-D398-42FE-87A6-02E6B705021E', '8BAB8EF4-364F-4F2E-821F-FDFC17A9B70D', '4030841007483', '- one touch verio 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45B63FC4-5287-4C83-A3E1-470D714EADF8', 'FCC8D31E-F1E3-4439-88C6-28F59A2F5574', '4030841208286', '- one touch  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('209F487F-D497-4317-9A08-98FF29194549', '29A19C72-13CB-4A2B-A095-7CB873CEE63A', '4030841208811', ' one touch   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5A0B1AA-C6F0-43A5-B398-A4957FB9F16A', 'FA5F1EEB-EA64-42E9-B79A-A88F95F9C250', '4030841208828', '  one touch   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F6C7497-6340-40ED-8AC5-6DC44D8E5347', '4AF17C98-5418-4A8D-940D-B6537A378971', '4030841215864', ' one touch select', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F8E44A3-B727-49AC-9357-02057ADB13D0', '5CA3FB58-B2A8-4BC5-B32D-00B2915E6EE4', '4030842220003', '- one touch  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5032EDB-6210-4ED8-8DC4-541465F090D8', 'D0BA1EE3-975B-40FD-B282-A01BF9616AB0', '4030855000050', ' 100  /-  100   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47C3C5B2-04F3-4CC6-94BB-44AB4D2166B2', 'BFB4F519-26F4-48CD-BC42-D59154EA2A1D', '4030855000104', ' 0,1   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B51BBAEB-CF0C-45C8-A3A3-EFC5F17F91A6', '91B71805-8DC2-449D-A4FE-C097C386C591', '4030855000180', ' 7,5 50 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12B94979-D914-44A2-B379-E2CC17D26464', '2CDD2487-2EE2-4FA4-864E-763F6926A3C6', '4030855000197', ' 3/  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('036BECA7-40D6-47C0-B196-5A800D15C48F', '9514D5EC-0FB2-4AC4-A7B9-BC2BB54892DA', '4030855000517', ' 10 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3EA4151-FA53-4984-BB51-841CA4E2D584', 'D923643D-B86B-4C2A-BC35-51BA3F60ED4A', '4030855000524', ' 2% 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D9434E8-3663-44E6-AFA1-F476ACA352FE', '02475B86-F8F3-43AD-A2B9-71A9D6FA48F5', '4030855001378', ' 160  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4ED51EC8-CF51-4A28-B482-36D83DB00C54', 'A010B5C5-DFEE-4F79-84F6-537153F14F74', '4030855002252', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1275A534-E296-4009-89F4-F6016B0EA9C7', 'D3D79191-BC7C-486E-A70C-6EFA232480B7', '4030855002320', ' //  5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28528200-6342-4CF4-880A-57BC602C2BE7', 'F0F8D09F-5EF6-42C8-A5E7-5052AC0C8B15', '4030855013746', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF95AE92-7596-42E6-8D4D-48F60DC2CD39', 'F5C526FC-EA53-4CF1-BFD8-8CBFF159FBFA', '4030855038053', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABBBE4F0-02A2-4C45-A0A9-7C48C1958A26', 'A6156C4D-5D07-4A7C-B1C5-0E4367DF1068', '4030855171972', '  10/ 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6882C899-7153-4A50-8CBB-170663FAD15F', '41E84953-A7AF-4765-A93D-9A51B01AFE7D', '4030855372171', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('348DF37F-F686-4551-B753-726FECE0F18A', '8DC4C45F-6FFB-4FCF-8B30-39C3DB7FC85E', '4030855372188', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('310C0B15-27D0-4774-9357-C03C90D24780', '3FC46EAF-517D-4730-8FEF-8A7038867F92', '4030855399802', '  6 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95FC81B0-3F99-4714-B9FE-8FB0F0C9C1DD', 'A7A099A7-BF01-47D3-B56A-8ED512ABFC9B', '4030855433988', ' 5%   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1C1987B-9F9E-4C76-AA6F-6C101DC79243', '33C72439-3E8E-40D1-B7B8-7E32F23BB7DA', '4030855444748', ' 1%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B01392CE-AD23-45A7-A456-A80D43373AD5', '0D648F12-3B7A-4DF5-BA30-E7E4F0839DF9', '4030855444830', ' 2.5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('001A2A21-6F6E-45BA-B5BC-52C154499368', '4D407D4C-CA6A-47B3-8450-94CE7DF86BA3', '4030855462377', ' 5%  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48418313-DCF2-4890-9943-FC4B76239466', '679F63AE-30C4-43FF-8BC3-56FA9CB87E58', '4030855464074', ' 5%  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FDCFA7F-5281-4423-8F25-4A7C5D8A95B8', 'F7B33774-9759-4851-B09E-43B78732F1AE', '4030855478194', ' 150  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0246B84C-AC6F-4BDA-96DC-392B68CCA771', 'DBA9B18A-9654-488C-94EE-0F212971264A', '4030855489527', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B77999E-AAF7-44F4-B7A4-2F5E19944687', 'D7F123F5-7CB6-40E7-BF54-79A601BE7E6C', '4030855489633', ' 10 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76C1AD85-3912-4F98-B53E-D37EEC3EE616', '999697E8-EDC1-4560-AC6A-F1EF13632396', '4030855492435', ' 5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87254256-CC88-437D-943A-BEE487E2D1D5', 'E40855A2-BA7C-4EC7-943B-97983D668EB5', '4030855492497', '  0,6   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAD93B3D-5179-4D3D-A434-12080B9C6A00', '6E5AA3FC-C7A6-45B1-B138-AC8F0EA28426', '4030855493876', '  25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95F43EBC-7A15-492A-B74F-440D696D8C31', '90B270AC-E403-458F-AD0B-3D13B3958A11', '4030855493883', ' 25  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81D7DE6A-1118-40F1-B259-EA99EF4C94EC', '5B8E846C-1BA0-4302-B5A6-F8631E0C20CB', '4030855496600', ' 2,5  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B46152AE-F4A4-402F-BBD4-DF9C4EB01913', 'D5A9A670-3D9D-4D49-9A1E-818DFDA53C45', '4030855496938', '  1% 50', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE4F0765-527A-47BF-87A7-B1DFE309CCFF', 'F4CBEFF1-D43D-4A21-B1AC-49AEBB73E450', '4030855496945', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B962F5D-3BA1-4DD8-9338-0C56E039A176', '460647B6-CF52-4AE8-8222-11D74FE40C66', '4030855496952', '   5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9FC7A9C-6009-498C-A200-7CAF0FEF72DE', '6F94FF12-C5B5-4718-88C1-E94A817A854E', '4030855497034', ' 5 //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('247650B9-52DD-475D-9435-7C553DE7644B', '0DD7D258-A52D-4357-B58C-0FB93AA2ACD8', '4030855497041', ' 10  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDF10069-833B-420A-894D-3508C62C8E4C', '011E8AB7-50DF-4917-8F58-DE599ED1E94A', '4030855501250', '   2,5% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BBE19C6-F08A-48AA-AFF7-0575984412FA', 'FF3564DF-EA05-49A9-93CF-2F16B4EFA19F', '4030855502479', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0007838F-8380-4647-858D-0C50889F616C', 'BEB622B4-8766-4126-8C90-C53E9504E402', '4030855504855', ' 0,02   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F221324-F72F-4432-B695-0D986C031567', '4F1EFD04-4CA2-45AA-95EF-861521BD45EC', '4030855505814', ' 30  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93A15C4E-4EAD-47C5-B1BA-8B1200214946', '3D7B72F3-833B-4865-AFC0-61184E64189F', '4030855506415', ' 5%  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00A77090-9667-4667-A072-D05B627E57CE', '6E44B664-3D37-4701-9429-C11B0636B982', '4030855507252', ' 20/  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03790C51-D0E9-450D-8C32-6F281F1D3A1A', '6F6D1754-2B54-4901-9005-DCC35D1D1655', '4030855507535', ' 0,4  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D4DA9F0-C648-4645-A6B3-45EC984CCC40', '351C4936-EE94-4E93-80F4-552C4206AAF3', '4030855509515', ' 120  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56E45F46-5502-40AA-A28E-C30E0B50B426', '1E617A58-5F54-422A-AF69-4CC80982C45E', '4030855509546', ' 60  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD775300-05D0-4372-AD4A-15BD44208980', 'ECF8E910-D641-4C98-8047-FC75261CF245', '4030855509553', ' 90  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B91282A0-D732-4D77-992C-DD2AAEC548B6', 'FC40F097-A038-40CA-83E9-10BF14A3BD84', '4030855509560', '  / 90 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C41033A-B975-4F96-AA15-78C33CF0528F', 'B730EE47-BAF8-4B00-8A91-BB57865F6E0E', '4030855511198', ' 100   100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8148077-F301-47F2-B1EF-BA15326FF6DB', 'B0DF178B-B9D2-4203-819F-2C32B1F08DCC', '4030855511204', ' 200  /-  200  3  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3350CDCA-BDC3-4E44-A554-072EBDF544B6', 'F6D7B146-1A5B-4FD8-A5DC-34EA6E9467E9', '4030855512539', ' 60 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDAFFE1D-CC41-4E0F-A28E-8A1A67B43B25', '30E21C39-755E-4146-9FCE-97AB786B2988', '4031083002533', '  20  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('142B9573-2BB8-4A40-BB0C-AAF688CC345E', 'A11B98DB-A3FB-4189-95B1-64A382872080', '4031083002670', ' // 20  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF98588D-1ED3-4241-81EB-83A3DFDF2739', '5F2DFAD6-3F43-4225-8843-81461798EED4', '4031083002687', ' // 40  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B4068BD-11E6-42F4-AFD7-D866D375D33E', 'DE681056-FE24-4655-A517-EFD2DCDEFA20', '4031083002762', ' 40  /.-  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDBF5CAF-2AD8-4594-B514-EF35A48651CD', '17C185FD-9698-4635-B257-B18E860377C9', '4031083002779', ' 5/ 5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4855D9B2-4B91-4080-A2E6-37ADFC5C2707', '68DA0CD9-74C8-4D9C-98A8-F364E0161808', '4031083003271', ' 80/  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44820D64-8FC6-451A-8D28-47EB3615760E', '535D3873-FA28-4139-8C10-BC6ED5DB5701', '4031083003288', ' 160 60 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF30F157-4FA4-414B-949A-715FF693A683', 'EA622E99-A980-4B89-B4C1-0DBD9832D2E0', '4031083004377', ' 0,05 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86929D0F-05BA-48BE-ADB4-219A42ADF967', 'D403B920-510C-4306-B727-3835EC072E6E', '4031083004384', ' 0,1 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D71F8D34-2CA6-4CB6-899F-6E10CA8EF9AC', '42AC4AD7-2F67-4755-81EC-0FEBA0B7F019', '4031083004728', ' 200  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08AA8B0D-0BF2-4AC4-A3C1-68E83BC405C8', '6FE7F2BF-08A8-48C6-A5B3-F6374D0CB267', '4031083005794', ' 150+30,39  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DCB32FA-06F1-4AC9-A6D3-F1EF79BA5B6A', '1A2C863C-E333-492E-8EBB-04440EA4A41A', '4031083005800', ' 150  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46C1C69F-DDC8-4179-8629-79190CBC490F', 'DE02D1AC-D6E9-46BD-9192-EEA2864E3A26', '4031626710024', '- 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EACB335A-A24B-4AC7-BE35-D55224177173', '6CFBFB49-D716-4D55-9C6C-2086DF541E4C', '4031626710086', '-  2,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54417805-17E8-4231-B7F0-B727C98593D0', 'D6009E5C-BFA0-4E19-A380-9F08F2CB9751', '4031626710109', '  1% 2,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BB097D0-E0E6-4E7A-A895-611B0F767F54', 'CEB4BF76-77C0-4A46-BB3B-1E99F4FC0023', '4031626710369', '-  10  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF0598DD-C592-4F0D-89B9-14DE25A9E9D7', '2BB44EED-FAF3-4D78-8C9C-BE733218058C', '4031626710635', '-   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C370A967-5646-487F-8393-C6D3D31A0DA4', '6C777EA2-F439-4A63-9FE9-2DC6E466EE53', '4031626710642', '-   - 10  .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F35FCAF5-7373-4AA7-BF6B-B2F1231F3FE1', '25355725-B812-4EB6-B840-D17C12A00D0C', '4031626710673', '-  10  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7738F972-8995-4DC7-8811-73984A7DDB6B', '32F87626-2CDE-4492-9A89-34C83977970B', '4031626710789', '-  10  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEB63944-3A92-4EBC-9CC2-3D904A2F4529', '7EE4404A-D3D2-49C2-AEF5-2AEDC6F674DD', '4031626710802', '-  /  10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('242FD8B9-78B8-4169-9329-B7B36D63A055', 'BA155FE8-3A6A-4289-B4BF-66A85F065565', '4031678050505', '  100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6524084A-50FC-45C0-806C-A9147FAF8146', '216C942E-E4D8-4710-8E18-9AECB15A91CB', '4031678057030', '   /.-/ 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B5F5072-3EE6-4EEF-A8E4-F6358357DDD4', '5EA7CFC1-E515-4798-B1C0-F68B059E39DD', '4031976500382', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('675A32F1-0450-48B4-AC2B-60469C52BF42', 'DFDFC4C1-E4DA-4886-B46A-8120E3821819', '4032046000443', '   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2402406D-396C-4D40-B578-35A0B9D29FB9', 'ED48C923-56B7-494C-8CA6-EF968DF63179', '4032046650068', '  240  0,24  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A0E40A5-D053-4823-ABC0-86BB03995701', '25ADCAB0-7246-4ED6-89E0-B62B8DB300B9', '4032129010918', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28AE7AD1-A715-4A7B-8988-615BAB44BBB2', '72EBAD59-048A-4EDF-BFE8-F73FDED11EAE', '4032129023611', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74C8F913-94CC-4986-B1FF-60F41587FD84', '70398C92-1836-45B4-AF48-C33BE86761BD', '4032651214105', ' 1 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DE62C2E-209D-4629-9FD7-D6318D4DD2C4', '3510E1C5-ED6B-4296-9C9E-3C0DA425A76D', '4032651214174', ' 250 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF3CA537-69C8-423A-9D31-086B25C40D49', '273496C9-9C26-464C-84C1-292DBA89642F', '4032651214235', ' 50 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('465E0439-5ACA-4CDE-85C7-1DCEC0D18EBB', '0846F5F0-B277-483A-9CE2-BCC9CB79315B', '4032717000017', ' 250  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18A7F0A2-EDC3-43E6-B857-D520B8973637', '3A9E1375-9D9A-483A-8087-B85D97AFEA48', '4032717000055', ' 500  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14195E96-37A3-4C20-A4AA-F75FBDC2E39E', 'A4B9D818-92D3-40D1-84B7-F3331E47AFE8', '4032717000086', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3D28CB7-1BA9-4A54-8BFE-081D9D8B7569', '63FDB329-7151-4506-973F-9E15D7C36A08', '4032717000116', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A7B2766-522B-47DA-9278-4ABD04FDA439', 'A720A47F-6A97-42BD-BBEC-4EBEDAB11B0A', '4032717000123', ' 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('124A706E-F57A-4902-A85E-2DD687A71C52', '8D390107-0592-4FA7-9E5C-3868D2F327C6', '4032717000161', ' 4/60    / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCEAAEC1-9E14-4758-9619-E3A371D832B4', '2A23FC9E-7C8B-45B3-ABA9-1483CF1A008C', '4032717000178', '   500 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F958720A-4A89-4D4B-8189-06754C778904', 'AFB1E460-6CB8-49EC-B192-BEBAC39AB55C', '4032717000208', '  / /.  1000 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13838ED7-0BFC-474E-92A7-998C942F2880', '4C0D75D4-1070-4A64-AEB4-2463F17D253E', '4032717001007', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02643245-833B-4F2F-AA4C-3032463A2EF4', '63DF46B7-62DB-43D4-B19A-816B433F31A0', '4032717001038', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF34403A-7852-4255-869D-134E6BDF5E74', 'C732FC77-4043-4819-A337-B0CE77E6F4DD', '4032717001045', ' 250  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3027C11-59D3-44FE-A414-E0A7AEC88603', '8EE459C8-9467-465D-BB5F-ED4DE75CCE11', '4032717001069', ' 250/5 250  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C1A74A7-C646-499D-988F-896F991F59DC', 'AE7EAC93-B4F6-4A49-9926-AB26F909AF59', '4032717005043', '   5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB645518-0CDB-4D52-A3B1-8CE6AC0EC697', 'F366B651-0366-4F1E-8541-D6921101C24A', '4032717013000', ' nm  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('386399B5-B055-45EE-A857-B75CECDA909F', 'FEBCA608-9CA5-462D-81BC-ADC77442DE89', '4032731503884', '    s 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E24D984A-75A8-4A80-BF3D-B6C23CA92B34', 'D3DC7915-0450-4D91-B809-824CD7A0C548', '4032855840162', '  2- . -24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('172E9A0E-083C-4CC7-B15A-FD3BAA2CCED3', '93CF4B1B-643E-4148-83FB-E9A5D39303F5', '4032855840186', '-   2-  /30/ 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DDFE008-FEBA-43CB-82DB-C71F14C68647', '091D6504-820C-4F04-A1A2-F35FD5F2738A', '4033033417015', ' /.   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('635CBBE5-1F3E-49D4-A893-42ABD7AA7C32', 'E09422D2-8FE7-445E-97D9-6609D407A12B', '4033033418036', ' /  eviplan 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F4243D9-FC97-4487-B599-E45B6D597873', '39C32BFD-80C8-48EF-A870-BC8E43A59354', '4034541002304', ' /+ // 20+25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62A270D0-EE8E-4D2E-8C9E-00FF84DAE253', '67212584-A1BD-476F-9646-1ED6D94478D6', '4034541002311', ' 20+12,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F9FEEEF-33C2-4DBD-A526-024CE73F16D0', '26D6B0A5-E7B4-4117-9557-B3559D81863A', '4034541003578', ' 5+10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16FA0049-50B8-4776-BD27-87C2A06EBB7E', '6479029F-D6AE-4AD0-8086-9D1DC94DE67A', '4034541007606', ' 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5C87466-F9D6-4F7E-9C3F-E29BFDCAE3FC', 'A38AF78F-46D5-4966-85D7-F09795AF80BA', '4034541007613', ' 100 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DB401E6-FAB6-40B6-95C2-B4EA67B2EC10', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4036534001080', ' /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E5B69D8-CB1A-4AAC-815F-5B0D5A22936A', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4036534001806', ' /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F4988BF-1BFD-4E89-A210-596C9D9634ED', 'B72637A9-EF30-44C4-8F1F-E8868D02AC5D', '4036534016084', ' /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('756267A1-EE2D-481A-967E-1ECBA0C29D23', '4821D217-F1D5-46D5-A3FC-64D4F71C8EBF', '4036534110034', '  18g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52F86978-CF7E-4D29-9C40-2827CD97A772', 'FC33DE11-75C6-4EE4-A8BB-DA12CDACD85E', '4036534113035', '  21g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE503C97-2CAC-4189-9404-90C1EE392E55', '41C30A34-B967-4B01-845D-CC428F64F219', '4036534114032', '- 22g ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('701C99AC-2B22-4C2C-B247-94D50AB7DA29', 'CB839246-65EA-4523-81BE-9D874DC64E50', '4036534115039', '  23g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20A9F7D3-A09B-4870-9C44-7959BB775059', '9C164E6F-F396-4556-BD3D-0D8D785C5ACF', '4036534200810', ' 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0B6BD92-AC01-46AF-8F2D-02D78B8D5D2C', '113DB975-CBFA-4A5B-B06D-DF7C682657C3', '4036534202807', ' 5 3-  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('507D0994-657E-4A73-BB5D-8D1FEBB3BA28', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4036534202814', ' 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('547971D2-5D34-4E05-A71A-FAE21E73506D', 'F439EEDC-8A21-46A7-BE57-1C2C99D040F0', '4036534203804', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28727499-FF6E-4563-BF31-510F89FAC24B', '908C1804-82F6-47BF-9D39-7568D1E04BF9', '4036534221020', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92BDC082-622C-4B8D-B582-8A45C8D86AE6', '6BBBA13B-EE6B-421F-8CEF-7DFA95FEFBB3', '4036534221075', ' 2 3   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B514AC4-8888-4155-B698-10A89BEA816F', 'FF6C3FE0-0526-48FF-AD5A-D0CD56E0DDA9', '4036534222072', ' 5 3 .  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A1C49AE-5350-46C9-B10F-BD9E91D8754A', '37A47F8C-2891-4700-B8C1-92C9C277181F', '4036534223024', ' 10 3  ///// 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E14BA1A2-DFEF-48D0-BB52-9195DEAC8AB0', '7EC8A61B-0AD6-42B5-8C62-B0939446F439', '4036534225028', ' 2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7456EC81-B709-449A-ACB0-64F17A1E8114', '730AC20D-6942-4C6A-92ED-E0032937397B', '4036534226025', ' 3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B3EC4CF-EBD5-46EF-AAC9-A3468C4545C5', 'E9E5D0E4-B8BD-4CB3-882A-957317E7F2DF', '4036534250181', ' 1  3-  u-100 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D8E20B7-F74A-4EB4-83C5-CD23151D7BD7', '365A3FBB-B463-4FFB-9A82-685791EFD1F9', '4036534251188', ' 1  3 40  10//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4A1F5DB-6175-44A2-BDE3-F7DFCD31EA83', 'A882E81B-0CD0-498F-B96A-80887266CDA7', '4036534264188', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7219DA9-C4DD-48FA-A2C0-63C5C375593C', '19FB2B96-6C9E-4F7F-9BD1-B0BCFDFA7A99', '4036534412206', ' . .   .7  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('098BFB31-012E-4876-AA4B-F295712AD2A2', '86EBC6AF-25CA-423C-821F-A8DE1D929B0B', '4036534413203', ' . .   .7,5  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5876D36-B5D2-4E4E-9374-BD96457CE5F9', 'B829DF3A-F612-49CD-B5AC-9416028B45A3', '4036534414200', '    8  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB3DBEC5-BF4B-48C9-A599-2BD373B1613C', '5953A21C-188A-424B-BB9B-9793E31A6FA7', '4036534421208', '  / . s 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEB67C91-1E41-4E9F-B089-3DB99A7FF6E7', 'C024DEDF-43E9-41A8-BE79-45E398DC9950', '4036534422205', '  / . m 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E43AA26D-E024-42BC-B17E-8C5F33FF54F2', 'BFA4555E-B78C-44CB-9696-D9AFF7D4C290', '4036534423202', '     L 50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0D03748-1604-420C-8E78-79EB5A3F8D1D', '87674C6F-25CB-4209-85FF-D419A0AA0710', '4036534432242', '  . - 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4BD9714-21A5-46E9-9DC9-1014C5522E4B', 'EDE7D014-ACE6-41D6-978A-17BD15E6E2C4', '4036534433249', ' . .   .8  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17CF8C99-F7BF-4B30-9156-1DEE83A88E3B', '7B5B1629-2798-441A-83E7-0020EF0DFE17', '4036534461228', ' high risk  -  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37EA8213-FC0A-4BC9-9067-D73BC160B83B', 'ABD3E159-C2D9-4065-9F34-14EE53F8F126', '4036534461709', ' . /   25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCC07CB3-93DD-4B73-87D5-F406E38E3690', 'C481366D-CEB9-497F-987A-FC73E7E90646', '4036534472200', '  / .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE56943C-8E0A-43D8-920A-901F1C1C69BC', 'EB63A46E-3AF0-4147-9E14-6A55C50881D1', '4036534473207', ' sfm   /  l - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('478CF6FA-33B9-4443-BB30-C7F09A272374', '9EA6EB89-505E-41AF-AFC4-602C586736D3', '4036534497258', '    / m 50/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1B4104C-486E-4174-A541-21DB977067FD', '3D1AF395-1E7A-4856-8B30-55041C0AE8FF', '4036534498255', '    / l 50/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8DEB00E-F50A-4073-AE57-E251A9C8C319', 'CF749B8D-346F-4B58-A28B-BABF51A9C1C4', '4036534501054', ' 2250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54E143A5-A155-4146-BBE0-E6EA54C0414F', 'CF749B8D-346F-4B58-A28B-BABF51A9C1C4', '4036534501061', ' 2250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69CA6C4D-7C31-4877-8EFE-9AB2876254BD', '1DCA48AD-BF3F-4592-BE18-4274BAC89D99', '4036534510056', ' 1500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B46888E3-A575-4EB5-B523-54FEF69EC5E9', 'FA7CE7F9-5EE5-4149-B7D3-A5E0CB22EDEE', '4036534510063', ' 1500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98799918-762C-4F21-B69E-530550A15E90', 'AF843FB2-87AE-4D4D-AA5C-66568FF11F22', '4036534511053', ' 2500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A64ECF2-C8E7-4769-8234-28A3BA51CA7E', 'B07986DD-7E1F-4F7F-A3F3-BC6BE1A969A9', '4036534539064', ' sfm-strip  7,22,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E348A91B-E45A-465B-BC19-B32333267515', 'EE53572E-458D-4A99-AAA2-4AB2EF0C8B0C', '4036534540060', ' 1,97,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FF66DFE-E865-46E8-B7BE-D262C5FAF6E0', 'EE53572E-458D-4A99-AAA2-4AB2EF0C8B0C', '4036534542064', ' 1,97,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73AD8702-02F1-47B3-80B0-C442F019F726', '2601D101-EC00-451F-8B9A-7C4B58F850CA', '4036534547069', ' sfm-strip    3,83,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84652DAC-29F3-45EA-A572-1413C20ED3EB', 'DB12D152-CFAA-4433-81FB-51C32B82E178', '4036534549063', ' 610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DF1B300-02F0-4AB5-A4CD-267737A50C48', 'DC67C6CE-8C60-4F79-9B56-DDC71054DDE9', '4036534651223', ' / s 50/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEAFB86A-8BCD-4EFB-ADC5-E99752AFC65B', '007825B1-1EDA-4DEE-BA04-B5A11B373052', '4036534652220', '     50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8BE8AC1-C708-4704-BD77-EE770CE11017', '534F9043-ECF6-4CBB-B1F9-2F7AAE45214F', '4036534682210', '  / /s,6-7/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('064B7C9B-5B46-4469-98D0-E2552D2A8BBE', '75442248-B9D8-44EF-8E57-E2B6498841E9', '4036534683217', '  / . /,7-8/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5384389D-CDE8-4936-9EBB-94E80480059A', 'DA6AA672-7468-42BC-A4CF-60383018A349', '4036534684214', '  / . /l,8-9/ / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35BB3FE7-E690-493C-8B32-9B8681AC050C', 'F11DB8FC-99A2-47DB-9612-980905C64A72', '4039581002017', ' 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('053BDB44-6F90-4ADE-86D2-C5434AE01D4B', '7A9B0BC1-B59B-4440-9E66-5009C735CB8A', '4039581002024', ' 50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69E7CC25-3CF4-48DC-A13A-CBC149D06C00', '1DCF538E-49C2-48EC-A05A-E227C15DC20C', '4039581002031', ' 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A19CA93E-0EAB-492D-BD12-A5D570065FED', '5FB15075-6672-4385-9B46-58896A837BAA', '4041932726718', '  10% 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1E48ED0-1D88-4254-8BC2-8FEF7805CBD9', '963AC60A-A32F-4E62-A9C1-C6F7C848626B', '4043027240024', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1C96876-818C-40BE-B3F4-A46F6B1A50AD', '7C25E18A-B78F-4662-A74C-EA394747CD5B', '4043027240031', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7376AFA8-BD25-4C52-8CB7-A5C7A882C7FC', '3F8E2CA0-E509-48EB-88F4-C4290CDE63CD', '4043027240079', ' 0,5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9890CF8-8F91-4E03-8B7A-CFCD252A8B9C', '8946480B-C234-49B3-A5C0-02990AE797E8', '4043589001750', ' 10 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC48E835-34D8-467E-B6B3-5114960A76E1', '3D410A1F-4AF4-4091-A374-5CA307E695E2', '4043589001859', '- 12,5+25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A4EF935-8ED0-4281-8104-7720C5A9299D', '77BAA13D-3230-4BBB-9BC1-882493A69D46', '4043589001873', ' 10  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('549C1348-5983-465C-99A9-4F2E4798DA40', 'A545B9DB-C10B-42BE-ACB5-EA2436597AE1', '4043589001880', ' 10  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3157A8B-F91D-4CEC-B62D-4138952B3D58', '6947A650-A8AF-4CB5-8B9F-9116FC24038D', '4043589001897', ' 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB50172B-8600-4BB3-8C6C-36935B1B60C3', '4B439971-2E3D-4DC6-9923-CE744BD6B1EB', '4043589001903', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4626C0ED-8EBD-4BBC-839E-8281F57633EE', 'AF580097-1057-4B5D-8400-4E8EC1BA41BA', '4043589001910', ' 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B5B93C0-6D88-43F7-A5EE-DBD7D432EAD9', '07AD9320-EB2C-4E67-9BA6-467938607114', '4043589001958', ' 6  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73B64D18-DFA4-43D7-9360-7CD140E55D67', '6E546F10-FA95-45E3-B3A4-DCD1529DC97F', '4043589002177', ' 300  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0437B9B3-E03C-4882-924B-AAE55BBFAAFF', '648D2AAE-4C3B-4173-B0CB-B596E00F42B3', '4043589002320', ' 60 60  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F065A664-4660-4806-83AE-72B507CDB3D2', '1AC73113-2000-4A13-AAE8-3B9B0B221D0B', '4043589002405', '  40    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8F27920-E01D-4297-838B-30A763C6A629', 'D3AA9C22-EB79-467D-992D-0F36C941033B', '4043589002528', '  400  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14CD9926-617B-4C33-BACB-7B71AF6EFC00', 'BBCEBFDD-0E93-4A46-8611-97C164FFA86F', '4043589002559', '  400  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7841C826-6E33-43D6-A290-FFA4B54FB977', 'D419797D-4CE3-4DF2-AD22-EBF001200DC7', '4046222226077', '-   3/ 5  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E7B949F-99A2-4EAB-B1A8-D6F639572097', '111E6A83-E56A-491B-B6C6-C531FA05F69F', '4046222302481', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F27B5E8-1847-4667-B64B-328FF5EDFB5A', '5DF968EA-6E3B-4151-9C78-3BB970209258', '4046222309787', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2AFCF68-6ACC-4003-9CA0-6F91F3586913', '69B7BC6E-5615-4337-B150-274C22915C64', '4046222309794', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B9859A3-4AF8-42DE-9C8F-BFBB271B909A', '5699B95E-FD7C-44D4-BE4E-307AB8E4B2BE', '4046222419608', '  20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D401876-83CC-47D2-9FE7-8580510EDE48', '2D5866DF-754D-4C53-AEE8-AB3FB0447DB2', '4046222601263', '    / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C82215DA-A24F-4F78-99A7-38DC6B396B49', '2A50C7B0-A996-4A47-ABC9-4DBA6EB0DDD5', '4046222704827', '  12*3 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DB2D0D1-1B3F-447D-A113-21EA654A8AD1', '0E7FCC5C-94A3-4AFC-A666-2456AEAE6174', '4046222754174', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9706A563-4687-4D64-B547-5021826142C5', '68A3F8B6-64B6-4878-8628-EA37A37C3938', '4046719343393', ' 3m   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4A10F3D-515A-46AC-BF0A-E7C21BDF7AAB', '3AB328CA-8EAF-426A-AE6D-C8B8B174D1F6', '4046871001582', '      - 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18511A90-F7CB-413F-8323-3AAD6F235D68', '313FD401-22BB-4BA7-8BD4-2FC05732BE53', '4046871001612', '        30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF656D8C-E885-4090-885B-68A5C00BFD72', '5530D24C-BDB3-4216-87C5-513C1910F193', '4046871004422', '       . 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('558F5CC6-62A4-4006-8FE7-7EA87119CC21', '9D986264-24B4-44CB-BB81-918859987899', '4046871004521', '   bel  nursing pads  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7436E4A2-573F-415E-8D24-09293E3149EC', 'F26681A3-BFD1-4B74-9AE4-178A7E5E09C9', '4046871005566', '   6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C98ED06C-EA8F-45F6-8372-AAEF3B0BBD9D', 'A112C99A-14C7-42DD-B1D4-6B4D44ED2C2E', '4046963423896', ' - / 350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8621F697-EF46-49F4-B569-4EED31F84571', '0A0B2B0E-B6BD-4282-86B5-35899A354ABA', '4046963423933', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C879DAB8-151E-4FBF-A731-E970A268A70D', 'DA98DBDC-40DC-4705-B7A4-9D2EE945BE2C', '4046963890155', ' 2  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6763F5D-8859-48E6-83BA-9429A05A63FB', '3F6F5807-94D4-423C-BF91-D707F02DFB05', '4046963890438', ' 20  b.braun', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E762AAF4-5AAE-46E6-9F41-DCD002B208DC', 'EB3A20D8-7F0C-498F-B8D3-A6806550387F', '4046964105425', ' 3 3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F568D3E9-55CE-414A-B789-8E161E9702BD', '78038AE5-231C-4D7B-8753-802287C1AE5C', '4046964105432', ' 3 3    23g  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D679F41C-4BB2-4472-908C-032AB7C01F26', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4046964115219', ' 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5602F49E-92EB-47A4-B9CE-9B4496238600', 'A8A48C18-B350-4AB7-945A-E26AB2C100D3', '4046964381591', ' 1  3    30g  100/ u-100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('819093FD-6BDC-46DF-B0BD-2DA11D6512B0', '73FC0413-6CF5-4A27-A99B-812B977B411D', '4046964466120', ' 1  3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1637DFEF-EF73-48DF-9CE5-DE9F491EF635', '4BDEFD49-C99E-474F-9BDF-0BCE922AC9EB', '4047400392041', '   / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B20CC3E7-F857-4AE8-A737-59E7B46169BD', '5A396721-41E2-4F44-BEA2-3C01292F4C60', '4047400393048', '   f / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82091019-4AD5-405A-80D1-A314A5B56099', 'E34BD482-0E08-4B4F-A227-CDF616A9EB88', '4048132002468', '    370', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53333CD8-22EF-40E7-9AE5-924C8F8D76C4', '88A5C077-B4FB-48C3-9A95-A732369EE58D', '4048132002482', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77DE7691-B7A7-4228-8A54-9249C7857EFB', '912D5441-8FAC-40A9-AFB6-B3068AA33F93', '4049500043328', '   foliodress mask comfort loop  . /50/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B406DBB6-BD54-4DB7-84F9-61B22A1EF7AB', 'F15F1808-CAEC-4FD7-A39A-A649E494B6C5', '4049500047623', '     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B21AE3F5-26B9-4ECB-8316-701BD3E74AAE', 'C8DD0C03-38FB-4554-986A-3531304E98C3', '4049500079402', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05222C2D-22EC-4075-A3E5-B7340A87E25E', 'FF712DBB-1A9E-4A84-BDA9-BB2C3DBE1036', '4049500079884', '  m /7-8/ - 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52F35C20-C41B-4EC6-9C17-7A5D52F72377', '05C40D1C-9316-4B7A-A9C1-BB576CB3AA1D', '4049500112864', '  menalind  prof. 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7D66270-B18C-4B59-B29E-0CB9C0236A2A', '7F107302-3F4B-425D-A448-6464978806A8', '4049500112888', 'Hartmann menalind    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E6B5E28-9519-4AA0-99CB-0DE18659646C', '264A0C53-D30B-4A0D-A34B-04BF07A78C53', '4049500112949', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A58AB9BF-CC49-43E2-829F-AB157657CBAC', '2A5791E7-0DB4-4A5D-8B15-9C4979FE7CE6', '4049500112956', '  -   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23C02F22-6579-41B8-A4BC-5C484BB8E5DC', '542D81EC-1DCC-4123-B69D-417EE34AE0F8', '4049500112970', ' c   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD311957-0205-4192-8BA8-1FA59E72D1FD', '3DAD9004-F8E2-4E9D-A0C0-9C61B0A2C667', '4049500141543', '  ria slip soft&safe .20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD74B603-6551-4232-B0BA-D75653539A31', 'DAF6D8EA-9A7B-4AC4-84BE-269CD4B143F7', '4049500207126', '  7,510 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C572AE52-F7CE-4C0F-A6B1-5EDEA80AC99C', 'E34487F3-44F7-4780-B3FD-B40E38DEB2EF', '4049500216418', '       7,510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9557EC7A-4A48-4122-A538-BC774BA2C27C', '2A7D3724-142A-40CC-88B5-3DB214B0A742', '4049500216425', '   1020', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77E28574-7D4A-4A75-9DCC-787471D87986', '59D4546F-F914-4CD4-A612-8AAE4C2D34FB', '4049500217668', '  e 7,2  5  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70CB31AB-3438-4F62-92E8-5892F3B9A214', '9E13387C-EF45-4A4B-9E98-A5D3BF896EF4', '4049500217675', ' E  -   106 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E37132E3-107F-4C84-BF98-0B8E72B088C6', '68FFA792-7A51-402C-891A-CDBC69D6B3F9', '4049500217682', ' -  156   15  16   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB24A065-0E1C-4C78-9406-6E8E66571472', '68E5EFC9-061A-4045-A0D6-7C78936102E6', '4049500217699', ' -   810  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A977CE3-0BC7-4F90-B96F-3A4B6C62E441', 'F260827B-83D8-44FB-9F3B-FCB9FC3C31AD', '4049500217705', '  e ...158 /874/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE68A844-D9B6-4114-8060-CBB42007FF1E', '539A4F25-A9FE-4E9E-ACAC-F5B4EA1DF51F', '4049500217712', '  e ...208  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D16EBD4D-B6A7-406E-BAD8-2F91340A476A', '6BDD5D02-AE28-4729-8823-78029D288956', '4049500217729', ' E  -   2010 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A30EA1D5-3C16-4E1A-9D32-8269C890DB1E', 'B3163FCB-85B0-4275-9138-F55D00B084BE', '4049500217736', ' cosmopor  e 2510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A1E6977-AFE4-4BD1-8807-37385A4EEF35', '09F92654-5C9E-49F4-9B68-8DF75C7C627D', '4049500217743', ' cosmopor  e3510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED58FC0F-1358-47C6-A442-1B3097814155', '54036402-AA9D-49D8-A3B1-7D7AE626C001', '4049500245203', '   56  idealfleuniver', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BC21970-302B-4E92-8307-4C30F32D93C5', '4922B0D7-AA51-4084-8CF4-1F74611EC402', '4049500247528', '      22-32 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7772A23B-0E79-4E53-A555-177DBBFDF4AB', '644D45A3-EC9D-4771-8976-C5F60EC51E76', '4049500247733', ' omnipor  /. 1,255/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4637153A-DB71-4A10-81D9-0526285117CE', 'E4085390-0737-4FFB-B681-FA8BF850A2C6', '4049500247740', '-  / /  2,55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ECE7ECB-765F-436A-BEF5-0B79507B69C4', '4EB12761-E583-4183-9D3A-0B2016145F3A', '4049500247757', ' omnipor  /. 55/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BF2621B-AA70-4B5E-A791-7E069955343D', 'CD2875ED-35EB-4E18-B21C-9958EE7E4B00', '4049500247764', ' omnipor  /. 1,259,2/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23E96EFB-31AA-42C0-A7B3-B781C0300682', 'ECAFCCFB-B9B4-44F7-8209-D969559AA10B', '4049500247801', '   /. 1,255/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29A91116-5C31-4BA1-A5B9-2C9DF5C25943', '2CC79422-1099-420B-9540-2BBF89842046', '4049500247818', ' hartmann omnifilm 2,55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9AED173-98ED-4177-9927-BB6B03B2A867', 'B7191689-21A3-4155-9A55-C6DE2CE7862C', '4049500248259', ' samu  /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B731F768-B63E-4ACD-B814-4F789115ACB5', '6E160329-549D-4FA7-A3CF-0EDEBBE7B89B', '4049500248402', ' molimed     28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2309F93-0ED9-4473-BB3B-64DC143BE912', '97D15A35-B3AD-417A-A755-499D5B0DFBA6', '4049500248945', '   Tensoval Compact ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B681D168-CDD4-49D2-8B9F-93C5146F10A3', '99BAC35E-BD19-4DE4-BBC4-881BB6E291B5', '4049500266635', '   26 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1340D8E2-DB29-48E6-8C39-8440FE87003A', 'D06DB8DD-C023-4622-984E-A402182E9E9B', '4049500266642', '  strips 84 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81BA113A-540D-4177-AC0D-85B670B1FFA8', '2A551290-96D9-49C2-A27C-3BB02FAFD395', '4049500271349', ' atrauman    ag /.   55 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB5BFD6B-B6F8-4783-B5F2-0A712C67A7DF', '6E160329-549D-4FA7-A3CF-0EDEBBE7B89B', '4049500302258', ' molimed     28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3334FBE-F0A7-4945-B419-7F1D568844E7', '1CF9F131-7C46-4D02-829F-4090B6554390', '4049500304917', '        2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBFF67CE-B50F-4415-A6DC-096673C1011D', '2073FF7F-CE74-4845-AE44-260037145B73', '4049500305167', '      253', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23A32698-674A-4AA6-85D1-853A4D1E43F4', '46BF66F3-3120-4EDC-A95F-CA09ABE96565', '4049500340397', '     /  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCCB7658-543B-4129-AB46-0F81AA172B73', '809ED89A-8676-4189-B5F8-D6D83AB2A52F', '4049500340632', '   / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CA5AADB-2253-47CC-B521-CB0926A71FC9', '72B98895-E900-4DFB-9382-F88894E60781', '4049500341257', '   /. /m/ /783/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F779A1E1-73E4-4FE6-86CF-1293191A1AE7', '2D686F22-28CB-457A-AF36-D6BE811C9270', '4049500341264', '   /. /l/ /784/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CBB5627-3808-42F7-90CB-A66A56F588B0', '823824ED-1B0E-42CE-B21E-D25771DAB112', '4049500341271', 'Hartmann molipants comfort   l 100-160 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8D138E4-9A37-4DD2-ADAF-FE7E6787551F', 'A41F48E2-526D-4E8D-9E3E-82A4BCC73943', '4049500342094', ' molimed     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CED74BE-35D1-4BA9-976E-1F0EF9C75EBC', '611A3194-39E2-45C5-8213-D53DBA90462C', '4049500342964', '   . /    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7B4C597-63E8-4DBC-9F76-266BA6D73F63', '5E28003C-929E-4B0E-8B50-3301BCDE878B', '4049500349611', ' /. molipants  .s 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6B136B4-3618-47C8-A512-9955776E9588', 'A744AF46-25B5-470B-BD55-D4ED563384F6', '4049500349628', ' /. molipants  . 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C781C2F0-BB4C-487A-A895-02204E61A093', '5FD69E6E-C53F-46D1-A071-9CF94E8DADC8', '4049500349635', ' /. molipants  .l 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF257540-6337-4C94-87F8-62D3945EDCAF', '2A519153-9B20-4783-9EDF-4A5C3A20D9BF', '4049500472821', '    610 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14C3889F-70AA-471C-9AF2-8109602B1A25', 'FF9A5E53-CC21-4147-A4D5-1F078267DC38', '4049500472845', '   2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('787419D1-4D36-4EAC-A939-FE0AC17C1541', 'E36C832C-A2F7-46EF-A1C3-16D7C36C775B', '4049500472869', '    610 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B67DA7D4-0E23-49ED-9BC7-BA4AB7707AB1', 'EDDDF0E4-5299-4A11-8410-BFDDD11F9520', '4049500472876', 'Hartmann cosmos   / . 1972  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2D5C996-4715-4BC2-9884-9B4A63144D4F', '74735008-DF31-4D74-95BF-17FBE9B2E8CF', '4049500472883', ' hartmann   610 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82A10CEE-8B8C-41E0-A4C8-0B9E3F69548D', '7F9965F6-A117-47A5-A070-227B70801B43', '4049500472890', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B721982E-01DA-4548-8084-BA428B1D970C', '5EE7AC52-59D3-4AD6-90A9-3C5CDE8592BE', '4049500472906', '    5 - 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5251D82C-594C-4E15-B782-F9F3EF6E5012', 'B798EA62-B11F-489C-AF1D-70B0DAF45B41', '4049500472913', '  sport  . 610 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27AB7497-0403-4347-93B9-91C63D674C3E', '6BF6E9A4-8672-4323-A048-98A7CDC32F27', '4049500472920', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7835F39-8961-467D-B9A9-037D71E0B0F9', '183207C9-600D-4AFE-A577-E77269FA4344', '4049500472937', '  aqua / 10 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57FBFD08-9476-4CF1-977C-9F3F397E5B94', '5BC8819D-4DBE-4DF6-8100-EC362780F1EF', '4049500472951', '   2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('300D466F-9372-47C7-9081-D508BD46D803', '05554AB5-06A9-42D3-B973-ACB696F6BC5D', '4049500487481', ' hartmann  hydro-active   17*40 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AB6568E-4A6B-4AC2-A5D4-A48CD73F717C', '7637F2E1-8E75-4C9E-B5E1-318E37E96028', '4049500487498', '   / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7A19023-1DAD-4CEE-BB9D-BB133685C72E', '7A7363BE-696D-4FF9-B2E9-9C0D3D42E828', '4049500487511', '   hydro active /   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBFDB5E2-6C92-4A6A-B08A-B6D2C27717C6', 'A27D0445-DEB9-4DCC-8A2C-1AD2E163AA7D', '4049500520393', '   .1,255', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94D729E1-55FB-4613-A9F6-288B3B47C1B3', '5134520B-638E-4FCD-91C3-314224977982', '4049500580199', '   .1,255', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0A6E5C5-3357-44C5-9DB7-52FCE09D8E8A', 'B5331ED4-ECFB-4DE5-8529-B536BEB2F182', '4049500585590', '  9,21,25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81C97F53-5833-4B52-8E43-7E8D032579E6', 'E4D60D95-9015-43AF-A451-F2A4407FBEA9', '4049500585927', '   .   7,57,5  /3/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CAF68D8-84F9-4BC9-B81C-96FA423D717B', '4760A5BD-4EB7-4ED3-B1C6-BF9F31BDF7C8', '4049500585958', '   7,57,5  /20/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00A48AD4-C1DB-458E-ABD6-A848D5C098F4', 'A927009B-D558-407A-813D-953E11045C57', '4049500585972', '     1010  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('901CD3A5-A1E7-4939-9AAE-BE922D3264AE', '47AACF23-CE24-42AD-81E1-0411B66D0C6B', '4049500585989', '   1010 /5/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86C7303A-3B95-498D-95E1-8994C41396AD', 'D7F95AF7-70E2-481A-AE63-55D050F88346', '4049500585996', '  1010 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58DD31D8-05CF-4BEF-9FED-92D323530A40', 'CF701709-0DA1-452E-BB5F-5B1C31ED22F0', '4049500586023', '   10 x 20 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B10887C-9FEA-4E4B-BB42-AEDC320C404C', 'BEFEC979-07E8-4BA0-B1AE-A038D493D3BB', '4049500586030', '     1020 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBB71AB2-9FDF-4157-A9BE-337A0D630C88', 'EB33B0CF-2F6F-4CE2-8F2E-082B1D823CB1', '4049500586498', '   . 2,59,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('796EBCA2-11E5-4DD2-BD57-3153963C9DCC', 'EFF62CC7-66EB-4020-96AD-709BF0DF2DC9', '4049500605533', '      .m 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF7EEAA5-9053-432D-94A4-E84F821C4960', 'BC64018F-13C3-4543-B8D2-2AD1E819A7C0', '4049500605823', '      /m/ /650/ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2105A034-0906-4303-8684-4008057308F6', '9A1BCC07-B39E-4F3B-8A53-E5B9B1A17E41', '4049500608916', '       M 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E5A86F4-5111-436B-BF57-E0169D45F7DA', '4007E19F-DA7D-4EA8-9827-5E235E04EBD7', '4049500609395', '      M 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49331642-8F01-499F-90FE-D71BF3B3C7C9', 'FA7CFA1E-D82F-4062-9CFD-08A1D51351DB', '4049500618595', '  3-   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAEE00D0-083F-4BC3-9416-967B8FCE0500', '9D9CCFCE-0849-4C71-96CD-6369F64468E5', '4049500649636', ' branolind n  7,510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45C06FA8-823F-4F23-909E-C20B64D4FB29', '085EB062-8630-4B47-B79D-5F454C96B0C7', '4049500649674', '    10  20 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E00B6051-2D71-40D9-87FE-75C634EE257E', '93CDAD66-E6BF-4339-91F2-6A6BE6D1BA64', '4049500671927', '   / s 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D872580C-EBD0-4BF1-AA9A-7590ED18D5B5', '523D2980-40AF-4F78-8670-EFBFF1A586BF', '4049500673228', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2181F32-A265-46D4-8EE8-4A7AC801A970', 'B5AB31E5-ACA0-4A13-BFBF-799A1611E76E', '4049500744027', '   / . peha-soft  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08CF1F8E-1D69-41F2-9E1D-CFFB1A4A24F4', '508CBF87-6D7C-4DFD-90C3-7DD504EB4A92', '4049500744041', '   / l 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E295B7F3-F454-413B-8304-27E1176D3E2F', '9438DC7D-9802-4AD7-8EAF-37DDD94DDCF8', '4049500749923', ' -  4x6  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B49F7290-8D96-4C35-B235-14639FB71201', 'EA157DEB-2A41-4FF7-88C9-EA43623419B8', '4049500754248', '     103', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA30C93F-078E-4DD9-BEA6-123EBC8F0803', '8A8D32C2-50FD-4B6B-A41C-4ABE13B5A4F4', '4049500759960', ' tenderwet 24  1010 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28918507-B724-44AC-B5D6-59A5E431E8B1', '255BAE0A-A387-40E5-80FF-39590EFF7D08', '4049500770064', ' cosmopor  antibact. /  7,25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2B6FA49-EF5A-4C27-AC96-897B158C6CE4', 'ECE11577-230A-43C6-8D0A-359A8B3995C8', '4049500770088', '    106 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31CBC990-FAD5-488C-B3EF-A239F6661647', '27AF9B9C-CFFD-4023-82B6-FA057C3AEF95', '4049500770095', '  antibact .106 /901001/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9182A78-8A64-46C4-8852-64F3EDA40BF5', 'AA386928-9BCA-4208-9111-CA7E8D60494A', '4049500770118', ' cosmopor  antibact. /  156', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1392BD86-39E8-4657-B5BA-CED36B0BE786', 'ECC35F07-9032-4733-B891-1FDB16BA7E0D', '4049500770125', '    156 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC0A76D5-7C8E-4743-8E1D-48ADA96C08AB', '883F9409-7D76-4A72-AEB4-C206686D274B', '4049500770149', ' cosmopor  .  108 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08976C38-82B0-4617-942F-F4433D2014AD', '802BC0C2-E592-4EDA-97E7-38934B5563D4', '4049500770156', '   . 108 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56410A6C-88C6-44A8-B641-0E4E4195FE57', 'F0792428-219F-4AC8-B271-EC12C2D79872', '4049500770170', '   ./, .158 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAA14567-4F65-437D-B7E8-BF43A2860B2C', '22619B4A-E395-43EA-A683-7438513E5CB7', '4049500770187', '   advance ...158 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB64F5E0-C81C-4ED2-82AE-BFAD91D897A3', 'E6EDBA9A-5DC3-4B9F-906B-CA7ED51E0F17', '4049500770200', ' cosmopor  antibact. /  2010', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92DBAE3B-609C-46B1-8E6E-84623390AA7B', 'D329CB25-0A83-4FC6-8731-D21CFB455878', '4049500770217', '    20  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('062DC304-0AC7-4B0A-A95C-032E1CFDC8B0', '6D6FD262-E9BF-48A9-93AF-8C41700DD07D', '4049500770279', '  advance ...106 /011/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64C795C1-0E78-4339-935C-26CB0C9B4F6D', 'C782FC96-9826-425D-B65E-CB9E44BAB908', '4049500770323', '     108 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C20CB452-7442-420C-8CD3-9D844F3EE24E', 'D7555285-476C-4A5F-83ED-48FE340F9EF4', '4049500770330', '  advance ...108 /013/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57F1D2B2-CAB3-4010-BB22-A02FB4240573', '531A7A07-058A-442B-BFD0-4A7C84502E7D', '4049500770361', '  ...158 /014/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FC9E133-730C-40D0-96B9-CE58A448A9A9', '30B4BA36-A5C2-4D50-9A3A-31DBDCE8CD1A', '4049500770392', ' cosmopor  advance /.  barrier  2010', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE8FE52E-D871-4BB6-BBDB-702DCF420AA6', '4B058E27-A729-4EA4-82BD-76BAAC53D1D8', '4049500812245', ' - 44 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85F6F278-F49A-460F-969C-324890E25BAB', '0CC01C3D-4E0B-459D-AFB0-8A7610B4342C', '4049500812276', '  - /. 46/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB9E02F3-D028-4C8C-BE7D-1793AC799502', '3C8A44E9-28BB-4216-8F77-454B1E67DC88', '4049500812306', '  peha-haft  48  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('743F815D-B53A-406F-8D33-01C429AAA084', '3C65D4BF-60A2-44B0-94FD-1403B71E8033', '4049500812337', '  - .  410', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D89E77AC-001F-480A-86B0-25EDB0B3F413', '855E9CAE-CECD-4AA5-8C91-33526F80C1BD', '4049500812368', ' -  4x4  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3DD0AFF-8D0E-434B-BB56-A65E78C387CC', '011D6D8B-4AF5-4A0C-B8D4-127916BB109A', '4049500812399', 'Hartmann peha-haft   64  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6478CEF6-4570-4381-9B73-632984F011AB', 'D23EB764-479E-4CEF-9A8D-1D59E26D7E2B', '4049500812429', ' -  48  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68B924C0-D3BB-42AC-AFC9-E55826CE3D89', '5B26A420-810B-4CF1-B4DC-2994EBD65E43', '4049500812450', '  - /. 410/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC0DB5AF-A39C-4A37-8396-C383DD14293D', 'FBED07B4-5F3D-4748-8EFE-F62C59D07488', '4049500813419', '  - 4x6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DF088FE-722F-4076-AB77-18F1E856C441', '7388B05C-C117-41D9-9859-3380EA4AC6F5', '4049500813426', '  -   4x8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F04F3955-364C-40C3-A71E-372F22A9B9AA', '84C09161-D966-4018-B538-293E29DE19A7', '4049500813433', 'Hartmann peha-crep   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D7851C4-E249-468B-BC23-582AFAA9DB2C', '14AD4E9C-831B-436C-9B14-0B6C65C0D101', '4049500813440', ' - .  4  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1225C03A-DC56-4355-8C6F-76322B029368', 'AFEEC142-8151-4516-9AA2-CD61500B863B', '4049500832496', '    /  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75DAA165-4371-43DC-A051-F8E2541E4CA8', 'B3E40387-D0AB-460E-B4DF-D9D6B2C1F1F9', '4049500834735', ' tensoval  comfort  / 22-32/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9525B3A4-1854-4570-B111-2258CD704B49', '87932D67-9C10-4432-A433-B8AC554AE4E0', '4049500857512', '      m 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE1ED73B-9CA4-4CC9-AE61-C7D99734BE21', '43982446-610D-4D45-9074-CABF572BDF24', '4049500857543', '      l 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C17B0A12-3B9E-4C9F-B76C-086A212E94F5', '7D406624-C1D0-4241-85BE-23BE564FC2C4', '4049500857901', '      m 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('060BB5FC-6125-4DE7-A827-7B53E4599C8F', '8F514522-2928-46AB-B0A4-29FDA6CF9EB4', '4049500859578', '      l 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('652CCFDD-86A2-4415-A70C-B2F2E22FFA67', '3858F419-682C-45D4-B475-FE73FDEAFFDA', '4049500859592', '     M 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C875C2BB-6522-4023-9503-BCE0EDF1ACA6', 'FEAEC908-464C-479A-9DCA-4F33703DA6E1', '4049500880084', '       22 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43F9A4F2-6BBF-49C7-BAF9-4A26FC1CD23C', 'A4C2FF11-E08F-42A0-B37F-F6AF3483E1AA', '4049500880138', '  comfort  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75963434-CE9E-439A-9E47-E397DFA1B3D4', 'AD45C783-ACEC-40CD-B82F-010699348A1A', '4049500881326', '  e ...7,25 /007/ 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2430AAA9-9CAB-443E-A934-9112E191BE53', '88EBCF89-F2F3-42D8-87D6-59D2D0FF0D03', '4049500881340', '  antibact . . 7,25 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F867A55-A679-4FD9-864B-07FFFDA2F20E', 'ADCE1A60-3E54-4556-89B8-D3EA1F665E7E', '4049500881371', '   -   57.2  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('540BA857-0ACC-49E0-8623-B41EA8D18BCF', '66B2DBB9-BCC0-48D3-B5EA-CD0D2DDF35F5', '4049500881388', ' E  -   106 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AEA5732-DB79-4DBC-925F-9E3D0ECCD2D7', '7090941C-4792-44B9-9670-823BA76CA8E8', '4049500881395', '  (  ) 156 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43E7C9B3-6194-4975-8D5B-4EE259B35FD8', '995B74F0-DC4E-4B5E-B9A4-501066D1AD39', '4049500881401', '   -   10  8  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BB9F3B0-33AC-414A-9ADA-C0589FE90EF4', '7B991D29-F99F-4A4A-91FA-48694FA5A161', '4049500881418', 'Hartmann cosmopor e   2010 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70DE00BC-1D33-4330-9148-D2648D4B1EF1', 'E399B657-B538-4553-B82F-8B8EF2CFC7BC', '4049500881425', ' cosmopor  e. /.  158 1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCF30A63-AA77-4A32-81C6-16FC01DE9233', '16924269-F037-414C-86B5-5233E7A75A0A', '4049500881432', '  e 35  10 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('926040C4-3F6C-4C3E-A6A5-A53BE498A5F0', '2BD0AE8B-08DB-455B-ABB3-60EB04AF3176', '4049500881449', ' cosmopor  e. /.  2510 25/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FD62B58-3ABC-47BD-8A49-8FCD4DB1EE6F', '756F1923-6E12-4746-8087-2CC8EE974BF3', '4049500881456', '  e 20  8 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C03143CB-81B5-4DCB-BC89-1AE6284B3368', '37B5F81B-B070-4A31-BD37-3219DCAD7439', '4049500881555', '    7,25 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0665A691-C65D-40A6-9288-D340C6C589EB', '66B2DBB9-BCC0-48D3-B5EA-CD0D2DDF35F5', '4049500881562', ' E  -   106 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB783AA8-09E8-4F7D-AD87-BB8EF11F62C9', '8DF9D684-D505-416D-9DC7-6362348B225B', '4049500881579', ' cosmopor  e. /.  156 25/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8C898AC-BCF4-4DE4-B0EE-93179DFCBDFD', 'A8D05D4D-DB49-4A42-8476-0235EE7D8303', '4049500881586', '  e ...', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D391FA79-44CD-4E62-A206-0F311ADDFFEF', '36B78E5B-FBAD-4EA6-BDDC-E11E5FB71328', '4049500881609', ' E  -   158 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E95E5BB8-2DA9-4442-8D36-67CF4640ACCA', '17A940A2-395C-4653-B132-916F74C72AFA', '4049500881616', '    /.  3510 25/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E72C9AFD-3A95-4488-8234-4739BE4A3508', '7B7E380C-E718-4FEB-9ACE-ADEE45CBF9A4', '4049500881623', ' E  -   2510 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD779C1E-476A-49F9-81F6-8577357E7C71', 'CA34648A-8385-4E1A-8A1F-5892EECF785D', '4049500881630', '    /.  208 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B693D52-2F32-4470-90E1-1E5CF7F82B9C', '3B198F81-454C-4F26-B93A-AAECA0732780', '4049500886857', ' .   2014 -2 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09A9E23E-3FE0-40FF-8620-7E2B4B1C83EB', 'D024750A-031A-4CBC-8B74-1AF83D2A86AC', '4049500900232', '   . 2,59,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB1F745E-0BDE-4467-9797-2858C1B6411C', 'C5331F58-A31E-46E6-A42B-78E49224F0A5', '4049500900324', '  2,55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('258D0634-CF95-4370-B3F5-C3D97FBFC161', '5375AF01-ADAD-4095-9899-D215FCDAA1E7', '4049500900331', '   /. 55/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CBF31EF-5FC6-407A-BF5C-68421DFEFAB0', '0709BD73-6E32-4A46-A8D4-3F09A82D4A7E', '4049500900362', ' omnisilk  1,255', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B8FC7A9-DF61-4AFA-A01F-F0078095CD8E', 'C771983F-39BA-44CB-A2E6-4EB833FD6603', '4049500900386', '   .55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBFC54A5-BEB6-4685-8050-67FBFBC1322F', '74DE52C2-1AF1-47A9-A4D5-47C03B1D1770', '4049500924399', 'Hartmann branolind n   7,510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37255BE9-5F42-41DD-B75E-CEB839FB31AB', '9D5DE769-AE84-43A3-A481-DD6F61BE933C', '4049500924412', ' branolind  n /.  1020 1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AF2A180-F534-4BA3-96F4-06096D49B1D9', '957F6678-41F1-4F43-BB87-015548FD2F3C', '4049500938662', '     65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EF652A8-61FC-43C3-9051-C0DEADE84A61', 'AA823430-6EE1-4AEE-A63F-D44FA65A590C', '4049500952187', '  -  84 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC8400C7-F798-42BF-82A0-014C261EABDA', '32FAFCB8-88B8-4C6B-A6AD-AA7DDC47DEFE', '4049500952194', ' peha-crepp  /. 104/ 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D96464B5-4D8D-4B65-8AAD-6CE7A5CABC8D', '420B1164-DAD1-422B-B4E9-46A92C4FE10E', '4049500952231', '  -   4x8 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06D877FE-947E-43C4-A793-B2393EB901AE', '2F378309-D6EB-4CF6-84FF-6A23FCE303B1', '4049500959896', '   55 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F221138-243C-4F09-8240-1BC3328E3D7F', '9DEDE029-ACC2-43EB-B3CC-1B226D76C17C', '4049500959902', ' omnifilm  /. 2,55/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('788BFFEE-4E33-40DA-957E-4EC561AAEAB0', 'ED502283-B2EB-432F-8D7D-22BF5185533A', '4049500967655', ' E  -   7,25 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAE6156B-7F8E-4565-822F-7934D32F65DE', '3DD3F805-7033-43AC-BC42-ADB1143FFEEE', '4049500967761', '   510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADCEB908-6FB2-4B34-B8C4-CAD641226BB2', 'A10A9D4F-CBDA-46C0-A00C-46E093617020', '4049500968850', ' . peha-soft  vinyl 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2F7F06F-D98B-4733-9532-F2429303FB4C', '20B22F8F-ECAB-41C6-8AED-B55B2A146D01', '4049500968874', '   / / . .l peha-soft  vinyl', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77EEB7DE-962F-42C8-B287-4E252312FE0B', '59D4546F-F914-4CD4-A612-8AAE4C2D34FB', '4049500970952', '  e 7,2  5  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94905F32-65AF-4874-B5DE-D807A8ADC682', '1BD08C62-69D4-454D-932E-621C82A71569', '4049500970976', ' cosmopor  e. /.  106 1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE7CFF9C-F35C-41D3-9A23-367FA989931C', '7D3BBF94-1FA3-4EA2-8D18-10146E6A4D5E', '4049500970990', '    /.  156 25/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8827F31-EAF8-44D8-8257-704712E88F33', '474975EC-F780-4BBD-A0AF-5DC6847ACE84', '4049500971010', '   .  108 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA6103BC-2088-4216-A335-A4E82A8A0165', 'E399B657-B538-4553-B82F-8B8EF2CFC7BC', '4049500971034', ' cosmopor  e. /.  158 1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F219A8E-F449-45CE-BFA2-6EA8F8941692', 'C68CA85D-DFCA-46B8-B8C8-4313E9BCF829', '4049500971072', '   e 2010  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68155A16-05EB-406F-A857-7EEEB8CF5A4D', '39B158F2-864F-4600-844E-02CA2CBBB432', '4049500971096', '     2510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F1D98EA-18B3-41B3-84FD-1B000BFE3B44', '8F8BF0F5-D61A-425E-BB62-9E75D9760E09', '4049500971119', '   3510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('665E8BF3-C21F-4AD4-9F48-665F776E52C4', '6E0744B9-2B4B-41CD-85AD-951343B93923', '4049500976244', '  /. 1,255/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EADA46DA-2141-4CAA-8F41-330B431E02AF', '888A1FCA-A5D0-4267-ACCD-B0C9E06348C9', '4049500976251', '  2,55  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A48B00B-2B70-4220-8001-D05C5709B067', 'A41F48E2-526D-4E8D-9E3E-82A4BCC73943', '4049500976893', ' molimed     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('942BE1DB-1B4F-404D-9833-BD7E17700FA7', '257D07C6-286C-40EE-A0A9-831ABE6182F9', '4049500996068', '   e /. .  1010 25/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FD382E6-9476-48DD-80C0-BA9EBD00E70F', '6CDE5A97-9BB7-44E2-B2A0-E8882D561E5F', '4052199004082', '   .   55  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09EB7C81-16F7-4A37-B8CF-5896B3E612E1', 'D66A0565-E7F8-4846-AB3D-1C109CC565F7', '4052199004099', '      55  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5D25059-715E-471A-944A-2EF1B0334985', 'B980CF41-12A9-44B0-B730-3E884A7D0998', '4052199004112', '   55  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EE649AC-9A38-4BC9-9105-795C6090C8BE', 'E7F19B60-E976-4114-B7D9-BEDC33A3D79C', '4052199004136', ' 7,5 7,5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1765698-427C-43DA-9E07-9D91B961A009', '63335E4B-6F94-46FE-8C11-2E6164BDE23B', '4052199004167', '      1010 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1B52F48-0990-4E9F-9307-244879A88382', 'FD53A144-5AC5-41AC-A953-3E68E8E9780D', '4052199004174', '     .1010 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5548C2DB-1328-4BC4-A4E5-634B84EEA277', '783FEFE3-3177-4DC5-A6C1-AAE520C8F0ED', '4052199004181', '   1010 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D54FD830-0DB6-478D-A06D-7611CA779FE0', '8E5D1B82-62FF-4730-AF5E-921E48E190C0', '4052199004211', '     8-  10 x 20 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7994B491-62BF-47A0-A937-8074107B2912', 'CA7627FD-8E0C-4DAE-8DF2-AF84A1165018', '4052199004228', '   1020  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE719C7E-744F-42D2-8A15-99A3837AB18F', '1DBE6076-24A9-4FC2-9736-3DA2B3850F64', '4052199203959', ' hartmann  hydro-active    45*75 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E487B824-39A2-4E73-9D28-DBCEA619A9D0', '3DA1C74A-55E6-4806-A13D-1FFF200E8651', '4052199204321', ' molimed     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0111AF6-C9D5-4B39-89D2-8FF255B8FC12', '9E3F78EF-13DF-4976-8EF6-38E639A76061', '4052199204345', ' molimed     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A122AF27-A300-4847-AD9C-89B74B21023F', '73A73954-23C7-4C8D-AB39-784E1D60FF47', '4052199204369', ' molimed     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8203308-A8CC-43C3-83FA-4BF450ABB130', '0012327B-F36E-4513-8DF6-6C52A2633AE9', '4052199204383', ' molimed     28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA826666-0410-4FA5-B96D-4046F2132165', 'C0591564-2F13-4945-B700-738FE6E90EC2', '4052199204406', '       28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('464A0648-B020-4FDC-A73F-D91ED66B116B', '30C68F60-F4C3-4E35-B1B5-5DC814BD01B9', '4052199204420', '   .  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B54D0C62-4F3D-4B0F-BE09-7308330CD628', '799595E2-7049-481F-AB64-21451C985B9A', '4052199204536', '   6090 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD20242B-A827-4FA0-894E-07DB4B508EE7', '70AB1E5B-A772-40B0-A2E1-2DD3D1F3132B', '4052199208909', 'Kneipp / /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D66914FF-A5B3-4785-B8F6-F54A52438A10', '9D350B9C-0B16-4E3D-BB75-D2D731C0BB17', '4052199210902', '  .   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC463700-B714-4ED9-AA0A-C7092DEC3DA1', '1F5C9CFB-D5D2-4E7A-9EFD-DB3E7E292507', '4052199217840', ' Hartmann thermoval ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EC33B7C-7377-4959-A536-14A71224B68F', '5416BABB-843B-44D6-BB44-8849B47D5956', '4052199218007', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A54E2D21-9665-4DBC-83DB-91B34E78CB2F', '5994207D-81D3-414E-A9A8-E608113065B9', '4052199219981', '  hydro active . 3  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4223827E-23AB-4DBC-9902-F8275571AD24', '9A4A34ED-1C1A-485C-B31A-39405C913D21', '4052199227658', ' hartmann samu  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF5D4488-3591-4F60-8A9C-1336B2C31322', 'E6875792-493B-4117-AB30-B1D1965686D3', '4052199237534', '  1,255  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CF97123-6FCC-4E8B-A5F8-4C5CBD8551F7', 'AC125EB5-6929-4D62-A6F0-8EE28887781E', '4052199238463', '   1,255', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7DC4213-99BD-46D7-840E-D2F69732C2CE', '4A701BC4-0701-4EE3-864A-C6B8EF2D1734', '4052199238777', '   /. 2,59,2/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B78116A7-7815-4D46-AF06-E2BD4BBC6A73', '6F4B1955-2961-4C25-B628-6C86EFF470CF', '4052199243825', ' /  p- S 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A6E1759-4719-4193-A324-931D535EB557', '9E2C6423-D430-4D0A-A1B5-49859DB82DAF', '4052199243849', ' /   p- m 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B662F42-DDE2-4F4C-A5DC-335E2D2627C4', 'D26D2E75-7C0C-4E36-A0D3-074F98E35B34', '4052199243863', ' /    p- l 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('483C9BB9-1DB1-4C54-BF90-D55A61A0983E', '205075FB-1514-45AD-ACD7-0C3446AB31F2', '4052500102568', '     2  8  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D610115-4EEB-45BC-811B-051E5733E924', '97FDD3EC-CE87-4697-AC70-89150906BEFC', '4053800080938', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('761A6AC4-0AD0-462C-9ABF-846D90A91C07', '539932EA-1782-4E58-9123-0389022B1520', '4053800081157', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('050E34A4-CF5A-4EE6-90D9-5BD2AC95A656', '5AA9AFDD-9292-497E-BA34-3F13DC44A2DB', '4053800081713', '  0+  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C108DB6-BCFE-4D45-AA72-10221CB586F8', 'C4FC1D5E-4CA5-4AC9-BA49-3F8C6B6C54D2', '4053800081720', '  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC5D9586-62B9-4B3D-A8DF-1EF5E1307C94', 'FF18BA8A-FCAD-46C2-B263-5E643B9BF65E', '4053800081850', '  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7645AAB5-37B5-40A8-A25B-924D3381452C', '5B055663-E656-4F14-A830-96044BA64BE8', '4053800087951', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A22F7A4E-6C38-42F1-94B3-0BA833123467', 'C4FC1D5E-4CA5-4AC9-BA49-3F8C6B6C54D2', '4053800411428', '  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C17CA87-BADD-41E2-8D7F-206B4CDBB04E', '306245FC-F11B-4721-BFF3-7E1C4FC7584E', '4054839084300', ' 0,05% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16B32D98-E298-47AF-A5BA-6DA84F6FC467', 'CD7E5F6C-BDE6-4DDB-A722-8B88F339DC2F', '4054839084324', ' 0,05% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EA1A79C-25D5-4639-AC55-2634E2893E5E', 'B527AE68-04FE-447F-B730-F40EAC90B25F', '4054839084331', ' 0,01% 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F50014B2-26C5-45E6-AEED-07333148F964', '90B9406B-28FE-46AA-B1F6-4EAFC87BE81F', '4054839084348', '  11,25/10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F39591E2-74E0-44A8-8365-26FF6B7B2CE1', 'E9D60315-5CC1-4D43-ADDC-17D8B5D12741', '4054839084355', '  22,5/  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3023B3B4-EBA9-4510-9BDD-9F74AC9D486C', '6A9F701A-F09E-41DD-85C1-490DB6771C2C', '4054839084416', ' 0,025% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('138AC73C-2412-4AAA-A4F8-0AFF80CD9A74', '40ECA7B4-30A3-4F2B-940F-96AB3FE176CC', '4057598000017', '   / 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('052BC014-8BC3-4B46-A2D9-C84E1674BAE8', 'DB3462AC-DDFD-4F51-A21A-EF3A368BD0EF', '4071300156410', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA536ECA-08FC-4C45-A3A3-39E1AE61BB29', 'EF37ABBC-C264-4B8D-90B4-FBCC332E040D', '4084500078475', '  -- -      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CA5B8C4-3E01-49E5-9935-BF7AE6DE440A', '57007625-96D2-4F31-8592-BFCC2B5A0F06', '4084500757288', '   25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71A79ECA-07FB-4BB6-A269-558161C9B519', '8C684234-636C-4095-A0C0-90CB51AB4B0F', '4084500980990', '     2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F41468E-416B-4DC7-8BFB-6EB00CE78480', '734B3887-E31C-4527-AD80-15A00ADFF180', '4086000006996', '  /  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BDB877B-3541-4153-AEAA-616A1F6D69AE', 'C37716CD-45AD-4178-99F4-53E6C1ACBA35', '4086000007009', '  /  1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A90F406-C333-4586-AA26-D6529558AB00', 'C4B20369-CFC2-4B5B-8891-FE1804C45704', '4102966003869', ' 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE04917A-FE20-43A1-9207-2607547C271C', 'E3DBD3EC-F13A-4D8D-A8EA-6238F8EF0B0C', '4103330031167', '  -  brush', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09FDE3BE-7D05-4F9A-9851-F65E891E3B61', '0FEB46B7-E4E7-4646-BDF9-D46A430C2A9D', '4104480460081', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5DEAAE3-0514-4EF7-BE61-DF81D4AB35E5', '03CD1A2B-E237-4484-89FC-841DA4005734', '4104480700019', ' 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0A5FF8F-20F6-4ECE-87DF-F5814318E37C', 'D60B8340-D02E-4B8C-A00D-E2BF693BBA38', '4104480705021', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0117686E-F128-4933-B275-C548B55BFA78', 'D60B8340-D02E-4B8C-A00D-E2BF693BBA38', '4104480708565', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15857891-0AFB-430D-A4DC-F2D05E9CC24D', '9E30F0A6-345E-4EA7-955A-2E076E26C98E', '4210201033783', '   Vitality -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E35F7519-000B-4615-A043-F0072C1329F2', '1D22CA9F-579A-4B96-B8A6-AE8E6980B888', '4210201036548', '  -  . 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1253C925-8EC8-451C-8746-6E01E808282D', '9B19AA94-13E5-485A-8FDB-4771C962D783', '4210201154709', '  - stages  d12513k frozen/ 3709/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12586970-6704-4714-BE25-AF7BADB5C82A', '02DFD90A-0584-4541-84B8-5F377514F17E', '4210201181101', '  - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDCFDE07-E3A7-48CD-990B-A84FFC87CBF4', 'E3E23167-9739-4655-A580-CD28F79179D3', '4250142198905', ' /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4AED7C4-0A6F-4113-87B1-D01D0687A346', '85DEECA2-C8CE-4D33-A050-3547E3952615', '4250369500079', '  0,05% 30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2E0106A-7622-4C98-A4F0-2857A573811C', '5042AF9D-479C-4F28-B003-DE6B3C8C2B5F', '4250369500277', '  0,25%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9435A4E7-8364-4926-AB3C-6D4BFB837FAC', '9B607E95-98E6-474F-B986-7441BE6FD15D', '4250369500871', '  / - /.    12 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F8CC430-1037-4282-AD5B-7D4C443F157C', '19FA92FD-C2C3-438E-86E6-35A1F4A7B6CE', '4250369502219', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('098969A6-5405-4D26-9AA2-63C0A7CFB49B', '5BE6619B-2E4C-40F6-A286-9B4A13F03565', '4250369502271', '  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9E7DE8E-145D-4CD0-99F2-6E62B4FC0144', 'D5C40FF2-05C2-497D-BE26-6869E33A96DF', '4250369502332', '  / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8556668C-5F41-46AD-B702-363992E7BAA6', 'AB4A45EF-4BA2-43E4-B897-C5D637FFE13A', '4250369502387', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('527F9706-7B67-4531-B69C-0DB608C5A940', '9883C85B-D31A-4774-830C-2CA8560EEB22', '4250369502448', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EECDBC4-2683-4F27-8DD5-117D71BAB107', 'A2114F44-D829-46CB-ADCF-8E0D2AA62B06', '4250369502509', '   / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE20A33A-1C26-4646-8039-1BB184A9B139', '03AB87E2-566B-4275-BDF6-B7A8FE46DF2B', '4250369503025', '  28,4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4C24C6E-2FDF-4141-9CCD-AEF4CEF9E376', '5EFAFC9B-F7FB-4396-9FF4-B034EF47A693', '4250369503070', '  1+40   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B23D5208-AF01-43DA-8F62-569749E38794', '04F38865-5C7E-4CD2-A8A8-8E022F76C933', '4250369503162', '  206 12  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04E8D258-FE61-40B9-8E79-C1044C6C2A75', '4D611951-AD28-42D1-BA48-5D3935A3311C', '4250369503261', '   28,4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5582CF1A-158C-4FF7-A813-1E8A2AF425AC', '5A06A6E6-710C-4541-BA76-D89ABB9243A2', '4250369503360', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78B2AC7B-4653-40E2-9A90-9BF057DDBB01', 'E6F3068A-0832-4BF2-B9B4-313240ED611B', '4250369503728', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AA086D3-0B3B-4A05-9D67-3BBCF48C053F', 'AD2283A8-066E-4A7E-B7A8-27341C3F2F16', '4250369503780', ' 500 +400 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87F82069-8E3A-4829-A5D9-4559459DA386', '8686A672-984E-4975-A92D-6092D8F0BD42', '4250369504039', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A673F21C-B88C-46FF-8C48-11B055D87980', '33804622-42DC-4348-98E5-B17D89BCB974', '4250369504084', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('324E6C90-02F6-4E21-BE79-477AD64C42BE', 'A8461548-F893-4B97-BEDF-3E884AE31066', '4250369504213', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7208F3E8-DEA2-4150-A703-7FDFE8B4E459', '16C1E502-9BA2-4157-A727-28D987C729D2', '4250369504220', ' 5%  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30CB691E-7217-4256-82CC-DF71EE3C97CA', '5171B06F-3054-4BFE-8D1C-BF711DFF1945', '4250369504244', ' 5%  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2258DD0C-B5CE-44A8-8938-E08A397ECA07', 'AFA0B1E7-B165-435A-ACB7-6F8EB9E45764', '4250369504268', '   5% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F594CB2-C800-4F98-A2EB-DE6E43871CC2', 'E8F04D35-2825-4298-8C97-290D29D1E945', '4250369504312', '  /   48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1841352-286A-4CD7-80E6-64EED11CD689', '3D982B44-15F5-40EE-8148-C9DE31030FD6', '4250369504329', '    48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CD10AAC-6B25-461D-8B24-EE220E9ABF00', '0A4D5A03-FD7C-497F-A2D7-3010CAC3CA4C', '4250369504350', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41B3EECB-E692-4C44-92FA-E6149F46F9AF', 'EF476D7A-B7FA-430F-B9F6-3295D1E97081', '4250369505036', ' .   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8812828C-FCF2-42C4-89AA-B39C40E33B97', 'A5518503-029C-4820-81D5-E8183E3160D8', '4250369505128', '    1+20/ / / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38D2623D-35AE-4CFC-9F99-D88B122C4916', 'DB73B627-3FF0-4D82-AF7C-42B5E09BE21B', '4250369505135', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('597C0636-7AA2-4772-948D-A608DF26169F', 'E864FC12-A6EC-4D04-A6C7-EDA333E648D1', '4250369505166', '  500   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D81CF7C-7CB1-452C-B2D1-3149A42E7FBC', 'F4482292-7971-42FF-B4DD-8FA74E80EA3B', '4250369505210', '  5% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62B47832-A55A-46E2-86F8-26AE5F5AD6FC', 'A2C6F032-9626-4B84-A868-B833E3A5982F', '4250369505418', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB1B7B6C-6D46-47D8-AAF1-C9621E1E5211', '88988A32-5A14-4C90-9391-754D7B25BC4C', '4250369505555', '  0,125% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A226554F-5A07-403E-94DD-012EDFA8D480', '7A033B63-C07A-43A1-A7BC-4E61C8466408', '4250369505586', '   .   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AB9DF9C-7AFE-4573-A8CE-E05EAD8AA1AB', 'F60E5F49-516E-4D3C-9DD6-384CF7331C5E', '4250369505609', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD72BB50-1731-4C30-BA25-3E6DD9ACFB90', '3C92BEDD-A5FD-4D11-82BD-BEE25BE9594C', '4250369505647', '  10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAA6C3FB-F83D-4C26-A8A3-BEC28CA42BDA', '2CBB2291-0B43-47DE-8F8C-A5EF380509DC', '4250369505685', '   0,25% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C06F4BDB-1087-4F42-B048-83544FC653D8', '351C0C8D-EB4F-4850-A666-DCBC454BD02C', '4250369505807', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4B7D954-61CB-4636-AB81-0FF62C8BB547', 'A5AA4BBA-04F9-432E-8B8E-CE774A905D11', '4250369505838', ' 80/680    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('883B508E-8215-461D-8B48-83E2A89EC462', '05A2BAEE-774B-4A29-BC53-BB13BDDE7388', '4250369505845', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3059BE2-AEE8-43B6-B496-48576E6C7DE5', '9236C2C7-37D8-46DE-98D2-B50206534CC3', '4250369505975', '  1,25  - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCC43866-CE5B-4FAD-AC5D-BA39CEE34842', '2F7C4400-24CA-4732-87EF-EFE606B2C15D', '4250369506255', '  0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04898389-6A6E-49FC-9579-DD544A6EF17D', '729F1008-8418-4216-8FF4-586ADC53438F', '4250369506262', '   0,1% 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24C4154E-C35D-43B6-9008-F71DEEE343EE', 'F6512FED-C805-47E1-A97D-202C9D2EAFE6', '4250369506279', '  0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BA5EFED-575D-48D9-A325-F3394324A7F1', 'F6AA2E82-FDF4-448D-AF67-44C09C6D6359', '4250369506286', '   0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68EF4FAE-21D9-424A-BB85-BB94751F5FE8', '315A0616-81A5-4EB6-9CED-6153E6328C7D', '4250369506293', '     0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7122683F-C584-4916-9327-42D1CB064C9C', 'B71E14BB-ACB3-44AA-8DCC-0F7429F9C46B', '4250369506309', '    0,1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6566181C-559C-4CBE-B327-B67F78878030', 'BD48EB3F-A576-4D6F-8EFF-3D26FC2389AD', '4250369506323', '      0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C560C22F-987A-4C4E-8FC2-4513C604E161', 'E39AD6DA-93B0-49D1-99C2-9A794BC3606E', '4250369506330', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A95ACD8B-97D0-4E18-B34E-B4E46A8AB310', '63F8327F-7D6C-49ED-B899-AA51E1625916', '4250369506354', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('543944C5-93DF-4677-A13A-B21F29C708BC', '821251ED-EE71-42C7-A789-43CC23342C00', '4250369506385', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93D8C18F-AD45-446D-826E-C63E40FAFF48', 'F246AB68-C2B8-4A18-B453-77896E6D87D6', '4250369506408', ' 0,5/  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EC9FA50-314A-47AB-B90A-6168C01E0B9C', 'BF826B42-74F1-4355-9561-210C7A1AB1B3', '4250369506439', ' 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('317D0D53-8019-4B47-9AAC-515B05E78295', '6945E209-B0C6-4541-A2EB-4FD6278589DD', '4250369506446', '  1/ 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E82CEDFC-2E49-4026-A5B6-A95591FBF8FC', '404A59F4-474F-4FBB-955C-EF15A6484DA5', '4250369506477', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('617B0F8A-7B66-4914-AFEA-82B43F8E2B31', '6288895E-1336-4CE6-BE24-563B5DDA3E25', '4250369506484', ' 0,05% 15   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBD4F788-55E7-426D-BA1C-6A7FFC9E80B6', '6288895E-1336-4CE6-BE24-563B5DDA3E25', '4250369506491', ' 0,05% 15   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A408B19-5841-464C-9360-BAF74134EEE0', 'B55356DB-1028-4A52-B9B2-1DEAEB1EA9C1', '4250369506507', '  / / 0,05% 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00729363-F82D-40EA-A313-3392EAC35049', '134F0D8C-1A25-48B9-B8E3-ECADC811F47C', '4250369506514', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E83B952-9A46-42B8-9429-9D6EAC69C16E', 'A2681E58-E53B-4843-BE9A-9F43CB9D1B7F', '4250369506521', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88ACE3FC-DDBD-4D38-8E13-322704350AA1', 'F8647B46-CDBA-4910-B6B4-8F91AEB3028C', '4250369506538', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E14246C-AE3B-411C-A6C2-A1B065E40408', '93FC8CE2-EA42-4278-9455-7305103797AE', '4250369506576', '  pH-  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4294832D-1AC6-4822-BF59-83E7B71FD116', '407EA112-54A1-440D-AAEE-33B52B2D73C5', '4250369506583', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC52376D-29DC-4DD1-9847-A7054AC92E58', 'E8545E95-C1EC-4553-8058-C1991E2AE920', '4250369506613', '  400   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC7A8990-C32C-4F2D-88AA-D8FB1249F728', 'CF44AF80-1DCD-447C-8894-4AAA115AAE59', '4250369506637', ' 5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('426054F4-5627-43DE-9C1D-9295CFC70C98', 'CB8F022C-6827-4640-82D1-ACEBAF1DBC01', '4250369506651', '  5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('604F7CD8-3F2D-42D2-AEE5-D15E9AADAF34', 'FF08B1AA-8E41-4931-86C4-1CD29EF9F0CD', '4250369506668', ' 5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95D93CE0-A28E-4D9E-B250-9C2423266FCD', 'E0242CCB-7D32-42B4-9B50-6CF717183871', '4250369506682', '   5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D660070-746B-4088-AD79-9B967E7921B3', '1297C603-062F-4562-AAF4-88571B00E46F', '4250369506736', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3B850CD-05D6-4B25-979A-2E52D83F114E', '7A52E8FA-6A2F-430B-9A0B-8E5FCF39E7E9', '4250369506743', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC059939-3476-4AB1-8AFF-0B699B533D05', 'F98DEFEE-82FC-4B3C-B383-BEA12706A90B', '4250369506750', '   30  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('277D4A03-8F18-4187-83B8-FFC72508BEC5', 'DB3462AC-DDFD-4F51-A21A-EF3A368BD0EF', '4250369506767', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22F8F6A2-8290-4978-850C-7A9467C7376C', '868828CD-63B5-4408-A3A8-D6A908A81943', '4250369506774', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B77221F5-BD50-42F2-A033-6A8DC7E4834C', 'A58C19F0-08A5-4BA3-A291-542804C9B0F4', '4250369506965', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48BCABFE-1DDB-4717-82E2-380E6FA35F0C', 'B47ECA46-504F-410A-94CB-21673C2160C5', '4250369507009', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('254D4AB3-2411-41EC-90D8-EFA66CA0C759', '33C2A3FC-5393-4C7C-AF9A-CCF21B5E33C0', '4250369507016', '    75 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58DF108E-86A0-430B-AE66-79864C7926DB', '7F134612-32F2-4258-A5E6-C49DEC558692', '4250369507023', '    75 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('578F704B-348A-41B7-AECE-6C0C94058F54', 'A5AA4BBA-04F9-432E-8B8E-CE774A905D11', '4250369507085', ' 80/680    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03526E1B-0F50-4B16-ADB4-A203ADA2A63F', '42BD08F2-5337-4692-999F-48AC5A88C2B9', '4250369507092', ' 80/680    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('695DD509-E061-42B4-A803-23A4D8119C89', '9F0E7810-5FB7-4AC7-AB3F-22A005ED5585', '4250369507108', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F34CA066-5F81-48A8-AE01-2C6E15F8A413', 'EB76C305-20BB-4BB5-9162-6C47AF0CD8B2', '4250369507115', ' 80/680    24 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A38D293-0C89-468A-8674-141EFD8E2A93', '16FA42AB-B401-4B94-878A-4643AA236CCA', '4250369507122', '-   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F37095F0-3161-4EED-B0BE-FFD7ED29BC94', 'B61D194D-F644-48A1-9852-D78C7D1E243F', '4250369507139', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6390BA1-26A2-462F-8407-57188CCB0221', '13AADF4B-B2BC-4A9C-932F-FEB918DBE6D9', '4250369507146', '     4 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF8A5514-CC0F-4822-9AF9-3DD98962AA70', 'BCBE18A6-5706-4558-8E6A-6CB94BA6B49E', '4250369507153', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61C9E27D-098D-4A99-8AEE-38347D4A05FF', 'FDA5AAA2-271E-4F52-8479-D35BBF859F49', '4250369507160', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18C23681-B46F-4372-BCC9-A7D68B819D5C', 'D7334713-24E2-4EB6-967C-203A4D71D455', '4250369507191', '    +5% 1  1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7AF99A1-5EA4-4697-ADEB-8B447157803A', '7ED1876E-6A1C-4FA3-992A-A1D33E69A36F', '4250369507214', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FFECD75-ADDA-4D1E-9BCC-7CA182033362', 'ED7FBC91-ED8E-49B5-B609-665CB0A76249', '4250369507405', '   / 1  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88E076F5-F7CF-476F-9501-495F7BD77D93', '71241BC4-6CD5-46C3-A254-F1F193E302E2', '4250369507429', '  - / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5D80DA7-D461-4D88-8674-DB8F824531B1', '38B34F04-D8C9-4661-8277-89EBAD1E391F', '4250369507436', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4955249-B172-4041-A653-5BEC853710D4', '5F8538E2-B2D4-452D-8714-7C73E3DB92A5', '4250369507443', '  - / 7,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CCB622E-6871-43FE-9286-10F233C24E04', 'AB378869-01C8-4508-B977-37984337422C', '4250369507597', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5590E0C4-8D6E-44FD-AD36-8C8A97DF40BB', '8F238C4E-EE5B-4F9A-A1B0-40B7524C54B3', '4250369507603', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D0D4AF4-62A0-4E92-9EC0-AB8880A474C2', '995A0901-243A-4A2E-8691-79884E89ECE0', '4250369507610', '      // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FC1F619-3ACE-4AA9-A8CA-0389183B5F8D', '9A0F2842-079E-4500-A3D3-6F0C987A9D06', '4250369507658', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DABF511-D711-489F-90F7-8DD50D959253', 'FDA5AAA2-271E-4F52-8479-D35BBF859F49', '4250369507672', '     60', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE6C21E5-1823-4AF1-8214-3C8F3B6C4D01', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4250431900134', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79AA9D5D-4E55-482F-8C7F-C8E9499E301B', '1F91067C-5D9F-4B14-A6AC-5FAB1262C699', '4250431900622', '---22g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23F04DC2-0F57-406C-B6E2-7E169F86C086', 'B5CC3852-33AC-4599-90FC-83814A529102', '4250431900653', '- 23g ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78C098C2-0ED2-402B-9950-6EEA545CF674', 'B829DF3A-F612-49CD-B5AC-9416028B45A3', '4250431901858', '    8  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6A7AE24-D604-4FA4-9E92-8659780027B3', '6F1D439A-99E1-45FC-818B-211F24723B1E', '4250431904767', ' sf   /   m /7-8/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D97E0BC-3829-45D0-B4AF-57FAC1E83367', '1A058825-5933-4610-A63F-CD1F6F826E2C', '4250431904781', ' sf   /   l /8-9/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB51B4F1-AA20-4A4C-80F5-E7786267DE86', '61E55D13-CF32-480A-B151-995E35BEE26B', '4250431905795', '  , , /50 /  m ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('453F4361-4697-4539-B603-E6F70134C591', '681F4BDA-01BC-4148-8CFE-A8E7DAFAD1DA', '4250431905818', '  / 50 .L', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A63AA25-D476-4502-99DB-77EB0F85FFC8', '7923C8F5-18D6-43CA-B107-F536836F2E29', '4250431905832', ' sf . . . s', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B29789E-A14D-4C8E-A22E-3B2AF98A9380', '03954DA8-FC2E-4522-82B4-9DDB26099AD9', '4250431905856', ' sf   /   m /7-8/ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A196278-535B-4A05-A7FD-3E41F8F274DD', '2FD3F8EC-9681-41B9-A11A-7B659B89DDB5', '4250431905870', ' sf . . . l', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94F3C0D8-6FEC-4C73-A722-0DD8F6C7FE0B', '91ACD5C3-8C80-4C5B-B269-6D3AE4650582', '4250431905931', '  /  l /8-9/ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07BE86FC-7EA0-49B0-B916-DB13AA97E208', '095AF622-3A0F-4480-8DB2-7DDBDB734AF3', '4250431906877', '   . . .6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB609406-6812-43D4-9CE9-1CE794D753E8', 'F5B4DB77-BCAE-4188-9BF3-196CEBD421E5', '4250431906907', ' sf      7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFD2B9DD-182C-4D26-ACE1-6334ADD2D31B', 'F840975E-7EC6-448C-8144-54ED54685C63', '4250431906938', ' sf     8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E78CBDB8-9A28-4416-A696-E5C3D0C99934', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4250431907621', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96F6E77F-BA4E-47E3-B512-B3785C3DB79C', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4250431913998', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30FC8AF9-0072-4480-90BE-0D5860B506F3', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4250431914025', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C207F8CC-DCF7-49F9-804F-5910345221C2', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4250431914445', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5B97377-A0AC-4093-871F-5F8B76748C60', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4250431914629', ' 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AF694A4-E80D-4977-AC06-F51265B2B178', 'E4CB5439-A752-49DA-BFCF-BF1E1A50C495', '4250431914858', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C7F0478-912F-453A-A036-FEBEA524FF20', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4250431914865', ' 3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53FE917A-04DF-499F-866E-FDD431D1C3EA', 'CFCA56E4-6878-4928-AB6A-1CDA43F5851D', '4250431918672', ' sf  /    s /6-7/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A951A03-6A2E-4364-82C0-16F964554812', 'EF0EA44E-5998-4B4D-BF56-378838718F9C', '4250431918696', ' sf  /    m /7-8/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECF0316D-8596-4613-98E5-EA78958AF685', 'ED9AA965-A42F-4EC9-B7C4-11F654AECA43', '4250431918955', '  / .S 50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9003B5FA-8234-4655-A2F6-8F3C9F89EAD1', '8D07D114-F801-4DCD-9356-9CF112A42878', '4250431918979', '   /50 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE4741BF-2B25-4B6F-9BA0-A2DAF8F1A7B1', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4250717500041', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E76EFFE7-E9EC-47BB-A2AC-9141527D6E70', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4250717500171', ' 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A5C5124-E3A7-4FCD-8B8C-4EC7153E83A8', 'B9DF628D-9024-431C-98AD-1F130B00200D', '4250717500317', ' 3 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63F32E67-AD0B-4241-9D41-CD06AABDEDE6', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4250717500409', ' 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EEF4C2A-6ED7-4988-8CE2-831F59BC6187', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4250717500461', ' 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA91E629-9AB2-4227-B3D3-9C7239C55022', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4250717500492', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A318A42-E7B7-4886-9A2C-14DD94D690C7', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4250717500522', ' 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF18AD71-9D34-4196-A67F-E44E90FFE5BB', 'E4CB5439-A752-49DA-BFCF-BF1E1A50C495', '4250717501215', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F293A8EC-7D4D-4C7F-BE17-19FF8E6BBFF3', 'FBD9060B-D269-41EB-8F70-E57905BB6A9B', '4250717501277', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CE3AA51-3C38-48FD-AF55-9D227910D68C', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4250717501307', ' 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('370597DA-B982-45BD-A389-C29141234476', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4250717501420', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BE25B84-6B4E-4252-8919-D3B7C5902C5B', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4250717501482', ' 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FF8F15D-5CF2-43A9-8422-8F2858C63850', '204B6BDB-120B-4863-A186-9D367D416199', '4260043459012', '  250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEA95A86-0DEF-4AC0-9F0C-E5658578511E', 'ED538E55-0C5D-45C3-B08C-741918006399', '4260083220085', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4D07C84-BC7C-4AD1-AA57-7DEC6551EC92', 'E970BD4F-0D06-41CF-8D3C-ACFBA73E50A0', '4260083220092', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73F33542-48EA-434E-B688-90284B2E2D27', '5739337C-DE2D-42D0-961B-F62F32879F06', '4260085520251', ' 0,1%   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('390CF579-05C1-4FFE-824D-40A083BF51C2', 'F16EB28A-816C-4498-90B9-153157021BFB', '4260085520268', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BF11C5A-7CB6-4700-9335-94CA5E404FE3', 'BA4C64FD-2AA4-4DF3-AA58-5F9D0EDBB3DB', '4260085520275', ' 0,1% 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EC08EF3-C4C9-4F1C-BE34-12E75ADC4EF7', '3C7B7352-FB3F-4295-A626-C56058565277', '4260085520282', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CF49384-2F42-47AD-913B-4D05BF2C00AA', '6B0F47B6-33D7-4283-AFD4-C3586B4FE13C', '4260085520299', ' 20%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A7B3F36-2029-4063-BF5F-489A63C70506', 'E91E0403-465C-4350-AF9C-DAD06F2973C5', '4260085520305', ' 15%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06F79076-717D-4882-8701-014853DA2843', 'CA722A92-9B19-4234-88AF-005F851E360A', '4260085520329', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B8998DE-5479-426A-B0C5-09FD4705B185', '8686720A-4936-4337-916F-119656800FB1', '4260085520336', '  1% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08CDE756-035A-4E57-BB23-176946246339', '87B0E446-27AA-49A3-B0C2-CADAA4BE9608', '4260085520367', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E999BD3F-16BF-4D70-B79D-829333486FDB', 'A58B64D3-E1E9-468E-8FA5-EF687D4ED9B6', '4260085520374', ' 0,1%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CC8CDDF-1B89-48D0-BE39-396F3F905B78', '7AFD70CE-35EC-4B51-8EE0-F92A670BB092', '4260085521210', ' 15%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1D6AF60-6B4C-46C3-8F49-8802C1ADCFB0', 'D594864B-07EB-430C-A80B-73E8072B6A35', '4260085521647', '  15% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F178325-3DE6-4D92-87B4-AA14D977E6F7', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4260090441329', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93A7ED1D-1B67-464D-BE79-A2720A9A8524', '7A8E4C2E-E054-48A0-9B0E-5361E8F8557E', '4260090441411', ' 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8A6FE9D-59BF-4E14-B64E-AF26624A375D', '992F8499-1D01-445B-9745-B6F8FEB10541', '4260090441428', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F660A68-B535-4226-A563-FEBF896FE4C6', '97C0F2AA-C5CB-4FA0-9788-FB520DEA5D60', '4260090441800', ' 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF1CA338-CF44-4302-A6C4-DBF8644DF92B', 'AAA0B26D-2D75-4071-BC88-416F2862B5D0', '4260090442487', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8937F0BD-51E9-4953-B223-977F192D272E', '9C164E6F-F396-4556-BD3D-0D8D785C5ACF', '4260090442562', ' 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9716C63E-B71B-4FFF-B918-D5A28C7F5711', '2D7F5C2E-7FF6-4B6A-98F0-DE0A9524B1E3', '4260090445396', ' 2 22g 0,730 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F73C8C52-DA0C-470B-9D52-2994400C187B', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4260090445785', ' 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C8AEA33-24EE-4992-AD01-E12BD67052D2', '0745D94D-DF3F-4439-9C62-F9B80C8BBE28', '4260090445860', ' 5 3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62F202DC-740B-45DA-B435-CCE6E05EB2E1', '16747F8F-0715-4279-903F-04137E1121CE', '4260099070018', ' 0,05  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('123099DF-CEE5-4830-A897-ACA76B0EA1C8', '81EEFAFE-5210-4BC3-B36E-293B4EE55940', '4260107455509', ' / /  fabrik cosmetology collagen crystal mask bio gold 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F155FDF-09CB-4B55-B4A8-5F0F2076D83B', '93E120E0-1159-4CC4-94E0-F2CA739D77AC', '4260107477099', ' /   / fabrik cosmetology collagen crystal mask bio gold 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB3BAEB8-B169-4B19-8194-6369B222AE0C', '6F2F54A3-9A8B-483E-BC5E-3EA6CBA2926B', '4260107477778', 'Fabrik cosmetology setiva  / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67920558-1F1C-4E38-BE1B-E20D3BFF5F9C', '1C8B6A1E-7AEA-475F-8937-2553E4E6C600', '4260107478096', '  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E867293E-65C9-4A81-9ACB-B60DC9C6E38A', '16EC0FFD-064C-4BCF-BBAF-990B3BBC73C6', '4260107479383', '   /. dismoi ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDCB4CE0-C629-4670-ACC3-B356D11A3CD3', '5C1D5058-543C-4027-9D30-9831871300AD', '4260142420012', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC1D99F0-F33E-4A65-90CB-E29FEEA43CC1', '9967D0CD-2728-4DAD-AAFD-53D5512242FE', '4260142420029', '  / 100 1+1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F7122E0-D073-4CE0-A496-DB2665309095', '01D9EA1C-3E95-486F-BB13-94BF8F11D72D', '4260142420333', ' 10000  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0D6794A-B60E-42FB-87F2-1152DC6CD98E', 'CBC121E0-FDBA-442F-BCDF-4E0A20991691', '4260142420340', ' 10000  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CD18827-D006-440F-9EEC-016408F29ECA', '192A6E71-577E-4D62-9001-900A14B3C76D', '4260142420357', ' 25000   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A458E74-0132-4D78-960F-E539A6633E7D', '946A16AF-E986-434C-BBA4-6AE39CF20E8C', '4260142420364', ' 25.  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('152F5233-59C1-410F-81D0-3A0A0AD86587', '8A936063-4212-42CE-8C7D-4F4F7A1779A9', '4260142420371', ' 36.  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E88490E7-46F6-4E9D-B2F4-87FA2FA71180', 'C721098B-9F58-4B6E-900A-EB54C444EC87', '4260196620079', '  . . 10 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2419BC82-942E-479E-9085-1473489B3B64', 'D7B5B0A5-B1B8-4AB0-8F99-A9FB6D8B9A66', '4260196620086', '     0,5 - 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17E485D7-9F8A-41CA-A630-80ED1601711E', 'C1647F52-BABA-4857-9883-017477FAC073', '4260202920247', ' vm     7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EFA5D7F-C66C-4893-89C2-BF847295D8D8', 'FFC30295-021B-4941-9F8A-1EA1DE399E0A', '4260202920254', ' vm     7,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4407CD9E-B628-4223-9ECC-66D78A4EAA82', 'FFC30295-021B-4941-9F8A-1EA1DE399E0A', '4260202920339', ' vm     7,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1990CAE7-13A0-4B73-A19F-230523AE046A', 'B78D0909-60AF-4E66-AAF1-385548ADE0A5', '4260202920346', '   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF6F899C-F79D-4FED-8C14-43DE157BD077', '3A70F55C-C358-44B5-A288-5F0F2C6C7EA4', '4260202920353', ' vm     8,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5EDC073-5B35-4914-AED2-129CBDCB0784', '132B0043-46AE-4EA5-88E0-8C65E69ED3CB', '4260202922197', '- 25g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13F607CA-78EF-4990-A5D2-777D14AEAB30', 'A1EC6C0F-1C47-4385-B353-4ECFF87A0A18', '4260202922210', '- 27g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5C2A39F-BB35-4FF2-B629-649A107DE128', 'FC33DE11-75C6-4EE4-A8BB-DA12CDACD85E', '4260202922258', '  21g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A182275-7DC3-4317-B0AD-7248AADD880B', '99D4B65B-92A6-4B07-87F6-7C85EDFD4670', '4260202922265', '  22g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AB4DAEA-FA4C-4FFB-9879-E006ED731DD7', 'CB839246-65EA-4523-81BE-9D874DC64E50', '4260202922272', '  23g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4D63E55-EF19-4C50-9B44-459C7490DC24', 'CFAB0A55-F705-4BD5-89FA-07046AA6FD75', '4260202922296', '  25g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F607D718-535A-4F1C-A0A5-FC0DC502A2F7', '7F0AECB6-011C-4962-AD33-ED62CECEF7E4', '4260202922319', '  27g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF9D57E0-9015-4FE4-B4B7-29D734A4992B', '70EF3D6E-238C-4DA7-97CD-968E7E334909', '4260202922487', '  24g ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62D35BF4-0086-4C33-B482-269D69167E6B', 'A1EC6C0F-1C47-4385-B353-4ECFF87A0A18', '4260202922517', '- 27g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D4DCFA2-85B9-4F07-A254-E6BB1049F69E', '4964DD6F-3C86-446E-B850-ED5F73964E1F', '4260202922647', '    s - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9325AF00-4422-4ED1-91E2-531607B3949D', '88603D49-73CF-4445-8A63-75AEC0F66AB3', '4260202922654', ' vm , - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1547CA10-8FB3-4D51-B8A3-11533B57F0ED', '938CBD79-1D7D-43D4-9FD6-3CCB1E589195', '4260202922661', ' vm    /   l - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('095C37DB-DADC-4249-A16A-B47EA317F074', '52C0727F-C4DB-4593-9D8F-C7C7562FDCC1', '4260202923354', ' vm   /    s 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('358E8936-7366-4761-BC0A-D0A0BE328D82', '8A170697-3EB6-4A6A-829F-658ECB440C27', '4260202923361', ' vm   /  m 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0D434C5-CA26-4A36-988C-9B3795720301', '671BC60A-2867-44AB-B5EE-ECDA1A101D91', '4260202923378', ' vm   /   l  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0995F69-E3FA-4741-8489-B8563E76CE53', '90841172-5879-4277-AB6E-01A4AFC23C43', '4260202923422', ' vm   /  l 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96098ABD-D289-4FED-8FE9-7F20FFAC68D3', '74E85C34-A4EE-44CB-A82F-B01BF4F71A04', '4260202923460', ' vm   /   . m 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D60ECF0-9DB5-472D-8A50-C4C8B554C682', '4B1C9F97-4C62-44DF-BE79-E0E4C793506F', '4260202923514', ' vm   / m 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA73FE37-378E-4C6D-9BF8-9CC521F8F7DF', 'BCD39F86-5567-460F-83F6-2531ED7C06EC', '4260202923521', ' vm   / - L 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36EBFC29-BB0E-4A4B-8883-A8E2968FB396', '4A2FB99F-6B27-4EBA-9FDB-AF32C7996A6C', '4260202925860', ' vm   / s 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9D01EE0-DFB4-4AC9-A40E-AF5BF6518CD9', '8A170697-3EB6-4A6A-829F-658ECB440C27', '4260202925877', ' vm   /  m 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB0B0687-7CF5-4B3E-8DCB-020BDBEE55E5', 'BCD39F86-5567-460F-83F6-2531ED7C06EC', '4260202925884', ' vm   / - L 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('839F72FE-891F-4B60-86B2-893CECEF4935', 'AF49CA3A-20EE-4EED-BFFA-6443999E3D54', '4260202925914', ' vm   / s 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('936DF9E1-B80B-4E2C-B6BC-17A818C71F9B', 'AA00A223-BC3D-4FE4-997C-FE35042B4E2F', '4260202925921', ' vm   /  m 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6C36F87-0DD3-479C-8FFB-FC7F0B407C9D', '5B7C3451-D32F-4F01-A2FF-082635F31A56', '4260202925938', ' vm   /   l   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48E92D83-9EDC-4C21-830A-D58DDE3DB745', '3E1EE470-1DEB-4388-88FE-AFC47281CEE7', '4260202926072', ' vm   / - m 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BE5AAC0-AD41-4152-86C7-8696880B3AC9', 'E30286A8-9800-4CD4-B592-66F0C7112F2C', '4260202926171', ' vm   / s 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84E8B1D1-0ABA-4835-9EAF-963028FB3EE3', '129BF944-AD61-4400-BB8B-E592B52F0BD4', '4260202926188', '   /  m 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6075C8D7-B3CF-4353-8D93-ED0E4D3B6BFD', '6D0B6BED-8950-430B-AD84-5F29201412DE', '4260202926195', ' vm   /  L ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0CC6D34-F033-40C5-9A58-B0831ABBA00F', '5F2CD153-C574-4A74-9226-F83FF316374E', '4260229080115', ' 130 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1163881C-E12F-4446-876A-FBD3517101F0', '260DB09B-22C1-48E4-AB70-63ED755777DB', '4260229080122', ' -   58 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8FA5F35-51AC-4ED6-AB96-4967087F21BA', 'E6C57F12-A068-4532-A382-4CF8E104180F', '4260229080153', '-    130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E7496F4-7B37-493C-9BC1-1718A13C5F38', 'D3DC7915-0450-4D91-B809-824CD7A0C548', '4260412320172', '  2- . -24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33EBAC1C-ED0B-4EA7-A62C-C734E5B5E31A', 'F621B074-ADCB-4642-90B8-BAE673D78935', '4260412321438', '     /1,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A03B056-6B0A-4563-989E-85ED86E883BA', 'DBE54EB5-3C2F-4643-A7F8-815CA5A9A484', '4260412321452', ' 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F35433B-E4BD-46E8-99C2-A9F011D319DC', '2BDB81C7-B2A5-488C-8A5A-4DC178F88E09', '4260532450049', ' vm   /  l 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A96AEA5-D8A3-4664-89AC-B8BA69461CDF', '7942210C-D330-4C34-BE37-187E8DB925A6', '4260532450261', ' vm  /   s - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CBE1071-FE2D-4B86-B5F0-21FD94DBCA9F', '41EF7CBD-C469-4CCD-AFD5-6B780D9567CF', '4260532450278', ' vm    m - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F0FA756-1D52-4AB9-A090-B7A7BD4B63D8', 'DBA41863-822C-426F-A89B-D9102C066696', '4260532450285', ' vm  /   l - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7865A58E-14C2-4C8C-94BA-8E08D834CE1C', 'C1647F52-BABA-4857-9883-017477FAC073', '4260532450759', ' vm     7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A8DE505-0C78-4E90-85DD-165F404E0B30', 'FFC30295-021B-4941-9F8A-1EA1DE399E0A', '4260532450766', ' vm     7,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31D5A0FC-950C-4949-A021-2A49B5D29F99', 'B2BDC963-6EA5-4E19-BA05-92C3BD2687B4', '4260532453354', ' vm   /  s', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('775FC05A-6541-4F27-9DED-74C14ADA8BF2', 'CB06B643-7ABF-4A8B-A2D4-CB23F78B7280', '4260532453361', ' vm   /  m ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CD5F6F0-5412-499A-93D6-C5EE6E0D4997', '10D0F027-0A01-49CA-807E-F1520B68F782', '4260532453521', ' vm   /      l  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0333828-813B-4C07-8E0E-E4DF941ABDFC', 'E64951B9-3ED2-4BB6-BD31-62D18D4DF1E6', '4342040649723', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('821FF49C-B3E5-469D-9EA6-3CFD2F32C5FA', 'B35E25E1-62CB-40D4-9DFC-C08E327DB61C', '4424400000020', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB5653DF-11EE-44DE-B88D-2E23F0DBA5EC', '488360B5-DF1A-430C-8E41-7700B19EE728', '4573181300017', '  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5932788C-0ACD-451C-A4A8-3075594F4F9B', '66BD890E-9D78-4B1B-8A9D-B1958C3E2AE0', '4580198173060', ' -103  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B17645F4-3FFF-4B6F-A494-CC74E515865E', '597AE2ED-F4D6-4622-AB45-ADE9A24E9959', '4580198174128', ' A&D UA-100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2FC2C39-9FF9-45F0-B2AE-49CCA23AF7A0', '236DFFCC-1A9E-4CBD-8FAC-6F89942353A7', '4582174745889', '   - 42-47  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DD91C1A-D2C4-49E5-8C33-92A3084B0ED7', 'AEAE148D-4D18-4B2D-92AA-3C6FB11116C0', '4600053003179', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EB2BB2F-E683-4BBE-B54D-2046D4364EAF', 'D2AF3F39-4AB4-4D16-ACC1-9AA2222EE627', '4600053003995', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9C7ACF0-CD17-411F-85EC-D84BA70BBB98', 'A2E86FB5-534A-4277-AC20-CA27F62B31A6', '4600053006118', '  1% 3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CC03CBB-277C-414F-B36B-649D2155AD8F', 'D54E0678-93D1-4678-BD0F-93DAA01D0AA9', '4600053008310', ' 0,025%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('377750C2-030B-4B57-BBF6-6306B7E7A484', 'ECB5652A-53B5-4487-89DB-016723CE3BB3', '4600053020183', '  0,025% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE3270F6-7DF2-40A8-934C-B3F207B96083', 'E6125861-7E3E-4542-9C22-5B7A3B8BCA49', '4600053020206', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B544DB0-44EE-4C5D-8445-95552666DA09', '81CD2E1F-06F3-4E44-A6E7-8AF7ED382354', '4600053020343', '  1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B89F9B21-0EA4-4976-B454-3BBD9C9D7404', 'FA559073-C2D9-4261-8586-06642C957147', '4600053020381', ' 5%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D24B6D2-BCE2-4A42-A1B1-8BFA9E1DA327', 'EC55BDC1-362C-416A-BB2A-DEAE8ACE14A0', '4600053020428', ' 25  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC26C0A1-CD60-4302-9368-4710D1F3DE5C', 'BCDBBA44-A035-4761-A02C-72A6889D6D90', '4600053020565', ' 3 // 0,5% ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63EBC3E8-B52B-41AC-A647-67F75913EBFB', '4A816934-5C93-4B97-A241-EED43439BA77', '4600053020701', ' 1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4635485-7990-43C0-9CDE-7FFBB572681E', 'DA5CB872-D840-4A42-BED7-8F05CE3CCD4B', '4600053020749', ' 10%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E61A369A-7E3A-4A6D-8452-F2B885E75170', 'E5E761C0-19B3-4744-B006-9043D89462A2', '4600053021104', '  1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86412EC6-4581-451E-B14C-E521B43B250F', '750F97ED-81F6-4B2F-BDC0-ECF35E5331ED', '4600060920193', '    / 27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7054D1FE-6651-4D9D-87EA-B3B06943C7FB', '73C36723-D4AE-4EC4-AED2-B99723FC564F', '4600104006630', '   125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('558E89CF-782F-4062-8C19-C0E37F0351F7', '97D35D5D-D8D6-47E8-99E1-0E0060F6219D', '4600104021176', '      120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A5D664D-3C7F-426C-B1A0-B96DC199AD13', 'E68918E9-BD9E-46D9-8CB0-03DEE980A151', '4600104023163', '       125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('080FBF87-2083-43E0-A5CC-E9172CD0CB1F', 'B1DF9ED0-8E85-4773-AFD3-6AE16A5A17D9', '4600104030031', ' hypoallergenic -      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90D54828-BFD8-459A-ADD1-EBBB7D9F47C5', '0752BB36-0169-4C4B-B5EE-35393B6D48A7', '4600104031007', '       125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC62E357-8115-4AC3-AA21-8C99DDD51870', '3CF69DC1-6BF7-4FBA-851A-EA16673CF68C', '4600104031199', '      75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DBA12A7-191F-4FAF-91D3-02A3953082F5', '482FA216-EA3C-42E8-B9F3-FAD53BA9C93A', '4600104032172', 'Picnic    125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1AA82F9-86D9-4321-AFC7-1FE3770B68E3', 'E7F8CDEA-1587-40DB-B504-F3A613ECCED7', '4600104033445', '   / 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('621B07E3-5829-491D-8069-F117DB0011D9', '99801F9F-03A2-4084-91DB-D255C806BAC0', '4600104033506', '     150  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E6C2D36-B4BF-4A2F-B1C3-395154CB6D4B', '67CB11F3-33D2-4172-85E0-6D49CCF9CF11', '4600104033513', '   / / 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C7613B6-D267-45B4-A298-B190C2F44B04', 'C940F22C-B25A-4892-A547-1AF6EFBA9D7A', '4600104033544', '       40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1F611FB-062D-4DD3-8A92-285F0BEDF84C', 'AAED1194-0161-47D1-B755-BAEE091A622B', '4600171025503', '  145 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C3D31C8-DB2C-4485-BDDF-E975B494B6FC', '832DA668-B482-4AA2-B6E2-7987F62DEC4F', '4600171081509', '   145', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2C5C19B-145A-4641-874F-0F555F53C60E', 'AE65D57B-AEAF-424C-9A92-2C04208E0F2E', '4600171107483', '     145 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('103206E3-7F3E-4CC1-BBFA-D521160E2E28', '8E3F1843-8216-40D6-9D6D-9263E0948F98', '4600171126637', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C29A61A-DBB7-4D49-95B5-8A4EC3466C0C', 'B9B38355-A634-496C-B2DD-8FB3C74D633E', '4600171127634', '    / 3 /100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22095709-4528-4A6A-83FA-600F7E674171', '00FEF607-2594-4B8B-9065-EBB1B0B5FF24', '4600206000024', '   /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EFED955-3DDB-4D7B-B406-D7E9B74D46DC', '232FC91F-38C8-41FE-B325-09B137D22AB4', '4600206000123', '   /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AD4F5FE-A575-472D-81D0-CA04A3A8E4E1', '04DF16B6-A0A2-4FDF-B826-C82D16BECD53', '4600209003039', ' -1    /1205/ 350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4D6AFFC-B6A9-4B70-9733-853B17D6C51D', '0AD7333F-66D4-4104-AB94-EEBF0D724725', '4600209003077', '-2   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9046807-0639-476B-A082-6EBEAC2C2B69', 'C3D5B1C3-66E9-429E-8B30-BF2BAC1EFFA3', '4600209003152', '-3      12  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B02D9F7-B043-4E9B-8CF0-D052490A138F', 'C17036D7-5434-43A5-9723-8E0C06F9007E', '4600209004630', '     220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CB4AEAE-D4CC-406C-8641-1D985EC79EA8', '050BAE8B-4F29-4F3B-BD83-FC985B9EEDCC', '4600209004678', '  220      4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43FF5E2F-73A5-4244-AC67-FEE278B839E0', '76757E41-307E-4ECA-951A-B08EA06436FA', '4600209004715', '    220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('863BDECE-2416-4A00-B9B9-06DC04184F36', 'E9AFABA0-5323-4466-AB12-B9C21184435A', '4600209004739', '  220       6.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B83F7BE-B76D-44DF-821A-CA56E5FAE1A3', 'ED5E6DE4-2053-4050-B1BA-3E9A40B6703B', '4600209004753', '  220     6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38016E53-2B4A-4127-B2A4-C3267357423B', 'B880F5C1-5F90-4DC2-AAE1-C64917CD141B', '4600209005170', '-1   700', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6361CD11-A850-43E5-9B1C-0817D78B987B', '9DFBD959-0609-4ECD-B1D1-F08D583AAD30', '4600209005187', '-2   700', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E631D65-082E-499A-946F-7ED794D2FFE0', '544B0CAA-4613-4CA2-96BD-7D082F968FB1', '4600209006818', '   0-6  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9FB56B9-E5EA-44C5-BB9F-F4CA287005B5', '67CB0894-30AE-434D-BF6E-AC22DABDA456', '4600209006832', ' -2   6 350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D441846-35BF-40EE-BA2D-1A4F5164D9B5', '49E65257-932C-4D43-A4BB-F85B89B99C35', '4600209007655', '  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9956412E-BF0E-463B-B8FF-457F64DF6011', '1F166B13-C932-4BF3-9D29-E4EBCBAE06F1', '4600209007679', '  200    4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8DC9E77-CBAD-4815-A7EA-18A1AD6CD1D3', '7194D303-7C6A-4BEA-9309-F9098C2E1E08', '4600209007730', '    220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9ADD2F50-971B-49B2-B15D-025B4544BADB', 'B8AD6F9F-9A0B-42DE-9F43-EEE18A96F366', '4600209009987', '        6 220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D8F4EB6-EA50-41AB-8A39-4E21EF3F18E1', 'BA1D5BD4-A18B-4778-B124-EA88024FBD59', '4600209010006', '  220    5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('731104CD-DE15-4EC7-9FC7-141A4D7897EF', '3AC23E9F-2074-4247-AB53-32071842258C', '4600209010020', '     4  220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('632FAB21-6B53-4125-8FAD-4C63E9219180', 'DC2F8C03-424C-4E43-9FA2-BE44122DFF23', '4600209010105', '  / 5   6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42460ECE-7294-4F35-81E8-AF90A0B3118B', '1DF470AD-6D02-4BFF-8733-47FE028B4B4E', '4600209010532', '  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24481DC0-D50D-4A07-98B5-BAD82D5851F1', '47ECE106-1272-40BA-80F0-5D9BA84B3293', '4600209010556', '-2  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0AC4BF2-7A47-4AAB-A9AE-91EC544DDDCF', '0657C81B-FB16-4B25-91E2-2D31CF3D8816', '4600209010747', '-1    350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB0C013A-A1D3-41EF-94A2-18E0616A62FA', '8BA35331-9F72-4B7D-86BD-8D0DD4231496', '4600209010761', ' 2     350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('455BF5D3-8B87-41FE-BFDB-3CDCFF0A830F', 'B71F7E7B-F8D7-477C-970C-2F94A196A39A', '4600209011089', '-1   1200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22960138-B487-4BA7-9B03-9980AB620A44', 'BE80220F-7309-4AFE-9973-C222318855DA', '4600209011096', '-1   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E48EA7D5-E631-4BC1-A067-FBF0487111CB', '933D461E-A33F-4D75-8E3A-61B006805377', '4600209011102', '-1   600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11748309-6716-4494-9548-8E6077DD456A', 'B161D00A-CDE3-499E-A839-B797B2ED4219', '4600209011133', '-2   600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7FBFB52-786E-49E8-A9DC-517E662F0C4E', '17C64400-6E98-4B7B-B7EC-6970A551B85D', '4600209011188', '-1      600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B0BD36C-56B8-459F-9070-341C30C30901', '343E4024-C83A-4BAC-8A0F-6289D2C79FE3', '4600209011218', '-1      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A248F6C-3343-4AF3-903D-8E7C8F172C89', '12CD6032-9C73-4445-B338-9667350895A3', '4600209011256', '-2     6 600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF4C844B-042D-456F-8A61-52C3FD974027', '170857EA-F7BA-4AD7-94D2-C87CCD4306FA', '4600338000121', '   . 0.125*27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('732F089D-E6FE-46D4-A36A-CD0ED1C33043', 'C8E2D6D0-5338-48E0-A6C2-1C5EE878D404', '4600338000183', ' /  . 0.2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62C5F4EC-0896-49BD-80F0-90E8094AB7EE', '3EEA34DA-BC89-43BE-949F-618A0B9197A3', '4600338000190', ' /   . 0.2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71A92F92-6A5D-4F11-8F51-2752225BB67D', 'D76BC7EC-2CB5-4271-8BFB-F45F28C0A369', '4600338000206', '  200   . /.  4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF3AB010-3666-470F-8503-F5DE4A1AE5BA', '0D149552-77ED-47D6-91B8-1B6A752EFE50', '4600338000213', '  200    . ./.  5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7027C473-A2D1-4B75-B9CC-65AD2D6CBEC4', '82F8EF55-152C-4000-9D46-C28C68725D05', '4600338000220', ' /  / 0.2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B67020FF-D8CC-495B-9ABC-3BAC12E64C1B', 'D82E6266-2E9B-414B-AC5B-62A0BDEDEB96', '4600338000237', '      .200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C537B42-9183-42DF-B8E2-080424D0C075', 'FF90463D-41B0-4DBF-841A-1730B057EE77', '4600338000268', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F4906C8-EAC1-41E3-9F78-89D38AB05227', '864C38E1-61CE-4202-A933-28722CCEDC8C', '4600338000275', '       4  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC4A8892-E6CC-4CCB-BDC5-B75821DFD144', '366FBE1D-4C36-4384-94B8-056D0F2051D1', '4600338000282', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF820B1E-6BF9-4DC9-82B0-0CC837E7EE5D', '1036E453-D08B-4461-AD0F-E08D6427B93B', '4600338000299', '     5 . 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C08F5DCB-FF68-4E46-B742-92F021EAE419', '4F338928-AA62-401E-8AB6-4987BF18E1E7', '4600338000305', '      0.2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05A25489-E69C-430A-BB9D-98AF5D32939B', 'D69D9A4B-80E0-4EA6-A635-19CB2FEDDD4B', '4600338000329', '  500  ./. 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C64A869-846C-4ED9-8353-51FFA783B2AF', '0D209FA0-6660-4B89-AEDB-920FA3F7EC24', '4600338000428', '     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('996046D7-AE66-4E66-9088-EB66080C027D', '889878C7-5D68-40C6-B5CD-2DD44E4F840E', '4600338001487', '    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C890672-678B-484C-95CF-AA21A85BAE5C', '63C080FF-3AB5-41F1-8489-54E59230BD0F', '4600338001975', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BAABBF6-5C62-4163-A44E-0E98AAA309AE', '2AE9D941-F7A1-4B98-A955-F402DB88468F', '4600338001982', '  -     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15D43927-9E95-4942-B271-F474D24A9A5A', '8355518E-81C3-4FCF-8D21-9A502A05F5CB', '4600338002071', '       6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('828FE3B9-6038-4150-9107-939367F65F09', 'E07B9D95-C277-446B-9B67-F1E9BCC8AB72', '4600338002095', '      6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('231F42C5-D538-464F-ABCE-DB65FCDE20A7', '8737E90E-D6AC-49B0-B693-A6B67DD84EF0', '4600338002118', '      6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37D241E0-6809-4F8C-A887-EBFE38CF30E9', '5CE3A776-6808-42F3-8720-8C575FB9023F', '4600338002439', '    / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94F63BE1-D810-4B2E-9247-3A220C74FBCD', '2F30A9B8-4FB1-4916-B8FD-E06680AE5E00', '4600338002446', ' / /   0.5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C96368A-4674-40FD-A7CF-72A538B3A3AB', 'C727B3CE-42FE-48FA-84F9-A86BEA7F5F2A', '4600338002460', ' / / 0.5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7995EEC-3381-42BF-AE50-55D66188265B', 'F7B4E044-FA78-4A1B-BCB0-F25802543B8D', '4600338002484', ' /  . 0.5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50D80E8B-1D63-49DE-B7A2-49ED57AC552B', 'C9F36234-BF8A-4CF9-9CD6-88E4C088D6F8', '4600338002491', '    / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('803C3B39-FB90-4314-96F8-F9379612A20B', '16C70252-0B10-4F88-BCA9-B84C6EFDA397', '4600338002514', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C260CA50-5E11-4E7F-8A83-F05916CD5C59', 'B698F4C3-4924-49CE-B9D9-2438C81574B0', '4600338002521', '     . 3 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77A953F1-E843-4143-8E9C-2A43B612F72A', '5ACA525C-A98C-40CA-B810-0B7DB1F337CE', '4600338002781', '  5    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C4FB053-B513-452B-AC03-F370396EB369', '6FDB9B0F-3BCD-414F-9083-A9EAC0009B82', '4600338002989', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CD5FEBF-4E07-42CE-9415-2558FB36E194', 'FE007C6E-E373-4FC2-B7D7-A2A8C7FE95B1', '4600338002996', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3EF661C-6D9D-4361-853E-888C2AE6BBD0', 'A1034838-644A-481F-95DA-5248C8FDADAD', '4600338003320', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1541DDA2-FA69-45EF-8DCF-8BCC6B14C9EA', 'BBF5C903-802F-4BA3-979E-B1B4AF4A81FF', '4600338003405', '  / 0.125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A085549C-B813-42CE-B436-2AA42B87BF11', '501429CF-9EAA-4500-9D5B-F25DA02FBBE9', '4600338003771', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDD9343B-158E-4000-A1D3-26D187411A83', 'F3BF1B5D-5A84-4369-A0E6-59A34742C96D', '4600338003863', '      5 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7528CE77-DD14-4F62-9A68-D477F41402F8', 'B5C7B551-1106-4264-B31E-6813BB7E3AB2', '4600338003924', '      200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC321A0A-BAAB-48B6-A448-231637ABE975', '1FBA47B7-C6AF-4073-A9BB-109BD2682188', '4600338004242', '  250    .  .  6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('131EEE35-FC3C-43C5-8F6B-EBFB181C68FF', '75A86045-62E4-440B-9E8B-E1AF3D94C20A', '4600338004280', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDF9D917-444F-4B4A-A3E1-0A736F2FD4D1', 'A740349A-475E-4FA3-A1E2-4AF6975DE90B', '4600338004471', '      6  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D7675A8-4DB8-4374-8B00-CB546229A426', '1D29F1F7-1B5B-46A7-BA3A-2B14B3610377', '4600338004488', '  80   6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('438BE935-B29A-4AF8-9E73-D2501E057CA5', '3AA4E787-8309-47C3-80F1-108F5F265BFD', '4600338004495', '     6 . 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2461E75-6AC8-4256-80EC-10C0E496A8FC', '6CB7018C-D623-410B-898E-5B896C1A9A94', '4600338004518', '  80   6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('324A708A-606B-4AF6-B5F8-EBF631CA6DCA', 'BD826FE8-A70E-4871-A84F-27BEE135B01E', '4600338004525', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F098BB5-EBAF-40B5-866C-7817F84AD58C', 'E9676934-696A-48AE-9790-75AD4A62B1BD', '4600338004617', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E060F32-0D72-4BE5-92FA-B0E74B121B0E', 'F6C3D46E-E1BB-4DC2-9505-7F2760AF15D5', '4600338004631', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BA6092A-3DA7-469E-A687-ED0450678F71', 'B0D613AE-0DEA-4DB2-9165-2F3E34F9CBB6', '4600338004648', '        8 . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D202D984-DC1F-4E44-8164-15FC98F9A9A6', 'B2764458-8254-430B-A722-EF825907330E', '4600338004686', '   110', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E42A088C-A9A6-445A-9D42-E68559A1F001', '8BB8C7E9-15A9-4AD7-8FC9-052014FF047F', '4600338004839', '     6 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB7F1C49-FFF6-4E1B-A5B6-8536599749EA', '5C409259-1F39-4FF8-BC7E-3E429F47DB5B', '4600338004884', '    4  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C26FB43-D558-4BB3-8C06-231D856DAABF', '72BC38DB-7500-475E-9DD6-90EFFFF18A99', '4600338004891', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFE51B43-E998-4151-B6DF-C115731E3078', 'F3BF1B5D-5A84-4369-A0E6-59A34742C96D', '4600338004921', '      5 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36A73BCA-2207-4075-95F8-C411EB1FEE9B', '7DCFA670-843E-48C2-96E0-B3965C6C670C', '4600338004938', '      80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDABC38F-6121-4496-BFBF-0EE00BE25FA2', '43155031-625F-4649-8F9A-49E01896949B', '4600338004945', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5461789F-3BF3-4CCC-920A-C692EC9F0C0F', '42600964-DF3E-4D5F-B9ED-70D3F5E77FB8', '4600338004952', '   105', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04658424-1CB6-4992-B99F-6B3BE5B07FBF', 'F7F69C1F-A9CB-4BB7-AE44-14BBAFD926C4', '4600338004969', '     5+80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBCEA384-3D09-4932-B156-4EBEE33195A8', 'DC28F4B5-26B9-4D7E-8605-3762E30AA374', '4600338005201', '  250    .  .  6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5745E0D-3BCF-4199-98DB-27F35A1CAC40', '7CDD3072-A60E-4471-8F74-95A8D5472C55', '4600338005225', '  / 200 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86726051-BBC3-4E59-8535-4C9EA99C866B', '910521C5-B47D-4824-892B-B55F81301173', '4600338005553', '     100 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38BE6DCA-F375-4344-8029-B5630BD83CB1', '9EEAD798-EA20-44BD-A863-1639734A68D2', '4600338005560', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA75E4BD-6230-46C4-8543-1BD5982782A5', '3756A418-1A59-4984-BCDE-8D7F8F162EF1', '4600338005577', '  100     6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AE19E52-44C8-40FA-939C-5EAA29E5085C', '3641ACB1-2C69-4D36-BF65-F6996AC99B2A', '4600338005607', '  100    4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F764F264-8F07-48BD-8D20-BECDC94BA89D', 'A208C7B6-B93A-45B3-8255-78B20DA44C68', '4600338005614', '  100    .  5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E99E361-71FF-4450-9D89-42CDCA3BAC10', '6FED36E3-6854-422C-A350-BA6AAC699A24', '4600338005621', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('407D38DE-8625-467C-B0B8-0CA352713080', '2DEA7BBE-E55E-4156-88E2-78C293C32230', '4600338005638', '   .  6  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('416B1BC6-002B-4B23-9308-571D9524F731', '2A1FD942-AFAF-444E-BB93-64F6D801E046', '4600338005652', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2752832-AF86-4DA0-AB2E-A505A1FF7A60', '501429CF-9EAA-4500-9D5B-F25DA02FBBE9', '4600338005669', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3D59CE9-CF2B-48E1-8F56-18D9AEC7004A', '485ED28F-7537-4B06-AA18-56466773F6C4', '4600338005676', '   . .  5 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('205295F9-23CD-4CE8-BD0F-BF2E30138516', '5BD5EDBD-844C-4895-86FC-538563E88DBA', '4600338005683', '  100  .  4.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0708D74A-DFC2-4323-B180-687316148EF7', 'B2764458-8254-430B-A722-EF825907330E', '4600338005690', '   110', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA34B324-A6F3-4A6E-9820-BB42639D169A', '66FEBA90-636F-40AF-93F8-391CBE561ABD', '4600338005706', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B9559E0-2FA0-4DBA-A5CB-A1634965F2DE', '10BE0C37-E807-43F8-AD54-2DD0ADFF1BBA', '4600338006086', '   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E18C8D20-FA4A-4F6F-A7A6-A1C0411C4AD1', 'DF335E61-1F23-458D-8FBC-B9487258C8A0', '4600338006109', '    1  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66EE4C16-C3AD-4ACF-BB42-419D569C6245', '63AB1EAC-3D71-4F37-9965-A760DC432BD1', '4600338006116', '   125  -.  6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBF0F182-9B2F-40F5-8D38-4991FC006133', '1919745E-C938-4365-A5B0-FEC84BFC8C7E', '4600338006130', '    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52F9BE45-80EB-4296-ABB4-C171E8E03020', '9C6BA155-DC60-402F-BFBA-B4E01B54B33D', '4600338006147', '  90    4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1270E4EA-249B-45DB-80F8-35F24EDE942C', '217BCABA-B823-4EE8-ABF9-3F793462F80A', '4600338006154', '   /   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93322775-4BC2-487F-B68C-535962477A2D', '567012C7-F1B0-473A-AE47-A8B8E7FFAB8C', '4600338006161', '     90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1D2D7EE-8263-4CB9-B6B3-2ED70A45627E', '66FEBA90-636F-40AF-93F8-391CBE561ABD', '4600338006185', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3ACA30A-15A5-4FD5-9D57-499B114402A9', 'CF92616B-34BF-44DA-8E34-25C3C9E27D97', '4600338006222', '  200   .  6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADB99F2D-DE8F-4F29-8C31-12EB49268BAA', '8456C8AD-7D6A-47AF-A0F7-5A371B114136', '4600338006239', '    .  5  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95234A8F-B496-4280-BCAD-6C198DBFE83E', 'B09416FA-7813-43C4-BF92-01AEEF52981A', '4600338006246', '    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDC661B5-93DA-4E83-A60D-5E5ED369A2AB', '158F22B8-F86B-446D-807A-736404F3CC21', '4600338006253', '  / 500 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F61F5B59-54AC-423B-925D-D8A2E006A03A', '8A15C41B-C531-4A8B-A1F0-F9DBFFDD8914', '4600338006260', '   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98C705C5-52B7-44FC-97B6-BF8901B0276C', '1BF77F19-B48A-449F-9743-6D02E49AD0AF', '4600338006277', ' / // 0.2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4E0BE01-9CD1-4CD8-BD25-1BB9C1B0175C', 'BFE885E8-9EB2-4FFE-9056-CF291D0AD616', '4600338006284', '     200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD01FEDB-241E-4A97-96EF-55A8816B5ABD', '5884C7A1-79D6-47F2-ABA8-36506A044163', '4600338006307', '  / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('773DE197-D4C4-4F58-96F0-9EB4DF325E99', '31E298A3-E876-4E22-AB47-EC6125505038', '4600338006345', '  // 500 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA0C7EB0-5A95-4B93-8BD5-E01B8728B541', 'CF07EC3F-45F2-4F51-88CB-E4FBC452EBCB', '4600338006475', '     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA0A5255-18A0-4B07-BEF0-216FE25E40AE', '7A0C2973-8364-434E-8659-0090A7C2E4FB', '4600338006574', '  /  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19347FCC-686D-41D7-BAED-B6BE74DA4A53', 'DC444AA2-1A61-4856-9F2E-3C39625CE44B', '4600338006604', '  90      6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAD6C1F0-6080-474A-ADC4-688A267BA6BA', 'E536E2BD-520F-405C-8E66-115B5364F6FC', '4600338006611', '     90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D549A5DE-A2F5-4B84-A803-7B22C5B1F19F', '2465008C-9B2A-4077-BD22-B9A2F170E3ED', '4600338006628', '     / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F3CC5D2-8724-4470-829B-54A42CC5DE05', 'A6CBD309-5852-4B4D-8B4D-C7120920F1D1', '4600338006635', '  500   . /  3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65EBAE35-2DA0-456B-AED4-6496B72238C6', '6DB81D75-CEDA-4C88-B4D6-A4EDC62D6E5D', '4600338006642', '      4  330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD21F5AA-F399-4426-88BB-00F1A1660FDB', '5035ACD8-EC3F-466E-AF36-A275DB2F0ECA', '4600338006673', '    330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D8E35E8-26B3-4118-9FBE-1FFB371E1D40', '32193B0F-B290-4F35-A018-6FCA8120DF08', '4600338006680', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D426817-37FF-46B3-8B37-AA4CF243D80C', '888A1E11-3750-40F4-9A38-F66CA68307D2', '4600338006727', '  80   4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61F1B1E0-2053-42D7-A860-ADB3C8B0BE99', 'FD60561D-C5D5-49A5-8BB2-CA98FEE06DC4', '4600338006826', '   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F844D43-9DBD-45B8-86B3-46B3E295ACBB', '56FB6107-FD01-4F8C-B0B0-AA0C89169D44', '4600338006871', '  200      5  .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('343DA01E-AFF1-4C73-A192-7832AEF3DB96', '5E9E1C12-3FD6-4FCD-8ED1-BF7C7A1E89CD', '4600338006895', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAB63E89-4B1F-4B93-865F-670636494C64', '388C343B-5F77-44D7-88E9-56A0774B3FC1', '4600338006918', '  / /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD5D2261-D50B-4BAE-8187-2C6AC8F4D668', '20B06D9D-A2AA-4B72-B6DF-FD16B2EAFB19', '4600338007069', '       5 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA75C29E-6165-49BC-BB6C-31C711383DC8', 'CD656790-5EF5-4AFD-8A6D-A85DFB29F30C', '4600338007076', '   , ,  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('676B51BB-B600-4DEF-AEAC-822B1C5C824E', 'BA56446E-2C60-47F3-9A91-64BE61608B33', '4600338007090', '       7  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F3D392B-F448-4263-816A-0CEAB0583550', '85410717-DA82-4317-83CB-A1712AE90466', '4600338007113', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB11A0CC-D28B-453F-B2E4-6C752E64BCC3', '220BF277-C7ED-4428-BC87-154EBA90CD3D', '4600338007120', '    . 0.2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAABEF8E-6D8A-49AD-BAC8-1FBDADEEA2FD', 'B371125E-D86B-4B51-8B1D-EE91C7A60BDF', '4600338007137', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60878CA5-11D7-40D7-A2A7-1728EA65841D', 'FC374061-2DAE-435C-8A97-A2E91CE6BA97', '4600338007182', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A605F755-6DAD-4F15-AD9F-D9EDD69CAC6F', '378C3847-F37C-45CC-86F5-89735D529EE4', '4600338007205', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10877EC1-2FA7-42AB-AB3A-FB34D0BFC417', 'BDDE38E6-35F3-4902-8CBA-A39B4716C071', '4600338007212', '   / 0,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9580856-AE0C-4A59-8B4C-AA3EC9F2159B', '62BD9DB3-507A-4A3F-BD21-D40E56427FD9', '4600338007243', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F98679F8-C711-463C-B146-AD5DD9270CB3', '2FD9FDCE-E869-4850-B74C-E4DCA209FC0E', '4600338007250', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B303147-1C87-4E0C-9BFC-5891CD83B6EE', '95CCC4AD-B36D-42A5-882D-04F018B245D6', '4600338007274', '  / 0.125*27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34ED8EF7-E7A7-4706-86BC-3F5AA087447A', '57E0D4AE-D305-4D56-B71E-676B852CBE66', '4600338007281', '   0,33  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECD928DE-9D8C-4BE4-A437-87D9C65C90DB', 'AFB93087-6897-4037-A7AD-9D69279A0A50', '4600338007328', '   100    4.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93897F7D-86B3-4F84-835E-CB64A2565A89', '84323DDC-8C29-43C4-90A4-7441CBACDB67', '4600338007359', '    . 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D482C01-D361-4F6B-B8AA-E95C7A54DAF4', '1271E729-22D2-4960-B1CB-B23014C7E036', '4600338007366', '   /. 0,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('355A9AF0-B4A4-49D5-B87F-C254BA57244A', '239ACA7A-2DEE-4758-8469-15C7820771D7', '4600338007397', '    5   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDB9C50D-2DCE-4EB4-A3D7-293B014DCAE9', '44C272D2-691A-44CB-81FA-376E7C16984D', '4600338007403', '    5   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('444A146B-D4AA-49AB-B97B-48C9B5716A66', '82AF35B4-128A-4761-86D8-BBEC783681BA', '4600338007410', '  -     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E46EB454-4A37-4FEA-9170-75BA9EB49189', '134450AB-A98D-4EF4-86BB-CE32BAD9D588', '4600338007427', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AE05D2C-C4DF-4EEE-AB6B-8181C0A1DED6', '1EE67648-03D8-4E26-BF43-C445CD271AF2', '4600338007489', '   125    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED3B33E0-6A0C-4280-AE8D-15CFDC940FE2', '2CBCE5CC-3CB7-413C-91B5-BCC0672FCE62', '4600338007557', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFF3DC13-000F-43AB-8EA6-B431517A8109', '30A8483D-CB24-4A12-B299-01DE4A456933', '4600338007564', ' /  0.2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76D6448D-D6C6-460D-99DD-E7874E3B6690', 'ECE6F1BD-CF82-45B5-A2ED-39212FCFF545', '4600338007571', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60E345C5-A86A-44AC-941B-AEA74762D5D3', '3182691F-3161-40BD-BD5C-608A7A61087F', '4600338007588', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FAB2458-C473-43CF-80C6-BB2E55978A8E', '115245F5-3622-455A-A6C5-2AC96945F623', '4600338007663', '  100   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76C0153C-DF93-45DD-ABF2-B8644A587B36', 'EB0C63FA-87A0-4200-8819-13881392CE06', '4600338007670', '  100     8.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('429FBC72-DB5C-446B-919D-1607C2D3078F', 'F5C0E1A6-463C-4304-A018-D10E0CCB4FA9', '4600338007687', '  100     8.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5F34BD6-BC92-41EC-82AF-BDDD43B53F37', 'AD72258B-5297-4F41-8310-1151C5C51000', '4600338007700', '  90     .  6.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('550F94BD-A106-47E7-B1EB-7F740368BB0F', '03877355-1B8F-493A-BEB7-C555025CCA03', '4600338007717', '   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98BB0F7B-D156-4F5B-AB2D-173BD1D799FD', '2EEA556E-1723-4E8D-926C-302F1FB268CF', '4600338007724', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC98FE13-6F0C-4036-BA8D-B1E0BEB706CC', '00C5FE0F-1FF4-4650-B79E-D97103985CB8', '4600338007731', '  100    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1341E8D1-605B-4448-8650-5AADC9965A74', 'CFBE1C36-7991-4F30-A8CE-11A80AD35F7F', '4600338007779', '    . 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF364120-C912-4398-A7A7-320D0353F1A2', '0F48F357-ECAC-453B-B10E-835662D961F5', '4600338007786', '     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB0C19E4-9964-4089-9C5C-4D21B3E305D5', '6E3D4252-4CE6-454E-A431-18FDA17227FF', '4600338007809', '      500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C0D7F5F-E839-450F-A188-67181B3925F5', '4980C3F3-3E44-4C57-B24E-3BE21CDBF097', '4600338007847', '  80   ."  "  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD9D0B24-0D9A-4E02-9652-729BD7FD372C', '2E88AEA7-29B9-4752-A944-CAF5D2B478C3', '4600338007854', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D17427A3-00F3-45D3-9B0B-35EC59BB1B08', '25D9EFD3-1E11-43D6-98E8-B68B81305BDC', '4600338007861', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEA745DB-F3D8-4669-8A93-7CE1FA613359', '8697B944-3B10-436A-954D-83E9861E7150', '4600338007892', '  100    6.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A79C7EE8-AC49-469D-B9EE-8C1D91251173', '3EC9EAE7-349B-4BC9-A51B-BF718200F203', '4600338007915', '  100     6.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97E36DAC-1031-4704-AA01-201E7A3D2505', 'BF56D0B2-3482-4FF9-94C8-202BC8EFEF90', '4600338008011', '       130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A76C20C-2CD1-4A37-A66D-F0A7E23472AC', 'F4D0359B-14C8-4D55-B3CF-352421D9F432', '4600338008028', '   //   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('702DE251-65C3-4950-A7E4-75D081DB8B0D', '89861F34-6546-4C8E-B09D-F957EE23833B', '4600338008103', '   /. 0.2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFC44C4B-94C3-4CC3-B988-49B4ECADCF60', '19AE586D-E9F2-4CA5-A372-EE8C57127440', '4600338008110', '    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E68871A7-B58F-4038-920C-13F7DE123957', '0F73BA27-DDE5-4872-ABB9-75EF9246C6FD', '4600338008226', '          6+ 130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29DC32D3-13BF-4B35-9AA8-0BA9272C10EB', 'B785FD2A-0A0A-41DC-BC75-2389A68838EE', '4600338008233', '    . 130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97536C87-563F-4743-A0CA-26122F56409D', 'B8FF1054-A5D3-424E-8DF1-D4505ECB36B6', '4600338008356', '   - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96F4EA72-A88D-48E4-A93A-7D91B0F5EF54', '5D3350A8-F4CE-4458-ABE1-42B90390D6E3', '4600338008417', '  //   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77DC5D0E-FC88-496C-B23E-4C93D8F33BD9', '7848B990-63B0-448C-B091-9156EA30E2D1', '4600338008448', '  /   250*12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E40F59D7-DC23-4A28-B30A-2132E4B1CB5F', 'A7A085D7-B8DE-415B-9DA0-C491C9C1B48D', '4600338008462', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56E9E3AD-1399-485E-AC9F-1DD905AAC966', '116D5E27-3D4A-4146-9CC4-B41F1CCF50C7', '4600338008479', '   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EA9405B-0FCD-4B44-B95B-6875F951E43D', 'C08E98EB-00E6-4A25-9B5E-1009C39B21D9', '4600338008493', '       6+ 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F84469B-1803-47C5-B440-4D585CEE862F', '4E20FF3A-A2C9-4022-A8B5-E392BBC1D390', '4600416002412', '-  - 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C873BB9-EA9A-4858-8608-563328E0666D', 'F0BDBCC3-C3F2-4C9A-9174-A22176EBE9F0', '4600416002597', ' -       /  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99106676-2092-4FC6-8CBF-D53156F78481', '414C394A-18AB-41AB-BEF8-6810E72464B6', '4600416002603', ' -   / 24/ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('548E9B30-4C5E-47F1-BAEA-2709433D76D0', 'FA55DB2B-7615-401D-8568-0FBFFA17ADB6', '4600416002610', ' -   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('199452D2-37A1-4896-8B24-CCFA53290892', '94EC89D0-C9BC-4872-9DB9-0F4E679A2BE9', '4600416002764', ' -    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38F5E2A0-1602-4EF5-8DB4-21FFE46F0D00', 'A0C9BFD4-9327-435D-A57D-F9A4FC265017', '4600416002832', ' -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E3469DA-4798-43ED-A14F-85D52A4C4F9C', '354FAED1-F39E-437C-9B15-902F1ED167CA', '4600416002856', ' -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A18156E0-84D8-45FB-8785-0E896C7BA913', '6C5F014A-AC27-41D1-AB5F-ACADB503FABC', '4600416002870', ' -    /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E500DF9-E00F-466D-A496-6042A9BA70EC', 'FEFE0B91-7F70-43E6-9DD4-03370159665A', '4600416003358', '-   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('882C0DEE-0352-434E-BF8C-7C4F123F5A8E', 'BAF7960F-21C8-4CFE-9F71-C0009F1048B5', '4600416003471', '-     / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CD13C3D-4728-4FB0-9E3E-AD02D32EA1E8', '379A4EB7-CB80-4DA9-BA0E-06C6CD53409C', '4600416003532', ' -   .   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0611F601-4A74-477B-9FBC-7699E705E236', '837138D4-CE07-40B3-A7BF-41EADAAAC326', '4600416005345', '-     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C33B7EED-824B-4347-8DEE-422D098933AB', '46D412ED-D1E8-4CDC-95EC-2FCB227ADE03', '4600416005369', '-    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AED2D706-8996-4E49-A2AD-51D28CE3A546', '394AAF3E-3857-4E7E-B8B6-9C17C8D3BE5D', '4600416005529', '       11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5079B0B5-513D-4921-A007-4C8F310DA066', '8511F66E-2A90-41D5-B1DE-3A8326B69AA4', '4600416005826', ' -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('951C6DD1-EA1C-447C-9384-3C8DA185B080', '23295BC8-C34F-4FDA-B375-185BCDB12FC0', '4600416008643', ' -  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6605E812-846C-4ADE-9F80-BF0809A94B0A', '4DF4D6DF-9BD4-4101-97AC-DBDE800C9722', '4600416011889', ' -       / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AA382F3-43A2-48C3-8A03-FEB4ABB49712', 'F0BDBCC3-C3F2-4C9A-9174-A22176EBE9F0', '4600416015184', ' -       /  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32C6DBD0-91EF-465A-8058-C6B7EFCC92B1', 'E383E140-B3D9-4792-AC73-F3CF52671116', '4600416015887', '   /,,/3,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AF71324-1FF0-4A58-B5D7-14A7E33FABFA', 'FED2E8A6-7215-47C3-B512-82CE6B10DC88', '4600416017058', '       32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65E1A261-854D-4825-A43A-8EE6AAF78F57', '9352D722-D2BE-466B-B64B-FE1C00925400', '4600416017072', '       32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54420A16-B93F-4AAE-8A59-6F8E1CF29BE8', '9CBCFFF5-69B9-4D46-9FDE-DD16FD5441FF', '4600416017348', '        30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E19261BF-D5EE-41C2-98D8-492F75CC593A', '2FF532BF-9394-46E0-A90C-E230FE062F04', '4600416017362', '   35 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5907CC89-2D2E-4995-B198-9B5F31F8550B', 'AAEF5894-4424-49A6-88D9-E3D25B144914', '4600416017669', '  +  . 3,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9630A519-552E-4C87-8AB0-2104238E0BBD', '90C261D5-7703-4551-83AF-DF9E746639BF', '4600416017683', '  / / 35 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5748D9CC-83BE-4144-885F-86F1068705B4', '01C12384-964D-42D0-9618-D6E73AD69A80', '4600416017751', '    35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAD8DAE9-9D9B-4696-9D56-0B640C6008BB', '2F027C9A-C3BC-489C-89C4-D977826C3F56', '4600416017959', '       11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99F5F348-EEF9-4D9E-88BD-33871E0512EC', '73294950-D317-4862-9DD7-C30C1B74DB3B', '4600416017973', '       11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36019669-BE67-4423-A903-394F6BD7BA0A', '394AAF3E-3857-4E7E-B8B6-9C17C8D3BE5D', '4600416017997', '       11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C487625-AA47-4CA2-A138-668663D8B38D', '5E840910-9FFB-4E96-AD34-0E885D283CAF', '4600488000378', ' 10% - / 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1F75BB8-BF55-434C-B62D-272E989D85B6', 'B85083B9-9D92-4EB3-9AB2-296CEB1BFD1C', '4600488002679', '   1/  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E20534AF-4875-4172-B8CA-8DB811031065', '97423392-A434-4937-A5AC-F9A143B3D4B4', '4600488002686', '   1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC8548A8-51F2-4B2A-AC65-FC1B361A1FE7', '311CEBC3-1086-4AC9-A3B7-42C32798720B', '4600488002785', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D760FE7-C7C9-408C-B458-7D3CE1A02B3B', 'ABF3EB33-C79C-42DD-9310-8C398B42D6E7', '4600488003003', ' 0,05  /- /+- /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8762C3AC-6087-4E49-B915-E6D3F57E5DC5', 'F1C62050-5F58-4872-9360-6AF6583D1049', '4600488003324', ' 0,1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8AE1352-13A0-413C-8454-CD2526E4A5A7', 'F1C62050-5F58-4872-9360-6AF6583D1049', '4600488003331', ' 0,1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9560F5D-D1C8-45B0-B540-923F283F9CC0', 'C90220A2-2065-48AF-9CA6-13C39F2AC71C', '4600488003348', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A7E7F9A-8EA9-4A14-BCDB-FF5A59DF70DC', '89733BE3-38DC-45C9-B412-36119F9B7643', '4600488003393', '   20 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ACF1FF5-2AD4-4911-8A2E-7CA92CAE850F', 'C62B21B2-FC9E-4B11-ACA8-7E49AA173ED1', '4600488003416', '   20 4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F83F89B-8F40-4CCA-BD9B-6FDE54C71E87', '732D6AED-2EC3-4755-B18D-178351201054', '4600490612071', '.   0-12  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54F9A0AA-5CBE-45A4-BC85-A71EB959DB43', 'EE9EA180-5409-4A18-B6FC-B475F28AEC08', '4600490613665', '    350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C474AF4E-6616-4C02-B536-BC9C9480760D', '3DB92DB9-261C-47CF-A266-872DDB21FFC2', '4600490615461', '  320', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EB54A38-A5E0-4E58-9468-457B9A86F92A', '89C83CA2-2275-47EE-A197-4B7859BD16AB', '4600490618042', ' 0-6  350 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1F2D7E6-3F4F-40CA-BFF0-884AE8E63FF2', 'AF7313E1-EF8B-4598-A27D-840F95297DA4', '4600490618080', '   2 6-12  350.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98B640A0-EC64-4821-966B-86B87E8DDDFB', '4B0EB8FD-2578-4A58-ABD0-3568BB0C5869', '4600490618141', '  Premium   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42CB4B46-95C7-4C8C-9E0F-A9F40517636F', '8025453A-F0B7-421E-9BA9-08C660BE6AA1', '4600490618165', '    350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BD3D58E-3452-437D-8751-2983D47B45CB', '3623E962-3578-42D7-8B8D-7BABBAB01065', '4600490618240', ' 0-12  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E66A82E-51D3-4BF4-BB36-0C7CD05409FB', '09716D04-301F-4C4E-B429-8626991B9E8B', '4600490618264', ' /  / / 360', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED743015-68D1-411A-BA35-9CCBD36E3084', 'E933023B-B7B7-464B-8264-2C13D9909882', '4600490618288', '.   /   360', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B733D98A-76C4-4F31-BE6F-DBE77F8677EA', '5D24AA28-55D2-4303-8497-8ECFA312F772', '4600490618325', '     350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EC2BE10-CAE2-486B-9C7B-5BAB5B8C667E', '6F4F618D-2C84-454F-9B47-2D64D073F291', '4600490618622', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC84CE3C-2AC2-46CF-A953-B17D07A4DFBE', '443009B2-9D67-499E-AE97-AA713CDE8CFC', '4600490618714', '  -2   6-  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31F49080-0855-47EC-BC10-63FC9E0DFB77', 'AF506DB7-2FF6-404E-8D0D-A81D6A5E3058', '4600490620151', '.   3  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('330D316C-7D53-477D-BD79-860B7C63CA6C', '5B18476E-FF35-48B0-BC5C-4267E0402509', '4600490620182', '    0-12. 350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A8916DD-4116-4970-87AA-DDA4E5928AE0', '9EC2A527-7E6F-4E11-919C-E25ED83943AF', '4600490620199', '   0-6 350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC555D86-1E37-47D1-A5E9-77FAE676B630', 'B8E6F8F8-51BF-44A4-9946-B7DDCBE0C321', '4600490620205', '  6-12  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABCD911B-0B19-40AE-AFBC-136B0DEC64B1', 'DD9AF179-BA64-41C3-A6B6-E58CF7EFDDC1', '4600490620212', '  3   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86588290-9CF6-43A0-A7F1-8D47AA4A7D21', 'AFD41E3B-DD9A-46BA-9113-4FE9FB79A7DE', '4600490620311', '  /  360', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C5DDD37-C01E-46EF-9D86-F294EA7F04F9', '3242599D-80AE-4D46-9B95-58CA5CCBF5C3', '4600490620373', '   /     350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B974ABDD-A3A5-4910-A170-5F71A3F1DA11', 'BB30A01B-014A-45F3-B0A0-33047C6B8534', '4600490620458', '  3  12-     600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49208A52-EF19-49E3-B5FB-D42266F54FB3', '6A8EE309-505C-4464-A66E-8C5C3797B05E', '4600536001005', '   0,33 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE08D124-C048-4039-9FFD-5E6EE40E995D', 'D25E8A5E-E7D2-470F-906D-A65CA9362D76', '4600536003009', '   0,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75AAABC8-88AF-4348-A4B9-27B62A2637F5', 'D25E8A5E-E7D2-470F-906D-A65CA9362D76', '4600536003108', '   0,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B872527-A2A7-4BFF-8705-6FB4D1034517', '6635C010-E7DA-4C92-A848-54DE9199B0A4', '4600536004006', '   1 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('746F5AB6-113E-4645-95E9-3503809CA837', '8D059505-1963-4005-828C-58D3AA9EEC3B', '4600536004105', '   1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66A5B802-BE78-41BD-BE61-6F1502EC750C', 'C1F76AC3-E852-48AB-B1CA-C9223D8DC209', '4600536013008', '   0,33 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9C9BE1A-6CFC-4A81-A26C-4DCB5C15AB8E', '0D1A48BE-F33A-4791-949A-7DB95D45E9F6', '4600536181004', '   / 1,8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BD32C23-A772-4C23-A6C4-6411160A544A', 'DCD52980-9B79-4A50-A5EA-20BB638D9D63', '4600536500010', '   / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A580D183-FF74-4985-8E68-C2D6680D4739', '2F53AE24-BD4C-4EEF-87E1-B512EB21D2F2', '4600536500027', '    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('251077BA-C6B7-4F93-879F-4ACFB940BCF0', 'EB3EEABE-8F3D-49CA-819F-B5AEDA889E53', '4600561000127', ' 5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('841E5F05-A2C0-405C-B021-329B8A5313EA', '2140A2A9-5CC0-4CA6-A937-2EDAF5CDF289', '4600561000134', '  5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1917077-ED95-4278-BD0D-9D59DB36FA62', '46F2948E-B972-4090-933B-2E0C15A82C51', '4600561020019', ' 5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53D5173C-BA26-4D8F-9D13-CE5A6C9CDE5D', '00AEBAE2-C3F0-4257-BB56-490CE01BA38C', '4600561021030', '  5   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8ECB70D-6EFE-4B51-BCAE-96F54874E3A2', 'B5923105-6E06-4001-A890-68D50057F063', '4600561021139', ' 5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9241BE2-BCB9-4F58-88AD-1634B938270B', '26EDF895-54AB-471A-8F23-0AD399613360', '4600561030483', ' 5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54B19414-70F3-46EC-AAB2-C8448C63AA06', 'A714D771-0E70-492D-9B02-A00FB4EEB477', '4600561030506', '  5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94BB1ABD-BC95-43FB-9B98-2E924B884330', '2ADA5F9D-5AC6-472F-86F4-CD64040FCC25', '4600561030650', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CCA8524-71BF-478F-87C4-D455B5FDA32E', '6DD9F796-88EB-4F4C-9D7F-FC78EB4FE846', '4600561030674', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCB2EB4F-64F7-4D93-98EC-544951638FB0', 'EB803A25-21CA-4755-B6C9-768113B878DF', '4600665000016', '   / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAD35B75-8489-4D49-95A5-61D13881ED07', '8352A103-57CD-4070-AC17-59FC227CF1E8', '4600665000023', '    . / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E888373-3EBC-4C9B-9A41-C65C048471DC', '328D37D8-0E69-46C7-904B-A059C5B089BE', '4600665000030', '   / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98479098-ED16-4F10-9015-3C171D8E7492', '65DF103F-7420-4A6D-A405-01804EF3598B', '4600665000047', ' 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48795130-EF86-4B69-B167-C06836E24ADA', 'D579F032-C1D9-4D65-B0C6-6D5182B1BA74', '4600665000054', '   . . / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('188BD0B0-873A-494E-9831-44C3A0D29426', 'C71FD1A6-175B-4F65-852E-E7A2D9A6C633', '4600665000061', ' 100 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECFE3796-DFF8-4434-B44E-15BDC2A5D0B3', 'B8D6F28A-16DC-4971-9C0D-F3A028E45285', '4600665000160', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('254159B0-17C4-4C52-BF87-FA55825ABFDA', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4600665000214', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A6E2BD5-AC6E-4187-8E28-E4CDB8919F0E', 'C9FD621A-0A8A-4BF9-B655-87163A8F3A38', '4600665000221', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F087B4B-9F8D-4AF9-9770-8AA59D4DC6E4', '8C5064E3-F542-4965-897A-E548B18B7C28', '4600665000252', ' - 50 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('039F4995-DFE3-492D-BBF1-479E4C26CA1D', 'E22CC5E3-1812-4102-81BD-9F19D83AE3F6', '4600665101027', '  -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6888FF72-883A-4A27-BD92-F3F9BB982FDA', 'C7D1893B-C461-4224-8E3F-EA7641A1B549', '4600665102031', '   70 / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62AB1C1C-8447-4296-AD51-0343BAC66F46', '3D9362FB-7EBF-4F9E-ABB5-90A499D4ABEB', '4600665203059', '    .  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B094D5E1-0B29-4D70-80CD-CFEC9B93D09C', 'F88CD411-591D-442F-ABF0-96695238612A', '4600665203080', '    . / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A86A4DCA-FEE9-411D-89C5-AEE85412CC20', 'E97EFE6B-6E4D-4441-8A72-37265BCBDC16', '4600665203097', ' 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D8C70D3-129F-49CA-9811-169B7D7D7217', '7A2AFB16-605A-4AB4-A1C4-B6C758F47F6A', '4600665203103', '   . / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E7CE976-3CC7-4CEB-B974-F0B62D24EBC9', 'F0A4C47B-F19D-486A-BD37-01E9601AD6A6', '4600665203110', ' 100 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4725829B-8896-4BD1-AC3F-2CD379EBEB6E', '65DF103F-7420-4A6D-A405-01804EF3598B', '4600665203721', ' 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFA7DEAA-0075-4C23-AB41-AAF9DE51BCDF', 'AF002861-74DD-489B-96B1-ED95DCB78B28', '4600665203738', '    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AD41702-52C2-4262-9E67-D0801EFB3DC0', '89CD93EC-5AFA-4BA8-B7FB-AEA5CEFDFB8C', '4600665203745', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98536970-0F34-40ED-8370-DE83F455D8DE', 'CB06A0F7-EC68-49D2-BA4B-29F8AA329F7A', '4600665203875', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B7CDD94-6ACC-4F32-83C1-F4E250894B94', 'A0468BFC-8AF8-4C4E-B610-B5AD9AD5133E', '4600665204049', '    (2) 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B7C7497-2266-4155-A298-BC84FEEAE4A4', '23E879E6-47CD-454F-92D1-659A61952B02', '4600665204216', ' . .  1614 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C5BC149-0BA7-4B78-A6BA-972301A3825F', '20B879CF-7AD3-4D65-981D-0AE257B5A724', '4600665204223', '    4529 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AE0C449-87AD-420F-BB87-FA8A03649517', 'D2EF02C0-A580-4749-803B-1981733FDB8C', '4600665204247', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2141DE5-A6F2-4052-BBBF-FD1D0095CA2D', 'FEFA2AF4-6D38-4B9F-AE79-407F31454EC7', '4600665204322', '   3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3AA71D9-ACEB-475C-B38D-FB2667C8DE48', '21F109C3-AFDF-4D4B-A0BF-CBCC03138AF2', '4600665204414', '   . 6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA634C7F-D71B-4607-85BB-C1E2792E8DD6', 'BA9125BD-E48D-4FD6-B567-EE24EF68FD4D', '4600665204476', '  6060    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3F25D02-39BE-4682-B502-3F7BD97F1880', '0FB59A6F-D541-4E3B-AD7C-80B1E727AAF6', '4600665204575', '   . 6040 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31662038-2A88-406A-9153-7F68224E3545', 'D254606D-B238-4835-9639-8F7C0691A998', '4600665204827', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FEC963F-892F-4C3A-B954-00DCE0028D00', '63295F77-2CF5-4477-9A6D-E7CF2D1F08F4', '4600665204902', '  6060    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBCC1E19-4AED-40E3-A31F-8DF62F3FDB6C', '7A1284FE-2564-462B-8D13-3542E9934D0E', '4600689601329', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C791314F-122A-47CB-87CD-5603002587F7', 'EEFFFE71-5865-4C06-A858-FCAE0D56D56C', '4600689601336', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62AEEE1C-EDB5-43B8-BF30-DBDC9BCFF1BF', '2CAE947D-C02D-4175-945C-0043C8E6F38D', '4600689601350', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6651AE10-F5A6-4EA5-A65E-EE109BFF24C3', 'EDAB47DC-D6F7-4462-86FD-78112032CC76', '4600689601367', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A808CE48-35C3-4F1F-9F85-DDF315148AAE', '0B7AA3FE-36DE-419E-9F64-1E1B0934F050', '4600689601374', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94C8CCE8-9875-4909-AD52-FE0471A0C469', 'E810A503-3288-47D2-A0DF-339C826EEFE2', '4600689601381', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4A35500-44D0-4070-B502-4B1CACCC1458', '371EC6A2-3F8D-46BD-9BC3-04AF84C0B1E9', '4600689601398', '    // 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CC9F129-4CB1-4B6F-B1AB-4284531E625B', '382868C6-7A92-4542-8C97-DFCE269AEB88', '4600689601411', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E94E051-2BD7-4E2D-833C-39A213A7D3B5', '8C50EFC2-F99D-4113-A228-04E2BE6AD5D5', '4600689601428', '    , . 5 . 1538 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9152EAE-7B24-426C-ACE0-3AEE102DB02A', 'B6845731-056A-4306-AE81-555C69319E79', '4600689601442', '  /  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06880646-4446-4ABC-9842-D431561C441C', 'EF0E6258-1713-484B-A875-58FBB593381F', '4600689601459', '   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75288B13-4A71-4238-9DB6-2B2E81BC0E38', 'FF0943A1-E664-4F54-8AC7-B699D3BA3C64', '4600689601466', '     180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56CA602B-B205-45B9-8C78-7AB292CDF33E', '49CE6480-BBDD-4E96-A0C0-5CC9FEB8DC51', '4600689601633', '    -   6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D33FF070-A435-4AB0-9E98-B3C6DA268805', 'A6658760-554D-4DD6-BCE3-8793F2C9A478', '4600689601640', '     5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C93DD24D-BABC-44AF-B28D-6C5B2279969A', '2B926B45-A00F-4D00-B367-E803F55DE165', '4600689602326', '   -3 / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F45FD07B-1D27-4D21-B5BC-28D1F60B42A4', '01A69468-7271-4E18-AB5D-CB11952C383C', '4600689603064', '    6   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('474A2CAD-310B-474A-B1FA-F0FC472767BC', '286F68BB-4BE8-43BF-8857-37E24354EBB7', '4600697101934', '  140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B573579A-C43A-403C-8993-E835435C9599', 'D10C7097-00BA-4F8F-9779-666380F23A38', '4600697140971', ' 14097 /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39FF5D0B-4D43-437B-A1AB-9BBA6C5481A0', '38E6FE3E-96AC-4C7B-8D4A-F2BD6C9F4AC2', '4600697171050', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E0E6586-584A-4EE5-971B-06828BB2F895', 'CEA12E86-6C84-473E-8783-465BE0CF28DB', '4600697171067', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D50E3035-BF13-43FB-8D4A-BDCE64B2AE9F', '081E363B-1047-4B85-90AF-BB23831ABBAC', '4600697171364', '       . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BE2EFF8-6DE3-4158-8591-469467EFE8C7', '3A6332EF-65FE-4721-A250-FBDD85AD116A', '4600697174259', '     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7A360B5-3456-4A7C-8205-0C614A59F8B3', '6BA3B265-F616-438E-A00E-A6771955D38B', '4600697174266', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7A99714-8C5D-4041-84A5-0E08E1E88CF3', '956B6ADC-226A-4F56-BB78-FC66CA54D376', '4600697174280', '       50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18F4C431-0479-4300-84FA-6ED3BB9E844C', '00063732-7C65-4BD2-A4C0-CE68B3DBDF94', '4600702023046', '  2304    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A133062-91FC-4022-9052-0F82EBD79FE5', '788CDA38-1235-4C6C-953A-23C6579CC79D', '4600702023053', '     bubble gum 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11109F3C-E3B9-4E46-A530-8DFBED42B570', '3CEEE095-7397-4FD7-8647-1D6484D8EE2A', '4600702025972', '   /  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD31B695-EE54-4E69-9C6B-13CD099CA340', '06E5F63A-D08E-46E0-A132-54F82F3BBB78', '4600702025989', '   /  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FAC7448-32A2-4C83-AF66-08D3EEBA3ABF', '0D14AB52-12D0-4B0A-B350-E52634635C8D', '4600702025996', '   /  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB0B055C-6001-4B4D-A00F-531BA2DF63A1', '81233957-6297-4C64-A8E1-4AEF68282D4D', '4600702026009', '   /    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AA2720D-98B5-46A7-9852-7D3B55CF9F4C', 'B8BDD998-990B-4730-8E85-59E71F580D20', '4600702035438', ' /   / 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6E6027C-40CD-4439-9E04-36CEF4D8A1AF', '51085BA2-5FCA-46F9-8107-2353040BD38B', '4600702037845', ' . /    /00 009 266/ 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8472014B-0573-4AD3-AF3F-5BB4CAE07C51', '82270A79-7491-468C-A1EF-C07BB9DF1FB9', '4600702057256', '  -  /250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E886450-7428-4770-9C2F-47E79F606A60', '7314690F-85C2-4779-8D88-5E41ADC4283A', '4600702057270', '  -  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D772BBBF-D14D-4FC8-85CA-AA272AA4684A', 'D9BDD768-D4D4-4228-B464-16CD72DB81DD', '4600702060027', '   /  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C76C5EDF-7C41-4060-B93B-57BF3899BEC2', 'CD33D9E0-ED46-45F2-8023-7CC1BBDC20EF', '4600702060041', '    / c .   . 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D964D86-5FE5-477F-92F0-9DFA8A886B38', '0AAD9C0B-2F35-40FC-86D2-90DBA2CD6D5B', '4600702064926', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F4DABAD-615F-44E0-9F76-FADDD6E6FCA5', '7545FB4E-B6F8-4673-AA19-218C2AA078DF', '4600702066425', '   /  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF1522FD-BFF0-497E-B402-4AF985A9F9B0', '5A5C5C76-B46B-499B-86F6-BE5BF257B39B', '4600702067606', '  42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01BCA4D1-E210-44DF-BA95-C69D9B64E908', '3078C781-19D6-489A-AC44-80B007A2D685', '4600702068627', '   /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5771DFA-64BD-438F-9045-D5ED4C05ACE4', '89069750-6DB1-4E93-B4FF-1A4F66CE3A65', '4600702068665', '  6866 . / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('119A7A2D-59E6-4001-B541-E1A91E026E19', '6C8AE725-B761-4CE7-8178-0D82C4B38710', '4600702068702', '     / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD030CF0-87EC-43E6-886B-3055A5D65DC3', '7969F1A4-3C80-428A-A2A5-3C2290E764C8', '4600702068726', '          75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76E13282-B455-4FB4-B477-0ACA951EC124', '61F3F661-A9B4-442D-BC47-1355D31D874A', '4600702068740', '  /  -    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D94F8D91-19BB-4961-907F-5C885B886B36', '4A4AA166-4FE8-4272-9136-EBA6E0FDD893', '4600702076776', '   /  / 80', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABA3EA58-B6B0-4F81-88D0-3812F8C31162', 'DF26F2C3-A7B8-4F64-A88B-39A50D7A0981', '4600702083613', '   / 31 .,.,.     714 3,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEC16829-583E-484D-A914-47B240423E80', 'CFB044F5-F7A5-4B1E-8647-197047B30386', '4600702083620', '   /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17F3687C-54D8-476F-8C7F-7FE67B31C4AD', '78B803D0-27C3-4A6E-8D75-38F0CF0B0F30', '4600702083644', ' 8364 . / ., / . 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8FFA657-9BA9-479F-ACD9-53A0717DEA3C', '0D5A17A3-8B38-4C21-A5BB-53E77EDA2756', '4600702083651', '   /  ,  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D09D000C-16A2-4BF7-889D-B9C2567189A4', '26BE4EC7-A5A5-4E39-BD2B-7E129239D9D4', '4600702083668', '  -  / 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0111C1C-C57F-4022-A441-A89E3F19C0BE', '29957668-6296-4C68-AC5B-4D62D276DD84', '4600702084566', '  -  / 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12E612EF-94AB-4238-9416-6D6B6FF701FF', '358D091E-5802-452A-9432-2048BA430DE0', '4600702085303', ' / 8530   - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2467B92E-1773-46CA-8758-55CDDB70ADF7', '8C341F9F-012C-42D7-9FA7-E61180A32E2C', '4600702086874', '   /   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9D72F4B-34E9-4B5C-8962-B86D95334FA7', '9FE422D4-8390-4A49-8BBA-B1AEF46D6339', '4600702087154', ' - /  /024/ 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B760D1BB-F693-4546-98C8-8FDB48AB172C', 'F5D2EA72-A326-4712-BD45-459F004FC4A6', '4600702087468', '-  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6856045-4B90-4438-B019-70A6D3B7FF45', 'B43AA896-7927-4F70-A1D8-7FFD9ADBEB85', '4600702088243', '  - /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52A771AE-8440-4F13-8314-127CF2A22676', '1A98AE9A-38C7-413F-BB1E-515F1BA911F2', '4600702088618', ' .  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1478CED8-1567-4E40-B220-1B15FE9CC7B9', '42E72B4E-5729-46D2-B6C1-6DABCC0C1E95', '4600702088656', '      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('778F96FF-EF77-4943-91B3-EEAA51934F81', 'E9AAB6DF-F339-45C6-B666-76CC1A559D38', '4600702091748', '   /    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBACAC96-4547-4BFA-8A92-C538330CB5C9', '03D62A7C-2D7C-4D20-86CD-7297617160CC', '4600702093568', '        1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECE72646-499D-4B91-A301-03AC4577EE1F', 'E2195514-4348-4FD2-BEB0-BCE1CBC40D66', '4600702094138', '  - /    400  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44F5485F-1177-401E-98C6-0763006B115E', 'F5434A6C-63A3-482A-88BD-FC4AF5148B35', '4600702094145', '    / /75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('177C2A12-2ECD-4710-89BE-A888E82C3ACD', 'A560E060-D58C-4402-AFFF-7502567184F9', '4600702094206', '  -  / 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F51F7BA6-AE99-4FF1-A61F-7F43CBD81B16', 'A03F90D4-9665-4528-B50F-8EF888DC5398', '4600702094213', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37447ADF-32AF-42C8-89EB-EBE86D336340', '45A08ED4-5E1D-4362-B701-8F3180D5669A', '4600702094404', '  - /     160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB93B7D3-3A9F-48EE-ABE0-74DB3757E644', 'B86D66BA-AFA5-4714-9497-B9D690C4173A', '4600702095500', '  - /       160 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC32BEA2-17E5-4F57-8D80-F6DECA1117BB', '44D530C6-40F7-4002-A9C4-B29DF4CBA816', '4600702095708', '    42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1F3A7DC-3AE9-4326-93E8-AEC5A87DB311', 'B137513D-097D-450F-A923-C2C53EA48C18', '4600702095883', '  /  /809/ /717/ 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BE103DA-EE8E-477B-A632-90813F7B6525', 'B6A7B7E7-AB66-4B2D-A639-44FAE154E9F0', '4600702096408', '        400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBF0CFB3-51B3-43DB-96EE-F82DF2F2EE43', '254019D2-9C0F-4EE9-A4F9-FF6103FD468C', '4600702096415', '          75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('831BE3C7-76CA-472F-A98F-39333B88F9D9', 'B8E86802-67BF-42D3-A5B6-815D215AF3B1', '4600702097092', '   /   250 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FC81511-F2FD-4BAA-A181-6DFE718C8A0A', 'A00A44BB-8260-4349-AC94-02982769B271', '4600702097702', '   /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF799C5D-213A-42B5-91AD-70CD180AAC2F', '81025B56-AE70-4069-97A6-47BCB6330CCC', '4600702098778', '     80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C6F47DF-6700-4560-9764-0AB8219CA6A0', '8A3224A6-DA99-45B8-8385-F36D10DE4B65', '4600702099003', '        75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AC5CD86-FC92-4BE0-8F34-1F6B88A80F40', '0DE9B6C1-4877-49EA-A3C1-9D388DB44168', '4600702099430', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2658AADD-2F37-4F45-98CF-A35C95761FEB', '800CAB63-7CB9-4C6A-A399-5599563D4521', '4600702099508', '     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6DA8092-187E-43A6-BB65-ADE3DE2BD5E4', '74CB3FC1-3966-4043-A859-15B37A301D50', '4600702099607', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('899DDA7C-FE18-489D-BCC9-CCBA13795EFE', 'E92F66F3-A0DF-4CF4-B6DF-AF5033F9D9DF', '4600702099621', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A842C59-5178-4B14-8A75-DB922468DD5E', '90F5D63D-6001-44D2-A044-430B495245B7', '4600720310005', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('879E0A3A-BA83-4D6A-9880-C08BB0024957', '07E7DABA-B1E4-4666-B967-29C727838CE5', '4600720330034', ' -2  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE24DD21-9274-4AD8-97FE-E6DEEC8A0D06', '193A0267-AAD7-4021-9F58-395551C3D889', '4600720939237', '   100++', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52E85BF7-8CF3-4EDE-B40D-4BA364DE4ADF', '6F9D1D7F-5AD0-4535-94EE-583785B17DAB', '4600728000014', ' ..    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F3385F1-D1DF-4FCE-B9F2-87D2159FA350', '0B4DE20F-B6BF-4A6E-88D0-10C5FA811E17', '4600728000168', ' ..    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1BD94BE-CBBF-40C0-B67B-2BEBE8BFFD76', '13D1D41D-0D73-4525-83F3-8BA591D2A050', '4600728000199', ' ..   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9BC1667-E38A-4E06-B22A-46FF06E8B133', 'EA4E8FD5-E551-4456-B2B2-9BC672B16816', '4600728000212', '       5 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2B64E13-34D8-499D-910F-F87DF13F68A0', '3F38680A-0540-4E1F-9709-363CCD7792F6', '4600728000229', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA319347-2545-4667-8821-C1E091478CFC', '2B921EDC-CE8D-461C-A272-4A4B8F973238', '4600728000366', '   +  100  7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC9CB91E-5EC9-44D9-926E-6A386F694D2A', '12803647-7E60-467A-B758-9A28FA7A34D1', '4600728000373', ' ..100    5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA53EF57-1D8D-4E85-8295-77EE2EE16727', 'EC28395E-5760-454E-99B0-2287C6EE94BD', '4600728000465', '     1,5  0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('910B41A4-29AA-40AE-A3A9-F1EA2D998CEB', 'CBA36110-10CE-405B-8CB5-85DC5B60A8CF', '4600728000472', '     5  0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61B8810D-CB8F-4D2C-A064-97312FDE52F4', '58643624-D09E-4B73-887B-D8424AF7186F', '4600728000564', ' ..   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E3AB9E1-C042-41D9-AA3D-CF3F6458044A', '8A1C855D-6AFA-4F27-A2AF-81F03D711623', '4600728000588', ' ..   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A5DD34D-C558-405C-AD98-ED842E5F47DA', 'B3718C0C-B02B-4F5C-A409-67B146E8A47B', '4600728002087', ' .  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('575E3429-1034-4F75-8C3F-58D0221A7991', '970FE496-F478-4CB2-AADA-6B9A4768FE95', '4600728002094', ' ..    4 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17C9E490-A829-440E-AEFB-943DE1DA47B5', 'D5292E79-D58C-4D70-9835-19BEB6760E2B', '4600728002155', ' ..   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0F395CB-871B-408E-A4D0-25AF8DE2D7A7', '98B6AB7C-D4DE-4AC3-9A6C-3564FF8CE3F5', '4600728002162', ' ..   5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9090181-8E46-43DA-80CA-66582C090BDD', '36419EEF-127E-4C09-BDCA-AFD50EBFAF87', '4600728002223', ' ..  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1F5F5AF-A79A-4D90-AD16-DA9C13068B69', 'F00CEDBE-2FB1-4630-9E24-C3475DCD8065', '4600728002230', ' ..   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0268CC7-1F2A-48AD-9F84-69E75E49BE8B', '3943C12F-7B73-4732-9223-E465C81B88F2', '4600728002278', ' ..  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBDE5C42-A10C-47D8-9215-DC8AC8522E08', '259AA7D6-E519-4162-B5C6-EF1D91BBC570', '4600728002575', '     4  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40FAC738-C1DE-4351-855E-ECB054DB6863', 'CE15D268-A868-49D2-9E4B-FBD1FCA0A30E', '4600728002599', ' ..200   /.  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD0CD22C-989B-45D3-80B8-7ECB3862D2BF', 'E9F2558E-B269-4C4A-85C0-27B34560CE91', '4600728002629', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F68ED95B-8415-4AE1-8718-95D79B38F3BE', 'F3A466B7-1E2F-4803-A474-18C588EEF428', '4600728002636', ' /    5 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9DB21EA-0295-4DCB-913A-088CD51AB9C9', '8FBDFCEA-8EC1-49BC-9800-FB834A9B1CB0', '4600728002667', ' .  200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97C58640-FBAE-4A23-8FB2-20DE8E56CD91', 'C8A62119-40A0-4648-9E2C-76782A8BD7E7', '4600728002766', ' . 200  ./.  4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7A6633C-A903-4C71-91EE-2A1E8AA49612', '8AFDB331-0B92-48A1-B01F-76931AA6727C', '4600728002780', ' ..     3 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14326776-90BC-40B4-A0EE-6A1798F1D2DE', '5206DDAD-B065-4EE5-A545-EE65F8985067', '4600728002810', '    /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0294958-CA44-4799-A644-4E842FF76CAE', '725CB72A-180A-4ED6-B302-5769FBBC2785', '4600728002827', '    /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F192B0F-B86A-4728-83F9-886CA054BE5B', '962C34AB-FE64-4831-AEDD-9AA90DC5EED9', '4600728002834', '    /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C0C3926-E635-4512-9B16-5CC01A782B55', '21763904-44A4-4B6A-B9AC-565A75C36618', '4600728002841', ' .   . /.  5.200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98055329-587B-4C73-8AD5-17F53D4839BB', '8FAF9F27-0C7C-4089-8A49-476A37301AC0', '4600728002858', ' .. /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A835F28D-AC00-4537-89AB-319A3E37F6BA', '9B2860E9-0259-4CD2-91F1-ED9A37B71D3D', '4600728002865', '    /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA4E7078-B251-4E12-B1CB-2F681E60087F', 'EF9F4997-2C96-4689-9D6E-B6325D4E578B', '4600728002889', '    /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D4724ED-F4D9-4305-ACA6-D0047ED6E609', '8AD8B4DE-3A4C-4661-BC2A-B979DA04A96D', '4600728002902', '    /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D70F0A41-EBBE-4143-874F-53AC983CBBE8', '7E9CA424-959C-4346-8C43-598669C98CB6', '4600728003930', ' .  100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38C938A5-75F4-4DF5-9F66-EFFF7409DCA6', '5D56E2CD-1726-4153-A74B-DB685A5D72B9', '4600728003954', '   + 100  7  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C3773B2-36EC-40D3-B703-458325EEB6D8', '238FE183-4848-4989-A055-1DCCC20F2A25', '4600728003978', ' ..    8  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD8B3749-8588-45C6-93B1-1F589C7CFC6F', 'E14743DE-CA2C-47D5-914D-3FC67008231C', '4600728004012', ' . .  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE8DB457-1260-44E5-A340-2DB1E907C837', '90E2F482-CB72-4A61-9941-2BE1D3D505E0', '4600728004807', ' . . 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A36365FE-632F-44C1-BF59-849D9F33D6BB', '2070F168-08F7-4AC3-9CBE-2B2DAB149FE4', '4600728004845', ' ..  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6A706F6-A973-496C-B023-CA06EF88F251', 'C940452C-FCE3-4325-8E5B-CE1EAEEF1A64', '4600728004906', ' ..   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('664B7D9F-8200-4BE6-8BC4-674DC5DE1391', 'A867D610-7E23-4F25-9E20-5CE4F0E3748D', '4600728004944', ' ..   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19C5DD89-691C-42D1-8E2E-B55B897723DA', '9E0E63C3-BED9-4955-9F8B-6F10A4EA3589', '4600728005002', ' ..   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45905AC1-65F1-4E8B-B2BE-1232B2B7A484', 'C47DB772-7B43-43F9-B2C4-BD7887D2D4FC', '4600728005323', ' . . /    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90B82622-E3D0-4CA9-8FCA-3C20F6701693', '1112B54C-81D1-434E-AACF-5B5010048DCB', '4600728005484', '       8  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8E187C9-CD2F-470D-9052-9F496B38275E', '781B711D-65A8-4B51-8E35-A2A81825D83D', '4600728005507', ' . .    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A896D15-6276-4C07-A626-A17D1FDD1105', '30CFDC3C-FE13-4E1B-AFC6-7E502D9D1C91', '4600728005842', ' ..  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D36A794-6CDF-4F80-90FA-44B6CEDF62D3', '1E0382DD-ECA2-4AB0-96FD-C55F25039356', '4600728006221', '   /    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('952593F2-5427-4DCC-B815-580EB55C9845', 'FA557CA0-92CE-43CE-97E6-D1C422A44555', '4600728006542', ' ..    6 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4A68F04-1005-4748-A305-8389F570155F', 'C715AD86-0063-4ECF-A8FD-450E64194B3B', '4600728007143', '     / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B121DAA-E61D-4607-A3A9-4B6B430CE772', '1576C630-B9EA-4DD7-A967-8116F8481A3F', '4600728007235', '   /  /  1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C00E34F-7526-4971-BB06-7AF30842D49E', 'D89D6D15-806F-42CD-A840-B70FFAFBABCE', '4600728007266', '     0,5  0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94AB008D-BD68-4D71-8BAB-EF160B1D6F07', '399CAC27-7CBC-46C3-85F6-E6B3A8ED2776', '4600728007433', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A5D1C17-D736-4F2C-847A-01FB558B1200', '905342C7-78EE-48D2-BC6F-EDA18F8F4012', '4600728007761', ' ..    5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AE4BB68-2B64-4E00-9E85-D5C8A6ED296D', '1A72F3DD-6FA2-4025-A16A-EFA9AD530990', '4600728007785', ' ..   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C690FFDF-D46C-40F9-978D-A00CB70997A0', '96358F3A-1760-473A-BEB0-B41D3BF45C58', '4600728007808', ' ..   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C99D4502-0B1A-4C06-9AE7-E53F529E08A5', '67C01FD1-0129-4396-96FE-3FADF946EB8B', '4600728007822', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D07C6F8F-9282-4528-BB08-5B23EA74EF94', '2AA682F5-B829-4568-B04D-2197E97E1249', '4600728007846', ' ..    5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DC3C4C2-3D77-482A-B2C9-3C44AC352E50', '95D3AC3F-AB19-49E3-8A47-8A8CC2653599', '4600728008027', ' ..   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97D7F17B-D2F8-4644-87D4-8A77737D31AC', '8F02A81F-3A23-4979-9910-FFFBC04875DD', '4600728008300', ' . . 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD824F81-5215-49BD-A29A-1872230D5B04', '89E99AB7-4F09-4F91-A0A5-B18DAB6040FF', '4600728008379', ' .  100     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4E3FF2B-73EB-4718-846B-3ECECAB59015', '7FA1EE79-9D55-4A64-82C3-0B3C1949DB03', '4600728008393', ' .       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28D1BEB6-3D83-4F6B-9344-359D2CFA2B0D', 'EC372A0D-AC1B-4D00-9214-D89782748B36', '4600728008416', ' .     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D8E489F-C229-4116-A26A-C3856230D850', '096A09CF-B595-49A4-B02D-BB86AB882294', '4600728008690', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AACA41AA-CA89-4F58-AAE9-B1CDFA5E6A44', '08323FC7-564C-45D5-AF37-9B9EE76FE8E7', '4600728008706', '        5+200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CF456A7-28E9-4238-92E4-FB773BF96209', '7175927E-C615-4538-932C-09C4EA798105', '4600728008713', ' . 200 -  .  5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('005DFD2E-6818-4C8C-9BA2-8DD5EE1D0157', '663BFE8C-6C3C-410B-961F-029D5D1732C9', '4600728008720', '    /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('944E038D-D33D-41DB-B047-49954BAAC738', '6C97044D-9C01-4E3E-ABF5-0D61C21CE3C9', '4600728008782', ' . 200 -  .  5.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8F8FCD9-C076-46B7-94EB-6E728A933C5F', '756BF84A-D653-44FE-BA35-D089A3C86C94', '4600728008805', ' ..90   4 . /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23370EBA-F857-4034-8A56-B7A955ECF3E6', '07FB9232-86D2-4C78-A0E1-9CAB38945890', '4600728008867', '       90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8271307-5A08-42E2-BE05-E0FD4831ECB4', 'B2ABEB81-AB91-4EF0-9AFF-1EF232B15CB2', '4600728008881', ' . .   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C86EBECE-3C52-4D7A-AFDE-E937EEFDCCC7', '798CCA1F-EBE0-462F-A920-6F079DD6CDDF', '4600728008904', ' .. .   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CFF0681-00FC-497D-8450-A02D70C2130D', 'EFB91C1B-3C37-440B-B2B1-26E556DE692F', '4600728008928', ' . 200  .  4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('792D35D2-CB9B-4071-9C4A-2861497EA623', 'E57F77FA-4E18-460D-998C-591824F6E7FC', '4600728008942', ' . 200   .  6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EC3F1F2-146A-4E22-8043-92E23D847853', '58DB59AA-3CF8-4030-ABCB-9DB0D568013E', '4600728008966', ' . .  /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4492F10-5674-4AD8-86A9-439C4156D171', 'AFF6CDD4-DDC7-447E-AA9B-1AC1B7C6BC04', '4600728008980', ' . 200   .  5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF422003-277F-40F7-8C9F-D3CC2063C505', 'AD1207E6-D1BA-4C83-846A-72078511A3BE', '4600728009000', ' . 200  .  4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81393F98-57FC-4EEA-94BC-AF875F3A3E57', 'B56A194E-A1D9-4A73-82B5-29867B9C4190', '4600728009024', ' . 200   .  5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E3A1CCC-56A7-4A4B-9CE4-EEBEA84980EB', '21BAC428-B11D-4B61-826F-B53E593875F2', '4600728009147', ' .       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F093893E-4AF3-4544-AD51-D12C95B3A6E5', '3DFCE72B-D730-4717-B999-41D443F69808', '4600728009161', ' .       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FC918A3-6FEA-45BF-89D2-E60B320545AB', '179C1EA2-C03B-4DB3-AB01-5A40C14BB29F', '4600728009185', ' .       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFB88775-474E-4B25-9B71-09793862DC93', '9F450139-9779-4B58-B4AB-1013229A899F', '4600728009222', ' ..   //   6+ 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E7801E7-DFE1-4B9C-B92B-E2F3FE207B6D', '30199773-1501-4BCB-AB97-AD0783081516', '4600728009246', '      / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C905D5BF-5D62-4921-B29C-C79B7FD9F094', '2B84D735-A3DF-4834-879C-B4655638B9B4', '4600728009468', '        5+  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AB8B00C-9FA0-446C-ACE2-B6478D1BE022', '1B5FD12C-C1A4-4641-A253-C74C60F78A25', '4600828000501', ' 5% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED77A61B-C796-4243-935B-F41E00919B76', '99C46E90-B2E6-482C-B256-2E71C9D286B6', '4600828000662', '/ 12/ 500/ 1 - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D57CC39-7935-49B4-ACEA-FEE4AC7062DD', 'CD4F275A-68F3-4EBF-AD8E-EB72C511FD3C', '4600828001003', ' / 10% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21C81ABF-18E1-47CE-8387-FCAE455D7A4E', '5A8E1E47-30AD-41FE-BB02-EC2B6D84350D', '4600828001027', ' 50  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EBEC8D8-8F66-40FF-B6A6-AE09F64B63CE', 'D466248A-88B9-499E-832B-8F4121FE80D6', '4600828001348', ' 5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('874594D4-30FD-4ECC-8645-61F53F781956', 'B0CF804F-E3CE-4C9F-9F4A-0A9685469357', '4600828001461', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6111E0F7-FBD0-4681-A967-2A2D7BE51D86', 'ECFDCCEB-C5B7-4A5E-A3F7-0596FF56B558', '4600828001607', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1325E8AA-77C9-4884-A6AA-096ACA8FCFB9', 'DB8CDD22-61D4-4F5A-A899-48D33B12D7EC', '4600828001867', '  250  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8990524B-6989-4996-8A2D-5DC4F3D0F4E3', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4600828001942', ' 5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87503FB3-D19D-42EE-9232-70E3B2137CF0', 'C774C8C3-7B93-4791-A2DE-DC449B3DFA55', '4600828002147', ' - 0,05  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34CE4BFD-B76C-4CF5-8A9A-ADBDEF1A0F06', 'E82F4C18-2FE4-4BAE-A539-D7E064811319', '4600828002789', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D82E5FC-AF26-4B38-8FE6-29D256505CD8', '982EC460-D731-4661-97B6-79114B56AC43', '4600828003304', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC8190F9-2DA4-4B40-AC53-D2178ABDCF05', 'C39D299F-E001-421B-818C-4C641D8AA8C8', '4600828003458', '  80  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EE442E0-DF6D-4094-BC89-CBA5F5F18E07', '98C6D0D8-467C-401F-AA3D-AF5AD53B9DD8', '4600828003540', ' 0,5% 5/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5892C76E-6EB5-42BA-AB8C-648933FCC7A5', '973B4D2D-3FA3-46B9-B5FE-7A10EA833356', '4600828003946', ' 250  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('520485D7-274F-4C5A-81B2-102B84ED0A95', 'D72D9EEC-C7A2-493D-AA48-CCDEC38CBC91', '4600828004257', ' 30/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90EB0BE5-747A-4332-A553-B16D9E69FF6D', 'E075309B-CCFE-4522-A71A-EAA345142CC3', '4600828005377', ' 2,4% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA36BC77-676F-4DDF-90C4-FC90778DD8D9', '31328CB5-CF9A-423F-A717-843794A11CEA', '4600828005414', ' / 50  /+ - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15157B36-4AD1-4D64-ACDB-C0ADF7278F87', 'FA626287-C50D-4CAF-9ABE-874C8B929423', '4600828012788', '  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B940851C-857F-4ACE-8EA9-51D87BB18ABC', 'CD902F00-85A5-4998-9D6F-34A1A5765F68', '4600908020634', '-103   25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('345E4A17-3AA2-4A77-B42A-7C7321FE95E4', '822E2F84-D478-420A-B09D-A1FABCE7461F', '4600908020917', '-131 //   / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64D8AB7B-F1DD-42ED-9E3F-D42544159A84', '49680836-6948-4978-8F14-5078D210210E', '4600908020924', '-131   25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4297730-EA30-41D4-94E4-009EEFB0180E', '5B24C58E-70AB-4625-9080-3A4F270061BC', '4600908021150', '-911 //   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('537F8816-93BB-4BE3-A663-562099B493A2', '91868860-3E1B-4483-B2E2-C641BE23E220', '4600908021600', ' -801   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('793EB9F8-B4CB-46EE-9A39-DED725E4C9F5', 'D6F79CA1-78E3-4401-9803-B8D9CC8975FF', '4600908021617', ' -801  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80D0189E-E0CA-48C9-9205-B1C64F8920D2', 'E7D38335-AD09-495C-BE43-9CEB85B46508', '4600908021921', '-306 /, /  1   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9415CE8-73E9-4833-8D0E-B22F1FD15E55', '8776AFE9-E96D-42BA-8372-5AF0B60A81B0', '4600908023253', '-127 //   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21D4CB4E-73EC-4F11-8818-365B561E8FA0', 'CDE388E7-BCAD-40B7-8683-8B3A652D18CA', '4600908023314', ' -927   0,17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EA940DB-6129-4093-A491-631EE2F9124A', '90F5BD12-C6CE-46AE-9D58-CD32D3111346', '4600936180379', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F46C9696-CFDC-4698-A558-CCDEC8EC3EE5', 'E4918A2A-4460-4DE7-85B6-D8792D79DFD3', '4600936180782', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FB9F783-E9B6-40A4-B09B-1FA80ADD4E83', 'BCF66C17-1524-4D15-8394-8102CB988A40', '4600936181161', '  /  . 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70DDD953-2E6A-45AE-B0DC-20A377E1F5B9', 'A6B5716D-891A-46A7-8741-9A2AA6701539', '4600936181260', '   / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1864F547-3D81-464A-8B1E-1812E4607A6A', 'C483D8DE-637C-4968-9C1C-6B3C43DA62CC', '4600936181376', '  /   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70E9BD90-F34B-4BF3-9CAB-C8633B07223D', 'B9048487-77A2-4644-92EE-42EA229CBE9A', '4600936181604', '  - 41', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F300C29-6480-4951-9E50-F1E3E107225D', '9E9B7305-C841-4FD4-98CE-B750CB09AED2', '4600936181628', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('650181D3-F297-4D09-B851-A023D322F04A', '18784B93-6113-4F78-82E9-9C228A516FEA', '4600936181840', '  68', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E4201FB-18E8-4B02-96DF-150729CE4B11', '9195FC34-CF89-497F-B0FF-FB138614DD9A', '4600936182182', '  / 82', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1954B78-84F5-4945-BA9B-FD9346CAABEF', 'B9048487-77A2-4644-92EE-42EA229CBE9A', '4600936182298', '  - 41', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35AF89E9-72A8-488C-975C-B7D824F3EEA7', 'ED55920A-7CD3-469E-B506-5DD2E096F503', '4600936182304', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A20CABB2-7714-43D6-956D-6462B14F5AE6', 'EB663CEC-40DC-4FA0-8830-9082086DF71C', '4600936183127', '    /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4A9DBC2-20A0-4865-82AF-A8D2B7CB1477', 'E4918A2A-4460-4DE7-85B6-D8792D79DFD3', '4600936183912', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C6DE21C-C6FB-4D34-B4E2-95760B91D50F', 'C23CFFE8-8492-4145-8410-4360DBF997B1', '4600936240738', '    63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6DAACD0-5101-45DA-BFBC-319FE4770D92', '5C577B62-EB79-4E4D-85E7-EC0EFE0251C5', '4600936240745', '     63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12937239-1A6E-4807-A50D-246FDE2679F4', '18D941DD-6BB3-4C96-A666-C8ED3EB7DB61', '4600936240752', '    63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E80AA69-D47C-458B-AADB-D02B75B59810', 'A7A91E99-09B8-43B2-AD93-DFDF075684E0', '4600936240769', '    63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAA60183-9103-4F38-BCBA-5CEF99646294', '3DE34B8C-86B3-4847-95C7-6AB0A48FADCC', '4600936240776', '     63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('818EB068-7AAA-447D-9815-AEF2B2069BB8', '8A62D94B-6F2F-44A8-8C5A-B321A49DFB94', '4600936240783', '    63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA576C53-018E-4A11-90E6-FAB92D31BF0A', '3B9862A5-0EA9-4AD4-8EFC-F72748107C10', '4600936240837', '     .  63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1839FDBE-F8E9-4186-A95A-5FA61D9F678E', '68CD9861-2D29-42E8-A41C-6FC430E02A2A', '4600936241148', '     63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28084945-128F-4914-895D-264537F80C7E', '919B7399-56C8-4A98-8B77-A61B06840D24', '4600936241155', '   /63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36F92392-2E89-40BF-979B-4BAADD3F6842', '2F8F2910-C74D-40B8-BCA8-682131DF4D5F', '4600936241254', '     124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5237495-E8ED-49C5-8192-EBE0E296DE5C', 'F8714D49-DFD7-458F-BF5C-C252D7EAF777', '4600936241377', '   prof +  124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ED3BC1B-2199-461A-A67C-8C373EDA03D8', '1F930DF8-7E9C-4F5A-8FC2-D83CDAED4F56', '4600936241384', '   prof   124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2FED2B2-DDC7-480A-B95E-42ECA8699A50', '4D68E766-E723-4773-9CE2-0CC08B047338', '4600936241391', '   prof + 124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5D671A0-CA35-4ED1-AC8E-C6DD6CE6F2D2', '82093022-DF29-420D-95F7-D40D7AA21402', '4600936252069', '  - /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02AFD9F6-55E0-44F9-8A43-1CC3D4316E55', '01E0C74C-0EB9-4AF7-86D1-01B7A48BE159', '4600936310264', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A25B0DCC-DE8E-4F6A-BE9A-7A5BBF25D983', '0EA044A4-8DF3-4467-93C1-2434E0429BC1', '4600936310608', '  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9768362F-9889-455B-AE4E-FAFE1C450214', '70810984-8F9B-470B-A966-D7D8BFA564C5', '4600936312039', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A09AD433-A0B8-4AAF-8CDA-A46BAF29E889', '920BE8E9-08BE-4A68-BEB7-F8E22EF92D2F', '4600936312046', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('822FF267-CFF7-4966-8088-7C643357BBB7', '42C06098-6D72-4732-B790-E564F011A5C6', '4600936312053', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D7002EF-4CB0-4BBF-9C24-DDE34D30B65D', 'E6064DCC-5AA1-4D24-BA37-BEC6589D37E1', '4600936312060', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E2C635E-4DB8-4624-95C3-1BAD2F9E9DEA', 'C43FF19E-8273-4C13-8DC1-C5DF24750943', '4600936312077', '   , ,    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF5015D4-BBBB-4500-9597-BB75FB6F1489', 'CBAAE02E-07DD-41C4-B8A9-EE4CB8A3205E', '4600936312930', '    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3432F098-3A9C-4382-95F8-4C713CF173D3', '91210622-DA46-4C75-BAA1-1840C9E5AA02', '4600951000027', ' -  10200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E899BFBC-2166-44C6-BCB2-B64FA5D481CC', 'E58A0AFB-A908-4828-96D2-E5883CD7955E', '4600951000072', ' - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20649554-B3F0-426D-B108-B2302D7D61F4', '002211C8-74D8-45BA-B852-D64244FBF38A', '4600951000249', ' - /-    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA1AD507-3A21-45CA-92E8-83F3C495C6FA', 'F61F4213-04D0-4F2E-842F-F35D752BC77C', '4600951000324', '  / 45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B2CCBD7-CE2F-4301-B535-6F5F5EC81A9C', 'CAAD0E34-D888-418F-8735-4791105A5AE5', '4600951000331', ' - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F9D5B1F-2CC2-4974-8860-6CB94CEDA1DE', 'A4D5AA8E-AFB0-4D2F-BBC7-0556EE6C4D77', '4600951000638', ' - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F11A87F-4440-4EFA-ACBE-516F276A6331', '393C3BED-7492-45F6-8030-5F89D273D1B1', '4600951000690', ' -  10200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D224DB5E-955A-4EB9-8D25-D95BEE67BA42', '53678C53-7229-4EFF-BEDE-9E1A7D4E009C', '4600951000782', '-    /  51500 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CFCD501-1A14-463E-A49B-5DF001916B3C', '92F50B04-C537-48C7-B67D-ED7A96A95C58', '4600951000843', '   . .2 / / 90/ //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD35CAFB-E258-4124-90DD-7E951422ADBF', 'CEDF42C6-8CA2-4CFB-94CB-AF073614DB90', '4600951001215', ' / / 750', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB83D066-030F-442B-96C2-49D6A2191DD9', '3FE664C8-D81A-421F-B677-BE517D848327', '4600999001376', '        30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1543772-30A2-4A30-AB04-CDB916A19C1C', 'D0852804-26E7-4945-8C55-9670BAF411D3', '4600999005152', '      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6334003-E281-4A09-9832-6984BE5C3B2D', 'A927CBDB-F721-4D3B-8594-34683D3F461C', '4600999005831', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B83F4A2-6586-40E3-B623-62F94EDCD3F5', '589C4E44-205E-46B6-9EE3-9BB1DF28FA8B', '4600999006401', '     .  72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07549179-7501-40B0-92AE-12AA701C51FC', '380CBD4B-BF69-487A-A666-B770AFEC66F6', '4600999006524', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D657569-A161-4CA1-869D-D7DEDE072E6C', '81C5C7E5-13B0-4B3F-B618-2B5D5C101707', '4600999007569', '      15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('067C1F75-2C93-42EC-8E59-7E8847EC3700', '95EE0543-E907-4D0D-977E-87B13BFE06E4', '4600999007859', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36278D96-E0AF-41C9-B81C-23D981FD9254', '65400AD5-DBE7-469C-BBC9-F4B7CD8AC356', '4600999008269', '      72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8606E05-51C6-4A8C-AD1A-4E35C50944D6', '89F9E3D4-A963-4BC0-B43B-041E3C15D903', '4600999008627', '    /  15//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B641EFE-69F4-4DAA-ACFC-E9A1F122F6D5', '3AED2EB6-E328-43D7-973E-06C8E6BFC1CD', '4600999010620', '      45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03E15B28-6A61-4FB2-8391-06CDDD4261FD', '8B35C736-9939-45E2-BC7F-403BD7624273', '4600999011160', '    300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2CD980C-06B8-4CA3-9A43-547153083C9D', '8B12E6BE-E9DD-4AF5-9427-4C709408BF2B', '4600999011177', '  maditol     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7316531C-3B0C-4C55-A8B4-382124F86E92', '2F93B57C-9006-450F-8138-8DAA7001AE52', '4600999011467', '   10+ / / 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2048EDE2-4251-43DB-881A-0E6351878292', '7A04742E-2C0B-449C-9BA9-318B56476D0D', '4600999011733', '       +.   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAC0519F-BF0F-458A-B942-8AB5C266094F', '0FE43404-7939-449D-A57D-E43939E48423', '4600999012990', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('865E4A4F-31D9-4B3F-993F-8BA0FEA943A0', '3369D007-BC6F-491B-98D1-A041FCCE50AC', '4600999013270', '   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01D96B44-EC20-42C7-884E-938D72C5A6BC', '8388E22B-EE58-497C-AD15-BEAA070C9F1A', '4600999017223', '   / /. 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7C54029-2F5F-4708-A8AA-C8DA819C1CE1', '69F9C90E-1A50-4D82-8269-88E242B2D1AC', '4600999018169', '    argan  sakura 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BBE6FE2-BFAC-4736-B6D8-48604552E85D', '2C9B340A-EA90-4565-874D-DCCD9D3EA877', '4600999018763', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BE15654-6BF4-4B34-B488-698861C03A09', 'FC6ABCC3-8E04-4E0D-8A5E-2F8115A8B282', '4601026003011', ' 500   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDD98B61-9347-4E13-83C6-7301A6ACA5D3', '887DC364-D565-4622-9652-F1F2F71C292E', '4601026011016', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BC81B91-3F0A-4475-BDF6-24919A83E140', '9D36BCBD-D59A-40D0-9802-8463B2C01850', '4601026012013', '  200 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2768B28E-AA24-4839-BB91-A96C57C867E7', '72638CAB-04B8-488C-B73D-4768387249D4', '4601026022081', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2757257F-781C-4759-B7D9-1403D03097EF', 'D588D9AD-5445-4B55-9972-7B5D60968DEE', '4601026029080', '  10% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1ACB968-6871-46C9-A275-DC30A0BBE345', '2F017AAE-25C9-4E29-BB45-A57171698FBC', '4601026039010', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAC0746D-80E8-4C29-AC6D-E4ACD10CC955', 'C5288CAA-E555-4531-8323-1CB07C385191', '4601026066160', ' 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCBDDD83-6D62-43B5-95A9-75F65C72D8B5', 'F59E7CFD-8A9E-43E8-992F-3101505C8D92', '4601026071690', ' 20%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('166D5EB9-5AF0-4CB3-8B50-D36A9E2A3DE5', '02788D05-4E28-4FBC-A3E5-7813C79DA5EE', '4601026125560', ' 50   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C7DABEF-E364-4064-B9E0-DBCD67AFC09B', '90539237-E575-4970-B4C5-12D2F2627413', '4601026130717', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('374701D3-DDBE-4043-8C90-92F28D7EF003', 'DAD94256-39A0-40A6-A30D-ED3E4F9A3424', '4601026154720', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AD53B19-7235-407E-9D1F-89001CEAA663', '4B927C20-9BC9-4862-A68A-880423578FC8', '4601026155727', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A122850C-2AF7-4A91-98EF-E9F204CDE00B', 'BA5180FD-C240-487A-8145-0E71F33B44F1', '4601026301148', '  15   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DB221BF-AB38-4CBB-80BC-4D55114CB7E4', '912F90B0-E6F8-496D-9409-C5128B34FA1A', '4601026301469', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD7A2085-D3C2-416D-8188-1E70F6FC7697', '1D8E6261-9736-4615-A765-22DB9831BD59', '4601026301735', ' 200   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75DF927E-6E72-477B-9152-EC83EA063A74', '60B0BE29-13C1-4B98-8C02-1158408407BB', '4601026301759', '  0,05   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69CCF3C1-EAF0-4EB4-A9BD-35034FE2445F', '0D5D43A5-61C7-4F49-840E-14EE83C8C9C1', '4601026302077', '  1% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4798F775-449A-4B4A-A6BD-C63C9BDD186E', 'E721C62F-87CE-4995-B368-AE763C65ECF7', '4601026302275', ' 16   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9958E7A0-EC7A-4063-BD98-7B96A70CA13D', 'CCB1C09A-B33F-4C4E-889A-93317CD777C6', '4601026302626', ' 0,125  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F74B19B-9CE9-4444-AC30-FDC8E24CCAFB', 'C1CF05FF-8EE3-4B5B-9F93-3766FF4B46A8', '4601026302749', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DDCEB0F-9C06-40F9-8D2B-5699EF7594C0', 'C9A45E63-64C0-47DC-B2AD-A2376592F1D7', '4601026302800', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('637EF88B-1D09-4BB2-BC3A-35542C1A15DC', '30A75F4C-7493-4E90-A4A4-6B003B542458', '4601026302824', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A259E024-23F7-462B-ABB7-3DF404C4CF20', 'F9AF7686-CD14-453E-A5F9-63860160546F', '4601026302848', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A715592-A406-4C43-B682-54E3E86ACAE2', '69B4D5D3-EB92-49C7-A1B7-5D9732586D53', '4601026302862', '  8   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEA0F888-C61C-47CC-B787-73A489505773', 'F50FB2D7-1F14-43CE-9D8B-36656C018251', '4601026303005', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('182D61A7-E821-4751-A0F9-DFF0927FFDAC', 'DA1ACE2C-B96E-4C87-96D8-6699B1070FD3', '4601026303074', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFEFE8CC-3AC8-4DCC-8809-5B6BD195785D', '2D01348D-3A22-4DD8-A2A4-E95EA14CE509', '4601026303470', ' 18,9   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82490882-E807-4D47-AF87-D0860286CFAE', 'B9FDA754-40D1-49FC-BA4B-9934364AB077', '4601026303739', ' 250  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E445EC0C-F445-424B-827B-76B4852D59B2', '93AA6888-FE47-44A7-BE3C-F7B80475444D', '4601026303838', ' 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFE59EBE-8797-4249-BF51-CCB2E526E5BD', '9AA4FEEB-3403-4010-A0DB-F69BD47E44A6', '4601026303852', '  5% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50BDE623-9841-49FA-8A12-39EDC4B6CFA5', 'C16C1B29-2535-406E-9679-DE7BEA1A71D7', '4601026304644', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51997436-285C-4070-A9C7-ACA2F4963B37', 'A5BC156D-207F-4B66-A5F3-A914234D0C73', '4601026304798', ' 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA2BAC0C-BD04-41D0-B884-4857AFA5088C', '25EF0B0F-83E5-4498-8D68-D63751A8CCF8', '4601026304972', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4401A72E-188B-41AD-83C8-6AAD4FA0D661', '909F99E4-D524-4118-A051-BC4E6C4A34FB', '4601026305177', ' 400   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2489854-F050-4EC3-BD9D-EA3FDD69614D', '3111C656-26AB-4CC0-9F1A-689089286777', '4601026305412', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94A904A2-F51F-4F24-BACF-7F8E6DA58865', '7608922C-E992-4A83-8DD6-A3FC6ABDE0FE', '4601026306068', ' 0,1   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('673F9A2A-DAB2-49EE-8B43-EDC5FD1D990D', '030A7D48-3054-472C-AEA0-26FC43B77981', '4601026306204', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C75267A-C7CF-4413-ABBA-C79CDEF4EE11', '840796E1-09EB-4183-A064-0A17866FD725', '4601026306235', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBF9F3EC-B17F-403E-8040-E98AA6484894', '5D0D3FC4-880C-4310-AA32-230327DB6F96', '4601026306396', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8084E994-85C0-49E6-8F20-8C7494851ABB', '1A48B66B-2A93-4284-A31F-94F80445D983', '4601026306501', ' 400  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF7C9E19-D628-43FD-AFB0-EC3D82CCF69B', '0EBEA057-DE8F-4F75-8C65-51F84ED594EF', '4601026306518', ' 400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('310D872A-1391-464A-BE21-6A945A2999FC', 'EF22F359-CF72-4BA7-BA3F-4D507B91384A', '4601026306532', '- 1%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E86B07A9-A614-4E34-9847-A6B3F786F174', 'B4951EE5-DEC8-4B4D-9C51-85C3C2B0C1ED', '4601026306594', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A9006B1-6296-45E9-A6A9-77EE04C6300D', '76B8F584-AF30-45ED-94A9-DE12B99C4A54', '4601026306600', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1717B823-A283-44D3-88BB-4014481FCC5E', '59AF369A-0ADB-450D-A28A-22DECDDDA24E', '4601026307157', ' 125  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9042838D-67D3-4D8E-B0C2-69D2961B51C2', 'FC0624EC-06CA-40C8-85F8-BB047C340940', '4601026307195', ' 250   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55A751D2-5F9B-40BF-B8DB-F2D9B4739A42', '72AF59D5-2CC0-488E-83D4-5980DE935408', '4601026307355', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF23FDD7-27D3-4A98-B4B3-FD02B830621A', 'F49C7DA6-CCA4-4684-A188-D2716F3E5935', '4601026307416', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C82FEA74-5A42-46B2-876B-D083C2187BAE', '101C5D3E-F6E1-41A1-A684-F45129CA7128', '4601026307461', ' 50 5 / - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('513FE91D-B28E-47FA-9789-B81F3D5DC3B8', 'A5BC156D-207F-4B66-A5F3-A914234D0C73', '4601026307485', ' 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20CA7196-883E-4E8A-88FB-310741E7BF88', '72B6D958-8AC9-40C8-95E8-7FD2F7E64892', '4601026307560', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A17DEFCF-161D-4ECE-A0F8-56AEFFCFC0C1', '72B6D958-8AC9-40C8-95E8-7FD2F7E64892', '4601026307577', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2311F20E-639E-4CF5-8398-DB338EF8D33A', '88217AA5-DBDD-4A09-8AEB-193FEF0C978F', '4601026307584', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC1EFC41-6B8B-4437-A7F5-43CD7CF37CA1', '1D1F8FF3-067F-4CFA-9141-4B4F1415B888', '4601026307614', ' 7   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D654D5CD-074C-4217-BFF2-0AB3938F75EA', '4311E9B9-8D0D-4F4E-986D-5BD7D9D61486', '4601026308314', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4690B35-4112-4BD8-B4E0-6465925E58AF', 'CB926E02-D4DA-4712-9207-87590762A9F3', '4601026308321', '   125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55CF4685-666F-41E5-A508-57665301C7DE', 'E12033F1-FC8B-466A-B5EC-C498935CB478', '4601026308338', '  150  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8AA2456-B0FF-495A-942E-F07CD3585551', 'EDE495F4-565E-4F73-97B1-67C8287F60F1', '4601026308390', '    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D836998E-3B5B-4247-AC24-9E18FC2C4B07', 'AAB1A829-0DB6-4D9E-8496-3211BA6EBD8C', '4601026308406', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C621982C-B5F0-4133-8D92-53798D33DB1C', 'B73E4A2A-083C-4441-8223-11CEC7C6EAB1', '4601026308413', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54A043BD-6F4F-4CFF-8274-B1B5A5C72B8E', 'B3DF35AA-F62E-4303-A6DF-CB0B8304A120', '4601026308420', '    /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58C0FAD7-3A88-4924-9717-361F52A72872', '96CD570C-4103-4F00-A2A4-3D0FF82A9849', '4601026308444', '   + 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F09DED5-66A6-4C34-B224-826B0620A153', '14CE88B9-DFF8-47E8-892A-7ECDC7E83C96', '4601026308451', '      125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E2FB9EE-1438-422D-8AE5-8B2A18EF42AF', 'EDE495F4-565E-4F73-97B1-67C8287F60F1', '4601026308505', '    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('633F57E5-1339-4909-BF94-15989E8EB161', 'B73E4A2A-083C-4441-8223-11CEC7C6EAB1', '4601026308529', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('501FDE3A-2310-4293-85B6-27F14679867C', 'B3DF35AA-F62E-4303-A6DF-CB0B8304A120', '4601026308536', '    /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('585B0148-44FE-4C21-A806-1F5CA3810E0D', 'D5441701-D957-41E5-AFD9-13585EAD99F6', '4601026308567', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C92159E7-36E3-4D8C-A68D-06F81A772B98', '4311E9B9-8D0D-4F4E-986D-5BD7D9D61486', '4601026308581', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45AACA59-2E8A-4244-86A2-7AAE7880271C', 'CB926E02-D4DA-4712-9207-87590762A9F3', '4601026308598', '   125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4051D4C3-EB45-4B47-BF8D-FB9CD6C6E401', 'E12033F1-FC8B-466A-B5EC-C498935CB478', '4601026308604', '  150  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E453EB90-4B09-4A44-A53E-F6112E8B7240', 'CB926E02-D4DA-4712-9207-87590762A9F3', '4601026308635', '   125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('145F0C10-91ED-4C5B-BB72-75E849368C63', 'E12033F1-FC8B-466A-B5EC-C498935CB478', '4601026308642', '  150  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1A6227D-ABA2-4205-9419-B8BA366FE88E', 'D5441701-D957-41E5-AFD9-13585EAD99F6', '4601026308666', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FF5A135-EFAC-48F6-B4B3-46CEECC917E5', 'EDE495F4-565E-4F73-97B1-67C8287F60F1', '4601026308758', '    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECD1728B-64F3-44B5-8BB4-106DAA359230', 'F03C8DC0-272E-4575-8A0A-4593B846E657', '4601026308765', '  125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2006130D-4B37-4206-85C1-F07FE8633D72', 'B73E4A2A-083C-4441-8223-11CEC7C6EAB1', '4601026308772', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0D26D82-DF0F-48FB-9040-4668DB4B51EE', 'E800A4B0-6C98-45B3-84CE-B1C4929543CE', '4601026308789', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B71030D9-B3E3-4EED-B13A-421565E63639', '260A1AFE-2B4D-4D4E-9A72-731B58B45970', '4601026308871', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B667892-E74F-4EFB-A857-44A5CF7F41A4', '3111C656-26AB-4CC0-9F1A-689089286777', '4601026308918', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDCDA4A6-2790-47E8-849A-10EB4EBFCBD5', '78DBA34A-2933-42C5-8D74-719EFC467C8C', '4601026309007', '  1% 15/+/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01D5DAA2-9594-4D3B-8723-ABB5A0A42F24', '51E40F50-FCE8-4F7D-9764-2B4606186A1E', '4601026309021', '---  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C31782E5-7BA5-46CB-93F7-26D79CA91820', '6055FE90-AAB5-47C9-8654-4B05273DDE0D', '4601026309045', ' / 0,2   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8B96F5F-7DCC-42EF-A2BA-B699686AF030', '3B3EF26E-2F81-4271-B65C-74FAD2735916', '4601061000082', '  /-10/  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F541A077-E257-409B-A5AD-34E9B916530D', 'C193D8FA-59BE-40B4-8611-84C09CE02C9B', '4601061101048', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AEE0009-162D-449A-9DB4-0DAE4A6B08F0', 'DCAECD3E-E6B8-48A3-9175-403AB0015F5C', '4601061101055', '   -12   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('707ADE6B-DF05-452B-9DC8-913288FDED84', '6F1DA96D-1E4E-4C99-A484-4124EA7B25DB', '4601061101086', '  /-10/   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DF44214-D0B9-406B-8057-8FA4289EBA5D', 'F7BD5FAB-E156-4293-959C-636DEE76D3DC', '4601061101192', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB5C61A0-D361-47DD-873E-61558485C677', '0E212E38-CB40-4263-A590-01B376B16C22', '4601061101208', '   /-52/    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5E5C617-D659-4D0D-A9F6-FB346D9593B3', '16816789-22FD-4A06-9776-AAAED8140458', '4601061101277', '      32 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA8CECA7-69D2-491D-854B-5169B6CF194C', '4810534C-EB13-4C16-9C12-D4C25268B5E2', '4601061101284', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B73165EC-77BF-4361-9A72-EDF8C9B81E08', 'CB2AC168-8FDF-4752-9552-6A0322222408', '4601061102069', '   /-22/   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('809BCE70-6C26-40EB-B711-7FF7625C9903', '2ADA47A0-4FEA-4966-88E8-5430AD09286C', '4601061102151', '     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D88A0A4-E084-494D-8679-8AA0B3D364AA', '8C4D695B-2D69-49A3-B133-9BF07CE9DA9F', '4601061102168', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD92B016-42D4-49CE-BC9B-B745E9B6EA7D', '15960FE0-8E1F-4517-A0A2-9D825251AFAB', '4601061103462', '  meed -s10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8652D56A-0042-4D1B-BCC6-C83B6BEBB3E1', '7565AD9C-E225-4A79-B762-3BC0AE58FF11', '4601164000910', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('107014DB-7C75-445F-8423-2450E5875D12', '87AF0254-847F-440D-86FE-898F2C3C55DF', '4601164001597', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8D18796-6827-43E4-B559-F1A40AF44C2B', 'A83FF40D-7012-42FD-B97B-3D2B7EBECE97', '4601164001603', '  5 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB805688-2BF8-4239-B4BD-39B155738CF2', '501C8E57-0CFC-410B-B720-1FCFD3DCADE1', '4601164001665', '   -  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7EE4E38-1F4C-41A7-A2F9-04C5B91B9541', 'B0E86E94-1E5E-4C70-8BDF-C660AF731313', '4601164001818', '    30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F848B039-0BC6-4D1A-9322-342C872994C0', '2FF9291C-D2C2-457A-8910-11FA51BC6FE5', '4601164001825', ' 5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAEE5517-D68F-4D6E-B671-DBDC90F9AF10', 'DAB3104C-14F5-40D6-B660-6BB7D793144D', '4601164001863', '      2,5  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46E561F1-05CE-46AE-8DD4-11A32BD0BB86', 'EE4D7346-F46F-4352-9FCB-1F81E172C78B', '4601164001870', '      12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1035516F-6364-4B52-BE55-0613C0906823', 'D359A52B-FBB9-4C60-8FF6-1D3834888ECD', '4601164001894', '- / 2+ 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('911E1053-4722-4646-9F3B-1C9D98E29635', 'C87C7B5F-14A6-44B1-A096-C4C487E71C9A', '4601164001917', ' /   / 0,4  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD133805-1F65-4123-B8CB-E4AB6BF900B1', '16E66353-88D4-4FAB-86A5-6860C54089F5', '4601164001924', '     7 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B76ACD5-ECDC-4653-9205-91792DF906A1', '992D367C-3C1F-4C16-9034-0F4A23A2A14D', '4601164001931', '     7 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C97B4111-9853-4D75-932F-7F42254AF1A6', '40BE3023-5F17-4C98-911C-CF69ECD310E8', '4601164001962', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FACBA58A-AAF1-4965-9B50-69A550C335FB', '3EC99C31-6D27-44AD-ACA0-481155A429A8', '4601164001979', '  40 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AD5C7D6-DE96-4FCE-BE32-9137E63C7F73', 'B43B2E9E-1604-4A68-88A8-2E378536966E', '4601164002006', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB59E686-743E-4D04-A91F-86F2E291C969', '06F8FCF7-A7C9-4617-A6AE-BF66A07F15E4', '4601164002037', '       12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C60D9C39-8AC8-43A9-A6BC-78B115C3A490', 'E2FE2103-8818-4A42-9354-C5DEA769F5F1', '4601164002044', '  /    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EC0C5B0-D064-4920-ACC0-161383DC54DE', '047C4218-52E6-48C5-8BEF-F25A89604E86', '4601164002464', '   /  /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A8218F2-5467-4702-A5FB-622F8CE18C49', '464F06FE-F24A-4743-A275-7BCB9B5E9C61', '4601164002488', '   65 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F4ECDB1-B01F-473F-82E1-B562B69A81DA', 'EE4D7346-F46F-4352-9FCB-1F81E172C78B', '4601164002624', '      12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F58B1857-1F8C-4809-A64C-C5B81900DD4D', '2A4BDD98-59C7-4AFB-B7AB-484217293876', '4601164002631', '       12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('048F0940-0962-49A1-B319-65B065F9DA3B', 'F8F5EEF0-868A-48E7-8406-0936286F3106', '4601201005649', '  250   /.  5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75E83496-899C-4539-B6AF-470D99D05D67', '9BE25D72-1A54-4883-B346-56A3347E82B9', '4601201005670', '  250    4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B597E2AB-C3E6-4411-9FF9-037E523FE2A5', '304C42DF-5712-414C-B14B-D3493705222D', '4601201005724', '  250    .  6.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08ADADCF-CFC4-4F14-9D1A-A14F0387CADB', '03ECF807-3858-4076-B3C0-E82E15ED7359', '4601201005748', '  250     .  6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CAC09BF-73A6-4BAA-8288-C35FC543B1F3', 'D4FDF69B-D430-4D8A-9DC5-2D6DB8E1EECD', '4601201005755', '   /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0815F559-051C-403F-AD08-C60C27C37F67', '74222963-060A-4E3B-960E-457F12DE9402', '4601201008190', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5E9CE01-CBF7-426D-8C84-F37DB76BB0DB', '08A8A9B4-D7AD-4939-A882-0BC7EE925047', '4601201008206', '  250   . 6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E12C52CF-6167-467E-96C1-0F573AE5A2C5', '605FA4A2-74E9-4A66-8EE1-E0253B8D9099', '4601201008756', '      1,5 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21216303-F3BC-4DA0-BC3D-5D2144A70AC1', '6F4A2E4A-22D2-405A-A83B-3BBC92B38025', '4601201008763', '   / 0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('523B64FD-4C37-4FF3-8D38-60713C3C4223', '24F945CE-6AB8-4343-AB56-EE4FB54212D7', '4601201008800', '    0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A17B5AF2-845B-4EEC-8D3A-1C092B0D9FBE', '0487B356-6981-4449-86BE-F505D8C00B6F', '4601201010964', '  /   .  4 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B790955E-C757-430C-8E34-40C941F7E640', '2FA67C79-9891-4F34-B08C-1D02E29D2762', '4601201010971', '  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF7A6075-FC26-4AAA-BA2A-14B0A22401DE', '89418F7A-FFA0-4F80-8D11-0192726C7FF5', '4601201011107', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64BC06CC-369B-4A21-9E5A-CC6C92FADD71', '4AFB7665-6863-493B-817B-029D832573E0', '4601201011114', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAA0C6B4-62F4-4DAE-B5A1-C250D92B2498', '3F493077-600A-43D7-9B28-6676CC701201', '4601201011121', '       6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D75E5EBE-5F53-4290-AF4A-B74B9D4F2126', '6BEBAF0A-3CBB-477D-B34A-A1169CBC41B1', '4601214000020', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A86B3140-4882-4ECE-81FC-333ED923B40C', 'F67C88E0-3CBE-4C9D-A312-81941E6C2398', '4601214000075', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('026E8C1B-808A-4A2F-B1DC-4809F51811A5', 'B6C9BC87-96C3-4285-9FAD-01189E81D4D4', '4601214000105', '--  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94979102-1893-47AD-B751-E99ACEF44DFD', 'C08FA347-858C-4418-8440-2FF0B4C6CCC9', '4601214000129', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B795244B-114A-49B1-998F-C01C8B964375', 'FD55BB95-4BEA-4624-A162-4AA263576999', '4601214000136', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('838FACF4-96E2-4BDB-A1A6-2460AA7FD60E', 'BC4522E2-AE70-40D8-AE20-F09A7882D039', '4601214000150', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB9E43D2-B074-4BA4-8736-B7ABF1E79611', '80573107-752E-458D-978F-1DB52073F236', '4601214000167', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0932AA40-A017-459F-BBC2-E77F1E5F03A3', 'F9BD7430-31E2-4F1C-ACE6-A319D067C10C', '4601214000181', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3810650B-0E17-4592-BF50-F0628DB77CD9', 'FF2DB31E-B9B8-40BA-AEFF-DA574263CAED', '4601214000198', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A54BF3C-1D9E-4804-83B4-063F165A8749', '53F44CB9-5048-426D-B10D-E7534DA99F90', '4601214000204', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8A6FCA4-75C2-4970-A94B-9CE88053F066', 'ED51CA63-C277-4CA3-8ED3-2D8C65944591', '4601214000211', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3B3A618-6490-4854-B797-2BB814FEE818', 'ECC1EAB4-BF04-4A3C-918F-E4A1AF4175F4', '4601214000228', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9267E4E9-0F7F-4104-ACE7-98AEBDA2234F', 'E5BDAF90-2AEF-468C-8CCC-39B8D3F7A5CA', '4601214000235', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADE4E5CA-ECEA-4931-8C35-D8C1E08E3DF3', 'D7FF7774-6A3F-4CF0-AFFC-F9BF68D3E855', '4601214000266', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7DE5C46-95C6-472D-831A-C6A0587C0684', 'AA2E326D-27EB-4F2D-8B37-AABC818B1294', '4601214000273', '  //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CDEB447-403B-4A30-98DF-C135C93CBB90', 'E7AB6940-680A-4A2B-B12B-66F8C3BFADCF', '4601214000327', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33B41E37-F682-46BC-964C-B9C5A4359F00', 'F0BD4526-605C-43F2-B775-2468C9A55D85', '4601214000334', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35F2FDB3-EDD9-41F1-AB8B-FC9EB6BE3C92', 'EE4EE182-86C7-42BE-9CAC-C227F7FFF692', '4601214000358', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC50C32F-7ADB-4083-A5D8-9C2CED3054D3', 'CC3590F1-019A-4ED0-BE64-99DC56099456', '4601214000365', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D65F9F1C-017D-4BD6-B4FC-83D653376B3D', '2FAB8983-8833-43AB-9D5A-8ECC57F03DD2', '4601214000372', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('931EA100-01AA-43F8-BAB9-85F65EFD5E00', 'DF8E27AE-2944-4C05-A2F1-5057EC2D5F8F', '4601214000402', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9374365D-ED51-441E-BB72-F7954AC865C5', 'DD1B9079-AB49-40F4-9D8E-3369A557E37C', '4601214000419', '- / /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7EF0FB7-3C68-46C9-949F-A21A4838E655', '05861903-7861-4F62-A69C-5FA31B4EF237', '4601214000464', '  . 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34823293-FE0B-476C-8DBA-BBD4A36D4400', 'F832CBDB-1091-4159-AF62-9C6A7ED1D5DF', '4601214000488', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('194DA3C9-14A8-4E18-8136-562277377442', 'E77D9044-DACD-4349-B2A9-D9AD44F5D360', '4601214000518', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC419EE5-BD91-496B-B927-1C6F04EF3669', '8AD9511D-C181-4521-8098-C3A94BABE2D5', '4601214000532', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65244ACF-ECA4-49F6-89DF-D53C395ED262', 'A9BA4798-D38F-496F-A867-EBC93DDD7817', '4601214000556', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0D7101E-E24B-46A5-A5CD-4C484030B963', '590483DD-D86F-474C-B024-FF0C34405C6D', '4601214000624', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DF2DA99-D784-40BC-89CA-FEC6F593622A', '4B12C0B3-4BE1-4E6C-94BD-7FF87D79FD36', '4601214000655', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C7B87A9-2AD6-4228-B6B5-415B0276E91E', '7905EB0F-B378-4710-9603-F4EF224550B1', '4601214000686', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85B6DD17-D4D2-4EED-B7F3-717AA67AD6D5', '650D85D5-C21F-4BAA-9059-16726E43AE09', '4601214000747', '  2 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12F8D20E-3851-4384-83DA-14AABF7150A5', '76B13EF9-1CFC-4F3C-B0FA-3434CA1D6CA5', '4601214000778', '  1 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D9AC87C-C423-4B6D-B6EA-F2FCFDC3B991', 'B6070304-E403-47A2-8394-966AB2BA7736', '4601214000785', '  2 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('851D689E-10EF-47F2-8F3B-A9F2F49E30A8', '3B666F55-0DA4-4C0D-BE8B-09B176C65372', '4601214000822', '  50 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('685082FF-6CDC-4B3B-9533-160A74689352', '6154278D-C8E7-4DCE-8B16-729AA52523A3', '4601214001034', '  3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('642ACD6B-FCBF-4FD5-8FCE-2734EC10E3A2', '70EA7BA1-A674-468B-8EE8-E0B87CEE4C7E', '4601214001119', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E94B2EB8-F561-42C2-A183-6B2FA8600562', '949842DF-4C56-4F79-86AD-30D54BED3678', '4601214001515', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('082717EB-C9F7-4D02-A217-C6E9AA4B49D3', 'F801B068-FC81-405E-8838-A141F7F908BD', '4601214001539', '     / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41DE2579-2DB5-482E-8B47-BBF0CAB6D0FF', 'FA604C1F-8D2D-4B0C-B85D-5950DB1A5E97', '4601214001546', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EDFC8FF-D243-4E61-B3F8-3445A2FB4024', 'AA50B6A6-FC46-433E-9DB3-6994E687BC6E', '4601214001553', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBCCC191-3A83-4B36-B5CF-AF760331FB4F', 'A769DC2A-BE04-42FC-9775-DE0AF2E65DA6', '4601214001560', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BE1885B-28A1-4058-8780-1EBD7C794EA1', 'EE7792FA-6DA0-4DDB-98D3-18ADEFE46BC1', '4601214001577', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E4F9776-EFB7-482E-9670-55E0C8141F8B', 'F08B2BB9-2C0C-4682-A2E3-F2B7DAF65422', '4601214001584', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90C484A5-8E96-4EA9-A0D0-3CBB11CBFFCC', 'E80CD40C-DE82-4C7B-925C-B1959A17E642', '4601214001591', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7990B1C2-FBD6-4EE2-9CC1-2CE099EBACD4', 'D3FBA49A-A4D3-4F69-A0D0-EE3652A8BD1A', '4601214001607', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E7DB85E-997A-4914-9FF1-A16A55880BD8', '8D2FF5C5-1A52-49F3-9A75-C4A3B161A098', '4601214001614', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36B06E86-161B-4A34-A7D5-A3553420A0E8', '42C9605B-7BCD-4DEB-8ECF-99BE0718DDF5', '4601214001621', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A90C63B1-FF88-4464-A17A-471EFA7E7850', 'F6FC2714-A739-40B6-AAFA-ABB0A3C23201', '4601214001669', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7D071CA-9ACD-42D3-80B1-A7626F76383C', '9A6B5410-1C94-4A55-9DB1-B7846369DA22', '4601214001676', '   1.5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA7DB89D-763F-402F-8513-82FDA53B5D55', 'A1F56594-05D8-4DFD-B722-3A0DED96B968', '4601214001683', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1F569C5-1E00-4DD2-9272-B1290D52A3C5', 'C8B141E2-45BF-4053-A865-05190EB15B37', '4601214001690', '   3 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F787293-B353-490C-90C2-AAC73DFAB802', 'CFFF73D9-112B-4ED2-99D6-E5CE326C7E01', '4601214001706', '  // 3 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FCD66CD-D84E-4648-AC42-D7C0AF8B23C8', 'C848E069-D72B-4971-A24A-D472E33D031B', '4601214001744', '  3 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01EFC289-34A9-4A09-BFC6-93EC5273CBD0', 'CDF9C81D-B3B5-4B3D-BB57-8C529EF8FE31', '4601214001799', '  1 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0F2E7EE-7BF1-4398-B98D-42E88AEC29C8', '49831AB3-F904-416E-9B78-095FD862EF57', '4601214001805', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1CEDADC-8A1D-44DF-BA1F-00AC50301098', 'B82DC6B4-4F53-4B60-88B6-FC861A2AAE6F', '4601214002130', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A83EEEF8-4602-4CE3-9603-838EF49FA6D2', '60ABB04E-CD32-4514-B5BF-7F7D479AD2FD', '4601214002543', '  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E531D3D0-7074-4372-8D17-3FD38BDEC758', 'FC00880C-6207-4C89-9BFE-3009638D5936', '4601214002765', '-  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F846E59A-0265-413C-83DB-D5711627C4F8', 'F929A27F-04EB-4310-84A0-346D77C371EC', '4601214002826', '    / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDD014F6-61AD-43F4-9A74-37057EA18211', 'F37B606F-F5E7-4A77-9DDA-7B38CB727030', '4601214003038', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6AAA85E-8B39-458B-BBD3-CBF88D23C799', '55741802-70C9-4071-B88B-A523CB162F12', '4601214003113', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EFBA5E5-9EAC-48F7-A3CE-961362CAB48D', 'ED0B028A-7632-4893-AEC0-033022417CE3', '4601214003380', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA500047-9512-4EFA-8E5A-1EA0449B236E', 'EB9764C1-8E16-47FB-ACFB-E9690C82D939', '4601214003519', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72831227-2561-44C6-BB09-2B85819DC333', '10CAA46D-DB8B-4653-AC2D-9A902DB1FEB0', '4601214003632', '   1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('712D614C-E320-45FF-A79A-32EC5F85094F', '4B08BA3A-C01C-4B70-8CEB-B4D1F0FE53F3', '4601214004882', '  +  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('242872B7-A5C1-40AE-84AA-699389559196', '8F519194-C982-4A8B-A0FC-45603BE96043', '4601214005131', '  2 20  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D867A5EE-1907-4699-9407-61C33601A4C9', 'A8F282A2-083A-4607-9B03-98845A367A63', '4601214005223', '    / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBA606EB-D32C-4D52-BA1F-351226CEA263', 'CD3D8453-9115-40E6-8F22-CC831D920DBC', '4601214005292', '  1 / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E967733-85A7-490C-9A3A-EEEBCDDFFF57', 'A08CC95B-1450-4E86-B731-AC96C42548FB', '4601214005407', '  1 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC246AF2-3CEE-42C7-AC6D-A83DA4ED083C', 'F2F3C922-1687-49B8-8BFC-60B51081ABAB', '4601214005698', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CAD1D78-3E97-43D9-AE06-FEE529F033EF', '26C718A0-877E-4832-A3F1-E189757BBBFF', '4601214005728', ' -  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC69B25C-CA5D-472F-B869-C8370FD40108', '3E1321F0-9BC1-45AB-BEBB-D0B750A2C079', '4601214005759', ' //  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B40E459-1489-44C3-BBAF-13DE2CA6348E', 'EC38FDD7-063A-494A-AB50-0602737EEF53', '4601214005773', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1637E7F-6879-4C95-BC3E-07017B2C2CEC', 'CF5AE13D-39EE-4458-A195-07BDD8999BE2', '4601214005780', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58A554CD-D0CA-457E-82D1-611DA8253CEF', '46EA9905-4423-4E58-B75B-206454E1CA50', '4601214006008', '-   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1120B452-E93D-458D-9231-A9CBD19F1C9A', '24029E0C-CCF4-431E-A200-5208A6A83E9A', '4601214006152', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4250729-51B1-4A90-929E-ECEA3FC5129D', 'EDE1BE16-04DF-4CF4-9788-4E26F8F9977E', '4601313000426', '   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA081930-5E22-4256-88BF-7D8B05B03809', '809DF8F3-A681-48BF-BE7F-6D10A69EAD08', '4601313002598', '   140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C37B4B39-17D9-4179-A74C-725F8FB4F102', '7827B28D-1B1C-4ED8-A9F5-53FC118BD973', '4601313003878', '    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96722860-EE91-4B4C-A6C5-930A9173460E', '3C8CD7B7-D3F1-4A65-AA97-2CBCD6D5060A', '4601313009016', ' -    280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BD83B04-F2D2-4DD9-88B8-C03DBF5A5248', '57D9D03A-6150-41FF-BBAA-F691710973CE', '4601313011521', '   / 280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F7E26BA-3F7C-4AB4-9074-E4177C5C17D4', '980A67EA-7F9D-466B-B01E-C755D347863B', '4601313011651', '    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCCADB22-756A-4E18-9F33-D3D6936E40FE', '1ADE997E-8856-4772-B399-4F7CBD79E176', '4601370000995', ' /     . . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42D1EBA9-95F1-47F4-84C3-53A524546F06', 'EB2DC4F9-E92D-4483-AA76-F4FE110E5F55', '4601372001631', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8DFB20E-CDED-4360-A769-8C29ACE6B09A', '8D5BEA2A-84D3-495D-ADB5-ACE99E596FE7', '4601372001648', '- /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD6B1D26-D803-4EBD-9D86-FD9E6AED361E', 'EDAC84DB-E9E6-45EF-83DB-1E68131C3D5F', '4601372001945', '-   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB6799F3-57A0-48EE-907D-1222A58FC571', 'CB9B20B5-1A70-4776-A587-FDB7F219EA5D', '4601372003536', '  Lili 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E62B7B52-29B6-4A56-A8AE-97E5E2C61A80', 'B7431D39-D8B7-4BD7-B5C2-2217E0F30F27', '4601420002078', '    0,6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81B3C6EB-4F56-4100-AC66-792D19EC4687', '99345AB5-912D-4148-9276-F9D76D54C15E', '4601420002085', '   icr  0,6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FBA2D32-F8B8-449B-BB44-171FFB7AFAAE', 'EB829087-84A6-40F1-8FB8-871746A82899', '4601420002108', '   znse  1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79F9092E-7C61-48FD-B0CF-5D629C51E1C0', '8F19EF44-DAAD-4487-968B-C24A10534A17', '4601429000013', ' 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE7E281D-BD3C-4DF8-BCB6-2DD37E76B238', 'DF6520C9-B184-4BC6-A9EF-136258D5318C', '4601429000037', ' 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6997E9AC-A6E2-4310-A1CB-A4E3328FBA5A', '54B34C68-B417-487F-85CD-49D3C3F9EA5E', '4601429000051', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE186B84-BF19-4021-8E1D-F3364250607D', 'BCD63BE7-D7F1-415D-B6EE-5B199DA96941', '4601429000075', '   /. . 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F127994C-732F-470A-968F-4B9CAA369996', 'DCA08CFB-90DB-4112-ABBD-ACD8B37D1736', '4601429000433', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0DF5DC8-D770-4A73-AED2-DCA722A5E3AE', '67D65AE1-1FCA-4271-ABE8-22A5050900C9', '4601429000945', ' 25 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FA31442-0C54-4D8B-A2B8-9A0B7C13B03D', '04803A7C-27B9-4AF2-A4EC-C4C088AE4F6D', '4601429000983', ' 5%  - 10   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0D53B6D-CB32-461C-A2D5-4C459B60741F', 'FC2468C4-6F35-4CE0-A832-9DC9316ED4F5', '4601429001010', '    20% 30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A89DDFB-5A90-4B55-B749-8C370A44DE6E', 'F16E9600-7C7C-44CD-95C5-725E249085FA', '4601429001072', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('201D0AFD-E8AF-4AE7-B4C7-D476F40367D9', '9A64E2DE-B2EE-4A34-AFAD-F08E70F8BBBE', '4601429001263', ' 10%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC7F8085-B136-4547-B6EF-0A351F9DE9B7', '2AE17406-9CE2-4275-980B-B93E6EF2993C', '4601429001386', ' 10%  - 40 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EE99D6C-4A1D-49E0-81BC-F4D1FBC1EB0B', '7FDB950C-61BF-4E8B-B2FF-22F4D4D970BC', '4601429001881', '-1  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('077B4E1D-45E3-4AED-A40E-946A92CAAFF1', '6CDCEDC3-4E15-4032-A72C-4495AF58770E', '4601429001898', '-2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('011D0DCA-D3E8-4F8E-8CCD-66FAF6A5D357', 'D12C4CE3-A4AE-4468-BF26-0A1DE7B655C2', '4601429001904', '-3  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5765A8C4-A9E6-4890-9B7C-DA5241DD3AF6', '060D3294-FED4-4642-9C00-175BE22C0F4D', '4601429001980', '- 2%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E18828C-D79E-4E0F-BB2E-91DFAA3527A4', '47347D5A-EB1E-4760-A1DA-A1CFC46AB4E9', '4601429002147', ' 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06CA4C64-7ADC-4745-BABA-E98C6BEA7C34', 'F723737C-C104-48EA-BB4D-533F006E61D8', '4601429002390', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1697B20A-53F3-4204-B1B5-62722DFBF4C0', 'F25EA392-F022-44EA-B882-EBD57C1C0592', '4601429002413', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F06A1DE8-8B6F-418B-8112-BA26E3B74A9A', '2276EE8D-6860-4DCB-9DE5-F240011C01FF', '4601429002512', ' 1,5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CACDAC7-9EB8-4385-8E55-A6A93F2784CF', 'DDD84842-F12C-4A7A-9423-6DB06487D11F', '4601429002574', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A15AE879-DFD0-4453-A159-9C0A8FBBBAAF', 'AE2CB834-4845-46A7-B4B2-AC333C765088', '4601429002604', '  20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECF2E95F-7256-456D-9049-DC623DCABAD9', '9015A993-23EB-4FD8-BA3B-29D1A44657C6', '4601429002611', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6B99EA0-C909-413C-AFD3-8FE0065A9DD3', 'C91E8F72-C8C6-46A3-9CB5-AEF6FAD95F66', '4601429003991', ' . 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('300B18BF-B9CA-489E-A0CA-F684251DD01D', '8D40BBFE-724B-49DC-8BAA-468D00AAD15E', '4601429004011', ' 14  / - 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E5BE4FA-4CA9-4E3A-A870-9F8B7F32497F', '38EEBBD7-F51F-4588-A33F-8FAEEC1266A8', '4601429004059', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04DAE210-C920-43EF-A871-B4DF396AB163', '67D65AE1-1FCA-4271-ABE8-22A5050900C9', '4601429004189', ' 25 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E256BF9A-FB62-462A-A578-3405B9058DAE', '44181013-FF35-4274-B242-1B92E0708222', '4601429004202', '  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16E14097-3540-406C-9D01-F11FE4BFA6F6', '9F85ACBF-8691-4211-BCB7-A5405B392AB9', '4601429004479', ' 10%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BF02D6D-5212-40F3-9769-8F9B8DAF47FE', '60698075-28C9-45EF-95DD-31B45FA66A5D', '4601429004493', '  20% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F135DF7B-1F6A-4195-982D-658181574876', 'A135082D-976E-4D37-8E1F-C9381A5A4419', '4601429004516', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9240D675-07B9-4E75-BBBB-5DDE16F0058F', 'D3B2013D-1DCA-4F18-88DF-A7F00FA7990C', '4601429004608', ' 1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36399D9F-DF57-4B12-8BCB-1597BE13D044', 'CAEF4753-569F-44D5-8AED-5934AA3C268F', '4601429004622', '-  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB491769-2483-4536-BC11-818FFAAE77F2', '49B31A40-8B89-4183-B6AD-45CE3DC14F60', '4601429004790', ' 25 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FACC7937-5408-447A-AB03-FAE09CE59815', '789E3947-EA95-40E1-8114-23424FFEF2DC', '4601429004813', ' 125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF536FAC-715E-4719-9249-AB1FCEB154EC', 'DE830E02-D2ED-490C-A935-EFC5D8846384', '4601429004936', ' 25  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2AB72B0-4F06-4851-A650-C183266A5C4C', 'E9ABFF26-DA98-416D-83F6-AB48FA73ABBC', '4601429004981', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07CEE93A-333E-484C-B2CA-C6E4EB4C2825', 'DE188173-C90A-4D1E-A5DD-41C406E2CCA6', '4601429005087', ' /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A98AF9F9-C2FD-4A4E-9458-8B44B47161E0', 'B773F4EC-4BD8-4A4F-B36E-82CFF1C1F2A9', '4601429005155', ' /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09BB11FB-425D-498A-A7B2-13833DBA1E76', '1033DED4-E3CE-4DB4-A9BB-75802ADD935C', '4601429005537', '  50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E90D16B7-19C8-4D23-BE3D-3D548E454196', '95B305D9-E231-4C37-9F61-D760F08AD466', '4601429005636', ' /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCC3DC59-AD7E-42EF-9AB7-CAFCB6989DFE', 'EDB9369D-9D98-475D-BF83-6C7BAC1A7C56', '4601429005704', '  30 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E59032C-FEEE-493D-B7A2-C14E2704D5BF', 'EF1A1D38-212D-4F25-982F-01E7FC0B6A02', '4601437053742', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EC1C3C7-A82F-4F04-9DBA-9A9FAA8B3CF0', 'D6015986-9E3A-45F6-BA03-3CD12F368EDA', '4601498000631', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('021772F0-858D-4BE0-854B-D73CD202C219', 'E3F0A76F-D596-4279-91CA-5233E7351F5D', '4601498000679', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7905751-C5D3-4507-A416-B7D982628F2C', 'E80CD40C-DE82-4C7B-925C-B1959A17E642', '4601498000686', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A8CDED2-4EC9-4137-8F51-1130F8EF710A', 'ACC05EBF-5B7D-407B-8381-86EBAD789E51', '4601498000693', '    1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37D4F2F4-577B-49AE-AE1B-A8B584D7F14E', 'D9A77BE9-D7F6-47F6-ADD4-144D4A9C3424', '4601498000709', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C204EA3-E0D1-4063-A530-6860B309B8EE', 'DB98B7FD-D599-4041-985C-1FE5048ABBD0', '4601498001188', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74E49420-F0F6-4D38-901D-CCDCA1A557E0', '592010A2-8CF4-4246-A62E-B30D44030F28', '4601498001959', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('089524E4-8831-426C-B558-96CD494AA183', 'D58E150C-0200-4E37-9A45-8130B1EB5751', '4601498002031', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C003781-F094-4D8B-8DA4-DC5920A36E45', 'B1D8B045-6870-49FE-AB88-48D0F84F0D0E', '4601498002055', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('206688AD-29B0-4C68-BB77-80812FAD82D3', 'F6FC2714-A739-40B6-AAFA-ABB0A3C23201', '4601498002079', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('548602C8-67F3-4B56-84A0-CA202C6B3AFA', 'CB813FCF-EFA6-4F7B-BF3E-E556A02E9CC1', '4601498003519', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32D3401F-119F-4BA0-AEB6-8996100E3502', '9A6B5410-1C94-4A55-9DB1-B7846369DA22', '4601498003540', '   1.5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('225C06DC-ECB4-4EB2-A8EA-C957993117D3', 'EDBF46D0-544B-40E5-B048-31A38738F0D5', '4601498003588', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DD31BCF-A5A8-48C9-9212-365829565422', '3E45D571-688C-4DAD-B2D7-1B08528B08F8', '4601498003625', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E432404-FFC1-49BA-8B6C-B2B18991F013', '95286DBF-421D-422B-8B42-315AA34BAEE1', '4601498003694', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7368EDD0-2A0D-4E06-ADEA-AB2BB3269EAB', '1A73C679-1979-4CD1-BAF5-529B45141DE7', '4601498003717', '  3 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11C1AB8E-4BE2-4915-8828-569E6D60AD3A', 'C0A630B0-D2EB-419C-8A4C-F5F89E176BE3', '4601498003748', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75B3A251-EDDD-4E33-81E7-7362C37DE418', 'F37B606F-F5E7-4A77-9DDA-7B38CB727030', '4601498003823', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75436345-903E-432B-B1E4-5F82421E9F50', 'F570B8AF-C81C-4312-8BF2-59BDD7CBE130', '4601498003861', '    1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA0F22BE-6F03-415D-A5D6-8FE4A09CE13F', 'CBA17BD6-BAEF-41B4-9731-2A6E77C48A1E', '4601498003908', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A93C1DA7-125B-4C96-807C-4E8634B1DE08', '9CE34760-BF16-4AF6-BD0B-4EBD598593F6', '4601498003922', '    / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7C28C63-2C7C-4A43-9D96-721E77AF8C51', '4DFC25B6-A0DC-402F-B381-6865B7936878', '4601498003946', '  / 2,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7830AC4-39CB-45A4-9DDB-D54D39FC5404', 'EB9764C1-8E16-47FB-ACFB-E9690C82D939', '4601498003960', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9445EDF4-D612-4DC9-90F6-C4E2E7ED6BF8', '1DA3B2D8-F646-46C0-8C4C-446BAF70048F', '4601498005032', '  3 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D07A6C6-1E0F-4AB1-9579-C49F29D463D6', 'DB08C61C-3056-4371-8849-2928E1C3819A', '4601498005056', '  // 20 2 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6606D06-FBFB-4CDD-A303-9292771B5641', 'ADEBE4CA-2E6E-453B-B77B-C86C73920705', '4601498005421', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C284754E-E595-4DAD-A4C7-F729327B903B', '0D0B943A-08E4-455C-BF99-7516F83797E7', '4601498005445', '    1,5 / 20', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('041134C0-EF80-4D01-AED4-67E4E8C8AAB7', '086CE0AC-57D3-4F50-A9BF-5EE4EC67A51C', '4601498005452', '     / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB05F9FB-8163-4993-94C7-37D8569641CA', '5270661B-F591-4938-B1C8-27E61DA02C24', '4601498005476', '     1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD89D3D0-A9E9-44C5-809B-6D02BAB09161', '1E4AE95E-AF0E-452B-A93B-055963455C2E', '4601498005711', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AADF9A43-11E1-4EC2-9DA1-19F470C9390F', '7B5CD0E0-B548-42D0-8935-D5945372B84B', '4601498005735', '-   2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EE83C3B-28C7-4228-B995-291E3E911A92', 'C8B141E2-45BF-4053-A865-05190EB15B37', '4601498005759', '   3 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2908D625-A36E-419B-BFF6-680CAE2332AD', '00E814A1-EF35-4461-BF2B-B698880A6E4E', '4601498005773', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F6F57D5-DF91-4417-BAFD-A157470B7E4B', 'AC014DEE-3723-4A7E-83BD-2C93741E5C06', '4601498005810', '  // 3 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F0E74D3-0165-4AE5-85E1-A371602B105D', 'FD1F9052-B926-4CE2-9D71-4D561037ADEC', '4601498006077', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2735FFB-582E-4B80-AAAB-F18B958BA515', '24D0C700-D905-495C-B443-3329163BD90B', '4601498006138', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52F7B2EC-E729-490C-A620-44BCC223F427', '7CB7DE9E-8A5E-4980-9676-BD30E76196B4', '4601498006169', '  75 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F7200B5-5181-4463-9E02-5F6CA479D401', '88EDB4E0-95AA-485F-B635-FBDBA8D07739', '4601498006176', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8F29C3A-F02F-4EB7-8371-4B70427DA687', 'DB2FC475-34C1-4270-A042-09191304A8D1', '4601498006190', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29A95787-188C-4431-9D4A-3CEB89E49BAC', '061CA084-A530-45A4-A9DC-5F4CF6D166D5', '4601498006213', '  4 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B313BC2-6427-4F81-9D6F-94A375B274C5', '66336D18-D19A-433A-8735-2993769EFEA6', '4601498006220', '   2 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9205534C-3667-49F2-90A8-6E3E1D2B30F6', 'F0D62E3F-EC37-4EEF-BA57-CCB1AE4FA3C0', '4601498006268', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1367CAEA-499A-4793-8ABD-29E532D72D4B', '6657E467-640C-4552-9BB2-34181BE9AEB4', '4601498006275', '  /// 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C33E9C29-B9A2-4BBE-BBDF-2D6039249A4F', '37FE16A6-7DB4-4C89-A416-9DC4738F8008', '4601498006282', '  /// 2 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8BB03CD-71C1-4FBE-BD0D-554233A114DA', 'E1E5FE43-A715-4A86-B267-1F60C662AD09', '4601498006299', '  3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('707B200C-98BE-44FE-BE74-AA92CBFDF28A', 'E1A6880A-04B0-4891-8F92-206AB17C7C24', '4601498006305', '  // 3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1676E2F6-94C1-49F4-8457-67C9B8B7208F', '490F020D-D4C4-4A19-BDE0-5F1D9D2BEA89', '4601498006312', '-  // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2931A12-1659-4B1F-A580-98EA233B1FA0', 'FFB79E56-8CDF-4160-B87A-0E4969F9D804', '4601498006329', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D841F7A2-A4C6-4912-9498-BBFF360B17AD', 'ECB5BFFD-3DBE-49F4-A23F-ED5EA3A554FE', '4601498006336', ' / // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE242950-03F4-4C62-9340-AF2F2E791C50', 'D1E429A8-95ED-4DEA-AA6C-A1C670368A59', '4601498006374', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEEAC1C1-80FF-4933-9FB8-A2FF8B1CF78B', 'C923DCC0-F8AC-449E-A946-09929741D1C4', '4601498006381', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FA3B32D-F382-44E0-933B-53BC54BE65A4', '18D05CE4-2C78-4603-B022-AF290F8B3735', '4601498006404', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('033AF7F2-7271-4251-8949-23310EE8A777', '66A5BD05-9C81-41D4-ACEA-7C622E4D8F19', '4601498006411', '  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41170967-6EC5-4764-A6D7-005A7AC88E2C', '2704EF28-3111-465C-8AC9-0C0BBCC17D55', '4601498006428', '- / /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04199492-2A23-414C-B39C-B38987381C8E', 'DB98B7FD-D599-4041-985C-1FE5048ABBD0', '4601498006435', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D00496E1-3520-47C1-9004-F687D3747AE2', '3DF3DE6D-41B2-4BA0-BF9F-98A7230716B4', '4601498006459', '    1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('812DB481-9E89-44B9-A078-E4A47B96C887', 'F9BD7430-31E2-4F1C-ACE6-A319D067C10C', '4601498006503', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B20F8FD-0BAA-47BA-A6E0-57A9C32D95DE', 'D359EA93-568C-40FF-804E-156724D5DB2D', '4601498006527', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F54BBA8-6EF8-49B8-92CF-3C918BA9E0BA', '3C1EAFB1-1196-46F2-9465-D03CD6560644', '4601498006534', '--  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10A00397-D2FA-4904-BC5A-839B72213EB4', 'AA2E326D-27EB-4F2D-8B37-AABC818B1294', '4601498006541', '  //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C56AE613-4CF1-42C5-8C36-2C2684214B5C', 'FE686EBB-8723-463D-B2DA-BF15DFF315BF', '4601498006558', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('579FB39D-F8A2-453A-A63F-0C383183F5A9', '088A03A5-6104-48B5-88A2-11C3954215D5', '4601498006572', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('799EDD0E-E7E5-48DC-91A1-563BD2CBCBED', 'ECF96B3E-F4EC-4FE3-85BC-7BDF7F0F2E7A', '4601498006589', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('923D5D64-21B6-4CDA-A33E-CC3F59ECFF9C', 'ED51CA63-C277-4CA3-8ED3-2D8C65944591', '4601498006602', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6468C17-D364-40AE-A312-D2BEAA4350D3', 'EB7AEA92-EAA6-496F-8670-DB337F4E98CF', '4601498006626', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('709A1C43-8CDD-4E12-B104-AEE43493355E', 'EEC7BC2F-9266-4AB8-91B4-869A0F619A89', '4601498006640', '  1 // 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2FC3938-4633-471F-8E77-14C77E24BEDD', '2F2B37C0-E7F5-455D-B3C8-CD687D1BAC65', '4601498006657', '  // 2 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BABCFE72-57BB-4B2C-B1BD-A47CB570EB82', 'F832CBDB-1091-4159-AF62-9C6A7ED1D5DF', '4601498006671', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3ABC730-6127-4C6B-82CD-2CCE39F161A5', 'E13946AF-3C31-4125-BE90-2AF53402FEFD', '4601498006695', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AB9F61F-46C3-4234-A3C7-B3EAE3C4BBD3', 'F6B2C78D-1942-4852-8D9B-0B0F35CE321C', '4601498006701', '  / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A6C2240-4DA6-44D5-8A0D-94520B4C86E6', 'A637157A-3541-483D-B2AC-F60B4AC79D7D', '4601498006718', '   2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27531A6F-4CEA-4514-A3DB-64D302957879', 'BCC26990-74B5-4C4A-9274-876EF3D0F583', '4601498006732', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00CC90DA-A772-4672-962A-5A79D537D449', '4E53CA28-EC03-4F83-985B-F7B09727089F', '4601498006749', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43C70040-7430-40BB-BB17-245F66B5A6FB', 'C73F6A15-8DCA-4E7E-8254-0BF629CD1737', '4601498006800', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76A34537-ECB8-470C-B107-C1B4CB1DE40C', 'FC6F4DDC-47F9-4CED-A299-52BF373C8534', '4601498006817', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D155F05-BDF9-49AA-A90F-519090761C5E', '0D4500C0-DDF2-487B-801C-61926E49EA5D', '4601498006831', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('726DEDFE-2FCF-4BC3-BD40-CD2529DB1059', 'EF82CC7D-0CFE-461A-9E0C-B04546511108', '4601498006848', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E974BDAF-18DF-413F-BC97-AB0861BCC0AF', '398C5B01-BB8D-457C-85AD-6618A88D316B', '4601498006992', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ACBB9FE-9D03-4955-85E1-31ECE7F79BFE', 'FC17E288-366A-490E-B506-0A8E986E750C', '4601498007005', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C87C131-EBC3-4596-9402-553483D12BBB', 'F67C88E0-3CBE-4C9D-A312-81941E6C2398', '4601498007111', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F53691D-1C0F-4693-8F79-4E3D58F1BA02', 'DF8E27AE-2944-4C05-A2F1-5057EC2D5F8F', '4601498007128', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24FCF08B-CFD3-4AD6-8C05-D38D34DF4EE6', 'A1F56594-05D8-4DFD-B722-3A0DED96B968', '4601498007173', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8433628-799F-4C5D-A0A4-35A81591857C', '7BB2CD0B-18F4-463B-8280-55449CF02917', '4601498007210', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FD4870F-FD84-4CB9-912D-45A8B513ED97', '971F7CE8-72E9-4F5E-90F7-58811C3B2105', '4601498007296', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B7EC6BE-55AC-4A88-825B-7C2DE21A0894', 'F0BD4526-605C-43F2-B775-2468C9A55D85', '4601498007302', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD0FAE27-A254-4491-9EC3-A11586393415', 'C08FA347-858C-4418-8440-2FF0B4C6CCC9', '4601498007319', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('759CE565-B5B1-499A-B515-5E22EF6BA05D', 'EE65B0BA-C51C-4648-BA1A-68DAD107CEE4', '4601498007340', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3218A8D4-573E-4D30-A7D1-D01EDB1F2B36', 'E7AB6940-680A-4A2B-B12B-66F8C3BFADCF', '4601498007357', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('414A8A77-31FE-4FC9-9E08-E4977296CB65', '5C72DCC9-615D-49D7-82E1-D124EFF0B75B', '4601498007364', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('335E4A76-62D7-4350-B171-C48E3A28E801', 'EE4EE182-86C7-42BE-9CAC-C227F7FFF692', '4601498007371', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CA0E81D-212D-4983-855C-77926E57ED1D', '58B867E3-677A-4CF9-8DCD-0EB5FBBB4D86', '4601499000012', '-   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('520326C2-CFF2-41EB-BD96-93BF8AD4D076', '9D1BCA4B-C9AC-4779-A40C-105195D84619', '4601582000059', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6DF6321-88CA-4C36-8C91-6DB4195D129D', '3CD6BEB0-48F9-4DCE-9D6A-ABFD908279BE', '4601582000264', '  10% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D6AB319-FFB4-47AE-B426-191070F118ED', '79A1B0EE-D552-456D-BF85-A81F17E8FB9F', '4601582000578', ' 5000  / 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0407434A-EC29-4663-9A23-9F2788E21E10', '1CCA1CD1-E06C-4B21-91EB-053FB3168642', '4601607000064', '   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8E136C3-E69C-4EC7-BE95-960D12C2C43A', '490C8E2F-DE6D-40C0-82D5-105F5ED13BF7', '4601607000132', ' 0,05%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9996614-3F2D-426A-83F8-23B0EFFB3FD3', 'C38C5FB5-2E51-4773-9B86-7C1806DC1373', '4601607000217', ' 20% 200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03E32406-88B5-4EC3-B973-012A405FC725', '783B7D4C-9AC2-437C-BD6F-94A6047AA9FE', '4601607000446', '  / / 100000  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C65ECA7-1E21-4A6A-8CC3-9C29DE8FA043', 'F37492EE-2058-4C7E-829D-8DBF62071086', '4601607000507', ' 0,5%  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDC847E3-3320-4301-8959-563D81928C41', '7E085990-75DD-47C6-8724-98F51122D6B0', '4601607000514', '  10% 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('825AF037-611F-45D5-986C-271BE7BD5769', '58A5818E-5915-4451-A858-280DCCCA8A00', '4601607000538', '  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51506998-16AB-427D-BC3F-7B879D4BCE54', 'FB105C57-5066-43DF-AEF5-87D726B6F1A8', '4601607000576', ' 2 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B297B99-1775-4582-B660-C7EEAA6207CC', '7CA12DB7-9676-402D-9B24-B1F39F111E6A', '4601607000675', ' / - 0,025% 50 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B32B1CAF-0EC5-496D-B1B4-B57465CEC701', 'D03D07A3-B0EB-41A3-BD0D-F23C40020A3A', '4601607000767', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8AB3B23-74E8-4CCD-B812-D4E7409E9D39', '765BA803-5355-45DB-8931-0AB5F3C00598', '4601607000774', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEBB46EB-15C4-4320-8C03-A2473FCD7FB1', '2B1F0074-D09A-4A0C-A84B-6A0D72A7D862', '4601607000781', ' 0,05%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('508B36E0-0A01-4625-BDDF-1F110EF74FE8', 'B486DD55-5A84-482B-A19A-32E61F647C72', '4601607000828', ' 30%  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3CDB7A2-34DD-4EAC-A33B-9FE0126303BD', '86BB5E8C-DC97-407A-B480-ADC01B533614', '4601607000934', ' 0,5%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('878439D3-DF0C-426B-B8E6-5189B6B663B3', '4D2276F9-6918-4727-A03D-8C186D686068', '4601607000972', '  30% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5019EFB9-9D40-4F69-81F0-2B3B6572A686', '6C848175-F715-4F1B-A6A0-F66B1718E3F9', '4601607000989', '  35  (2-8*)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54B4A1FE-88DB-4E92-9814-D52F18955F4D', '8338B8DF-8CA9-4C5D-9727-3E7645C939D7', '4601607001023', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46DEAE8E-4FF0-4478-8A08-C3DFEE37C749', 'F65D2D5A-4147-4562-AF84-E3375E6249E2', '4601649000398', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF99D008-F01B-40DA-ABE8-2E2158C8A702', '6C38F8B1-7E64-45FE-9F19-B1ACDE74D7C2', '4601654000031', '- 30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98C38C03-5ACC-4553-8A37-D897296012D3', 'B509E495-A4E4-4108-AC76-00D5CB9FD72A', '4601654000062', ' 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C8734E4-DB36-4C09-BD40-DCD3320F1AFA', 'BB8D8775-30D0-4AD7-81D1-40CF313AE5AC', '4601654000109', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('453FC433-D86E-4FBE-8ADB-1B1E3E367DB6', '2B6171C1-BDFB-4E69-B35F-6E8683B77F56', '4601654000116', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06B2751F-59B2-405C-B165-DAE41B70C56E', 'B867D8E2-67D4-4B34-B8EC-6BED2E3DF746', '4601654000161', '  2,2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B635929-6E58-4BF2-84FA-79E01DEF00D0', '23682324-AA43-4CAE-86C4-5F073D1FE66A', '4601654000192', '  . / 2,2 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('871989B4-1C6A-43F6-8BF1-E74B2CAE288B', '02EDFB5D-DFD0-42A6-8DB4-C53EBF5D6C1C', '4601654000208', '  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('704C24F8-C870-4A2F-B45A-A8DA03D20C7D', '1402DA87-4810-48F2-A39D-5E4095E8262C', '4601654000215', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AAF5225-3F34-435D-B225-32144AC8E022', 'F7A44A42-1F25-418B-935A-1B21FCCECF05', '4601654000246', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26CD6F06-FCB1-4C10-A2BF-A703AE211CD0', 'CACB1D71-EA3A-4E5F-845F-09C403AB44E3', '4601654000284', '- /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE8808F8-D640-49C1-AF02-42651573E684', '3B09942E-EB83-470D-8C66-466B37E99DD1', '4601654000345', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('341ECBAB-4C70-426E-8F27-E96C025BDFA1', 'DA196497-F132-446D-B3D0-438698A19036', '4601654000369', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBBB70B6-6629-4A41-A69E-4D2530677542', 'F8D4BF9E-EB15-493F-8A02-3A8505BF1710', '4601654000376', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27A27225-B190-49AB-95E1-99D715530BEA', '84FC4304-A130-4887-8B6C-B0A598779449', '4601654000468', '  2,2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC6C4F52-C510-4760-8D91-A70E8CCBD22A', '8E536882-544E-4C87-ABEA-1DAC413F9C93', '4601654000833', '-    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('603DD423-EEDA-4069-A440-CE8818EFF6E5', '1B994867-6A9C-4587-81CE-E6425C0ECABD', '4601654000871', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC5B947A-C1CB-413F-A110-5269B19E8F7E', '106A052F-D110-44F8-853E-4A86F3A98549', '4601654001007', '   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFC48500-670B-484B-8CBB-B3FB88ADB491', '60F90E71-9250-4708-BE2B-43885B08E058', '4601654002264', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('275C9E4A-BC17-43B2-A98A-141FFF68D25E', '4D8A6216-C28B-4473-9BA8-3C92394645B0', '4601654002363', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10376864-A455-4F66-A0D1-B489B83A06CA', '1F642BB2-FB5B-4351-9BDE-65D42DFCC0C0', '4601654002387', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B56EF32-958C-4DE4-BC99-139BCAEB343C', '314F1671-B64D-486C-8579-10BC2C7D926E', '4601654002448', ' l-  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94D489DA-866F-421F-8CDB-1F1BB2855140', '99E534CA-0EA0-405C-8D20-E3CC14C856A7', '4601654002912', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1D1382E-2490-49A6-A75C-F1BB4A9C41D0', '2A698DFF-67FF-4825-80DE-2AA9CA30CA0F', '4601654003070', ' ++   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0210251B-60E0-4DE2-A8A4-8F0EB4BDAE2C', '42B68F6E-B307-4529-81CE-5CE8C57F2FBD', '4601654003094', ' - 3   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E4D97EC-1313-4D9E-8FF2-BF377743F3AD', 'D1A256E4-82CC-4844-B388-E7FB3414429C', '4601654003117', ' +    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F995FF03-1673-4660-9BE9-7CD7BB7A0DCC', '59DEE09C-290B-452D-BA33-ECB7C231618C', '4601654003131', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F63681E-9B9F-4C8F-8798-8983E60A130D', '669EE63D-2FCA-4A4B-816D-DEA182026D92', '4601654003186', ' 24   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D9803DD-B2C2-4231-A2FD-184040B53E36', 'A3BF68FA-7C54-4154-B25A-EEC6DE65AA5B', '4601661000604', '- 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0529A64-D14C-4DEB-B90E-1292B080BAFC', '230CB945-0EEF-4372-AB47-CA0166471F77', '4601661000703', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('259B500A-03E2-41D6-8EF2-05806CD67907', 'D62AFF1F-0046-4244-A07F-FDC2B4E961FB', '4601661000819', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8738665-22A4-4BE5-A3CB-C90186E5502C', 'C042F94D-B419-4FE8-9D92-001AA78DEF00', '4601669000811', ' 0,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('540DD35D-D239-4C46-8734-30ADF16CB974', 'BC5CF39F-6951-4B8F-8FB3-852CC62F4DBF', '4601669001719', ' 200  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('600926A3-3B11-4A54-85DA-5A7083304037', '34F64146-AD2C-4B36-A496-78A79ED4E659', '4601669001856', '- 480  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6305F9E6-4EF5-4133-A9D7-3E4ED1D62175', '2AAAC010-6E19-4DFA-AA28-6EFB855E24FB', '4601669001917', ' 125  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('437CC490-A058-4D01-BAA9-1567F730FF26', '76C42BA5-D868-45C1-BF21-2792E6486DFD', '4601669001931', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('048B0895-AD59-4E7C-9EDD-0E55127A5C07', 'D3E2D93D-4D5B-4154-9C97-451756E7E821', '4601669001993', ' 200   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F933AFD-A797-4D44-ACEA-06036242514D', 'F5CE54FC-0153-41BF-B655-FB6DA9FF6CF7', '4601669002136', '- 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A07B353A-39A7-448C-842F-CAA62B942235', '4A2A2FAD-7F15-4817-AB9C-D8207F650EE4', '4601669002341', ' / 10/   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B61268C-17BB-47DD-9D4F-BE42DBC0A5E1', 'DB1F4BC9-0CB7-4ECF-94BB-71B89993BC9D', '4601669002402', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('762EAD26-56B7-4E1A-B553-8837F0CD35A5', 'CD0E3051-713E-4AA4-BFD0-EE3CCB13CF4A', '4601669002754', '-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81CF0D87-517F-46A6-A14E-75FBCDC4A44D', 'EAF107A7-A913-4CFC-AF6D-683B96EF407F', '4601669003218', '  60 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AACBA105-254B-434D-B7A1-D8EA2956D248', 'D92CC5DE-8C17-4825-8295-1FCB412F1038', '4601669003416', ' 0,5   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB3BDAF4-C6A6-41F2-B281-D073AC823FB6', 'A2F22080-F499-4C67-93F3-5BEEE8C33401', '4601669003539', ' 15  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CA323E8-7B08-4D82-864A-269FE6FF77B0', 'AE3083A6-61B3-43F5-9C5A-7642E9F46AC9', '4601669003546', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8813D7CE-92F4-45BC-8C5D-A4F4EAC85033', '9B1798AA-CB80-4A91-8053-AE560908659E', '4601669003669', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DE3669C-A237-4DF5-BB50-27A407B26592', 'E92A4600-C9AC-40EC-84F3-85033E9DC672', '4601669003713', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1421DD5E-A44C-40D1-A231-759ACE3B7D56', '9E273658-910E-4D04-832C-A5C47C44F93A', '4601669003775', ' 250  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B26B96F8-CB1F-4A67-BDC0-84F656AAE210', 'E2ECE793-45E3-44B7-8A36-13EDCEE8C3A0', '4601669003812', ' 1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6ADEAE7-E382-4B02-A178-25FAF5AB4D34', 'D39961C3-D481-4735-9CB9-E9561CA174F9', '4601669003904', ' 10%  /  38', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6161B6B0-EC5E-4545-9903-E3C5DBBE3001', '2D8FEF20-17A4-45A2-9FA1-D7911D2EA691', '4601669003942', ' // 300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('115F15DD-6577-4B34-8401-5F7FC8717856', '2FF4B321-0515-4490-B0C8-D0D164617A67', '4601669003973', ' 250  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F53B713C-3110-4317-A629-3430D55550EA', '68567D25-F135-4C20-9B2F-7720D815056F', '4601669003980', ' 250  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A1253B3-5F31-4C02-8AE0-CCFB1EAAB05F', 'BFED6D21-41C3-4200-BDCF-868860339018', '4601669004000', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75E51D27-4324-408D-9576-BBD5A548E6BC', '21A976C7-7924-40FF-A08C-069ACFF2089E', '4601669004048', ' 0,85  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('360AA35F-77CA-47F5-96C6-6DD8761ED09C', 'D06A2EE1-D551-4F32-B59C-CF7F007C4A72', '4601669004055', ' 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08BBAD21-BD9F-4186-B705-B62B29138E07', '3614DFAA-2D95-47E4-BEA1-2827341F7C34', '4601669004062', ' 0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE0D9FBB-71A9-4B97-BF9C-794C46CF073D', '14EC4226-0F7B-4F1B-946E-68523734589C', '4601669004086', ' 1000  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8A8FD11-A73E-41A7-9276-6F5889AAA4BB', 'C921ACF4-1343-42D3-AC41-3D6004D6E694', '4601669004093', ' 50  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('414E65F4-F1CA-405E-8657-C8D7E4EADF4A', 'F084AA56-5F9B-44FD-B4D9-25C5A2CD8C76', '4601669004239', ' 50  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50D6A9DF-FEE2-4599-884A-244058BB4061', '70472DAC-4600-4451-B7F8-19663FFA848D', '4601669004314', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB0DF56A-E641-4EF0-A774-96713BB2B5D5', '72500404-51B1-4261-9977-DE657F101D63', '4601669004604', ' 0,1  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD7164E2-8290-497C-8F88-C3DA203005FD', '6EE0E3A9-AFFD-418A-A424-1017E8D57AD5', '4601669005311', '  150  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E546771-3E2C-46C1-B7AE-AD3694687D7D', 'B3AF7FFE-631E-48E7-B239-546B6CCE4DBE', '4601669005366', '  150  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0981CAC7-1F50-4BFF-97CE-CC91EE0B9D11', '791570EE-8684-4852-B1E5-445E7D4B653A', '4601669005410', ' 3450  550 /   >7 / 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59A63F86-05F8-4A2C-B936-39DC0C26FF1D', '605E59AD-428F-45B9-841A-37A065001372', '4601669005427', ' 500  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85AC6FED-9245-4FF1-B600-7A73EB039F46', 'F6BA0BE5-5FDF-47B2-8598-0EBD2A817BE6', '4601669005540', '  5% 58', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2394D1E9-8C7B-4B99-A63C-A754FE3889DE', '9FE805C0-520B-45E3-84DF-CF4C0BDCD748', '4601669005601', ' 50  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6642533D-D945-466A-8FEC-0533F709F9B0', '912209A9-1148-44D6-B6CA-0F03B6624B30', '4601669005694', ' 0,2% 58 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5397439-0F31-4FD8-9521-91EC160AB1F3', '1062A170-32C4-4DB3-A443-B586031CCA73', '4601669005724', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E4A2BDC-47F0-437C-ABF5-8E6EB827D0B6', 'D217FC68-F417-4A8D-8681-F17A2E7B36F5', '4601669005847', ' 0,15  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84F57FDD-3BBF-458E-889F-CC458063C8D5', '527A6A91-CFEB-4536-A94A-0B758804A645', '4601669005854', ' 20  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04E4F25D-655A-4D5F-9968-5471C1F260C2', '2B032388-F94B-4AF6-829E-6D29771008A4', '4601669005861', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A39202A0-A821-4B04-885F-84BD6FA62F05', '46084D96-D0D7-428E-806D-A194A0DA8251', '4601669005922', '  -3 /  43', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('849C1E2D-67A5-4C9B-87AD-34B3E5C9E32F', '5D16CFDD-2D43-4BA5-9846-C49EF96A0F49', '4601669006004', '  //  15 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DD24D53-B463-44E1-BB57-6A16BB864D4A', 'D69E63C2-CAA0-446E-A1A7-D21F3D1D4711', '4601669006011', ' 5   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B716BCD5-3A91-4AF1-91B2-6B571E9A47FA', '3D2028C7-AFFF-47AC-9B96-221B8D195571', '4601669006028', '   15 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5330BC35-49EE-4B08-A0A5-71FF717966CD', 'C5F81595-9C3B-45E8-8D1F-46D8BE14915B', '4601669006035', '  / - /. .   15 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAAD3CB1-40F3-4031-ABA6-DD6C8D9215E2', '1207F8C1-8F02-4E28-B158-D9E1CAF474FC', '4601669006042', '  / - /. . //  15 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C4B97C2-E337-434D-9E05-0985B3E7B726', '294389F0-BFAF-4CF2-8741-68DEA20B2D8A', '4601669006059', '  //  15 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('586A9459-0E19-494B-AD46-6F817D37339A', '349C2186-DE54-46FA-A13E-827F22C573F4', '4601669006103', ' +200  // 400 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B45A4063-1131-4DF6-99B5-ED273676A2A1', 'CAD4A5E8-07BD-4E42-9E4A-6AF1BEB4AFB5', '4601669006110', '   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F650301-9C1D-49FA-AE9B-D7897D17A5A6', 'FA9BE22D-8941-4818-B117-426ABE516632', '4601669006202', ' 8 /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5FA1D4D-8596-41DC-9B37-FEAADF740D11', 'A1CF98F6-6A2A-42C3-8A0D-97C4D81B0D96', '4601669006240', ' 3   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E4E8A1C-C7B3-4050-83A9-9D3AC0DDA438', '06CCD78C-BE08-463A-89BC-322D9AD78C1D', '4601669006486', ' 3   10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA35E13D-5F6E-4B48-90DE-E8C81BBD1BA8', '177B847A-55F1-4780-BAC1-698EB95E88D2', '4601669006578', ' 500  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE4D67A3-F482-45EC-854E-8619DEB2556B', '1347EFA7-525E-4681-9D3D-3A3243879A3C', '4601669006585', ' 75  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E771F45-AE77-4E35-B4C1-6E94AA2AF0FD', '47AEB003-12DB-49AF-B997-D9B06F783050', '4601669006622', ' 3   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDC74385-0259-4851-8709-8FF1ABF9528D', 'D84E5C98-C279-482A-875D-B8D3726886DE', '4601669006646', ' 3  10 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B48622DB-6CFB-40C4-BE08-CF950028A3A9', '46EE872C-D217-49E2-9CFE-D73D789BC806', '4601669006790', '  12,5+50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9F9E89D-8878-424A-B8FE-1A6BE256CE68', '7CB2E56F-E4D4-4C77-BC23-0AA3B6A758C7', '4601669006844', ' 12,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0074BE8C-6A70-4CD7-BBC7-E093B4F0E855', '00B1970E-C918-47F5-B1DF-7578742BA6FC', '4601669006875', ' 0,1/5 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5C6B296-6959-4E0D-8B42-3976A747EFD4', 'B3D21F5B-674B-4E8F-8919-C4A015E28F69', '4601669006882', ' 0,2/5 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('682ADB4F-B1E3-45A7-BB97-015E9E67A933', '548E1E98-4627-4CE5-9E10-02E07ADDFB5D', '4601669006905', ' /  /  4 5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65105E63-D25D-4620-9D1F-A1CC7CB28131', '4AC9D2B5-96CE-4DE7-8E7F-23DF4AFCF7CF', '4601669006974', '  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB6B9F3D-0A65-4BBB-9F89-279E3739C1D9', 'D831EA28-63F4-4909-B484-99D41586EF08', '4601669007070', ' 120/5   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE83B871-C389-4EAA-A89F-999928088259', 'A58FE073-2425-4F3F-B4E2-D893F716BD81', '4601669007094', ' 120/5   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FC09160-8D64-4020-A515-D9C981FDF2A9', 'EB31EC74-0BDF-46A3-9AB2-C8280C1AF23A', '4601669007230', ' 100+6/ 120  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E21FA8E5-A05C-4DA7-936A-F19971DAA612', 'E64152B5-E558-4402-A82D-1646D742C895', '4601669007254', ' 12/ 120  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6067C4FA-6F27-45F6-A8D0-C325F5CAF60D', '7A67A1C2-2665-4AD6-9EB6-1C8989E757CB', '4601669007292', ' 0,25  200  / -/ / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C5C19A4-76E4-4513-AAB6-519A7B9D95C5', 'B8D9C432-D021-40F4-8DD8-671CFB7EC909', '4601669007353', ' 0,002  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19406E50-9728-4399-8B1C-4761A3E6F29B', 'D7871D5D-0746-4A24-9693-341F246CE1DB', '4601669007377', '  500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22B11F36-9767-4DC2-9982-84C20D4694BE', 'BF1AB733-8B80-4111-8B11-8CF393C1E501', '4601669007483', ' 0,5 //  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A68EC92-8886-4335-B3CC-F15FA9DF4708', '74DA2FCB-C23D-49AF-AAEF-B071A542FD70', '4601669007650', ' 15  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AF7AF83-647A-4679-A1CD-4843CD8A227A', '3ED907F0-DD6F-46AF-9C7F-D6E117024BC2', '4601669007667', '  0,0015  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('005CBBDA-AEC2-4CC8-8A35-267C2A3DB2A6', '80606A26-5EBF-4D70-B9C2-DA395837DD27', '4601669007681', '  0,2%  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEBE088A-0DCF-4666-8898-9517B187AAF1', '88439F56-823E-4339-9E64-DD30E4900A01', '4601669007698', '  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70E64C99-F844-41F7-B098-394DF815088D', 'DEB1158A-6DDC-41A3-83CE-F1DE72398592', '4601669007704', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F6231FF-947B-4E12-B136-0EA018E0FB7F', '7D612AAB-5175-414D-B49F-43F8B8E2577A', '4601669007995', ' /. . /  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FFB4954-2743-4F8E-9E94-0C4EAFE655B0', '2590BA5C-61B2-4691-9094-56EE42EDB16A', '4601669008053', '  0,2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9704073B-9B24-4E22-BA11-464AB83257D2', 'CE8E2401-1669-4AAD-9A82-84279B41A14E', '4601669008138', '  25/ 5  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92874A52-6F92-43F2-9916-A16BA955971B', '605A98F3-0DA7-4AFB-BE04-3650F7CD68F5', '4601669008145', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('375B6236-AADF-4C49-96E5-3DE37DDD3C46', '6F433DC6-B94C-464B-9168-B4F539463264', '4601669008312', '  1% 10 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03BC2007-0C3B-4113-9D89-935324C92E0D', '026D6240-8044-4111-8961-6F9D2D866278', '4601669008329', '  1% 20  - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F52B88C-EDB6-4D53-9BEA-AE0B984842F7', '11515C6B-A246-4C19-97D1-57B62B88BE3C', '4601669008343', '    30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DA1287B-3EF0-4E67-A710-9E04B2782F17', '9373FC4F-3CD3-4A99-BBC9-3C376525E301', '4601669008367', '- 100/ 200 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('146D056A-327D-4895-85BB-7662347E7B4B', 'E21CFFAE-A38A-494C-98F8-12984D088B2A', '4601669008374', ' 250/  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6598B82C-EF31-4531-8757-FA69C7EA635C', '2D2915FB-4E8F-4D7B-B286-D8A14A19070F', '4601669008718', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BD2A609-FDBC-4C32-AFDC-C834EFCA5D4F', '0DA58AC5-4F22-40CC-AD78-D4998449E019', '4601669008770', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC775751-C37D-4832-94AA-73CA9AE9CE36', '25F7760E-8E2F-4670-A361-1C8702E317BF', '4601669008817', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3429A709-A4A6-465B-8F4F-47B955058DE7', 'B8AC7B74-C48F-4050-9190-092B98878CE8', '4601669008831', ' 0,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('718CC10C-4C10-4D6F-BDE8-7B82BB581BF3', '374C7698-9F99-4A1F-8A54-294C47D35DDC', '4601669008879', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDB16079-4524-4DF5-9FDD-14D4C33325A8', '502E7002-4875-4361-87B0-D6AB66E31E3A', '4601669008886', ' /  /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BF8717F-F693-4C80-8EBE-0FB71BF81866', 'D8258614-BEC2-43E9-B3E6-45F8C2430578', '4601669008893', '  14  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('971BBF4E-FE87-4579-8FB9-472CCDD63310', '400AD489-061E-421F-9E02-E8F969F23217', '4601669008923', '  14  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFCC225B-C049-46E5-A2CB-39E650B93419', 'D3EEC32D-9195-4C65-970A-CA436B55C88F', '4601669008930', ' 40  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1D2E5B5-3005-4902-8965-8CA11D01AF6C', 'F77164C6-B997-44D7-83EB-0F108D6CD1AA', '4601669008978', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84D214D1-17E7-425B-AAB0-DE5C85E55F0E', '0B04AE94-9383-4C3A-983F-F34BA064185F', '4601669009128', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB8FEF97-EF56-470F-A0C4-EFE5FD0FA37E', 'FD6522C1-FF78-46BE-9098-2478886D0300', '4601669009135', ' 40  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FB37835-71AC-4211-BC63-31162B68B948', 'BC5022B3-678D-42C5-9765-3092CA3B4A23', '4601669009142', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8D5F852-257C-42C9-96B2-6950F2F9C000', 'BB961CFF-8878-4AAF-BC21-252F65F73106', '4601669009234', ' 0,05  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7D2C441-FCCE-4F42-A2CF-103BA5502E99', '9A76ABBD-20E9-4B44-8025-0E420A01694B', '4601669009326', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D39CB909-EC10-4B6B-B029-00D7B3D44119', 'C77A4272-2686-403D-B66F-2581C5DD85D2', '4601669009548', ' 60  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('589FD648-02BA-4EC6-8C98-859C86047AF0', '3915D57D-2C64-4D38-A30D-3F67D84729DD', '4601669009562', ' 125  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDD18AC1-1AD5-46E3-AA0F-6F29BE2406B5', 'BCDF6553-B19C-4137-80C3-F459DF7AD38A', '4601669009586', ' 0,125 //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4DD06BC-A726-4347-B0DF-A6AD5CB8A7D7', 'ECFBE344-67EA-497E-872C-F059631D9E8C', '4601669009609', '  20  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55769644-F9CC-4C7C-8C68-B93D1BB60C7B', '70426C7E-341F-457D-BC39-FB3540735EA0', '4601669009647', ' 600 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9959F65-68A8-4B37-96D2-99A6C1E44BF3', 'EB3D1933-FD4D-47C6-A86F-BBA9F3B7449E', '4601669009791', ' 0,25+0,5/ - / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22224780-96B2-4A60-9C75-3F5FE6B36672', 'D28C9FD5-E19C-4B1C-A5B9-89C28540C172', '4601669009807', ' /-/0,120  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F0BB011-A406-40C0-9BC8-B2CE907F992E', '0C616721-8CEC-42E3-8670-F1EDB1C5F1EC', '4601669009838', ' 0,120 //  112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBBE321F-DA89-4462-890E-83B174BC7237', '5B00D313-2A37-4B3A-BCCA-C72095D953D3', '4601669010223', ' 100/5  200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('238849FA-E103-468F-9774-5E70F0D34EBA', 'E217BE3E-53BC-4BC8-9F1E-C095C11EDDF8', '4601669010285', '  //  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6752C49-6983-44B0-B22B-A02981CD8DFD', '0880DF6F-A390-4DCE-967F-57E15F944176', '4601669010308', ' 0,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A350E83-4A79-479B-91F3-C682168C7563', '03081798-C38E-4773-B011-6B0A79109F4B', '4601669010315', '  3 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('411EDED0-853A-4BAD-ACBC-F7FACD181ED9', '235EFB18-30DB-42F0-BACD-ED1A61750F5A', '4601669010339', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BAA5C40-6F06-40D3-BB12-FCCC8DCB4F92', 'F0FB237C-7025-4F58-8256-AE8D54F28ADB', '4601669010452', '  20+50 200   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44B0ACAA-2B6A-4D45-A60D-581D8F7EE3F9', '893AED98-5359-484A-91D5-952FBB57917B', '4601669010506', ' 0,25  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6BB42C3-162F-4B5F-91DE-D98E50D70022', '5AC37AD0-5441-468E-9ABE-C1C077E2D63B', '4601669010513', ' 500 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58829DB5-7E36-4055-80F0-E91608BD8535', 'D74BBF56-B10C-4D2F-8927-FD732C433E3E', '4601669010629', '- 0,25 20 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38B405FF-19A7-4E9C-93BF-66D0D9BD89B2', '7A26AEBD-20B9-4C48-9B84-B9E0125019E4', '4601669010643', '   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41F09348-D638-496B-A5CD-2A3720CAB1BE', '56F14CE4-1BAD-4C24-A6D4-F8AE6DC96183', '4601669010650', '  0,08  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48020218-D8B9-4138-B80B-C24AF631CE54', '42E05CED-D92D-454C-ABB9-BC23C9E86688', '4601669010667', '  80  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A4DD9E3-0994-4797-A427-AC1F78B7C340', '5281804D-1CB9-4EC6-8914-D7B5757D768F', '4601669010711', '  300  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1036C58B-2AE6-4409-9BC0-0FC9C7B8BEC6', 'AD275A61-27D7-403E-A648-7B0DE1ABE429', '4601669010766', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31E48B3F-C7AA-4B04-B7D9-F8416F744410', 'CE3EABD9-C074-426D-BFA9-CC6CB84E10BD', '4601669011008', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60D1AF96-DAE2-4A4D-A187-862197B53CF0', 'FFDB3BC8-F181-4ABA-B401-D935425DCCEC', '4601669011107', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('431E33C9-373D-4148-B42D-0804C7F75ACF', '4EF0665C-7349-4A79-865A-8296B3F8F569', '4601669011206', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE230CED-68DB-4AB3-AB1D-8ECA3A372112', '5E61A7A8-4077-43AA-8D88-DF04E5A3E5A8', '4601669011268', '- /. -  3  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C175740F-7B4F-4671-90D8-C6247FB20F68', 'E6438359-4EAF-4E0A-8462-26FEC1E76D41', '4601669011305', '   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40FE6AE9-0E3D-4F25-8001-B99B60B58279', '4832E253-418B-4896-A81A-989078F3FA7D', '4601669011596', ' 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('310F240F-457F-4DE4-AB6E-B0AA861D14D7', '2BF34C85-B3EF-4404-B184-E76507DF76C9', '4601669011879', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6098A6F0-8DC8-4DE7-820B-0140978E6C5E', 'F7AD8F24-09A5-43FF-89CE-080C4431B38A', '4601669011893', '  200 12  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0272375-82DE-4579-AC75-FAB5D1EC7F5A', 'EF61023B-301E-43C2-8875-E1AAFEF2FB6C', '4601669012081', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89663A58-9180-4A97-8B92-850CCFF21CD2', '98BFA456-3F36-406A-8C42-8C40522BF168', '4601669012197', '   0,05% 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54359D05-3C0A-49AD-92A8-D431E4927022', '4D77BEDD-717F-4696-BA77-3C202C8ADF46', '4601669012258', ' 75 +15,2 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2B222B1-652B-47D8-AE2F-F775C3494074', '2C651B33-C3DA-410D-96FD-408ECB165AB9', '4601669012265', ' 75 +15,2 //  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('008B1CD0-FF5D-4B93-8D46-F95E384CC9AB', '82EE0F98-EC62-4667-8138-FD42FB15447E', '4601669012289', '  0,15+0,03039 //  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0D58FAE-4528-43E4-8ACE-EB14A6449460', 'CB8014F4-C95C-4D76-849E-277DA717ADD8', '4601687000022', ' 0,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8347DB8-CED3-4B05-BAA4-A3B9B4D686CB', 'F22BE266-E844-43E1-B197-1B2BF59181FA', '4601687000046', ' 105  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0798965-A9E7-41BC-AF06-7B18C4C56315', '1CF990B5-6DC9-4199-A06D-4A3FE7A7B341', '4601687000053', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2483773A-006F-4568-B509-5CACFA75F255', '631CDA7C-1FAA-4732-BCF3-0A73AB1FA1A1', '4601687000114', ' 0,1   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1495CD86-DF30-4180-803D-59847BCF4916', 'EF363B13-BD10-4FD2-A36F-A149280D3123', '4601764000013', ' 725  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1355E6F-69ED-4D9F-BD6B-1FD084826CA7', 'B2E3351D-2640-4BD7-897D-1B50CC5293E8', '4601764000020', ' 250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4050632A-A473-44E1-984D-5BF2FB1538C7', 'BEEE52DD-C8F5-407F-8CFE-3C1DCACAFD00', '4601764000051', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A4EB896-9943-4BAD-84D4-B76383A5A4C1', '834C6BD2-970E-48BF-8AC0-28D4D87A4C9C', '4601764001133', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49F9D4D7-9362-4D88-912A-DF5326808F1B', '32583F65-DDF1-482C-A1E3-71E782FA818B', '4601764001720', ' 120  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9AB4A1F-6C6C-4A83-92AD-04B6003740B1', '877C237B-9F3C-42A8-9F28-43BAB7382256', '4601764001744', ' 0,18  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40613DD1-8511-460C-A4FF-EAB776A99C14', '7EEB07AC-B61F-49E9-AF50-FB49E19B8791', '4601764001898', '  500  /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('807D0CE8-CF67-4D76-BC83-84971B504BBB', '005E3987-9E20-4CF2-BF67-A647CA54913E', '4601764001904', '  1000   / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60196340-D759-4C5B-84D7-707173CD10D1', 'BF02079D-04F1-4BAB-ABCE-E89CFAD565CC', '4601764002116', ' 400  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0DAA846-FD6A-42FE-A321-41C047569CBC', 'E2850EE8-0411-45F8-B19D-49FC0905617B', '4601764002376', ' 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFD8482D-8447-43F0-8182-1C2437750BA9', '869A6D6E-02C8-4315-AADA-B9C01AFF7601', '4601764002734', '  .  .   56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C12FB409-674D-4DC7-BB55-7C3CDD69FD9D', '4BF78D2B-DD7D-47F6-89BD-49347A2F8466', '4601764002949', ' 0,4 //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('650F0206-9DEC-49DF-8165-D71E0167428F', 'E2510582-8E80-4D2D-9A31-4BFF2019BAC9', '4601764003632', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8F2679D-A88D-4A5A-9A1A-FD426013EDEA', '39A3F135-4AB7-4AAE-816F-72E3D60FEAFF', '4601764003656', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F628F82F-E5D5-4A9A-8DFF-25220BF09456', 'F62A9E35-0E19-4743-8515-065BB52E95A4', '4601764004806', ' 3% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18EAF1D1-9302-42F7-BF87-82026162DFB3', '6C3BFB11-E10F-408E-BF7B-7E052D88FEE5', '4601764005056', '  500  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31B91794-2656-4054-BACE-5F9C111AD888', '8AEF411F-FC9F-4F1B-98F0-2299D82D4267', '4601764005247', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90B1257A-4759-4D12-9C76-6F8BB43FA6C0', '5E42E9F5-9136-41B8-B572-EAE94AAE8DE2', '4601764005254', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ACF3BC0-23AA-4758-AE66-2E1638A127AE', '0FBD5AE1-AED3-4422-9CD5-80F829086FFD', '4601764005414', ' 0,5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1BC49FF-5640-4BC7-B084-89B4B9ECEFD2', '58D78E64-E28F-485A-B654-76602CA75E73', '4601764007098', ' 10  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('280AE5CB-F5F8-4270-A415-F504DBD84454', 'ECF8E6DB-A566-4468-9B6F-C8EAD394F34A', '4601764007135', ' 0,01  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4316C945-C475-455B-9F91-D5C97FDA478B', '10929D96-E615-4DF7-B936-7EBDB7C48709', '4601764007234', ' 10   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BE529A5-C88C-4087-978C-AA25700BA623', '0F2566F9-DB63-497C-A05B-6935A76BA53B', '4601764007265', '  0,5 600  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BD89466-D0CC-47BB-AC9A-78623CD55F2D', 'EF363B13-BD10-4FD2-A36F-A149280D3123', '4601764007326', ' 725  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B535E945-873F-48DE-9220-0A4ED23207FB', '8B4F2FA7-63D6-46A9-9140-4F159EB348C3', '4601764007340', ' 3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79719C34-E4AB-4EF7-945C-D7B70749A7B6', 'E30CDB43-FB65-40E4-AEE1-538504C55064', '4601764007357', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47EF9210-5DA5-4611-ADB7-AB0FDEFAC9B6', 'CC35E694-28D7-4D00-ABC5-6FBFA5A9462A', '4601764007388', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('394FFDDE-B33D-4E55-996E-F7B0EDF62DB6', 'BF7D7420-3B3B-4C82-A152-3B298141C849', '4601764007395', '     24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F71EFB7-69C7-412C-9CFC-8CAB246F57DC', '40143BD7-C49B-4A06-9BF5-743C814C5FDC', '4601764007401', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('792BA1ED-7DA6-4C9F-85F3-2FFC751A197D', '6E80988F-CE6E-4F09-83A6-805DCD9238D1', '4601764007418', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E0800F2-0BF5-4821-9FA7-620C3F96BCD9', '693CDEA3-B805-45A0-80EC-D7C4525FF4D9', '4601764007425', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E473A5F-EE93-4DD1-99A8-361B925F8C53', '188AE503-E529-46A4-9798-11104375B98E', '4601772000173', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE86FEBD-8FBC-4AF6-8179-34BE1F7A7A47', '8500894B-7D54-4DE9-9AA5-876E944E6CC5', '4601772000180', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79532216-2207-48C4-A82E-BD4698A9D572', '85D90BC6-668C-49B8-802B-A3BF6EC5DD93', '4601772000197', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CA07077-8FF4-4AFF-85E1-0EF93809B613', 'EA515E0A-D81B-4E3C-B85E-6A64A0AAD416', '4601772000203', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8164B71F-CD2B-4055-B3DF-3621603278F8', 'F94134F8-2B99-4A4A-9482-870F49060BEA', '4601772000210', ' -  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('636CDCAB-C8FF-4083-A284-6DA3B9079428', '6435B542-28AA-4665-B648-3CF67475F044', '4601772000227', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBB1CE35-AB31-41DF-B823-7171823F73B0', 'A332FCE9-452D-490E-A939-AEAD2E46D6B5', '4601772000234', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7EB0439-EC5E-442E-9D0E-64163354A4C2', '8BB0AAC9-2018-426F-9315-E8EF2339A54B', '4601772001576', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2BFFEA5-5B69-4445-A6A2-DA41C9991FEF', 'B11231AD-A68A-49E0-9C26-C0998CE84CF6', '4601772001583', '       . 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('846856FF-B210-4B40-92CC-90B7139346E9', '8B7025C5-0EC7-4350-9677-177175258920', '4601772001590', '         40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4E84068-A4F1-4A70-A558-436814E2A03D', 'F1AD0EBA-455F-4378-AFB4-A924765A8532', '4601772001965', ' -    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C401EE7-785B-46D8-B59A-B3D7C397E62C', '3DC83416-C028-4B07-92CA-64AB5704C6AC', '4601772001972', ' -    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('987FFF75-78B7-4234-9FE3-1B494EEAB280', '9506E046-2D06-4DED-83DE-55DC2AEBB4CF', '4601772002092', ' -   // 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41E50C34-A7BD-4B6D-A5B2-D2B2C93B5DFA', '14547EF3-C527-4126-9DB5-42F33E1692C0', '4601772002108', ' -   // 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC02D07E-20D6-4DB7-AEEB-6E98E748532B', '49BA17C2-869C-4F58-86E2-D45F7D47E01F', '4601772002405', '  -    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16A5E41B-7E6E-4BB6-92F7-AECBD10BBEA0', '54D88B34-5875-49C4-A34D-2F1753655720', '4601772002412', '  -     . 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF69232E-A962-4895-8AC5-8FCF2ED5E538', 'D5D63B36-9082-4F80-9891-36769E4AB5DE', '4601772002429', '  -     . 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DD0FD8F-BA32-4531-B6F8-7C32690A1B14', 'C64E48CD-2E46-4D5E-A23A-39155186AC12', '4601772002467', ' - 4    ..40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE78532C-BD8C-489B-A884-8267A5D43EF2', '34A74A7D-E18E-4129-9037-391307BD0FC0', '4601772002498', '     ..40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E099B06F-82AF-4BEA-A81B-416394BA2DF1', '9492875F-AA0D-4102-9FF2-038E91E99806', '4601772002504', '     ..40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F15164E-ABBF-4AC6-8005-F6B402123727', 'DC235C11-9F64-4AC5-BE99-2598F47F5637', '4601774004117', ' 1,58 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A5A88C9-EE0E-4687-B968-E8094F30F1CF', 'B1BA9059-0365-4DA3-8E90-074A06167053', '4601774004124', '   38 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F06757A-5FCC-4834-A104-D48EE60B25B1', '5BF49E70-0123-4EA7-AD56-E80FE7673344', '4601774004131', ' 310     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7312CCE-EDC4-423E-A07F-6B661BD0D897', '5A6002BF-7E5B-4A12-98B2-B13E0EA7C968', '4601774004155', '   310 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2040D6C0-A333-4A14-BEA2-07B285828A22', '4A159597-38B5-48B5-B691-FD920CF1AD40', '4601774004162', ' 38  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6CA85D8-8892-42F1-BB0D-E73AEA068C2C', '77D9F15C-3B64-4D2C-BDE4-14B38242BA1E', '4601774005572', ' 58     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E1BB2F4-A912-4022-BCD7-0A3A0374E8DD', 'D40063FE-998E-4941-8A36-B51B667A985F', '4601774005596', ' 58  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE190F2D-3C25-42B1-8E25-E358C08A51CE', 'F9AB7963-7B05-41D7-A706-1E5262AA8DCC', '4601774005602', ' 28  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5CB4D69-26C8-42B2-8B1B-BF5C3BE1BCD7', '091250C5-A831-43BE-B7F2-AC00111E767B', '4601774005633', '  / -  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBBE0C7C-2678-4CEA-AA1A-97B031353259', '15E624EA-E2C8-4E76-B827-18E781DE8B86', '4601774005657', '  /  -  .5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82B87556-BE03-450C-8CDF-54EA2BD56E7A', 'B93DA679-E3DB-4029-9234-4F7EF2CFC4DF', '4601774005664', ' -  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A067C29A-0E08-4062-97DC-0480ED4CB3B7', 'D076E15D-10A1-4227-B0EF-D6BE2F7FB04F', '4601774005718', ' -  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78F94BD5-F38C-4AFD-BC5F-A5395148F23F', '6170E75A-ACBA-4778-8343-372C917A03C6', '4601774005725', ' -  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D40C1FF-E2DC-468A-9F4F-3C7EC6508181', '1962FE9C-5CD2-4C51-AF7F-F3D97086C5B3', '4601774005732', ' -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('088B23BD-0DFD-4AB5-8C9A-8C08AA1BD242', 'D19082E6-44EC-405E-B0CC-80D86851B5B7', '4601774005749', '  / -  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF9DC5C9-AE6D-499F-BDC3-1C6BC370D3CC', 'AA477272-45B8-49FF-AA42-26A897E536CA', '4601774005756', ' -  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD17B1E8-CCDC-4909-81F9-651C73F5C917', 'D19082E6-44EC-405E-B0CC-80D86851B5B7', '4601774005763', '  / -  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D717766-34D8-4EDA-832D-0514CDE69A05', '976E0CB4-B87A-4E78-AD0A-C064F30DEC40', '4601774005800', ' -   4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40EDE961-9ACD-4A5B-98E7-D4552D01B330', '5C474519-A276-46A4-A687-185E77A8956D', '4601774005848', '   - -325 .8 / 121-137/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9459DD8-DF8E-40CB-858C-6CF245CE1AFB', 'D3A1673F-544D-45AF-A49A-B2ECBE9AB532', '4601774005855', '  1 8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('638CD38A-1F6B-4416-B839-F16F2E48BE0C', 'F9530F35-DFA1-4ED8-B29A-385C27927000', '4601774005862', ' 0,68 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBC7BD9C-1BDB-4EAC-BC15-CAC46202050A', 'EAF05799-2E34-488D-9337-94781425E9F6', '4601774005893', ' 210  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DB7E29B-B6CA-4D90-8130-4B8FCD616B6D', '121E2BF5-1B95-4867-A89F-3062F44CF758', '4601774005923', ' 510  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6ABDE98-C2C1-4532-B195-00015C2C822D', '11701C5B-4666-4492-BD00-6581713E03D9', '4601774005930', '    - 18 / 306/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AB309A2-9E34-4357-8362-292DC694EA46', 'F562DB1D-CB9F-479D-8B2D-7FBBB7E3D325', '4601774005947', ' 3,58      -305', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56A02377-733E-4C38-A08B-FDDE5F79E426', 'A2229676-0303-4CC6-8646-9440AEF00C7F', '4601774006128', ' //  2 / 327/ - etraplus', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C77C606C-8F82-4279-B155-3ED23AB9300F', 'FDAFE2E1-4CE5-454D-AE22-29B6EE9F932A', '4601774006135', ' //  3 / 327/ - etraplus', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8910CA95-9661-4178-BF33-5518AFC3A462', '46EA20FA-8E2A-408C-A847-C65112063A00', '4601774006142', ' //  4 / 327/ -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF50677D-470D-47E2-B510-8DBAF00A8432', '9F59473B-1E2E-4275-87A9-88B3CC1553FD', '4601774006159', '  - /c327/ 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3960C364-23A5-4EA3-A420-A614E81A7185', '218C9E53-1AD4-427D-BA40-0E555F08541C', '4601774006234', '  -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C400452-D1E0-4841-BB57-31EDDC070131', 'A58A4DC3-2B0A-4F67-B1F8-C2381E1940ED', '4601774006258', '  -. 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22736746-7683-4ECA-9093-FB2908B10DA0', '0F4A908F-6FC7-496B-B276-D33943102DA6', '4601774006418', ' -  .329  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2E612E2-971D-41A8-A2BC-AE1CA8152231', '2721E32C-45EB-45FD-9FC1-CA71A023BC70', '4601774006555', ' -  .329  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AC2C5FC-9A21-459D-84FD-CAEEBA926943', 'AEF82A9C-502A-457B-A613-1B4794E38877', '4601774006708', ' 510  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC7371BF-019F-4340-89CD-0D1486C11412', '4AC303D5-446C-455E-9F13-04C8F5C611EA', '4601774007514', ' ./. /./.-  2 // .-320 /lycra/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64AD24C3-0D6B-40AD-A564-E64BEA2253B4', 'D19082E6-44EC-405E-B0CC-80D86851B5B7', '4601774007552', '  / -  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8B16B26-9E78-41EE-A555-B4004877CD75', 'CC05B78B-6656-4D6F-BED8-EA35EF61F3ED', '4601774007569', '-   /  /  7/c 320', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DEB9034-8C1A-4C84-809D-E7086E3213CD', '893AD87C-D3F6-437A-B95B-EDFDCC749A91', '4601774009327', ' 81,5      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('013A5BC2-8D93-4DF8-97B4-89282F81E773', '2A190555-4081-4894-8BC4-F22809EE7A86', '4601798006241', '  / 18 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D2A6300-FFAB-43E3-8543-1CF5838FA671', '23357591-B13F-4ED8-9550-49B9C7C52D00', '4601798006265', '  / 18 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54ECA280-6C3C-417C-ACDF-B4C57165DBF7', '056240CA-1869-4E44-A88D-EE550279AEBA', '4601798040146', '  / - 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('706244FD-2D28-4812-9FB4-4CC4FE9A6F7A', 'E9F48E08-0E42-471D-BADF-2EFE5ACD7D8D', '4601798060779', '  /   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDCB0BD2-064B-4342-90A4-D44BFFFB35C7', 'AD0E76E1-F649-425B-A326-BE359DA937E5', '4601798060786', '  /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B718C6AD-9A6F-4367-A5B4-09A34605B87A', 'A46AA8D7-1750-46DE-B93A-5F2E931CD5D8', '4601798060878', '  /   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFD550B9-13BD-4B14-8333-5327D55527A6', '1D308555-B44A-4AB6-8530-C3E617EEDD69', '4601798060939', '  /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65AF6F11-856D-412B-BD99-D0683B26B13A', '781F5544-998D-4378-BDEB-3DD0A5CF7533', '4601798250088', '  /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AF04894-89C7-486E-8519-CECB8D230391', '468274E3-4F1C-4AFC-A35A-181F7B995ECF', '4601808001327', ' 0,02  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AF91611-6009-4BB5-9297-A817AEF5FA39', '174A623A-68B5-44B2-90F6-3614AD7329FF', '4601808001341', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFB4A0B4-B86F-4077-89C3-AC35E807F034', '66F860E9-FEC7-4290-A96E-D67D29F3B623', '4601808001419', '-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A23D9B6F-0B3C-42EE-A5FC-A750A43EAB01', '4AC556A0-AB3B-44BD-BACE-79567112645B', '4601808001846', '  0,25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FF8C59A-FF1F-45FE-AB2B-54C9FD6720FA', 'C774C8C3-7B93-4791-A2DE-DC449B3DFA55', '4601808001914', ' - 0,05  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E25ED84-49EF-4835-9761-AFBEACEE1B5C', '8196749D-0B86-4E76-A7D4-52E084239060', '4601808002331', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CF0926A-C725-4304-A322-37E40663D6AA', '8B2EADCF-9C23-467B-8307-B64F68E5BF00', '4601808002607', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCCD7C1B-B71E-496D-9704-A6CB11B6A214', 'CB02BC0F-625D-4C98-B8FF-CEE2FE7CF35B', '4601808003963', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCA18E13-3472-449A-81FF-D67885C6736D', '46480FFE-C84E-423F-BE2A-9882AF6D2B78', '4601808003970', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('943BAE26-B456-4489-9828-87274A21141F', '5DACB984-7385-4048-B25E-B8B069E47AC2', '4601808004588', '  /.  . . /. .  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ABF4310-91B5-47C0-B12A-11761E12E559', '8F3BED58-A995-4974-B7BC-90059BBBA35E', '4601808005028', '  100 . 3 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EFF9E0C-431A-4364-A54A-C4A62D7D1ED1', 'F65D219E-D14D-4114-B189-122EEFDA53B2', '4601808005325', ' 30/ 10  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D73CB1A-E89A-46F3-BC03-A774C2545024', 'B01DDFE3-FABC-46C9-AF5B-3A933F3AFE6D', '4601808005714', ' 0,25 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('314858D6-12AB-4876-A398-8203C8CDE38E', 'B56D80CB-0964-483A-A268-9F4C0F755A52', '4601808005776', '  3 .30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E35D490-8523-4215-9485-4BC22AFCF868', '2B909417-1D05-4386-B722-C1B0B27E4F38', '4601808006315', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4CE6A31-E525-4132-96B4-D98DA1433250', '890FA170-AF6C-4EE7-9A5B-71C0F4B90124', '4601808006322', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B02FDCE-6BEF-4FF0-A789-624B2E08C942', 'ED110B95-85E8-4BA4-A1F2-F675ECF93C81', '4601808006445', ' 10% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE60500D-CC85-4D0C-84E0-74A3F35D1CBC', 'A5078BEA-4546-41DA-A0D7-1D3DABB5F8AE', '4601808006896', ' b6  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D840DD25-8664-4515-9F0F-11B26DC768D6', '3108DC3F-EF56-4417-A034-AE572AE009FB', '4601808006933', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ED92457-8764-412B-91A8-C429A66A7C60', '80153ECB-A556-4436-B9E9-DA1BA23C6317', '4601808006964', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0636B76F-364F-4762-B6CE-03CCD612EB15', '1ADD7DD9-FFF2-42A1-9E42-0FA1E4F3AFAA', '4601808007510', '  /  2,5 / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B2225BE-D9AD-4108-81EE-EE90885BF356', '84499DD2-A4E8-432B-8D45-6DDFFC4B9B99', '4601808007541', ' 45  /  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9AFA840-0278-489A-AFB6-31D7CCCA2A3F', 'F7BCC90C-F07F-41A0-AF2E-5009DA38E856', '4601808007565', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40653867-2A93-45F4-B4C0-A3262841ADD1', '46FF8D56-68A2-4005-BC87-375B2CD2CE42', '4601808007572', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4B67C4D-59ED-446C-8E0B-9CA4AF1F669E', '2C3600DC-D5B6-4A38-A5AB-1D1236080550', '4601808007589', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('621D1B75-8033-40EA-B1A7-571EBDFA5F3E', 'F5169AEC-EF03-437B-87CB-33F7F6723360', '4601808007763', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('699BD939-A40B-4C23-A265-9F3BCB91899A', 'C5887317-D85D-4E09-B95A-4573D051056B', '4601808008043', ' / .. /  365', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9ABE603-7203-4D18-A087-A984A57707B6', '40DABF14-B2F7-46FD-AC10-994CDF833D6C', '4601808008050', '  3 .100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD882A68-A20F-4C4B-98CC-6010E4D429CD', '1C86121E-8025-45E7-8D0C-4C85C8F17491', '4601808008159', '  3     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B27AE3E2-92D8-4927-B786-8D275FE8DB99', '49E75A43-17A1-462A-9F03-B46C3BCF92C8', '4601808008180', '  3  //   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37ADB5B3-65B0-4FEF-99F2-4C8B4F98A4BE', 'EEF7BD5B-4627-49EE-92D6-5E21218A1A01', '4601808008319', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C35DE03-ED2F-49B8-B3F5-5CE64CB2391D', 'FCECDB71-DDBA-4033-817A-B20E748941CB', '4601808008357', ' 20% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('344415D6-B2C5-486F-AC59-475DEBE1AA13', 'A61B0470-7E32-4DA4-8E29-679761BA42AB', '4601808008708', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBB11276-34D1-47C0-96E9-47D655CBA1EC', '41702359-E8D2-40A2-B3DB-4CC5AC3C0504', '4601808008715', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C41FF72-FBE7-4842-BC80-7C0DA75733B2', 'D3CCD7AD-5BEA-4A7C-9833-A74D71AB47DC', '4601808008869', ' 15/2,5  -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0C9B506-F0A6-4283-BE88-943EE580494B', 'E548733C-EA22-452D-A0F1-C336AD8D41A8', '4601808008876', ' 15/2,5  -  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71AD8976-D2C6-47A4-9CE1-8334679030AF', 'EA365621-F087-43C6-A6BD-C991F29074F7', '4601808008890', '  1   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAF4F567-9532-4709-8433-DF1403677576', '59447477-96D8-4013-841B-F4A29A19550C', '4601808008906', '  2   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63893AB4-D1B9-4BA4-A8C3-4D740F3C81EA', '872C1178-6896-4904-A18F-2EB11ADE7DD4', '4601808008913', '  3   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A033083-9D9A-4EBA-AD6E-24752B5CB433', 'FB35392A-0454-4770-B666-EEDD6F3D3E82', '4601808008937', '  /. .  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('131C17E1-9E0D-450C-9269-C2A6EA5C066A', '6C14FE12-7D15-480F-9A98-8D4B50B8C5F4', '4601808009033', '   / 42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6787EB37-50BA-4575-B9C3-9A2C19D430E0', 'AF98CABC-3679-4CB6-9E16-69192ABD211F', '4601808009118', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC351E06-3619-4849-9321-10F91FE21F37', 'FDF333CA-BCC9-490A-B8F4-735A667893E7', '4601808009842', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1215DAE8-5A32-4A2B-95FD-9709CC2D9F28', 'D21F7B2A-3018-4DF6-A1B5-A2D9850EB00E', '4601808009934', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED9A5A87-9BEE-421C-B33F-42502107CBDC', 'FAA29A00-F920-4612-99E0-D585334998B4', '4601808010190', '  100    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55ECDC91-17F2-4281-9C06-54F85BE6CB4F', '3DA2B406-914A-4A82-8A68-8ED4D8CF26D8', '4601808010428', ' 3 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E99E729-942F-4482-9430-3B5847E8CC77', 'EE2B2A2B-58D1-480C-AD2F-D156D1B7EE29', '4601808011388', '  3  45+ / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F408C546-83CA-498C-BA2A-53DCF0DC36F8', '05C5B7D7-9587-4425-BF12-091379E164F2', '4601808011395', '  3 / 45+  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8417878-AB9E-42A0-95E0-DE8F82CAF07B', 'FC5899AF-E589-46F2-B262-6CEC9A424DD8', '4601808011586', ' 2000   /0,2  - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0912D488-B8DA-4B61-A647-F937C20A26DC', 'A91BF6B2-142E-4EC8-B5BD-981F77AF3E93', '4601808011623', ' 40/0,4 - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B0EEA75-6B71-4755-A52D-364A0FC9D6D0', 'F3BB94F6-9037-4386-B511-6CED324C2919', '4601808011753', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A76B3B5-08FA-47BB-99D3-E3D5059E9DD3', 'BDF63905-0639-4B9A-9132-B8C1E6444CE1', '4601808011807', ' 120  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0A7C63B-0240-47B4-8A9D-EC9B6EBC2221', 'AE8DDEB0-C35C-4AA0-B081-F463B2DD42B7', '4601808012293', '    1,26  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AEC5869-365F-4DC3-A504-A5BCD62C47E6', '5ECE6FDB-A83B-4077-8501-02A9851DDD1F', '4601808012859', '  3   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01D3FD9E-0B2E-4BC4-A410-E48B1C646AF7', 'AF613676-8C36-441D-8816-537CE0FC6CCC', '4601808013092', '  50  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4724F35-2091-48EC-A6AF-6036D6857984', '61AC034C-2973-47CD-9CA6-CBB517D2D4FF', '4601808013146', '    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0877F18-0951-4BEB-AA3E-94B9C2FA1C6D', 'DEEF3BFE-7D43-4907-AB78-F4AD438638DF', '4601808013153', '    / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BDA41C9-C57C-4EC0-A9EA-219B0A488C52', '4F0F22D8-C9FC-4540-9B04-B106DADA9E0D', '4601811001383', ' crystalmatri-fs   /5n5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E70E4A0-1394-48E4-BBE3-8F8810E6F39B', '42F59689-C6E3-46C6-9DBA-E41004276166', '4601811001390', '  - 5 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5706F298-26A2-4F82-A2B8-6C66A953FFF1', '5265F916-F4F4-4374-B13F-9FA044C74510', '4601811001444', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD5F23A9-2F2C-434E-88FB-C89F35C60EA8', 'BB7CE05E-505D-4D49-88AE-9B6DC20C7D4D', '4601811002007', '  8 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80DE7693-E54B-4597-AE47-88A910DAA0B6', '7632E227-82C2-43B3-91A9-8C12B6A6E41B', '4601811002656', ' - / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AE92F0C-304B-4DE3-BB59-0AC24AB018AC', '875BB96F-FFF1-4F72-9600-C9B7C2939210', '4601811002663', '  - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8FEB0CD-E150-4D55-9479-B4604ED3B333', '785BBF5E-860B-4506-8F8C-1FFB4226E87A', '4601811002687', '-  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A06E280D-F6DA-47EA-A4EE-E1EAFE887171', '6F38A759-096D-40BF-8292-371067DCA817', '4601811002694', '   -   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAD6C5E7-67F0-4CDF-B407-A2A827A41DED', 'E1EDFC39-1924-410D-BB34-A01B6FE941CD', '4601811005084', '-  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CE8317E-896E-488A-B07D-74AAA7D46600', '693C49F4-20F9-4408-8DB7-20F24B210D18', '4601811005091', '-  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B80DE41-C8D0-48A1-9988-3C7DF3BC8B78', '4F0F73D3-5422-4D66-ADD5-463A2A59893B', '4601811005206', '-  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51782458-0441-4359-9F61-7A3255A0369E', '9517AEC8-D4EF-4F9A-8734-11B7354C910B', '4601811005213', '-  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A901E69-8C59-48CC-AF82-A3213C42388F', '85BCC4F0-AD4D-4548-AF38-074A403561CB', '4601811005268', '-  eotic 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A8ECF7D-39D7-485F-A616-B2EB08E4E1CC', '125F7B7C-F4FC-4BCC-B713-789B238C8D9A', '4601811005282', '-  orange flower 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D41DCDED-594C-4452-898E-B8EFF428076A', '4860BD78-3845-4BBC-B048-FDBE9DF08EF5', '4601811005299', '-  strawberry 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8F7D3D6-D355-48A8-9DC4-32303312E24E', 'B8694A51-E643-44B0-A52D-EF099DC68EB8', '4601811005381', '-      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE14881C-92B3-4CD5-81C8-3BE70689B9D2', '237E00D8-843E-491E-867E-B00CF6E78C65', '4601811005404', ' -    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A93E4FF0-78EB-4BB1-AD55-F50A0971B2CA', '76DF1890-7587-44F7-B46C-90DACA2C7D2C', '4601811005442', '-   L-  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6544074A-8703-407B-8FF8-D6694DC85317', 'BD2D58E8-C290-4ED6-B2A8-221CE019F09A', '4601811011009', '    / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6742EF5-D186-4892-AED8-42ABB8C410F8', '06152593-D8D2-4756-B2A6-4F5B88D5492B', '4601811011016', '     / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BF3DCB8-2409-48A0-A20A-8415FDF51E33', 'C2C8FF1F-1780-4465-AD7D-D898328955AE', '4601811011047', '    / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E45A6AF-216B-48EB-8345-81EBE4BF4AE3', '3E3128BF-E4BC-418A-81CC-2F2BB88BF15A', '4601811011054', '      /    . 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15DE0881-61DF-4FF1-A354-90E75046147C', 'F48160F8-2B43-4394-B904-1D8BA8D6D8BA', '4601811011061', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98D41EC4-CAE8-45DC-BA6B-2D47DA30324F', '1FAEB88C-A99A-4DEF-81BF-2801F5E1CA8E', '4601811011115', '   /   10 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A7A198B-DCED-4003-9B1A-6B91ADD31B62', 'E3154F60-1E73-46B3-A9DF-728EAEEB36A3', '4601811073434', '   // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09BF45F8-FCEC-4FB4-9EDB-D520F7285606', 'C6E9195E-A19D-4C4A-95A6-29890858AD3F', '4601811079498', '   /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B3D2EBB-31D4-4F48-BCFD-A2778389E96D', 'AB68F265-D456-4AA7-BC20-466E56FCA54F', '4601831000397', '   itest ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E8503B7-E94B-4A17-BF08-1962A721499F', 'E6E1EDA7-AAAC-42F5-ADCA-F9E60503DB9B', '4601834000110', '   /../ 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3187C250-CFC4-40E4-9B74-F505485E214F', 'E7D066A7-DD22-4F49-AC7B-91E57D05EF86', '4601834000516', '  hi-tech   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06C762C9-4087-4258-97FA-C405E610F253', 'F0BE3C04-2BD3-472F-9EE6-073957481DCC', '4601834000622', '-   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABC8A697-3EE2-44A6-90FB-A948655B2E28', 'A938BEA6-98B8-4E8A-A221-E061D33B3DDA', '4601834001353', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA4AA6C9-4122-4766-BB42-C0E1CFEBCA8C', '3FF6A9D9-7329-47E8-A9C9-04D11354A3EF', '4601834001698', '    5+2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E23B87F-22A5-4C3F-861D-73EE625D91C1', '89366169-48F2-4EF4-A158-F40F1A15FB46', '4601834001704', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6274E7E8-AC0E-42E2-914A-C9CB0F46A6AC', 'C8DFD474-18C1-44BD-8D4A-F5771B7BF9E9', '4601834001711', '  3-   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC4B31EE-CAD8-4F19-BB5F-0610F394A8A9', 'C8009DFF-2C09-4393-B979-27EC84ABA26D', '4601834001728', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAC143E9-B6C5-424F-B745-9B01EA417385', '47A7C885-874E-4CEB-977A-8971E7D88538', '4601834001766', 'Frautest menopause    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E1D4715-2F9F-4CA1-815B-0DEABFE75FCE', '92FBD1C6-AF97-403D-A8EE-6AED72387AA5', '4601834001810', ' frau  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FABAE78-2E21-4BF6-82B1-4CC126940C8E', 'CC703C49-7BA9-463A-B8DB-7AB3A0C24B9C', '4601834001834', '         /5 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE71C446-74EC-47FE-B6AF-FEE60E327FE3', '83F20CEA-BBF1-41F6-A602-FF9E0B2A76BA', '4601834001858', '     23 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0BD4374-F5FD-4DE6-9679-628DC8BF5CE3', 'AB4EBC7B-D598-4BF0-AFDA-0E4E95370066', '4601834002442', '  hi-tech  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('722E441A-4068-402A-A4A5-7EABEC928378', 'C0BFC259-3315-4BB5-BD86-2EF63FB0BFF6', '4601834002466', '-  hi-tech Sensitive // 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15926087-7040-4F5B-9BD5-973E6A3D6256', 'E88531BC-848F-412F-9443-127EC42F3F8E', '4601834002480', '  hi-tech  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10839EFC-6A8E-487B-A13F-95BE235C9389', '7C428F00-8366-45E2-A51D-2467E9C3E332', '4601834002503', '-  hi-tech Erection / / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('827CF4DB-160A-4D1F-88ED-25D039799D7D', 'B4FA70A4-3241-4895-8525-CC16FD74CA5F', '4601834002602', '  hi-tech  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46E6477F-4023-405C-AF8E-FECD7D7A11F5', '7FF62B1B-1C39-453A-82C3-9209445F2C34', '4601834002664', '  hi-tech Sensitive // 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3395CAD9-518A-456F-B047-F244CC38DD4F', '0719394E-2B5E-412B-8417-8DFBD1C7C7AC', '4601834002749', '-  / / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C431CFC6-34C8-45F0-A4BD-72C24BC3B02B', '2A2BBFB3-77A0-4B07-B4BC-785ACAFD8C21', '4601834002763', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1A662F5-E531-488E-875A-216AE7701595', 'D0EC7470-897C-4E5E-8435-378DC7EB8596', '4601834002787', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0159585E-600B-4EFB-9391-193C88521837', '3F9EE316-F1E6-4E2B-92D0-A0A612F316D4', '4601834002800', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E847BF7-E239-45B5-81F3-35EDD8835F53', '6C44643B-EE6B-47F2-BA0A-85709E56573E', '4601834002824', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8F25A36-5656-4E20-9808-E04C7396A1A5', 'C1FA5242-6EDF-4E3B-9736-E745AF27AC59', '4601834002848', '  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('436C8666-C814-4A54-91A3-190D2ECC7A7D', '728D36C2-7812-49D7-8175-C2A726621E02', '4601834002879', '  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ED01D83-A060-4ABA-A41A-33473AD36C4C', 'E6A87C03-DE0D-4B06-8CFB-5E2CDFA2D3AA', '4601834003173', '  aroma-   , 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E032C5EB-8DF9-4F8F-85C0-37BC750490F2', '1D1E2EDA-3C33-46DF-A830-80061D9B0CD4', '4601834003548', '   frautest  -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC9227B7-38E9-4981-8639-75E6C0E7C51C', '6123D7F0-64AD-4985-8808-6DF0371EB061', '4601834003623', '   . // 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E836B2F1-38DE-455C-AAC8-3BFC519138A0', 'D0894D79-65CB-413E-86C4-62BA3BD68EC0', '4601834003647', ' silence /  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44F39DE7-F426-40B2-9E6F-D9809244FEBF', '7C7F5310-D764-4CF8-8443-998FB7527C0C', '4601834003722', '-   7  / 3722/ //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97522AE2-E669-4E1C-9ECE-5E2B67710DC5', '1DBDE04F-1534-4BDE-B365-F40CD89E6EAB', '4601834003739', '   7  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F8E1206-691D-41A0-8B37-F68D3195A2FD', '75C13186-DFFD-4EBE-889C-45E244809CBF', '4601834003746', '  7   /.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7719F7D5-9962-4F0B-A1EA-E7D863FF8689', '4951EDDB-2346-485F-AF93-95157643DC3E', '4601834004088', '-  dotted // 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EBD507E-4D68-4D3F-B9CC-9293A5A777F8', '69A8F84C-5ED7-4599-B217-44FED41F2209', '4601834004101', '-  ribbed 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03528071-8F0F-4386-9CF7-0A54BE854EED', '46043817-D371-468C-9A55-58E43499192E', '4601834004125', '-   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDACCE8D-D2C7-4540-AE75-B6622A4F1D4C', 'AA887C6B-74C0-48BF-A64C-D75C96F87D61', '4601834004149', '-   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68167830-DDBF-4354-A80D-08565C8217F6', 'E6E1EDA7-AAAC-42F5-ADCA-F9E60503DB9B', '4601834004163', '   /../ 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EF77095-0099-4AED-8AA0-AD144B362747', 'C335752F-3994-4AD6-B23F-95C8BDB3CE5E', '4601834004187', '  dotted // 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CB6B5F9-3D82-4758-A189-C3D284966404', 'DCBA452A-4710-4FD8-94B8-2F78647175AD', '4601834004200', '  ribbed  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFCD2687-DADB-429B-A291-3800A8D1463C', 'F0BE3C04-2BD3-472F-9EE6-073957481DCC', '4601834004224', '-   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('847E7D29-2354-4EB4-9358-AD01EFBFBF44', '1601B6D5-C968-46E8-99D3-38E0D6184FAB', '4601834004248', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BD79917-A145-4352-B249-7E7E93CD952D', '1B97AC58-1465-453B-8961-D13A2C40DB6D', '4601834004262', '   /./ 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D23C4A0-6EC8-4CB7-AF1E-21B4299C2CA7', '7F2A8EB3-07CF-4554-A9CF-1A9971BD1A88', '4601834004286', '-   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52642433-468A-4113-A387-D4A784BCA403', '634B1B10-B925-4C79-87E3-B76AAD415F73', '4601834004309', '-   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9446BBE0-7AF0-406B-B1F1-6C4BC1603618', '6E706C30-AF2F-45DE-945C-86BCB6CA7571', '4601834004323', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E92DACFC-276D-4463-9905-B74838614D34', 'AC4BB1BA-BEEE-45B3-BAB4-818AF5346618', '4601834004347', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('129C6314-6A3D-460A-8A10-8F930A1186C6', '3F76B2C7-E375-4A88-BEE4-7F022F4752FE', '4601834004422', '    , 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FFC6BC4-814B-4C82-84ED-1D4F2F49EB6D', 'C734DF4F-6C8C-43D1-BE99-39EFD5285401', '4601834004477', '   1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8405C67F-7296-4939-8ECB-64EE43B47C91', 'F7BC6B45-58F1-47A6-9ED4-E8EF7AAF1D34', '4601835000027', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10011EB6-07B8-4EA6-8954-4368D8FAAD77', '291055FB-CB23-44F6-8372-C907FE21C560', '4601835000034', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8884F83A-2B02-4B63-8D89-5AED4C469307', '0C552523-8B1B-4FDC-ADE4-BB12776802E6', '4601835000041', '  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91DA6007-BE67-4B89-A858-B2394141E180', '9378C57E-6B3E-4FC4-9321-247000D5FBDB', '4601835000058', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0FD935C-B574-4C35-9D80-40CBD97F5998', 'E01C63EC-8A55-42C3-B62D-49BDB1CAC312', '4601835000065', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('432457E4-D8D9-425F-972C-D7D3DC2E51A3', '70948BE7-C7F2-4D1B-AE46-B92118C5E3C0', '4601835000089', '   /380*130/ 1 // 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5747FAD3-1B19-4D61-8260-B68088533406', 'D966BAC2-BCF3-4AAD-9A5C-C15C15C74E1E', '4601835000096', '   /450*140/ 1 // 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B4A563B-2207-4504-A5C4-BA24AA2C6AFD', 'B2C9D13C-ACF7-4260-B410-18C5057CB123', '4601835000119', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('370BB9CB-096E-466E-801A-6EE1D84E6621', '522EE27B-9ECC-4965-97BF-BE41E6E52F65', '4601835000126', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('954E9ABE-E31B-4645-8791-CE574152F231', '8E68B9BF-9B17-4862-B196-3E5225107A5E', '4601835000140', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F12B7648-8F51-4B95-ABCB-AF83644915D3', 'B304F7AD-BD3F-4C66-A27F-8302057709CB', '4601835000157', '     210', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('118A274D-CA11-4E27-89B6-F325EAC3855E', '06D59D05-A2B1-4204-BD90-038EC14036BF', '4601835000171', '   9 ( 2 )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6D2753B-671E-44FB-8E06-96DB0968156A', '1446A668-9069-4DA7-AE59-2A3EA5F2AF03', '4601835000195', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1537565F-657C-4CB5-BD27-AB84285AF118', '5B09C52F-692B-4968-A3FF-F7874C100FB5', '4601835000324', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('331E86A1-A1C6-43AF-9AE6-F6C20A650177', 'EE310950-52D0-4A08-8F6E-6620772A7AD6', '4601835000447', '   9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBC700CE-0A90-42C6-AACA-2858A3B735EB', '13A3D6C1-4190-405A-888D-22534CE369B2', '4601835000485', ' . .  /1400*25/ 1 //', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98E19E31-94B2-4BE8-B985-1FC7D87332ED', '7CDE57CE-C98B-4A6C-9B45-F343B0F77E3D', '4601835000492', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FE59A61-0F68-4184-AC67-7B5FF93C1F6D', 'C38F1EAF-8DC2-46D3-8870-0E1016A4A9AC', '4601835000508', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04F1B598-B342-4282-8549-088CDC7D492B', 'B07F6DFC-9C1B-45D2-B2A8-10236F11ADCE', '4601835000515', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDC0BCA0-ECA2-42B0-B58B-0F19498D02F9', 'AB49641F-3360-4EB0-8397-7B8169B2523A', '4601835000522', '   -3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D657D6D0-4E07-4429-BFD7-7D93AE69F85C', 'F3C5D6DC-CF41-482E-806F-AC29F40FA007', '4601835000546', ' 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2298CBF-F675-48DE-BC30-497A57027FE3', '41A75B1C-87B5-4413-83EB-EEF73CCD33B2', '4601835000553', '   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7B027FA-3B0A-4627-A412-71545FBB76A9', '26AEBB01-BA53-4910-BE24-4A139A316359', '4601835001123', '  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('665B4A06-A5E9-4A3D-929B-89C8681AB384', 'E3808BC9-A9CA-4B00-9B0F-B44D7D8405C4', '4601835001147', '  2 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42AD15C2-8A9B-49E9-B541-BFAAB11FDF4B', '56F6C33F-12B5-4DB9-89AD-A2C61BAA3EDE', '4601835001161', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9F55DD2-C501-4B4E-8789-D8CFE1DD0BB0', 'B28D4F6B-0F43-49DF-B070-917C486C742D', '4601835001208', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BEA0F95-588D-46D3-ADF2-E3F704C9BAC4', '430463BC-641E-46CB-A73D-702A1E448F63', '4601835001222', '     -3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCF38658-39AB-4930-8CD1-5614D791904C', '9F465A57-315D-4D14-BE28-4D3E711496FE', '4601835001581', '  /-16 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BD6CBFD-C245-4112-BD23-843FFD89D6B1', '574A6C08-3998-4799-AC0F-6BC2CDAD73F0', '4601861001555', ' 1000 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91D9F68B-7417-4D79-9FB8-EF75D34A4452', 'A03E583A-4190-4261-BAB7-B0D2D46174E4', '4601907000054', ' 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('377FB34C-2570-4C3E-B94D-341CCE07B143', 'E0242CCB-7D32-42B4-9B50-6CF717183871', '4601907000092', '   5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF11D041-54C0-43C6-80AF-8DE3321D32AB', '172AED8D-607D-484D-8D13-75666C8FF775', '4601907000474', ' 6,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D41B83C8-6DC9-4306-BEF8-E0B1B97A4EF7', '64F0129D-8739-4814-83D9-B553A2D4D754', '4601907000672', ' 125   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14533CEF-5A9D-4AC2-8E13-83A59A768BC4', '682AAC40-605C-4686-9249-3CCD64747161', '4601907000771', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C01415A-A84B-4A99-A28C-E6E2A44C4CF3', '18AB8092-D40F-41DE-8997-3F6EF83FE09B', '4601907000788', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C69989D4-1AE9-433C-9F8D-4FA100F05343', 'ADA59562-9529-44C7-BBAB-EEEF3F0EF508', '4601907001150', ' 150  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9B048FA-EFBA-49F1-8547-2651F473CBA6', '2EB9BADE-9E7E-4985-BC88-83DF6EECBDB9', '4601907001174', ' 1  / 3,5  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('231E1188-74EC-4237-849B-D62AB4C43946', '46D2B414-4319-4396-91A1-6DCE8BFF8C78', '4601907001211', ' 1  / 10  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08446B23-E464-4F3C-A61F-459CF77AD3B4', 'EDB0E8AA-5E6F-489F-8077-E0D6537990AA', '4601907001341', ' 0,003/3  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDE0265B-D0F4-48F2-A113-B7AA3A341A1C', 'C99C4E9A-7A28-4E44-A45F-785CD793D787', '4601907002225', ' 125   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58EA6B26-89DA-442C-86B3-A8397FC8E95E', '4C459B99-42DA-409D-B3E2-7A993D8CA04D', '4601907002249', '  100+25  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('193DE15E-6817-483B-AD84-6E4479BCEB41', '84A386CF-3B3E-4C21-A5E3-D002D693520D', '4601907002263', ' 200+50  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('734E51CE-5200-4179-87E1-1878786D9F47', 'FBC10CD3-DB10-4CB6-901C-D7391AF66571', '4601909000069', ' 0,015+0,120    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4072881C-65A8-476C-9DCB-9325FDDD17A8', '05104D81-71E9-428D-9662-9B5D02BAAB2B', '4601909000090', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BADB75A7-F645-4330-A8AF-4A5B2BCDE54C', 'C61D0CB4-B6B4-41DA-953F-D75BA2265FC9', '4601909000106', '  213', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42FF866C-0249-48ED-8394-B87F077271B3', 'A4113E7E-03E9-4A54-9BBF-31BCD6140A61', '4601910000119', ' 0,5   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DF651C5-70A6-40A8-8E60-7F6855F7BFE9', 'C05653D5-3E76-4460-95F6-B3A378924392', '4601910000232', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4FD42D0-3F85-491C-AC3E-DFFC6328F1F5', '7C19C119-0565-4C1E-8F3D-1A7882A7CDED', '4601910000454', ' 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC2CBB35-1FF0-45B2-8886-BBF421566565', '992B8384-10C9-439D-A338-759514A55D2B', '4601910000515', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('093B73F4-044B-4666-81C0-FC0CD3E609C8', 'FBC10CD3-DB10-4CB6-901C-D7391AF66571', '4601910000522', ' 0,015+0,120    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB13BF18-1789-4764-A7B9-F11D34216FB1', 'DAC90220-7D49-4605-8BF9-62DFC396F7D5', '4601910001062', ' 2,5 +1,5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73144530-2C71-46DB-A856-33DE9F30DCB6', '5500C587-49A6-4514-8233-26D036F2B809', '4601910001079', ' 2,5+1,5  / 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A038AFB3-EB84-44A4-A818-28F93984FF23', 'E19714AA-C497-4026-AD86-765102EC5F19', '4601951000055', ' 10 ++', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1C277E4-18F9-4609-BC47-B6176CC60238', '60BC1B9B-7C4F-495C-B4EC-4A374D459AFB', '4601951000475', ' 0,005% 2,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AAC656C-A206-4F5D-9794-F91FDB40B436', '0E41A826-0FA4-41CC-A624-0DDE98A67EB6', '4601951000611', ' 2,5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('192CBFDE-B380-41EE-BF49-2124D2AE834A', 'D6D855DF-33D1-4008-85C4-3593390A8A81', '4601951000703', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE560A16-399B-4F00-AF63-24A4820A5BB2', '8544A27D-B435-4DB1-9C1D-6945F0AC1A6F', '4601951000741', '- 250  /- /+- 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5089988A-91C7-4FEF-B0A4-67060E281B34', '1C74010E-285A-43DC-9EB1-47B7E1D27012', '4601951000765', '- 1000   /  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B38C50AB-D677-4FFB-8C5A-0AC7350C9FA4', '51DCE074-EA3E-4717-8B4B-56C186844888', '4601951000840', '- 150 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8C9B1E5-4BB4-4EA7-9D37-943EABCD1BEE', 'E1CB3857-B348-42A2-BA6B-9FD28B1CDD8B', '4601955000068', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A80C17E-B3E7-4C5D-B415-3D3911A6B34B', '70571E80-E935-4789-9527-F1D375885209', '4601955000075', ' 10  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B993C66D-9E96-416D-A583-854CE742AFDE', '5F01BD0A-9235-4526-BD2F-A05786F52B19', '4601969000191', '  8 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDA759AA-5C2B-4833-B041-DA760D5752EA', '2F91C866-8002-4870-BDDE-C92DE0681553', '4601969000511', ' 0,1%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECE5C478-5673-4F12-8494-D2DCF703093E', 'DAF9DDC9-439B-4B87-8FC7-7EFAC42A2610', '4601969000917', ' 4  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1A03BC4-27E1-4540-9830-AE7E6AD38EEC', 'D3287B03-A116-400C-8B04-097317556EF0', '4601969001891', ' 50  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D8F8FBB-93CB-476F-BB72-7C230C71378D', '957C8582-8708-46F2-A376-6D765A366EE3', '4601969002386', ' 40  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE03F05D-1793-4313-834E-5FC2206D33D8', 'D1476D1E-5E66-4223-BB4A-F1F099401AD0', '4601969002768', '  20 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9775F3F7-52BD-4C9E-AB18-529765BBB697', '1120458C-5300-4DE9-981C-EE738075FA03', '4601969002843', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5B34AB6-685E-4C04-BC9F-13D0C515D8B2', '032781D6-992B-44FD-9662-4042ED384FC9', '4601969002850', ' 250  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C85BCFA5-15DC-412A-B2B8-6952C03B220D', '50D75C6F-BF84-4CE6-BD6C-BA9162B8138B', '4601969003024', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71DC2A4B-0950-4221-98B5-7400BE9C8E0D', '6ADA6B28-F1D5-4BC8-B31D-3A4C6731E3CC', '4601969003291', ' 80  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEB87676-3A2A-4F69-ACC3-54666DA94A65', 'C8A7C5E7-E838-4A04-B852-1CF715C382BB', '4601969003482', ' 2%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CC4A9C7-DAB6-4979-919E-C0E243EB6C6A', 'F13F44CC-91F4-4493-8E64-95ADC30823A7', '4601969003598', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E4570F2-6C55-40E4-AFFA-D895432BBDD6', 'CC256289-31DD-45ED-B209-4B9C150C8B1E', '4601969003604', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A1E8A04-5CAC-4E9F-99A4-951444125D39', '3BECAC7A-982E-49A8-B4F8-0884E92522D1', '4601969003734', ' 12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95724B1C-E6CD-44C3-973F-B01FF196B66D', 'B02CA214-C092-450B-9614-C3E5EFF2FCE4', '4601969003765', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8CB62B5-D78E-4E2C-97E1-A9CE5DA98C7A', '1CDC56C3-61DE-4C54-9C8D-026CFF387190', '4601969003796', ' 2%   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C2B2EBA-293B-4C3E-B9F6-6001D4A2C447', 'F8B7485F-EEF4-4B1C-B47A-8EADB97857C3', '4601969004182', ' 500  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B70F3528-F77B-482F-8209-52045873DE6E', '92018A79-B910-4888-8DF8-3793A4525B19', '4601969004212', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D9CA175-C527-4EC1-A498-949C9ED1AD0D', 'DFE4D980-80BB-49A7-98EC-1CECBC52C3E2', '4601969004441', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97749BAF-3825-45FC-A2C1-A1BA2781CA2B', '1275F05E-09E9-4F2F-B791-06A5058929A9', '4601969004458', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('957753B1-BE76-4F34-B87A-D64E965BA452', '203A9682-7282-40E9-B099-2108E1D7D2AB', '4601969004496', ' 2,5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EA2F5E8-1FD8-48E8-9354-240A94652009', '29A473DA-83EB-437C-B6EF-6E80E7AE26B5', '4601969004502', ' 2,5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('074C70A4-2803-473D-80F6-3A0720F22737', 'B86FB3A8-A75B-45F9-8C22-76770D3C60E5', '4601969004700', ' 0,5  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('183880F6-065E-4596-9DB8-9D99B0668C30', '08C0536F-98E1-46B7-819E-29160833EA8B', '4601969005042', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CDAECD4-428C-4457-AE88-5E68B3B012EC', 'EA8603FC-3C99-4E6D-BEAE-6736D87CDBAC', '4601969005059', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('597B35D9-500B-4CC6-9EE4-59991F5785E1', 'E654ED6C-7666-40A5-8C58-E1F1C8C75839', '4601969005073', '  0,03  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52287357-F72F-4F40-BEC4-4D9EB81E1581', '190B839D-92FA-4854-B368-073B68578ED6', '4601969005080', ' 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B958A5DB-123F-4796-8B62-D28761164D84', '388F973B-2C92-44A1-9AB0-307D60E96132', '4601969005462', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('633DFD7E-DF47-4979-8003-C964D769843F', 'EA8603FC-3C99-4E6D-BEAE-6736D87CDBAC', '4601969005479', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96897796-7B03-4F86-A55D-B9C4CD41E585', '4E3EB1E9-2A7E-40F3-8FD1-0BB2839AA4C8', '4601969005486', ' 0,05%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32762AA9-C6EC-4BE8-8FE2-D41964F5BDE5', '1C448958-559A-431A-8246-CC77E47A81B5', '4601969005523', ' 0,85  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3731983E-633D-4256-9C64-AE890CEA2F64', 'ECE59B0F-ABA7-417B-BD19-7E3BFF45222C', '4601969005547', ' 1  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E3B438F-BCAE-4482-9EF1-541122105A4C', 'BDF492EB-A817-4A11-87A6-9814140DEF0F', '4601969005561', '  0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3BDC8C5-A30F-4A02-9A54-566AB0376D95', '1834A306-B0F0-4D8D-B2FB-E52189638623', '4601969005578', '  0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99889D37-2D4E-40DF-BA6C-F125B475E71C', 'DFE4D980-80BB-49A7-98EC-1CECBC52C3E2', '4601969005585', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20A27B2A-11F5-4D44-91F5-297C6CA268F9', '1AD383B0-4AAC-4E10-9286-6C71FD35C422', '4601969005592', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9D56102-C3B2-42D8-8E9D-25673EA471FD', 'E31A49D1-2983-4D4C-B795-B9A0072A53A8', '4601969005622', ' 100   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84D12F5A-C3CA-4FB3-A4E0-2D1B3B90E892', '37D13921-0CCB-4799-AD42-94180F5BFADB', '4601969005943', ' 40+500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83495ABA-D97F-4CB5-BCA7-AF16B1012348', '58DC9EF2-9BD0-43CC-8A16-4368E8BE912B', '4601969005981', ' 40+500  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03DE57E6-28FE-4E03-959C-F51416DC0770', 'DDB12D84-497B-45EC-B21A-6B5E38049395', '4601969006001', ' 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FB566B7-22F2-4A33-912B-C45DF019E06B', 'DCCB415C-6686-4C61-9B22-D17872AFAA61', '4601969006186', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAE7AF59-FB84-4591-BCCF-838C92B52B93', '2F4B1A7C-902A-46BA-9636-34A78A52C3B5', '4601969006193', '  2,5% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90B1DCBC-45A2-4AFA-BD80-54C72A95440F', '9A00DBE6-AA79-42B4-AC39-2AEFDBB79277', '4601969006209', ' 25 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4778FE0E-7836-4627-AB59-081190FF15DF', 'AEDEAA48-3A59-4DE3-9DEB-272F2CB9F57A', '4601969006315', ' 15%  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21C43705-FC2D-4FB6-AB9C-42C22B85D8A8', 'AE4145A2-228A-4853-9160-97B5EDCF1C06', '4601969006322', ' 15%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26F3DAC3-4CC8-401A-8743-008338205E16', '82E3CBA6-4A6D-41AD-A6FA-A2C425FC5F86', '4601969006476', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93F95C16-C62C-4F79-BD19-9512A31566EA', 'E56889AE-DEE8-4119-B56E-B2ADC6EE039B', '4601969006698', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E04CB7FA-C23B-45B6-AF51-F7FC8485F98B', '88F75AAA-A4B0-42D6-88E5-BF6248F5AAF6', '4601969006759', '  0,5   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F4DA62A-24A0-4820-A0C9-F873E7C6D6B0', '449876B7-94D7-4750-A656-CCA0F1944B0A', '4601969006773', ' 10  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF3548AD-EB50-4568-AC45-D1DE58E84AFD', 'D9C427FF-0CA2-4631-93C9-10A171A774ED', '4601969006780', ' 20  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39974305-B5D9-4DBF-B52F-B118A204E696', 'F77B1958-5B9E-4F06-A21D-A3AC30B45708', '4601969006810', '    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('883DD7AB-AB1E-4B81-911C-A69F44D3D9AA', '6D269696-B5EC-49AD-A8D8-77F35518F3CA', '4601969006940', ' 50/ 120   18  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09929777-F177-483F-A746-8CA29FDC5780', 'BC680F60-FB99-4BF2-B1D0-388F00EE78BA', '4601969006957', ' 4   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1787C72-1C85-4122-997A-2D2E2333CE60', 'F4B432BA-12F8-4EDD-9144-B5D96E1B5B5F', '4601969006964', ' 5   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13AE6CEC-C66E-46BD-A9CA-ED62F6684D40', '1749606E-FBF0-4505-8E62-E1E48B884230', '4601969006971', ' 10  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55BE9F69-C7CB-49AA-B76B-0BBBE18C2923', '2D7E2009-150C-475E-A0AE-E5316F649DBD', '4601969006988', ' 50/ 60   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBCE0FEF-C8F3-44D6-9969-0C853FC01F81', '84D6A89C-1FC2-4B0E-AEE6-347018F2C3D1', '4601969007039', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57034A9E-41BB-498A-BEDB-5D55B1B6DDDE', 'FEC7CC7E-2EE3-4970-A502-EF29C81842B3', '4601969007046', '  250  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('200E8B25-65AF-4211-BBDB-C43CD37BF4B3', 'D2365D67-D719-49B5-ACD1-71B8DDF7CBAC', '4601969007145', ' 0,1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1DC2FC7-817F-4B7C-90AF-3DEF7B00F24B', '0E492CF0-F715-436E-8876-09DAF51F8B15', '4601969007152', ' 0,1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2211A81E-F41A-4BB8-9EDA-B8E38C387EAF', '7E6CBCE7-8948-4074-B2DA-E9108A12343F', '4601969007169', ' 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE9D697F-41C7-4418-8FA9-6B6DBFE0C620', 'F75919DA-F6E2-4363-BACC-B45ED2DB1767', '4601969007176', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36320058-413F-44E3-A4EE-F4FC5F7349CB', 'EAABE21B-C9EB-4C05-AC33-1C4555D07091', '4601969007213', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DB09D8A-48C4-45FA-B5DC-26DA381A2EF0', 'E74DD113-C4B0-4783-9B2B-863CAFD185DF', '4601969007251', '  2 30 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEE77A4E-1115-4C79-BD1C-45A7E230111D', '4636E4AE-1A82-4163-B5F0-66CEAB137846', '4601969007282', '  5 5 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F74BA14D-0A09-45A0-9A8E-8855B9037652', 'FD012C79-DC6B-4E92-8420-9C30362F3452', '4601969007312', ' 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE61D6D6-EFB4-49B8-905C-D671EA7B8282', 'BA8C5220-C7BD-4A4A-AEEB-9F79A8B80CF6', '4601969007329', '-  1% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4164FC90-D743-4438-B4F5-627E0F336C9F', '0EF9567B-FF8D-40AD-82D3-AA3DDD2F3877', '4601969007343', ' 1000/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDEAE59B-128B-4260-83DF-1D9531A87F80', 'B78A67F2-CDDF-479C-B2D1-F445642E6FE0', '4601969007367', ' 5  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63F518D6-D23A-470D-9B6F-C8EF80E37710', 'C23F2FF1-BDB1-4BBB-95CC-A323B7240A9C', '4601969007374', '  - 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85D9D310-FE1D-4BDA-8162-7A3CCCD93B85', 'E4045D6F-72D9-45A7-BEC8-1BBCCCC2D6ED', '4601969007404', '- 0,01  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8E93838-709D-4FCA-9B31-670B7512CE17', 'C850D548-6686-460C-8A93-71D49DED7A90', '4601969007411', '-   10  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('620FB6A3-786E-4557-858F-B69F6F24CB86', '079D82B7-CB2D-494B-8FDB-FC80E8D9BFF2', '4601969007428', '- 0,01  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B59B57E1-59D0-4342-BE3B-B7CF703152B3', '81EE232C-40B2-43BE-A748-DBBC7F335243', '4601969007435', ' - 0,025  //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AD176D2-49FD-4C7C-AF49-D5737A1D3093', '7852228D-F97B-4080-9564-974E0044508F', '4601969007442', ' - 0,05  //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE5E58F3-E795-4B8B-9A47-1E829D36A5D9', '66E6620D-C54B-4E7C-A65B-8898841E9FDC', '4601969007473', '- 6,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0FF5CF5-39B4-45AB-A03E-9B76939D5A95', 'CEA69828-2E1C-46B8-A4B9-8A402DD3960B', '4601969007527', '  5% +0,776%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3947B688-625E-4163-B745-2368F1AFCF32', 'F0B3F7FB-F063-4BB6-9838-A75AE04C0E9A', '4601969007534', ' 0,03%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('065481BE-5307-45D1-87C6-93ACF8B711C1', '61499132-56F0-4E2E-93DC-2D4C08E56755', '4601969007541', '  0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5461A8AA-41C7-4091-9425-CA21C3819E94', '246FC815-8579-41CD-8F78-FCB3BA70E6ED', '4601969007558', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCC0883E-02F9-4A0E-B617-FAD0877C80E5', '47FC787E-48C4-4416-A61A-DC5B98794C76', '4601969007565', ' 0,1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80677C41-B048-4AC5-ADE2-06C741F24DAD', '6218548E-5367-47B6-B01D-A46DE71F9FD7', '4601969007572', '    0,1% 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D9FB01B-C080-4653-99DB-A049BD1D518C', '2A9C2163-94BD-4647-AB78-481F9917C103', '4601969007602', '  // 0,1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45516FF7-380F-407E-AD73-893A0BE47174', 'DAF9DDC9-439B-4B87-8FC7-7EFAC42A2610', '4601969007619', ' 4  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('466353CD-E556-42D9-86CF-0F9186D73155', 'DB3DDAEA-50BD-40B2-8D81-B547DEFF707D', '4601969007626', ' 8  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87D59935-0C73-43D4-AEAB-74E31A09ED01', '1B7A9823-50A7-491D-8367-E3F801CC03EF', '4601969007664', '  0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC39319E-6C4E-4C93-939C-9126A07D4E52', '1FA4F4B8-3D70-4D79-BC1B-3B8AB1294B94', '4601969007671', '  0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAD8E7CA-A88E-47CA-94DE-082E4876D1ED', '7C2161FD-B127-4C77-AD3E-59B2DFBCC3DE', '4601969007763', '- 1000  1000/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('104B4B63-A7A8-4F35-A01D-38D9CF31DD3E', '57C1EFEA-9D91-4A46-9860-4FCF6BC88A5F', '4601969007800', ' 15%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86915413-E0FE-4D48-98E9-2791EE56DE09', '3F26F906-1AFF-4E67-B0C3-E79DD8E4237C', '4601969007817', '      2% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E811AC9-F300-46C9-B777-E8ACE8AF8726', 'FFC9E47A-0225-4C06-98C7-D4D062B5A237', '4601969007862', '- 2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E14E964-2CA6-4211-88A9-7F837A2AEC22', '4B0DE49E-CAA1-44EF-B050-E43D13CE86BF', '4601969007879', '- 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0F2BFD2-1C0C-4160-8EE3-875D087B935B', 'AE75AF0B-4021-4126-B5E3-889B517EA8B5', '4601969007886', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('558BA46D-EEFE-419F-A527-9A6D9B013112', 'D920C4DB-D583-46F7-A4C3-70941DB3379D', '4601969007985', '  //  /.  . +2,5%  2,5% 5 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17D1F134-0A13-448D-B868-83C0FFFE3D9A', 'AD2B5CF8-619B-408B-BC3C-BBE232E6CC6B', '4601969008029', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98DBC8C2-E581-457D-BBD4-54FB6EDB5F38', '027E3190-2342-4A4D-A7D3-4359133B5C13', '4601969008074', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AF90870-4CD4-4685-A0CC-81C8A06C1F6C', '206BBD12-6745-4FF0-A002-A025F7EBD230', '4601969008081', ' 4   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5585B1E-9CEA-4E8E-81D1-48FAE047502D', '73239187-10BC-4C4C-B7A8-4B16F8EDF36D', '4601969008098', ' 5   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('451D4335-EFB1-44E8-AC05-01FF3C2482E6', 'FB09A453-2805-449B-8623-D7D0A0546025', '4601969008111', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06E6B685-381E-457E-9DF4-B1B310540451', 'FE857C28-EF71-4D9C-B9EE-A222765DE70D', '4601969008128', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7694CF7B-CF15-4366-AAA0-FD29434FD74A', 'FA559073-C2D9-4261-8586-06642C957147', '4601969008227', ' 5%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7807086-ECE8-4B57-9B93-D0022E842963', 'F7A2F513-40C8-4DC8-B37A-77A07CAB106C', '4602009251900', '  /  2 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9DF8EE0-EB7C-4CAA-9176-04CEFAE1FB6A', '35EAA0A1-FBEB-4FA9-95EB-5ABC94B65415', '4602009256622', '    / 1218 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('677DB02A-9B83-445D-9164-C5822E5274AD', 'A1B739E7-B168-4045-B8C4-BAC512F6A484', '4602009256677', ' .  / 912 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FE0ABDD-D90F-4634-A594-F84CE92B2339', '414EA184-ED64-43C6-8558-0FACD28B4480', '4602009256684', '  1218 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBE03123-27EB-4C13-902F-43016A377E4A', 'C38C29F5-5B3D-4C0E-A1EC-DD079C10C2BD', '4602009283291', '   . . .  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5672757-A4AA-4E6A-B722-84883DFFF54E', '93524B0A-2649-416F-89E7-9A078AE05713', '4602009309403', '  /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D3211A6-E110-4A90-8913-1A1E67CF847B', 'C28F0A80-A746-49DE-BD4A-011D242895CB', '4602009336287', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB0FF613-B39F-422E-A275-6DA909CB9953', 'ED013FC5-83E8-4413-9E52-F4E89EC7FA7E', '4602009351464', ' - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91E745C2-0EE5-4D27-A0C3-BD439F444BFF', '8E510F3B-A31C-4376-B237-6DA89645802C', '4602009353529', ' -  bifidobacterium  40+50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84A5CA43-560F-4C7B-8428-44D4CAD8AAD3', '8D125576-44E9-4F95-8790-B3831C4841C7', '4602009354410', '   1116  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BAE3580-B39C-4679-ADEF-9768B571C017', 'FAD6A46A-5B3E-4659-B819-D3373A93A193', '4602009418884', '  /     2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F2AD64D-3BC9-49B7-B5C9-B3E628504C64', 'CA7A9AF2-477E-4B69-BE3E-8FEF08EF67DB', '4602072001099', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('826ACC81-0BB2-4B93-BFEB-D7942BE98396', '81B46BA3-7A26-4C82-9C53-9C10727C042E', '4602072003093', '  0,01 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F59FE6F2-B3AA-4265-B894-9B30498DF6D0', 'C1934E67-1772-4858-8C75-D1AA1F33B5ED', '4602072021417', '  10  /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B648D01E-DFB4-45DD-9D58-B34AD48111D6', '79C69AE0-0339-4925-BF36-FA6B6BCD182D', '4602072021547', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EA702D2-4AB5-4B23-9B17-2972EB5340DB', '6318E289-3CC3-4B9A-8CD3-8716DE7DE45D', '4602072021554', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA35F775-7878-4D6C-BBA4-D5E5D7006A1B', '8CAC4B04-2C1C-46C3-ADCF-B61C28C19B1A', '4602072021578', '  10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05571EA5-F1CF-4E31-8047-A88286DBC582', '2E8B20E1-65F7-439A-900B-EE5C98A9A238', '4602072021745', ' 64  /- //  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0824F441-785A-4946-A97F-A77CB0C5E13D', '01B6167B-142E-4988-A42B-4F84B7F52EDF', '4602079001207', '    4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE7D2804-6574-4B7D-B26A-87E2537F8EB3', '8D77ECDA-7DB7-4B9F-BF3E-40FFD9A73539', '4602079001627', '  -  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C80B1F0A-8256-4429-B3BD-A73150494AFB', '6C09BB0F-81C8-45C4-9C87-B87F88AAB609', '4602079001634', '  -   4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35ECCFAE-3771-4892-B069-CF7397C2E378', '5AF3F9F2-6FB4-4376-9C20-8C7262055E75', '4602079001689', '  -  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('809F0529-FD9B-4C00-9B6E-63B311026DCB', '9048A81E-F951-4041-8C8D-8EEDFE3BBEF2', '4602103001722', '  100 3 - / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7531379F-5405-44C9-8F41-4983BB607C99', 'D237D22F-C050-4355-9605-BB48CA362FC1', '4602103002583', ' 20   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4A2419A-CB2F-4456-A3BE-9594FC2F8483', '6CC6A050-9BC5-4DB8-B78F-00AA8761FF52', '4602103002590', ' 20  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5D22066-2E90-4A0F-8FB6-FCCBBFDC52D7', 'CF0C56E6-11CC-42D3-BC3B-CBBF5C32F0A3', '4602103002606', ' 20  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EB265FB-E92A-49E1-A974-3049B9C1E0FB', 'B1063EE9-2952-4992-AC73-B77ECA4F7C78', '4602121007867', ' /  .      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('759967C4-5AE4-4EF4-93DE-8C0FFF221324', '66A9EF80-9F9B-45BF-96E6-BA17A9CF9C04', '4602121007881', '  /       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E394E2DB-18C9-4599-9D97-AB3F097A1AF9', '6F59B214-5470-45EE-9112-084515DB931A', '4602122000072', ' -01', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('920308F4-BEE8-4B57-8174-2A24E9743628', 'C6BDA797-17CD-400E-8D4A-226A4E5C8AFE', '4602122000331', '   -    -01-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1958A2E-919C-41F5-9C46-F94908CE8405', '2B1DD1F1-F601-4C2F-BADC-12513170D08A', '4602122000737', '  / /-100-02-//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E501D92F-F583-4C3A-B4C0-3805B704CF74', '29F6D1B5-E50A-4B47-A510-A04DAFBCB741', '4602122000966', ' /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93C710EF-DEF2-4C62-98D6-DF0D6BAA5685', '4A6CEE6F-9D6F-4026-B93B-E0A8E174C0BD', '4602122003219', ' /  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB130EE2-48B9-444E-81A9-353F79C69832', 'A54F153D-D731-4DE0-9764-94FB5343A75C', '4602156000048', ' 40/ 2  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FA49475-98DC-42E6-A3C5-0A12C2B93BBE', 'C49E004A-D1EA-4A75-90D3-424979B92D1E', '4602156000062', ' 0,2  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21463484-83DC-4817-BDB5-246D484B8F3F', '7A2F345A-0BE0-4D24-96DA-B1C71B9704F0', '4602156000086', ' 150+30,39  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C6085D6-5514-431C-BCDE-A0813CB2CD82', 'F0974B5A-87B9-4813-BF04-B14E1D9A7A67', '4602156000147', ' 150+15,2  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7F958C8-7623-421D-AD74-FC1C1385446A', 'A13EB2ED-5D52-4ADA-95A4-AE0BDA9245F5', '4602156000161', ' 3 500   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ADE5C9D-5949-4E9E-888F-4ECC346660FE', 'BAE43E0C-A99A-41D1-84FD-A9FC6135B813', '4602156000185', ' 3 500    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('559E7DDB-9226-4E8A-96E2-16B758AE4127', '287B80E0-C26C-4F6D-989B-605A97615E7A', '4602156000208', ' 3 500  /./   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF0D8D1D-10FD-47D8-BA10-E80630F27D98', 'AB51CD8B-9B89-44AA-940F-C2C1213645DA', '4602156000222', ' 3 500 //   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3ED49BC-DF23-419B-8229-307FA515E9AF', '83ECE5E7-577E-4A11-9813-28E65B403EA1', '4602156000246', ' 3 500 //   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E695099-CB1E-4265-8F7A-A6682FE62DA8', 'EA7200A9-8555-4E29-B15E-A963AA625E7F', '4602156000260', ' 3  500 //   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('748EBEC5-2D42-4DF6-8274-6A7E5008F7C9', '98D6BDAD-0705-49C0-8F3E-7A1193F0C702', '4602156000284', ' 3  //  500 +400 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEE1DFE0-62A1-4288-A517-5BE248EC07AB', '183B0EE6-5E1A-42BE-B628-0C7164678965', '4602156000307', ' 3   500 //   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('916C5461-3400-4113-8B2E-F797BD5B22F1', 'BAC3DDBA-6ABF-4D7B-9B18-2F382D33027E', '4602156000321', ' 40 10  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('092A9111-31EA-48E1-9C30-F8AE3A4B9DDE', '217DD280-AD23-441A-AA64-0632F0A62850', '4602156000406', ' 3 //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F01D8711-6D2A-4A68-9BCF-1ADF21A07BB8', '71E2D10A-7D0A-4793-9328-8FC9B4509FAB', '4602156000413', ' 3 500 //   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E23DA186-70E3-46B4-B490-AFE95416AC1F', 'B38E6131-DA21-4473-9CAC-5F65B2AD777D', '4602156000437', ' 3 500 //   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09D40BC7-A3AC-469D-B2A2-8AF2726EC49F', '1ECA6693-5A7D-4777-B612-79173BF8FAC0', '4602156000444', ' 3 500    120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79023820-379B-49C5-8425-71CC7F3FA534', '22C2FF21-1A66-44D1-AC8D-6D4E853D55DC', '4602159012703', ' /    4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('625968C1-798A-450C-B68B-EA0015E509D5', '6724DC84-7EB8-4C19-A206-8262A6F28F7F', '4602159012710', ' /   /  care/ 4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('909A8925-A295-485A-9669-66F9E220DA60', 'CD9FB0E0-C309-4C65-A2CF-075D8C584CA4', '4602159012727', ' /   /  care/ 4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('734643FA-4B83-4BB7-9095-55D82BE732D5', 'C6E62DEC-F913-4695-8AB8-733D639FD0C0', '4602186000018', ' 0,005% 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4347C4E0-CEF6-4ED6-A43C-8382971963CC', '6F6D1F9F-F5D9-4818-9CAD-18D3F6DE9B16', '4602186000100', ' 50/ 40  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43E39AD9-4895-45FF-BC14-FACB778E1356', '494F68F0-E3F5-4CB6-A47B-0B82B40B14E5', '4602193002845', ' 250  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('393249FE-66E1-4745-AFCA-E9A38384D495', 'D5331362-F5C2-4243-80E0-9AEBE1D867FF', '4602193002920', ' 2,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80CE4787-956B-45E8-99BB-0A5D2D0F9499', '7BCAC7EB-293B-4F02-95DB-051F853F7041', '4602193005358', '- 0,57  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB4103EF-4B68-4681-8977-8A93A238F647', '9446EDAC-C9FD-4364-B854-02EB50AE1E39', '4602193005921', ' 25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05E3963F-2CEB-40E6-9F70-2C826C9BDA62', 'B982188F-5D5E-4846-A71D-43D50182CCA0', '4602193005976', ' 100  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC4D6218-F9D6-42FD-8196-7547D08DD027', '67B5B2FF-7776-45AE-8782-67159E486FA0', '4602193006485', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12FB202F-084D-4A3A-85D5-168800B0BC05', '98E77C4B-844D-4A99-8AB8-90383A45A4B3', '4602193006492', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('843A2B21-FECD-415A-AB4F-690F7C1F9773', 'B76CB83B-C161-4342-98CE-F48A3D71F92D', '4602193006768', ' 0,1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C9A2A91-FD60-488F-AB46-FD1BD4EF91F2', 'A7AF4CA4-2672-49CF-BA2B-FB448434B362', '4602193006966', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('318990C4-FF75-4365-A6B3-9587CAC05FCB', '029DEABC-2FAB-4491-96A4-B8B1F75D2D9F', '4602193007031', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('170A1E93-26C3-4543-85BF-B611BE293CC1', '871E30D5-5FD2-4DB8-A44D-67F4E035F69F', '4602193007598', ' 100  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C72C48E-27A8-42F0-9193-7955D6993F43', '0E30D2C5-7EB8-4ED9-AF18-3AE074718786', '4602193007840', '  500  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77FFB4C0-739C-463E-B141-0D33998B314C', '518FCFCD-E83A-4F17-A143-3824E50B4CA5', '4602193007864', ' 250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36A787DC-360A-4E61-847D-1BAB9D0306D2', '37E8AE56-C9CE-458B-9740-55BCC3EDD8B8', '4602193008830', ' 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA280B0E-752D-47B9-BB10-4ADEFE5E1CCD', 'D28200AC-8DA7-4EBA-AEA6-843D839904D8', '4602193010109', '9    0,4 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77D7010C-30D6-4155-B0FF-EEC16EC358C4', 'AD0B13C1-296D-460D-BB26-815A553C8030', '4602193010505', ' 0,005 //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77CD7975-E93D-48A3-8E4F-BD093E3E7002', '7B05DD2E-4F50-4847-A471-BF4C61D37C02', '4602193010833', ' 100  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B8B3045-1D33-4F5E-816B-9915A307BD74', 'BA6C6AB3-FE8A-4996-83B4-160417DEF148', '4602193010857', ' 0,1  /  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2754DDF0-C6B6-41EB-8833-3BFC94BE6FDD', '3BE37A01-281F-429B-9485-D6CAF17060DA', '4602193011144', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1159F771-DC91-448E-BA92-75B8A0194F33', 'E5BB6F28-C655-427C-B7A6-68B815F37302', '4602193011243', ' 100   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2B51C0A-2C30-4474-9A94-3A217FA89EF6', 'EEF7BD5B-4627-49EE-92D6-5E21218A1A01', '4602193011250', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0A98C18-E1F9-4A35-81FE-01DCFFEDC67D', 'E0BBA473-E65A-43C0-9D50-41A0D8555F9C', '4602193011656', ' 5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('592E4FF1-C0B4-4E78-92F9-6ADF7E8FAB83', '47F0A3A1-7312-4462-A250-B5262C9FB1DC', '4602193011717', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0CF561C-72D2-47B5-9288-F6275451DC09', 'EFEFA916-7C4A-479D-B471-DA5E3D270C3E', '4602193011748', ' 0,06   7  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73D02738-C4E0-49E1-928A-3F9AD8F10C2F', '2A8E6CC2-D994-4DBA-93BB-A3AF659A6D8B', '4602193011830', '  50  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('239EF7BC-3CF8-474B-9965-75AE5F881F4E', 'D3A78C4F-A2CA-4089-B816-4C5E6235B49B', '4602193011847', ' 0,1  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('053CF44D-EFD3-4CEF-83C2-DA832ED5E787', '7A2DA99F-AC41-4F91-B927-5B3EEF6CFA34', '4602193011885', '  1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6801A69E-1569-4823-9A90-64FAF4EBFD9B', '19E910C2-AECE-41DB-9AF7-77B322A086AA', '4602193011953', '     12  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('425DB571-CA99-4B00-A273-D8BBEC29F33C', 'F101974F-B791-4FC0-A780-BA1066F49854', '4602193012028', '       12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AAE062E-CD29-441E-B5FB-43F2EA4576C2', '0500C527-E84E-4A48-BCA5-1439A0CB5E9C', '4602193012196', ' 25  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E5246F3-60EB-4B68-A7AD-F52C0D618B51', 'B33227CA-BFD3-4F39-B71C-8D5C3DC3EF53', '4602193012295', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFC6FA07-9641-4922-8561-152DC45BDFEB', 'DB0BBB85-D8A2-4B31-B9BF-2B2163576991', '4602193012462', ' 0,06+0,1  112   /..', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B6FA9C8-59E2-48AD-AE0C-69A6FEFFB876', 'C14EAEC7-BC02-4C0B-B3C8-6E5617C42305', '4602193012479', '  300   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F9F4F54-AEE2-4BFC-AB12-5A1A0E6DC15C', '7A1B503D-D640-45FA-AB1F-36F5F69DA372', '4602193012493', ' 0,03+0,1 112   /  / 6 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7BF61D4-3AE8-4F40-8BBF-E581ADCB34E8', 'DB1F4BC9-0CB7-4ECF-94BB-71B89993BC9D', '4602196000350', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B6119FD-AA10-44BD-B20D-5627BB223D4E', '25F7760E-8E2F-4670-A361-1C8702E317BF', '4602196000565', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E49743F-F626-4FF0-8305-CC4124EB5398', '81639B89-8F0D-487D-9E17-02C2464F6AB6', '4602196002125', '   /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE4089FB-4CA1-426C-BA4B-7327BB4532A2', '788006EE-EF03-42B0-88F9-21947550DC0A', '4602196002439', '   / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B25288C1-65C0-4873-B1BB-EE954697B3BE', '03F20BFF-46FD-4345-9F50-2D6B6C42366F', '4602196002453', '  /. . 0,2% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('210BC766-98A9-419D-BA6F-7610C404735D', '635B598A-7E74-40B9-85A6-964DB7F94AE6', '4602196002460', '  0,2% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('362906D8-2F62-4762-99E3-149F7944F28A', 'E2ECE793-45E3-44B7-8A36-13EDCEE8C3A0', '4602196002484', ' 1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DF435A2-54AE-40CA-963A-210A1AC5105D', 'D06A2EE1-D551-4F32-B59C-CF7F007C4A72', '4602196002507', ' 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4CCE590-853A-46DD-81B5-38B433380B76', '3614DFAA-2D95-47E4-BEA1-2827341F7C34', '4602196002514', ' 0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04D31A32-A782-4AD6-9BF4-0D0CEF218567', 'EB235F24-9F09-4AE4-827B-0FDAAA3F3F16', '4602196002521', ' 0,85  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AFE2541-2A1F-491A-B74E-480D39682B08', '21A976C7-7924-40FF-A08C-069ACFF2089E', '4602196002538', ' 0,85  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74E32832-B79A-4A4E-958E-D3F4245EA9C2', '14EC4226-0F7B-4F1B-946E-68523734589C', '4602196002576', ' 1000  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F09EBCE1-EB68-440D-8BA3-441D1A987144', 'F8D67142-7611-4E21-9F89-20C4373426B8', '4602196002583', ' 125  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48E71D7C-1E00-48C9-84CE-3190A41E4CFD', '717ED0D9-4D6A-4394-899D-4EC00ED8BB8D', '4602196002606', ' 2,5 400  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A63FB78A-6AF3-44E0-98E9-55FE3270A70F', '545D0D2F-241B-4D5F-B10C-543D5E68E80A', '4602196002613', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('043C4920-0446-4DAE-84FA-9EA5DD025805', 'C77A4272-2686-403D-B66F-2581C5DD85D2', '4602196002682', ' 60  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAD7088E-515C-4C7E-9044-65BCBF04522B', '3915D57D-2C64-4D38-A30D-3F67D84729DD', '4602196002699', ' 125  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D6AC962-E0AD-48E6-BFD8-73FADDB40552', '9EE49160-6556-466B-9DBB-5F8AB499CB5C', '4602196002705', ' 400+200  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFB67679-2992-4811-B7C0-3FF0007A6734', '8E8D9B6A-11A5-4393-AC7E-3970A226716D', '4602196002736', ' 400+200  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E347936F-B2AA-4768-BB6F-C996B8A0A34B', '70426C7E-341F-457D-BC39-FB3540735EA0', '4602196002767', ' 600 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1AF75EB-B36F-4504-9F16-D7465FB9E2E1', 'F962F0F2-06B8-4FFB-8A44-C1E93585AEB4', '4602196002781', ' 10 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF4DCF8E-5668-43D5-92DE-BED1172E3830', '367931D6-43B8-48DA-A56A-30E5AC787666', '4602196002798', ' 20 //.  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCDA3230-AA5E-4017-AA83-DB1AFB97F576', '83D7D223-6998-4B26-8341-F488419CBA9F', '4602196002842', ' 0,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0572B4D-B100-418B-A1CA-882ECCDC66A3', 'ECFBE344-67EA-497E-872C-F059631D9E8C', '4602196002903', '  20  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5E3C54B-8D3F-4B25-8B58-18A4BDAD3C56', 'A3DAA986-85A0-456A-AF62-8B7C81D7E0E9', '4602196002910', ' b6  100+10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('226A9A49-961C-494A-BA44-2AE992126518', '13A69045-1167-4241-99A6-B0D2CD1C9438', '4602196002927', ' b6   / 100 +10 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3375FF5F-3E6A-46AD-9389-E0F6AEA2CBB0', '90B0AA12-F64E-4AFE-867F-20164FB44B01', '4602196003672', ' 500  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DF80F48-ABBC-4D88-A444-40A2A4959C3C', '65273C3E-FE3E-4D86-88E0-06F80FAAE28A', '4602196003894', '   1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60C431B9-1B7B-406D-9765-36CCFADAEF50', 'FD462CD6-0BBE-4843-9E14-DDA4DA7AC30A', '4602196003962', ' 500  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDBD36CF-491D-4BD6-B29D-92B6FA789986', '3BA0EA70-B7CE-4EEB-9095-2CC5D867FBBB', '4602196003979', ' 0,5   /   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDCBB2B9-ECC5-46F2-9715-C116F1DFF0D7', 'A3DAA986-85A0-456A-AF62-8B7C81D7E0E9', '4602196004051', ' b6  100+10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35AC289F-ED35-4DE1-8C29-66220B1D1334', 'CE3EABD9-C074-426D-BFA9-CC6CB84E10BD', '4602196004068', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5723D866-31E6-43C1-9082-8910BEE22FB2', 'C937B741-0151-42DF-B533-8F1A2FFCE992', '4602196004266', ' b6  100+10  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('858DDEA6-1C6E-4066-880A-F321609C144C', 'FA098192-95C6-4DC0-B2F8-81E1FA572FFB', '4602196004341', '  / 250 10 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8852330-5F34-419A-AB6C-A38072F57CCA', 'B0D08BA3-273B-44E7-A295-E4463C9B6A45', '4602206000035', '    100/ 3 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23656EFD-9912-45E2-B2BB-0F228A3395BE', '4EE517A0-8D9F-44D5-90C6-33FA0AC38CAE', '4602206001179', ' / . 6 - 3 - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F84746EF-5EB2-44C1-89B4-8785B1EED246', '9A5A63D8-4682-4991-869D-8134B3BA1D4B', '4602206001247', ' /- 30g /0,38/ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('612B9A7C-10D4-4503-ADFB-2029A155721F', '05F08C97-F4B2-488A-804A-34C120359F64', '4602206001285', '  31g 0,256 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6745CEF4-D747-4EC3-8F92-BCCF9A4CCAF8', '2A7B2982-CB02-4957-861A-A9B3507B0051', '4602206001513', '  100 - 3 - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6B9CF33-A3E2-44E8-BAFE-6F63BF480235', '613088CB-A550-4748-A4E9-DF35F5D53D44', '4602206001551', '  100 // . 3 .+- / - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0302F0DB-0C94-402E-8119-19057294A819', '4A00A788-B6D4-421A-BE86-787642E57615', '4602210000113', '    0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A248CAC-9DBA-4EDE-AA57-567FB186C158', 'F6AA2E82-FDF4-448D-AF67-44C09C6D6359', '4602210000120', '   0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D481D526-6837-496B-8459-8A24B4A27097', 'B71E14BB-ACB3-44AA-8DCC-0F7429F9C46B', '4602210000137', '    0,1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1035CFB-DCEB-4BBF-9E00-8F3361FBA867', 'F7862A19-E3FD-4269-B757-54042749E43B', '4602210000144', '    0,1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E3139DE-77DB-44B9-A86A-9D5881B234A5', 'C91419C6-E28D-46C5-92E7-D648F783967F', '4602210000175', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1D41C48-57C7-4F0D-883D-6DE29E8FAF03', 'F99F9837-A6B8-4430-B91C-459FA8AA2440', '4602210000199', ' 0,1% 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9216E87A-4434-4C9E-8D2D-CF23DC9DFA67', 'E39AD6DA-93B0-49D1-99C2-9A794BC3606E', '4602210000311', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE15A01E-EB70-4F97-B9F7-9B02EE72F67F', '3DB85CAF-2F51-40C8-A9A7-13F53EB4942B', '4602210000663', '   0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAA39BF0-F629-41D1-BCB0-D4C2FD3D3B34', 'F6512FED-C805-47E1-A97D-202C9D2EAFE6', '4602210000670', '  0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3A0CC3C-6DAA-4406-89F6-182389DF8A59', '7193E8F0-45C2-4DCE-AEBB-C5ACACBEB03A', '4602210000687', '    0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E9F2BD7-FCB8-437B-9CF7-A336429A3E4C', '5FFE2A59-D8AA-41B4-80F4-4D5F130CCD66', '4602210000809', '     0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC1688A8-480C-42E0-B837-873D95DD0391', '6945E209-B0C6-4541-A2EB-4FD6278589DD', '4602210000915', '  1/ 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07F844D1-38A8-4050-A5A0-2E3BA476466E', 'BF826B42-74F1-4355-9561-210C7A1AB1B3', '4602210000977', ' 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2152398F-49B2-4405-914D-CE19F3D80D5C', '85741E66-7C6C-49FA-80F5-69D7434FFAAA', '4602210001141', ' 10  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('864ADA55-4C7A-4E34-BBCB-A8D79FDCE17F', '8955D315-8C75-4BB2-BDC0-DA3434C13630', '4602210001158', ' 0,01  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD07C0CE-9E2C-41E8-AC22-522BE5C46E2A', '7ED1876E-6A1C-4FA3-992A-A1D33E69A36F', '4602210001165', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C538C8C-1806-4A4B-829B-4B7AA0525D64', '9413A9E2-5EC6-44C6-882A-D3D32ABFECCB', '4602210001264', ' 0,5/  60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE6E87B9-DF17-4C8B-8CC5-E8DC09B02674', '42055EC5-8A75-4EC5-AF23-4B2449A7B5F3', '4602210001325', ' 5 .  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4F9FFD1-C08C-4249-9987-8F72BACF93AC', 'BF826B42-74F1-4355-9561-210C7A1AB1B3', '4602210001332', ' 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14011CEF-5312-41F8-9259-605D61577939', '32FF7465-66D7-4E36-8DF0-D3C879696375', '4602210001349', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DBB8FD5-12CC-4B2E-98C0-269BBF58B9FB', '0228D214-F8EE-4109-B4CF-28C144408D8A', '4602210002094', '    / 75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A301C74-C77C-46D4-A588-D71DB818E2B3', 'DB76FB87-5CA5-4BB5-99B8-C95D51ADFEE6', '4602210002100', '      75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27EF3E81-ABF1-43AB-852F-580ABF9A8FA1', '278BE805-6080-4BF8-9FD9-05897CCC1972', '4602210002414', '   0,05% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01E56281-5F6B-4275-A23A-0671FF01F0C8', '6288895E-1336-4CE6-BE24-563B5DDA3E25', '4602210002421', ' 0,05% 15   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E15FB786-0A76-49C9-9994-0A522D89355B', 'C8ADFB72-032C-4898-8999-DF57AF664D49', '4602210002438', '   05% 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('246CDDFF-DEBA-4A42-B445-E839568E7EA7', 'A9FA5FE6-0C31-4EFD-922B-3E59A7EFE74A', '4602210002506', ' pH-  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45067D8E-6A78-4E04-91EB-1C1BBBE876E8', '9B6F4F46-D63B-4196-B51E-4E7EF1EAC454', '4602210002544', '     20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE7FB403-6DC0-4E6D-924C-5C96F5143842', '07391399-BC55-49F1-82DA-46688276C180', '4602210002599', ' 0,005+0,05  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC76468C-1E91-420F-9FE5-059E7F1C1B3F', 'C1ACC51F-E03F-493C-90EA-F1113421F5A6', '4602210002612', ' 5 +100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C62FFE36-452E-4A7D-B417-E4CB07407E52', '37B7A88E-0662-4708-8924-0FEC4C5F6863', '4602210002643', '  0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66B78A1D-DFD9-476D-BBED-526A17EFCA3D', '736E92EE-93A7-4304-B5A1-522E86BBEBFF', '4602210002650', '  0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6959467B-4AEF-4382-BE04-04BCCF017B80', 'FE83339F-A01B-425D-A521-0FB1CD17D373', '4602210002704', ' 36/ 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8921EE04-367C-41DE-9E2D-9A04FACC091D', '63F8327F-7D6C-49ED-B899-AA51E1625916', '4602210002711', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28A948C2-43B2-4BAF-9F89-9DA35D0BB30D', '904DB5B7-AFEB-4387-9820-C6B5346343BD', '4602210002780', ' 60  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('320DEB45-7DCF-4BAC-A457-FD150FFF5376', 'BCFE6A44-12A5-4FB1-B461-86B67883937E', '4602210002797', ' 60  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C200FE5-E96B-4E00-BFD5-87E1CB957BAE', 'FF0752F4-BC16-4F6D-91C0-8C99B552B881', '4602210002919', ' 200+5/ 120 /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('454825BC-19FC-481A-BFAD-43F0EBE266AF', 'FA6FD273-5300-44AE-B267-3ECA67ADAE77', '4602210002957', '  . - 1  0,1% 30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D178CC74-EF48-4387-8D82-488F2A4B5DCE', 'D410F076-8989-424D-8B97-A67460B2B9E5', '4602210002995', ' 2,5+1,5  / 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A506867D-9C43-431A-9530-416B78FA48EA', '81F134A8-B25D-416F-B2C8-09A0ED99EAFA', '4602212000043', '  30% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33EEF063-8F31-41AB-AD25-A73B9710372A', 'FA15C994-21A1-4F25-8940-BEF9A39F2B9D', '4602212000470', ' 2% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('351A692A-5596-485F-B9D2-EB3B559DF501', '8B75C400-B246-46C1-B0F5-52BEBB3F85DA', '4602212000692', '  0,01 / 1 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB652B15-1823-41BF-B892-45CEF85786F3', 'FDB4C8C4-C0B1-4A62-8476-3BE326FD7D3B', '4602212001101', ' 2,5% 25/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1A58F6D-579F-4A3B-96F4-B32BDB58B35F', '17F7DB43-99B1-47C8-B7A8-F580F04A19D7', '4602212001163', ' 0,05% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E975D99-7EE6-493A-AC08-01D3CFA3C1C9', 'F9649F8F-E801-4478-9D1E-5425A3133F04', '4602212001972', ' / 2% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE0D3809-3D2D-4600-A67C-03D9B6C83CC2', '51C88FB7-F3E9-4208-B63E-6BE713AD6BDB', '4602212005390', '  610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7039795C-A469-49B1-B9BF-F593A33F192D', 'E320E588-0635-4C48-B465-47E2767B47AC', '4602212005413', '   1018 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63F13B89-EC58-4D80-AD8C-4AF33942F3B2', '5EF97AD1-48CB-47B1-95C1-3794E245F897', '4602212005697', ' 0,1% 1/1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('827870AF-9C32-4163-BF23-EA288FAB53DF', '6B6FFB8B-A8CF-469F-846C-2F5A58611A4E', '4602212005833', ' 2500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D2D2106-B644-4DE9-9106-353D5FFC45D9', '6E13DBEB-894B-48EC-B9D6-EB8312F477CA', '4602212005840', ' 3500*', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCE4129B-8FA0-4C7B-BD84-FD05B64502DB', 'C61C6F94-F4AF-468F-84C1-B4C9443BE495', '4602212005857', '   4500   - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02E6FE8B-65B9-4088-9B4D-6FCA98AE2128', '560D0AD5-D8C4-4680-97F6-1CB3E7699342', '4602212005864', '  5500   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CBF9BBD-E2EE-48B5-8128-55A41B88104F', 'B56579A0-1868-4313-9D03-AC53AF6BAF00', '4602212006007', ' 1% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9081B21-6183-4A66-99CE-82FEEDA7AAD0', 'AF8070BE-F6B0-4D5B-83CC-6F78ED272241', '4602212006229', '   210  . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF88DDAF-A48F-4940-9136-A95C33FC9984', '19C4B9D6-4813-4355-ACE4-0EB9E11C659F', '4602212006625', '  //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03463028-4BAB-4D9C-AEC5-C39376A89D54', 'B1209ED8-43BA-4717-A3E7-5C04584F7041', '4602212006632', '   //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEC9DC2A-4C18-4011-B507-251955708B38', '8BC7A42A-312F-4B14-A92A-C2A0C23EAA85', '4602212006823', '   .    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FA618D4-1CF5-4E10-A616-BE9FAD8305A6', 'B1EE6233-8214-42E7-ACE8-954239D7EC72', '4602212007431', '  610   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AB80D35-9F1E-4874-A3C3-8AD60CA83ECD', 'BFC82E45-6B9B-4E9A-843A-AA6F45FFB226', '4602212007677', ' 2,37,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26621050-9A8C-4D69-8593-C285EEC3D0D4', '56AF1FA0-358E-477C-8E49-ECE479C7685B', '4602212008094', '   //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('125B669B-18FF-45DA-9033-BADE8F7E8975', 'FC342286-453E-4E4D-A088-FDFF404648CD', '4602212008391', ' 2% 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CAF4C33-DE67-48E6-9C2F-5D6940B01F79', '638E3986-5629-4D5E-9F6F-A12008A15CF5', '4602212008841', ' 1% 5  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D595B0CF-E892-443F-85C0-7C9176A86CE6', '4363C6AE-2FE8-4F94-897F-3F379C106E9C', '4602212008858', ' 1% 10  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6BA44FD-4BA6-46FD-9E74-DCDEF38D2C8D', '917C1E6A-FA7E-4EBD-9AC1-E6B88B594D2E', '4602212009596', '  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B79CA368-2260-422E-A7B6-0A2CE6FBE298', '7E2288F8-076D-4138-A7BB-CD9400091A5D', '4602212009756', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3F75838-2BA8-41FF-8CE0-09FA7E55CE54', 'FD184F1D-4D95-4F14-9CE9-5B90AC7ADA0A', '4602212009930', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75270B5C-F956-439A-805E-F0C65EDC82BC', 'EC54ECBA-80DA-4B78-8FAA-6C54D6092FBA', '4602218000368', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07B71E88-FFA0-484A-8C49-FD960D7C7617', '25775C2E-5D87-4C8B-B1FC-34839595953C', '4602228000075', ' / evisonic 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B51795A7-BA94-40C5-8481-5EB710FC4BB1', 'CE9E78BD-074B-4A9E-B646-31446D20895E', '4602228000310', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDDB7AEE-88DB-429F-9163-2152DED99841', 'C07312E9-4F21-4EF8-A927-8ACE4361E152', '4602228000334', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA331F27-5A25-4064-947B-F8964CC4443A', '76FBF154-717B-4D33-8D84-EFF3DD476C54', '4602228000419', '     3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75B41049-B987-40B8-BCC1-D9A01A363EB4', 'CF100BD7-5BB3-45E7-A48A-6F7F56377C1C', '4602228000679', '   -3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('180E4654-D91B-43F8-AF6F-A8F129ADB910', '8C70269D-58BA-4891-B211-03B328F363A4', '4602228000730', '   20  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFA57D94-BB3B-46F7-AEE9-5AD9DB7C9AEF', 'D20D6949-9B52-4F8D-8604-43C23224B6D9', '4602228001805', '- Dure /lubr/ play-mssg 2in1   200ml', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04B2C97F-D321-4B82-8CC0-2776B05D93E2', '16144D24-A10B-4D89-8F36-42DA86757D86', '4602228001829', '- dure play massage 21sensual 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1C7ACE3-8B9C-4399-BB92-E12FAE84D599', '88C1A7FA-D589-4F9C-B2EC-FD36591469F5', '4602228001843', '- dure play massage 21 stimulat 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('785510CA-BCB1-4228-91CA-FCFE943637BE', '2CAE3441-7BDB-4682-9BE4-C3F1FA664139', '4602228001973', ' silkofi      7*5  /5 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CABE3FC-146F-4EE3-BF67-36B6462DCC95', 'EF85EF8C-F9EF-4C69-9C2B-9D006A9D7A98', '4602228002406', '- Dure /lubr/ play-sweet   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DA30C60-5ADD-4901-BCEA-B40A36F276FD', '694BDCE1-A6AE-44D4-8B2E-3C417D13E0C7', '4602228004219', '    .       1972 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55DA1600-7D8D-4303-8A9A-0A379E7EC0CD', '45676202-8356-4C4A-BA6F-D08018007E1D', '4602228004233', '   .  . . . .  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('324BFB69-C43B-48AC-BAD5-EF15D821A3D3', '1435546F-22DD-4BE6-A80E-827C552E4022', '4602228004332', '   .  . .  .  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD5A3737-714D-4DFF-9B1E-6AD9FD87C959', '90A52959-D994-492B-AFA4-AAF0D6FDA78A', '4602233001203', '   5  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('574DA5B5-6CF0-4F34-8ADF-8448228F4DC3', 'DDA1AA66-3103-43F4-9DF9-8539B0B813C9', '4602233001739', ' 500   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('589DCE4F-E96E-4E5E-BFEC-544685A8DEDB', 'DDA1AA66-3103-43F4-9DF9-8539B0B813C9', '4602233002088', ' 500   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40AB7340-6749-4749-9E93-743658B92FEF', '3A36766E-B64B-4794-80C8-6674F2EB74A2', '4602233002101', '  / - // 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A12240C-969B-4148-985C-96A4F60004F0', 'B4F52DE8-AB68-4C15-BCFC-30035E7ECA0F', '4602233002170', ' 200+28,5/5 7,7  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF74989C-86A3-4C70-BC69-491AAD34AA87', '0FE1FC2D-640D-4F2F-92C3-F6FA2EE9BA74', '4602233002187', ' 400+57 5 / ./.. / 3/  12,6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('287D4C36-077A-4EDE-8227-AAF2289BC7C6', '688E2D1C-E1D9-4215-8150-0E369C8B1BD1', '4602233002224', '    5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66106A69-2AB7-4955-87A3-EF891F84BDDA', 'AF4C9118-5F91-4F54-9216-16ED07D17A82', '4602233002231', '    6 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B323C8D1-7B3E-4585-BC58-E22A72C8575E', '6C53D6ED-90F2-41AB-8CCE-8411BF2B20C9', '4602233002545', ' 500  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D42C308E-FB01-42D0-BD9C-51B13D8FA11A', 'A20D9B79-F0DF-4739-AB65-392ED2F5C90F', '4602233002552', '   5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B826842F-8181-4435-8BCD-C9929566EFE3', '8AC9EEFC-8515-480A-AB1C-E1CB3A8A9773', '4602233002637', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('230177D5-B5D8-449E-9664-916D5CBC0618', 'DE4659A6-630B-481E-98D1-DA75971B25CE', '4602233002644', '  125   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF5ED171-D8B4-4881-9D79-77B8CCB9BE35', '9F6BF9BE-CF44-4E29-81E0-636FF882BA28', '4602233003399', '      6+ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99577EDC-3A67-4503-8A61-E456DB9718E2', '1538D40C-CF44-42AA-968B-450C44EBF1C8', '4602233003405', ' 250 / 3- /    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('732E779D-BF10-4366-8122-07AAFA92F385', 'C8BF9128-BAA4-4A1B-BEDB-8A4AAFBFDF81', '4602233003603', '  /  300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9450AAEC-D435-460B-81EB-F94B4F60C6D8', '8FB241DD-75EF-44DC-A2F6-6DF768227D5B', '4602233004136', '    300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82E997C3-3034-453F-9C3F-926A40085DA5', '5EF0A4AD-3D1B-4FCC-A414-6F73FAD310BE', '4602233004723', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC3FCA03-3917-4756-A4AB-19C8000CB033', '3EDE7854-BCA3-456A-BC9C-C2FCC0B7C73E', '4602233004914', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81064452-3B1D-45AB-B1DB-7C067628A405', '308FB3C1-DC53-47E5-9734-A319E064DDC2', '4602233004938', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2502E7E8-E84A-4A50-A316-B9CFB0EF10A6', '93E4817B-6637-4550-B262-847C28F46232', '4602233004969', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4230BE4A-CB2C-497D-88EC-4326E63DE3B2', '4FBF7BE2-13FC-4042-A1D9-FAED6A72884A', '4602233004983', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABFD4165-B225-41A8-B7C3-DFBC5935BB89', 'E8DCAC54-394E-4377-AC81-5A1CC78D37E6', '4602233005003', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('850D71D1-EACE-401D-B5B8-3AF035AED154', '688E2D1C-E1D9-4215-8150-0E369C8B1BD1', '4602233005058', '    5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72AB61B3-04F2-46FC-846B-31588E500F19', 'D19190E4-888A-4459-AF8F-BB841C17FA18', '4602233005096', ' /   0,2% 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22104879-2D1B-4873-8B44-64832F02C028', '83D58461-F916-4654-B8C2-622F194DF38C', '4602233005232', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4145D55D-34FA-4DDE-B1D2-3A054FB699F8', '18C4932E-380F-4DEB-B617-1DCBDD27D12C', '4602233005386', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BEE59F8-8FAB-4F57-A49E-D55C6DD8337B', '9990FC37-DD50-41A3-9CEA-946D31CF62F3', '4602233005393', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCE070A7-6EF6-49D8-AE8B-EBDFE7F3EDA7', 'EE5BDBB4-1F0E-4DE9-B9CD-DE1C6F48B82B', '4602233005645', ' 5%  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3310E5AE-66FD-4D27-9BEA-DBFC216F14E9', 'A38DDE1A-F9C2-4DA2-95AE-5EF4E18EFA7F', '4602233005669', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('920D7849-A8AA-45FC-B35F-3552F74723D4', '165C6437-21F8-46E9-8615-2C93C9FA9DF9', '4602233005713', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDF65F2A-FA5D-4E6D-A6F1-DD9B021B2F71', '851F150A-4FDD-475E-904C-797CCEBDC1D5', '4602233006161', ' -   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D68D9F94-3A56-434C-A37E-DAE498082BEF', '166D2759-E09F-4E31-B506-4C64AB6421F6', '4602233006246', '   . .  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B47F2204-8126-4DB4-8847-2A3D7E8B3FC8', '3C75F7C8-A8E9-453D-A14B-037FBE4ABA71', '4602233006260', '  //  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D8BBBF5-C4E0-43FD-B987-4CB7679D2F15', '9C554A14-00A4-4F23-8679-C08837C6FF2F', '4602233006482', '  / /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9F63566-9C13-4621-9C85-8CE1F8D9BCDC', 'E05BF905-A7EE-45DD-9102-6779035CBE54', '4602233006727', '   50/ 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08CFE0CC-6CDE-4DBD-8ABB-42EB8D1642A5', 'C0D92A64-F13B-49D0-97CD-8A28B50451B3', '4602233006796', ' 100  /  0,1%', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ED6DD41-8D56-4E68-BE22-8095AF4FEFDD', '7732DCFB-D124-40BD-9EB0-D43A2E6BE821', '4602233006819', '  1% 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48E82BD3-2C14-4C49-99FF-90679468B96E', '63B6F41B-466A-4294-AC4A-30608585F8ED', '4602233006871', ' 50 60   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DB44D43-503E-4FC8-8227-858593ACB597', 'C8C27DF6-9C4A-4D24-B19C-EECF1C4332D3', '4602233006895', ' // / -  14 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1940D27D-E5AA-491F-9DA8-E258EF06E061', 'A61309FB-D345-48CD-BE6F-766A15BA8D25', '4602242000389', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('008ADDFD-09C2-4E6C-B55F-FE52E4791A8C', '11BFF875-A1B7-4E15-8D9F-97572336F1B4', '4602242000549', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1604523E-B57D-449E-BF53-A26A904851BD', '49194F41-5B40-4B46-9DBB-286F5F953471', '4602242000648', ' 0,08  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A8C39ED-39F7-45B8-9C11-50E98AB8CB23', 'A4FC95B9-47D0-4890-888B-0D5CBC2DD3C9', '4602242000730', '  250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EE5C067-5002-4995-9959-327E8C5AE134', '908E0665-FA13-4BF7-B54C-4B52425DD8EF', '4602242000792', '  0,5 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA68F185-5D94-46FE-ABF9-C2ED270CA713', '2878CF91-490F-4E59-B7FD-DB0EFFF3CFDD', '4602242001010', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F63B090D-6EAD-4D6A-A6BE-5E27F84D6B3B', '6E45B64B-7B7C-4371-BD67-8294CDBF5375', '4602242001041', ' - 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36C0DEEE-C8BC-446E-9DFE-6182F7720CAE', '9CA5629C-EF5D-40D5-9106-94F103AB5105', '4602242001126', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3271B36-F720-41C2-BEF2-B8442CD53F2F', 'B065DF65-B8C7-4E63-9958-437FF1737B91', '4602242001157', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09502A44-DA81-49CF-8736-94D3163429C7', '580ECF5C-C3C0-4493-8A32-5851F1208CBE', '4602242001249', ' 500  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBC677DA-ECEF-4405-9625-7542813F9FC3', '5DA62911-8B5E-4438-98A0-DCD5FE2EF1AD', '4602242001256', ' 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEBB7340-78AA-470F-9FA8-AAFD3D3B6C3F', '31B44FB8-2849-4AF0-B755-D825DD672A20', '4602242001287', ' 0,56  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FBD5E29-ED04-4F72-A38B-EB8DE80987E7', 'E239965A-E479-4301-8AAE-074797DF7EB7', '4602242001317', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51E3F832-C8E0-41BA-B0C6-EBE7CB835F31', '23BBC9F1-5E85-4239-8470-5A1964403B6B', '4602242001324', '-1 /. . / 0,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB7E3F6F-24DB-480F-B577-5451F97EE8D5', 'AD30AB5C-CC3A-43C9-A5E5-A1080D0D7304', '4602242001355', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA6FB3BB-D9E2-4E5E-817F-B5209D2CBCB8', '7B3163F7-FEE2-43C8-BE2E-CF87A58094F9', '4602242001379', '     30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E9F56F3-EAE8-4B06-A9AD-3039DCA48BB4', '2A1A6D4B-F26A-4A9C-A012-DC29AAC487DD', '4602242001416', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B9C0F33-2615-42FF-8876-30754099C008', 'E3278663-D497-4372-8841-F87A3419864F', '4602242001430', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E40F01D-B9F9-40C1-84D0-78B33DA754F2', '756B083E-7A2E-4087-94D8-8E7D06AA7D57', '4602242001515', '-6  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70CA933C-8CB4-4BF8-94D5-2615A0C01297', 'A47E01EF-D2F7-470C-A4A8-727623410932', '4602242001522', '-5 // 500  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE6060FC-37BE-4CA1-BEA6-37AD8D9D659C', '68916825-A88E-42A7-A944-595F607C9375', '4602242001577', ' /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('603E7958-B107-4ED1-B643-6B752FB5B03E', '452DB7E0-530B-4601-A120-5605836F8340', '4602242001607', '    0,4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9E85C49-7B1A-4BB4-A8FA-7EA5F322D6C4', '78758350-C13C-42AA-BF83-87C0E8E6FEB3', '4602242001614', '-8 // 0,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7620F50-8F22-4938-AD30-BDD7CDCEE783', 'D5574012-4B8D-4DDF-8507-77137849822B', '4602242001621', '  250  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD16BAFF-8E4B-43E3-8618-5A7FDC362A53', '8E820F25-2AC3-4898-8DC1-B21049D99037', '4602242001676', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DCB608A-91FF-47C0-90A7-2BEA6EFE753A', 'F437F91A-A3B4-42A4-82B7-78E9EEB81329', '4602242001737', '  /  /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01DA10CF-DCDD-4AEC-A677-7720853B64C2', '57666CD1-9A42-40AC-BA5E-B6A4EAA4F612', '4602242001782', '-9  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('747CFC57-369C-4588-842F-217275692226', '67CF29B5-E044-4E8E-9352-C8538ADD710F', '4602242001799', '-10 /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAF5CDDE-9C0B-4EB9-A1FB-72003D65F4CC', 'DD67D415-C9A2-4A9F-9A4B-EACA48143823', '4602242001843', ' 200  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFCFC65F-E750-41CE-9238-22B5827553FA', '1256A2DE-C486-4987-B578-7A08B84DE9D6', '4602242001850', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('306E2B3E-4F63-448E-8523-559B8C8D3B9B', 'AAF72BC6-9487-44EF-8368-6F28ADD3CDD5', '4602242001867', '-14 /// 0,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FCF5994-CAF8-4651-B604-A30510C7F660', 'AF57D20A-9A96-4EDE-938D-DA68EE1ED851', '4602242001881', '-11  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDCF99CE-4E4F-42D4-B2F9-8BE0E816E624', 'E59D3460-2CD1-4992-9759-92BAA51E0657', '4602242002086', '  250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E551333-40AC-46F3-915C-B00695AA241B', 'D3821EED-3525-4C0D-B535-0F08E521A0D0', '4602242002116', ' 500  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A7EEB78-6566-4700-92D0-7E1BCA1237D5', '115D1AF0-11C7-494E-807C-7B41E1647583', '4602242002192', '  "  24 ""/""  2  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51532CE8-EA4A-4EDD-BDA8-5DDBCE46DDC6', 'EBDC6E5C-FDDD-4D7C-8698-A6B6D0109097', '4602242002215', '   2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('813187E7-FC7D-4726-846E-5F7713FAAB9C', '69649903-3A8B-44FB-A7D5-7C815D80BD78', '4602242002239', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D679330E-24FD-43BA-9BE8-E92A1AEF234F', 'CA7ED2B5-3689-40D8-BCDF-291BFABA713E', '4602242002246', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF7420EA-356F-4464-88AA-EE57B0565A2C', 'EC2B3C9B-DC3C-4A57-AA83-218261525AC0', '4602242002253', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F487DF27-4BC8-4CE6-BA81-2CD5217CB83C', 'DDB9F1A4-685F-4310-980D-0E59D1035260', '4602242002260', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9094DA13-2DB2-4991-AE15-E1AE7DCEA30B', '02138B99-23DB-4003-B893-2B61E6F5170B', '4602242002284', ' 0,5 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DB25E5B-0B50-4916-A63B-3FC3F51423E3', '79017E3E-187A-49F5-94C8-7C6702B605DA', '4602242002352', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14FCC474-CD50-42F4-B375-00B035BD71A7', 'CA69428E-A8CC-4536-97FB-DE715DFE6816', '4602242002376', '      250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BE360B8-F682-4AAB-A585-4E5F293FC907', 'A66C0F77-437A-44C9-A072-7DBAA22B9942', '4602242002406', '   400  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EB8ED3B-C910-4C03-922C-CF78A2F5E32F', '5241F94B-A340-4E33-A250-DD29EC14D58E', '4602242002437', '     250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A0BACEB-81C4-4E19-9EAC-8D8C7EA95C04', 'E747CED3-4AA1-4552-9AFE-1BFBF2D3EAA4', '4602242002451', ' " R" .  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('948C46BB-817D-4D4E-B02F-0114F92CC670', 'D22ECDEA-FCB5-436F-9816-0A663B10E3A7', '4602242002529', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D98DC44-89DF-4B45-AD24-6FAB303EF254', '1283A49A-C2C3-4DC9-B68C-78F719EBC0CA', '4602242002604', '  25  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('391CDCB3-4027-40C9-B2CB-997FE7E31808', '56D61C55-7207-4379-9A16-0E07D4DE2935', '4602242002611', '  24 /  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4811B19-596A-4C2A-AF1E-4E5D56102FA9', 'DDAE4D0A-3AF3-4EF7-AB4B-2845F4839670', '4602242002628', '   / 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD04C0F8-E927-4E38-858B-5893371E2830', 'BE1F9046-3E98-4564-A1C1-08CA4262F03D', '4602242002635', ' 275  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFE1C48F-ABF9-47A7-B452-711213AD416E', '3FEEC591-EA8C-46E0-9C03-F2DC8698A06E', '4602242002703', '   7000  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7053E73-7266-45CE-9A55-745E609F7305', '5477510F-D704-4615-94FD-3B2E8A037AE6', '4602242002789', '    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32D05D65-A969-42FF-93AF-0157736948BE', '84C918D5-88C1-46E1-9E29-8269D7220DA3', '4602242002802', ' " " 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('993A9E81-5269-46ED-9ABF-CC3518CB1D1C', '07E45D5E-3527-4AC5-80D3-ABC876B00B8E', '4602242002925', '"-".  50    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('812FAF15-62A9-42FA-8F53-1CA143CB7F61', '4E4D3BFE-75F7-4AE5-8F8C-7F94174F6ED2', '4602242002949', '   0,275  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE571582-D613-4626-9861-77F45A8ADA21', 'E97B512C-5472-46C5-91E2-0D939A72ABBC', '4602242002970', ' "".  10  2.0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('335E55F5-D623-4973-8708-41F08D520CE5', 'C8CA729D-E443-493E-A389-933F054A7FC5', '4602242003038', ' .  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70477231-6465-487C-ADB2-1ABAB92907E5', '973DAE34-A07E-4086-8DC5-A98B17E1A194', '4602242003076', '    120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93647056-7038-47E8-BFBE-D1FFEFD66872', '45E44985-97AD-4834-AA0B-E161EF36BE54', '4602242003090', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05F4C69C-6C27-4E5F-9CEF-D30D02B02D1B', '79213249-F8C1-47D4-8350-2B6E50C17519', '4602242003120', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D122E116-4DCF-4A46-908F-A9DC340F6A9D', '5ED7B2AB-0C09-4E86-851C-B0F29F3BB45E', '4602242003182', '   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A979AD5-2655-4F82-BD8F-09FCD13F5C1F', 'B825525D-F7B8-41CE-9D66-89FC6090F4C4', '4602242003205', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7B49175-9B69-4C04-A9C7-38A686038041', 'B8B091D1-53B5-417F-A2B3-13113326D418', '4602242003250', ' 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC3B6C65-4264-4505-885A-F2E849BB35D6', '16A75095-AE77-471F-9DE3-08A28DAAED88', '4602242003267', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A0F5BED-EFD2-4282-82E1-723E2C8DDE3F', '1DF08919-429D-4273-83FA-A43C0629E729', '4602242003298', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D06F7B4B-B8EE-49D6-BAC6-AA301A7F9BDA', 'F390E7F3-20E3-4952-8EBA-596AF69B48DF', '4602242003304', ' ""   .  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8F66349-9842-4CF7-9EB8-DAACBCE360AE', '257DCACB-8F9F-45E5-8F80-F0C0BF8B42D9', '4602242003311', ' 0,25  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2B4F1F6-6155-4962-94A4-2B30B1CF964A', '3E22230E-986F-49D4-BD95-FA0709354002', '4602242003359', ' 330  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8AEF162-86B4-4607-9D0E-1420E660EB2C', '9E807FF7-BCAC-4B96-9D24-043BEDB5C1F6', '4602242003434', '  d3 0,7  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5853D18-0499-45E3-8FDD-5C73706F6A97', 'C40D4AD2-848F-49AC-A2D7-B4B9733317DA', '4602242003458', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC6BE290-4CE9-4B05-8722-5F971C192A66', '9DECBA6D-F12F-435C-B0FB-8F2FE4570F14', '4602242003588', '  // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA050E00-BD29-4FD4-B3BF-793762336B57', '6FEF5F86-CA10-46E2-8D19-1DAEE0E335C9', '4602242003595', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7B7CD29-8ACE-481C-A520-4F2DE65A4419', '583483C3-D89E-4264-80B1-126076B8FBF3', '4602242003649', '      100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E0DE9C8-2247-46B6-96EE-AF6AB92B7FAB', '312DF4FE-8D47-4746-AFE8-40A542DDCDBF', '4602242003656', '    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('779865CE-1939-4E0A-B69B-54D04163F181', 'F48F55AD-34BC-423D-A872-5D87DD86564C', '4602242003717', '  250  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FA90C10-835B-4681-9E42-F933B6D0C3D5', '9716D711-23FF-4D39-93DF-B4E5B1190EFA', '4602242003731', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('363A48E1-B66C-4FD0-9634-EA7D9C8E2FCE', '822A9EFD-722D-4107-9D21-83BE160EFB2D', '4602242003779', '  260  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43FA55FA-47A6-47E4-BC9F-EB0852ADCD87', 'DDFE29EB-7F11-4AAD-BE4E-64EE5735EAC8', '4602242003786', '  230  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('475B3A89-0C12-4DB7-9056-30D39BB4DCF0', '557E9780-5E69-4E7F-9C07-5AFE10D379A4', '4602242003816', ' -  "".  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF07A186-30B5-4FE3-8252-860B94485C4C', 'C17DA837-3B35-41E4-B983-C6F25F24C953', '4602242003823', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DA06934-8B84-4438-9155-B08A846B01AF', 'D8C1CB4A-039A-4327-A60A-6204150B415F', '4602242003861', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87310C93-8BCD-47EC-B0D1-285C20BF881E', '14286068-EBB2-4D20-A94E-8F36313FDD29', '4602242003885', '  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6BC9922-63C5-4995-9B9F-6662F7573F90', 'DA1C61A2-7C50-4A29-A80E-566AB84494FF', '4602242003939', ' 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B956157-AAC9-4AE0-A289-AE064D7BF68E', 'E39F7FCF-BDE9-4689-9EE8-F51FCEF33532', '4602242003953', ' 40  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D53FC5B4-AC7F-456E-BB6D-6B9E0AAC11A1', '4FC13262-B93E-4412-9909-6A6E5CE24C84', '4602242003991', '  / -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('474ABB0E-BE39-4FF5-816B-AD3E3872CE83', 'A0FBB80F-E11A-41DC-8C5F-D797FB4C5761', '4602242004158', '  200  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('725B6B33-1341-49D1-8A3C-94A3C03389FF', '968C9FB4-EC7F-4708-9EC8-E2BEFCFCFAFE', '4602242004301', '  - 3,6 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90FAE261-578A-4725-A361-AA1BF2A7F963', 'DE684B9D-1397-4A62-9C80-2B2E2FB55F65', '4602242004332', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B6DE751-5666-42D8-805B-44B90C4E9DB0', '02EB7995-4020-4B9C-A5A9-EC172BCE20FE', '4602242004400', '   0,56  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B667696-FA96-43E2-B6FA-0CD915F4CA3B', '6491B293-E4FB-4F4A-B5B5-9A9CDF38B638', '4602242004417', '  / .  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D998BCC-2262-46B9-A276-DE3C895379C9', 'D71B134B-245B-4404-BB55-713F4401105A', '4602242004431', ' 0,52  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D581E76-2BEB-44AC-9836-5EE06799F494', 'CB2BE5DE-F95A-4DA0-ACD7-930E464EE60F', '4602242004455', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC306DFC-68ED-4A8B-8C65-70A9B7F03914', '0F654179-945E-4DB2-9B06-A9F97E15B095', '4602242004462', ' 0,5 . 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('277444C7-EB11-441E-87FD-9756B9B80B90', 'C94BC86C-675E-4E51-A5CB-203216CEE610', '4602242004509', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DDB37C7-6C4C-4B55-9462-143C8C7FFBB3', 'F82DB51C-9D43-495E-8D08-7987A3C7ABEA', '4602242004516', '   / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D4BE35A-B285-4605-9C62-E9F11CD4BC7C', '74EAAACE-603D-4C1E-9065-E8346BA1DA67', '4602242004523', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E490B9AB-724C-4887-80F2-5BD7E6D6552B', '5E918B80-AF44-4C6C-8DA2-252EFD74F2B3', '4602242004585', ' ""  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8830E137-7F29-43CE-8250-629BEFB9E67F', 'E8323ECA-C01D-447D-8F84-3DFEEAE0BF67', '4602242004622', ' . 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42E681B9-CCFA-4E12-80C5-E3F5A4B01184', 'B93BC980-E274-457F-A7DA-A3E0F016A4EF', '4602242004646', ' - 500  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC8A6FCB-D4E9-49A0-A823-B4532E83DE10', '7209C901-0C1A-42B7-8BAF-6A50F8468AF1', '4602242004653', '  250  / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('150D5CD6-12F0-4EBA-B03F-FDA6BC7022B6', 'F8911B38-552D-44D7-900E-B1EBF52E1828', '4602242004721', '   1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08965672-FC27-4D3A-8E55-F221A6A22A73', '6AA0D7AC-92A7-4741-AE7D-9648BFA6150B', '4602242004745', ' 0,25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CE8A081-E50A-4EC0-9484-2427F872D80D', 'AA133096-35BB-4F50-87A2-53821F84DA55', '4602242004776', '  500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC191401-8348-4952-BF22-5D044B282CD0', '5455F6F6-4343-4BFF-BAB4-B4EC94766D43', '4602242004790', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A8A9109-6709-40DD-97E0-2E91229DF961', '47956DAE-69DF-4987-84DB-6A965140A058', '4602242004868', ' ""  .  50 ', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CD34BD9-CCF8-4CC5-BA17-F2FCEC1B3A70', '07341C50-D156-4F12-BF4E-F7F37C3DE9E2', '4602242004875', '    250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC23C92E-2DBE-4D18-A2F0-046B01917F89', 'C951BE74-2111-4096-8245-2D1906CBBB48', '4602242004899', ' -  18+3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('978C5421-580A-4E73-A7DC-88EBC3E98563', '64AE9561-5A82-445F-9315-ACAD1E661569', '4602242004905', '  24 / 0,53  32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('411F148E-1406-4C72-81A7-E9E6945B429F', 'B38479BF-E7EE-4E96-A2E4-83A209875B90', '4602242004912', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('064F6068-ECB8-4808-8786-995A2AF54023', '5CAE5FD3-703B-4CE0-BC52-6AC10255F665', '4602242004936', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F19DF97-6AA9-4D26-87A7-ED26D3CA8495', '3368778A-8EEF-4089-8A80-A06845661741', '4602242004998', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15C9AFF6-45A0-4C65-9067-A2AE8583E779', 'B9F146FF-1991-43FE-B9AE-F0AE52A2616F', '4602242005032', '- 0,2  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F26B705-6C6F-4B6C-B8C3-6F63901A597E', '00B5F783-513A-4648-9F1D-0783D3316FE3', '4602242005070', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8C496C0-D10F-49CE-BEF6-CF81CAFD123B', 'C9BE52CE-148B-4954-92F4-AD9C1247938D', '4602242005087', ' 0,65%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D98E32BE-82E1-4A1B-8FDF-327787554CC4', 'D6A4C10D-E6D3-4237-90E0-A502554A6BAE', '4602242005230', '  0,1 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD3D2910-FC7A-4BDD-87D2-449EC3D7D24C', 'C40E2903-6F38-4EC6-B5B4-141EF1E38ABF', '4602242005292', '-  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE6A31D7-C907-4081-AB12-61CD3F84DC54', '4AF83BB7-6FDB-4F1C-9BDA-223424EF9381', '4602242005322', '  100  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97862D58-2D2C-4050-8D78-B56C4E32C85F', 'D62B477E-DF12-4C32-8894-AF1CC2E81452', '4602242005421', '   40  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64A07E52-1175-4C52-A994-FC7DDEAFEFEF', 'B104EB66-B106-4D8F-850C-6DA99F983676', '4602242005445', '-  0,4  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BBCD0CC-1897-41C5-B3D9-CEC3036FE228', '43BAB7D4-0C79-4853-A536-893C08820E14', '4602242005476', '  0,0075 /    100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A9D0FF8-AB20-41C3-A9C7-1C9722CE316E', '0DF211DA-9759-493B-A8A6-4417CBB14B33', '4602242005506', 'off  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3B0159C-77B9-45E2-BB2B-15FEF44B3BC6', '4DEF186C-B644-470E-B4EF-0F9C80F0D86E', '4602242005537', '  3,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77EFE807-BEA5-4BDB-87A8-DF2D0707A674', '58FD062C-B7E8-44AF-96FC-AAE0A293D27F', '4602242005544', ' L-  10 3,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B853D191-D7CC-45F8-8A5A-8FCD5448A4F8', 'F4F672F9-E4F0-4B6D-9F03-D781D01BD92E', '4602242005551', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81D83EB3-CFC1-4C37-9B7E-23ED29DACED8', 'D19F27AF-2A70-496F-B1AB-37CBB9B25964', '4602242005599', ' -     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7B4439D-2EC2-4B1A-97AA-4FD043CEB1C3', 'A93E2F74-3F98-4E79-92A4-9E3389C4C999', '4602242005612', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E91829D-D1E0-4262-BD51-976557B152DD', 'BC4715A0-0A5F-48CD-BE63-48FA8EB776A2', '4602242005643', '   2,0 / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27830687-E63F-4F5E-9982-FE27022CA5FC', '30AB3483-A99D-4576-827D-AE99F71A7A85', '4602242005674', '   700   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7AC7622-9894-4744-886C-5D78F14247F8', '2CF99B52-A9D1-4CEF-ACD9-B2FD773E140C', '4602242005766', ' 380  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2490F7F1-586A-407E-9BC6-2D808FFCAF73', 'E40BE0AA-22FA-4D23-9010-93EF254FA36C', '4602242005773', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E62F36D-ADFA-4A8C-914D-4AAB57FF80D2', '42E66F76-E63F-4AAF-9567-AF56C7097743', '4602242005780', '  300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16CAE18E-10FD-40DB-B8DA-4123E61C26BE', '986A244F-4363-4EAC-9B14-60EA049ED02A', '4602242005797', '  300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8985D320-3D8F-4935-A4DA-F02ACBB301EF', '668316A9-B168-4D65-B53B-A03EA8832C28', '4602242005803', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81061486-4A0E-48AD-9A23-9C6B6E5A3B19', 'C99BD8B2-3B99-40F3-B6D6-B64872A93C51', '4602242005841', '       3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80E11B12-F531-4CD7-8644-00DF94356022', 'ED56B45C-8AAB-4A5F-881A-8BFA9F0E3F3D', '4602242005858', '  /  / 1  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C66C7480-BD88-4BE5-8DB1-2AEFC0A81224', 'B59B6C82-FDC4-448A-A77F-F63B04E33943', '4602242005902', ' +    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4BB45AB-B1F2-44F3-A030-7479A0E8EBD9', 'A1DCC176-91D0-4579-B4E9-AA08A5A8861C', '4602242005919', ' - -  l- 0,55  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32D131C2-2F40-4D56-99DD-11E252AB91CD', '1692CF06-3CA0-4A67-8A90-3EBF8A02D86C', '4602242005957', '   2  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B564991-5382-4CD2-840A-501AD94747C8', 'EFD0D0ED-9DB2-404C-BC53-C1410CCF8248', '4602242005964', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CDCCF94-72EB-48A0-B837-BD65E8A2C89E', 'FBF9A3E9-BE7C-44D8-8C9B-7E2B6E2ED336', '4602242005971', ' / /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E42441D3-6D4A-4425-9F58-FDDD2CE4DF3F', 'A8CB2E97-1239-4C86-A669-C56FBC93A458', '4602242005988', '  +  12 6 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E3699F2-9876-431B-8DD7-FD7ADE377513', '8D3CFFAB-B9C8-498B-B51F-24572D27FEE3', '4602242006015', ' "-".  100     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD7F6C51-023F-437B-BED8-A52A91162E88', '8D68A332-F5F0-4BC6-B7F4-0AD3ADA3FC85', '4602242006022', ' /   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A02633B-5AAF-4C46-BF5C-7DCFA53E8B18', '84F7ECEE-F461-425B-A42C-668E3160BC4B', '4602242006039', '  /  / / 30  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24387A1F-5C86-4FB9-B7F5-A4F2B4B71CB3', 'BB65876E-7429-41DC-8306-204442999F2A', '4602242006053', '  Q10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0011EDB9-2194-47B6-B45F-9BF5F8F9542B', '0F936573-7733-4C19-AF75-852E8C6220F0', '4602242006060', '  . 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7E58466-B1AD-46A4-B5B2-42BCB6753CD6', 'B431AA01-D8B1-43E1-950A-60C4BCE65AF7', '4602242006107', ' 0,4  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A5BBDD1-DD55-4F37-AB00-399DCEB86F0D', '64481551-28CF-4BCF-A1BC-898980ABA69D', '4602242006114', ' 0,42  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6CE6052-F0C0-4A03-9BBD-8929E5F9FF89', '7DEC0A62-7C5B-4CB1-85F8-CA3BFCEC7CC4', '4602242006206', '  24 /  32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19919761-25C1-4D18-9617-583D7229194B', 'E16DC6D2-2E2D-432C-8DE7-7C37551A96A0', '4602242006213', '   64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E5E2054-4A22-42C1-9ED8-32954139AA60', '7F67DFDD-B556-4816-AE8B-824409088A31', '4602242006220', ' - -  l- 0,55  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFF41601-F03A-478A-B51D-59AD75A36849', '0E3109A6-6F65-47BA-BCE4-372E4F97850D', '4602242006237', ' 1,2  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7390E103-A999-4193-9AB3-8C63B7B745F7', '606BF8BE-873E-4AC7-8132-4225BDDC14D8', '4602242006251', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5787C848-737F-4AC1-AF14-ABA332ADDE5D', 'CED33C5A-BF96-4DF1-8EE9-780D9CA8D671', '4602242006275', '    / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F3AC5B5-A3EE-4DA4-9416-91FA35502977', 'BA536D6F-1B21-447D-8BCD-B1C7DC582D45', '4602242006282', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDB13084-B7A6-494E-B28A-E83A0C71E00B', '241DEB0C-3529-41BF-A4B0-3D9CA36F92AA', '4602242006312', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95F14B3C-D447-4550-80AB-8CD0D05AF794', '3B4CA716-A0AB-4214-94B4-2E4F3D6A3A33', '4602242006329', '  520  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D456B327-29D1-4EE3-9E92-6F1642873706', '7D7C4F00-6508-438B-A431-2851787608CC', '4602242006343', ' 25 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BAC9AEC-51DB-4A6D-9A35-5E673969A6A6', '5525D4D4-CFF4-4CF2-859C-84D4B49FE612', '4602242006381', '   3,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BF0B324-B4D1-444C-A411-D6336EA98148', '611A9D1E-0803-451D-9DC0-B06AD308D28F', '4602242006404', '-   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0CCFF1B-1C1D-482F-9801-1904796CF187', '30E18AB3-87B1-483B-84B4-21D710EB4F95', '4602242006411', '  /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0E7904C-060A-4239-93E3-55D370ED6E1A', '0051C21A-C8BE-432C-A495-E634A5EE4A33', '4602242006435', '   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3E6AE95-5962-49FD-A29D-AA426277DD72', 'DD8D9C38-237C-427D-87A5-F58BEB7200DE', '4602242006442', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B87B7681-AC5F-48F1-8AA6-4D5A38EB4920', '580C5BAE-398A-4340-A5AB-E7C85717B75B', '4602242006459', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD9A45FD-EDAB-4D69-BFEA-CA9D002CD2C6', 'A70DAE0C-A7A8-4831-8BDC-3C844B49E93A', '4602242006466', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8F7ACA1-9B28-4DB4-83E3-E9F7D9E07F48', 'A2A5EFF2-4CC5-4B79-B524-A7A36B7DCC91', '4602242006480', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BED6B48-2565-4744-A222-77F0C9F898EF', 'A1007192-DF4E-4C95-A473-51ED5979B3F0', '4602242006497', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65838F38-4E8C-4EC7-8A4D-A3AD2C334CC2', '65FAE8A8-8142-424F-9B8C-990F49494F33', '4602242006510', '-  / 45+  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABE182EE-9B75-493E-AA3C-0AF4093CAC95', 'D2CAAEC8-6530-42D0-9D9A-56B6F61179CA', '4602242006565', '    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('072E2D31-85D3-4393-B2E8-484B9B735C2B', 'D55EA8FB-4AAE-4399-B3E2-0B6AD9A9C2D7', '4602242006770', ' 50 -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1314EB8D-6D52-4BC5-ABB5-BF979F017370', '5C7C19B7-C6F4-4D8F-8F20-319D4A7443BA', '4602242006879', ' / / 0,55  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('677E6ACE-EB93-4155-85CB-127DB805CA59', '3E1C74D5-FB19-4C81-9941-5277BE45FEE2', '4602242006893', '  SPF 50+.  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99D19E16-8F72-4E1D-9452-D329BED8CFE1', 'AF7D74CF-96C4-4D6A-A44C-39E534D0C142', '4602242006916', '    0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E22E5756-4251-493E-96E2-8B19EA7D7C9B', '6EA198CA-EC51-48B1-893B-991890BBEF00', '4602242006923', '  550  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00413DD0-7487-498B-AB81-699C154B8CA1', '4C2924D7-AEA9-41BA-96AD-E76C726CDACA', '4602242006954', ' drink 10 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B11685D8-64E5-42C9-974C-08985AE63A2F', '2C4D51D4-15D9-4227-BED8-1D7C3ADF5A43', '4602242006978', '  . 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B601752F-A072-4A28-9E4F-C6E92F0760B3', '253A4E2D-D22A-4133-8856-A383C2F3EF6B', '4602242006985', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18F8BB10-5CBB-4124-A6F7-4DBA9B6B74A4', 'C06DA297-1AA8-4A07-9CC1-12B7331894B0', '4602242006992', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C60C82B4-2367-453A-937E-D2D54E4DA5EB', 'AF7D74CF-96C4-4D6A-A44C-39E534D0C142', '4602242007005', '    0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4803ACBF-DEBA-43BB-B88B-4B226D770394', 'BAB9849B-EAF9-44CE-8C3B-C90F7D8343CB', '4602242007029', '  / 0,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F71E4E3-4F7A-4E2B-81E6-198770A5DDA6', 'F3BD49DF-5BEC-4B2B-8251-8DE04F829246', '4602242007050', '    . . 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F567197-21D0-4FFC-8E65-AEDC8B2670CF', '1A5D2FDD-79C0-4F2A-8A4C-6A70BB750EED', '4602242007081', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A6CB9E8-A284-48A5-86E9-98E7C8387C06', 'B0655C4F-2954-4BD0-9FC0-A268027E9E23', '4602242007128', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED0685D9-929B-43B0-A733-1BBEEA2870D4', '5AEB4E3D-F609-4316-A5CE-DB19F4EE1C17', '4602242007210', '   . . 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFF89EF3-B7A4-4867-907E-DE2B38C1D8B1', '497D4BE2-74E7-4C6E-BFA0-6D2365F71D57', '4602242007241', '  . /  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFE112C8-B6B0-49AB-92B4-45E9AD8F881B', '72C1756D-80EB-400C-B4E0-E2C52EEAB85B', '4602242007258', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('377ABACB-2C97-404D-A50D-7C18657F1E95', 'E8BC60A8-7C7C-447C-9C99-42FEA8F7CA23', '4602242007265', '     250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD9C5164-9B9D-4628-A090-D25C31EFCF86', 'FFA7BB08-6969-4B91-80E3-8D609D99C8CB', '4602242007272', '     250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('021D5560-3EA5-45D8-8048-EC2938E5048E', 'A8572802-E4CA-42BC-955B-25A1B96C2CC6', '4602242007289', '   / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17B59803-75F8-41A9-8B9E-D2D073A4E10C', '21BB223E-FDDB-4D55-BF9E-33C619041E82', '4602242007319', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88E49FF8-B699-46BB-8B3A-DB1F58282617', 'ABCB55A4-077D-4BB9-A3A2-BBE66ABC94DE', '4602242007326', ' 0,35  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3A0EECB-E3DB-4929-9628-C17C76B0287E', '00A175AA-AB0E-45C8-8846-130AED41EB1B', '4602242007340', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D03411D-1060-4982-80A7-F29250D13964', 'A1044FF8-ED60-47B4-B42B-72155511EBFE', '4602242007357', '   0,15  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9F89205-72D6-4116-964D-8E6E8421E283', '257DFB4A-5BC7-4A6A-98BC-F0ACC6CAB28A', '4602242007364', '     2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE4C1BD2-65A1-4486-B1E9-63230E83E12E', 'B5DEE8A6-8D6B-48DC-AD81-8759D07D87D9', '4602242007371', '    0,4  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C872664F-7591-4C34-986A-37182F550A6C', '85322145-B8CB-454A-9F71-6F42F1DA9882', '4602242007388', '    3,5 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABAB6EA8-951D-4113-873F-26746E011487', 'C9CB00DE-F0C5-4F2E-86F5-42702120B4AB', '4602242007401', '  /. / 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F8C76A1-8256-4BF6-9B94-FAF8298F2560', 'E5701352-4707-48F5-BFB5-7845471B9D59', '4602242007425', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1B76EDF-DD58-4EFD-A947-3CC101FD4FC1', '77FD8960-7D01-4393-B274-956B180F434F', '4602242007432', '   1,5 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F1ED525-36CB-478B-809E-9999FE0D8B2D', 'D6F47471-7276-4FFB-94E0-B19EB4966D8A', '4602242007449', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C251330-0F04-4039-8239-C54BC4466FEA', '19832336-B062-4976-8CD7-DAB6CD35A5B9', '4602242007456', '    12  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD1B2C05-F9E8-405D-A34A-49F23FE6C4B8', 'C1065898-1E97-48F3-B6B8-832549B7AF3F', '4602242007463', '  /   1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B358F78F-8849-478A-A2C9-3ABA3282E76D', '11BB47EB-855F-44F4-98EE-977D3F7D4F1B', '4602242007470', '  /  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C4A104F-C39A-4AD1-A316-EC16B9D6D885', '50A67445-74F5-4318-9905-87B359862465', '4602242007487', '  / 1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F6C8B47-7078-4E70-927F-87F6F738C199', 'A0605C81-2E9A-4A22-8808-6D97367B249D', '4602242007494', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D77DEA85-9FD2-4946-A7E2-B4AE9DC8E60E', '7544B990-5392-43C7-9500-3005A180E27F', '4602242007500', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F07025F-9FE6-40EF-B5CD-190C7A01668E', 'E3728033-35F5-4816-92D4-F7820D7BEC14', '4602242007524', '  /  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBC047E1-EE23-4D0A-9B87-E1FB195F92E9', '744562B8-FF10-4311-9DF7-54BD49638186', '4602242007531', '  0,59  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBF536BF-7DF5-4841-B261-CDE1D5C9C2BE', 'D4766404-F5D4-42B1-AC0F-0D76150DDCA4', '4602242007548', ' 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('236259F8-018E-4936-A271-3F59D9B011F6', 'B91D812A-5370-464A-ACD8-9BAB2AD8F81A', '4602242007555', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B148A1E-4490-4022-83D3-F4119D1D8D82', '6738A091-59B0-44B2-B73D-C5481B6BA2E5', '4602242007562', '    4,6 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('777D2EC1-9B3C-47D8-87E2-E0F644562AD0', '96E7FD1C-0BC9-4579-9581-9B8DB77729A7', '4602242007586', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('464389BC-7D7D-4495-9A3A-928B1864C4FF', '2735AFC5-7251-4278-A1D2-24CB24142114', '4602242007593', '    2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD88EDB0-999A-4F9B-9733-43978A41F9DB', 'DCCECAB0-62FC-48FD-AEAE-47F421283A60', '4602242007630', '   . 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F76FFDE-DBB4-4191-A6FD-3FB69B123A9A', '08117F1E-7D7F-45AE-BB1F-DA9249C69B80', '4602242007685', '  /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B226E7EE-6796-48C9-9C47-7A200F2877F6', '2D7A12A9-4311-40DC-B814-5AD58A1E94EF', '4602242007692', ' 5  330   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39F481AF-65D8-4D34-BFC0-6F4B6E1D753A', '810977F9-2D09-4FF3-B909-5C839B2C7EE2', '4602242007722', ' / /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23AB73C5-245D-46A3-9EF8-00E778A55AAA', 'F6CBAB35-232D-4F0C-B076-B96FCE35DC67', '4602242007739', '    1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('628C0FA5-6E69-405B-A245-229006EE58A5', '32F0FFFE-A6EE-4A5B-9328-87DB82CE999B', '4602242007746', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D82A3A41-8F67-4A65-B3E0-DE9E3E7C9DEF', 'C081E48C-9E8C-48D1-911C-6483C3FBD37D', '4602242007753', '  -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('816856E3-D2F1-46D0-A7D6-2372890426F4', 'FE6508E1-9EBD-4C28-A633-DAFB3161B751', '4602242007760', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51566D9C-4998-46D1-AEC1-1EDD02201997', '2733E8CC-1048-49DC-8074-713E0C4DABA6', '4602242007777', '  .    30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4796977A-5ED5-44DE-B51B-DD6B381A2D88', '5CD2BAB2-2AD5-46B0-8389-782CCDFC022A', '4602242007784', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9E279CB-1B68-4014-A1F5-142E22B43F11', '1C5CD60B-FF2B-45AD-8951-56A229711D2D', '4602242007814', '-   1,8 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('305EA24E-5B55-40CB-A25D-450A0C3D420D', '449FC10D-1E06-41C1-9485-64DA8B67B745', '4602242007821', '    2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BD16B1A-F94D-40BC-8D81-E47B42ECB5A7', 'CEFACE1B-30C3-4242-9E84-7EC6BC2B073B', '4602242007838', '    1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6938BA2B-986A-4B0B-BE92-F200144012DA', '2D1E057A-3BE0-4042-B18F-391D6957C626', '4602242007845', '  50 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BC7D230-19DB-4959-BE3C-D7A3FFAE966B', '3E2555C7-0E8E-4A7B-932C-8AE3998FA80A', '4602242007913', '  24 / 0,55  32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC62430C-D4F2-44D5-B7A5-F3D29E8A8101', 'A8592282-1A73-4429-8BB8-FB0000BFC20F', '4602242007920', '  0,59  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE3CCDFD-45B0-4057-998C-E6BD47063E0F', 'B6D06889-4169-4376-B689-DA03285B4B34', '4602242007937', '     / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92CF3B41-AF04-4A91-B4CB-BBF8E066F3EE', '0A76C0C3-D425-49EB-8736-33C61A340039', '4602242007944', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94AF7D80-7A4A-47F3-A471-9978200C1BCC', '7C412C68-3969-4083-AC6D-8F70D115E3C2', '4602242007951', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C38B328-72AE-4FA3-94E7-F7CB01F2E03C', '4B47CD15-5CB1-401F-AB71-CBFCD15BC629', '4602242007975', '  / 50 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8B8A1F7-686A-4FFC-96C1-EB02FD54FE37', '758D5EF2-9152-4CBC-A9F4-F854CC4AFEC5', '4602242007982', '  0,33  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A2D9C99-F892-45F3-8D54-476037F9F711', 'EE2A3443-13B1-42E4-8899-7082696794FA', '4602242007999', '  0,12  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E7C3A6B-EC78-4C25-9581-F0C5AE9FF6A0', '8F6C3F2D-0C47-4D5F-9738-F4ED175F94BF', '4602242008019', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81F12BED-143E-43FF-93B9-B79AA4D2DA46', '92E07AA3-3F16-4A49-B65D-12C9B2A05DB7', '4602242008026', ' - 0,15  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F48639C0-BAAE-460D-A02E-4A7DF451EEF5', '49C827DC-FC63-4148-A796-C66A8E668B62', '4602242008033', ' 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23E788D3-4F92-42E9-A393-2C57E97FC58B', '5003BDA4-7645-4770-B91B-EB5AD966AA3E', '4602242008040', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9E827D3-96AF-47DC-8924-F854C32FD9B2', 'B686AC63-A01A-4FF9-80D9-9EE243C18064', '4602242008057', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E0F7700-B1C5-4EA4-B96D-F21138B51A94', 'CE60F970-1A4B-4D02-BD8E-79F02B5B597D', '4602242008064', '      +   3- 2 30  2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75EA3544-0723-4251-AEEC-60736B9B8661', '9A8AE8AB-DA35-4B3B-B32D-E83AAD98DBD2', '4602242008071', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E20AB102-9A63-42A2-8E12-B44D3E091322', 'C2F14E34-29C5-422B-9259-1F9CDA60B088', '4602242008088', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6B69C13-1E34-435B-B190-E9E1B2F3349E', '75508A7D-7862-4F16-8306-A0E699F776EB', '4602242008095', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('951734EB-F9BC-41B7-8327-927E09D8F730', '7B96F63E-1DDA-452A-892F-9A98944C3684', '4602242008118', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CA71417-9FD7-46EB-8944-3D99C1EB3A2F', '100A7946-30A5-436C-BFB8-E34414B7B096', '4602242008125', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B38D251-2960-4C33-AEC2-D106274CDA67', 'D19F27AF-2A70-496F-B1AB-37CBB9B25964', '4602242008132', ' -     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4C65387-6CDC-4CCF-9F36-D97E19839887', '3BD5D259-555D-45F5-8711-AA2BE3C093DF', '4602242008149', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FE05DE1-B789-47FD-8613-8DAA94C80D16', 'DB72F7E5-9889-4F90-8243-4A58EDCF188E', '4602242008156', '   6  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AF8E446-78C8-4068-938C-939DD98BC935', '3B756F56-F008-4A52-B678-B355C709D0E7', '4602242008163', '  /   - / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DF5E288-177A-4381-8802-D780B0ED66A4', '8AF1BC1A-AB65-44ED-A13C-EC646CFCC180', '4602242008170', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C61DFDD-1F39-4DD6-B65D-DC8178A8F2EE', '90B16477-1B1E-4210-A09E-284EA68DA209', '4602242008187', '  0,23  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67F07D2B-3DC0-472D-9129-CF8EA1DEB66E', '36BB376D-9A35-4FE4-BD6F-255D84132039', '4602242008194', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97C082D8-FD7E-4225-A3CE-0CB4933181C0', 'C8F0910B-209C-48DA-8A9C-4636E2786C0B', '4602242008200', ' " ".   5  7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB9E2FB8-7B00-4877-B224-26AC33EDFC38', '4E704765-9097-4D61-85D6-CE8DB386F23E', '4602242008217', '-  9 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C3A79FA-DF77-4039-8C5E-B23C9E035A8B', '03895054-2A0B-4C61-90CC-5855D29FA57D', '4602242008231', ' 0,7  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BD5C383-B830-4730-987F-079A4B38A2D2', '856439AF-D66E-4ECF-872E-E491B0EBB066', '4602242008255', '    0,36  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7010D809-1D0F-4032-9E3C-087345EADC6A', 'F791D9D4-D68C-49EB-B643-D6E12E2ADE3F', '4602242008293', ' -3 .   .  7,0  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3A6F7A9-7836-4344-BDF1-DAB6EC7F85B0', '91719961-FC5B-437A-B396-996750027C6F', '4602242008309', '  5 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5461F3C5-487F-4C8F-96AB-344E4441070D', '34DB5EB9-18E7-4444-AD87-D7EA4FC283DE', '4602242008330', ' L- 1800  6  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2856487-F654-4166-85E2-100A9C98F2A3', '314E7F79-60BB-4D7A-AB63-849FCAF78382', '4602242008347', '  0,23  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E67A964-8339-4EA7-BB13-CE064445D081', '370B61C3-F967-4104-A8BE-25AB008FAA5C', '4602242008354', '    / /  + 15 30+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('590DFB86-4DE2-4D9D-9513-528684D1555A', 'A4D83015-ABC0-496B-89F8-3807A1711B59', '4602242008361', ' 6 1,1  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EA249D5-75CC-40D0-A587-009411F83559', '4A6B4976-EB8F-444C-8932-BE71AF0BA517', '4602242008378', ' 6  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64B751C9-B9F8-4F22-B355-2DB6768F6A03', '96CFCB8C-BCC8-4D3A-B24A-C43649932447', '4602242008385', '  1,25  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('469EDB9D-7996-4E5B-96A8-FFAC1A27634E', 'E48F2BAF-E095-469E-A9F0-2940084FA626', '4602242008392', '    20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('386B1020-B53E-409E-A42E-D98576A6FC17', 'EA854B24-A705-4420-A368-E55CDE230778', '4602242008408', '  /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E48C814-D5E2-45F7-863B-63D5CB342167', 'FC4BE382-43CF-4297-9292-E39AB5654AAF', '4602242008415', '    . 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7B20060-F9F0-4F87-947C-FED59A1D216A', '6FB96DCA-B807-4457-90CB-4176B47A467A', '4602242008422', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FAD87F7-0F6A-4E8F-9092-ED010420138B', '207D8C39-52B3-43BA-A22D-4C27C719EC91', '4602242008446', '   6  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4CFBDA0-CBE2-4A69-AEA3-3DDF53FE57E9', '4B77CED4-B7BD-4D16-ACE0-42A3DDCD5AFA', '4602242008453', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D419D9E-A9C7-4C12-8BE6-1A1EA334D3DA', '53FD2231-095F-4AF8-B2C4-8F16B707890D', '4602242008484', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33C274F2-C0A4-4CAE-9A90-A32E6E2CF5CC', '05D06E3F-1009-4E0A-861C-6661FFE7533E', '4602242008507', '   -  .   ,  1  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC5AF3B5-D1E8-4BA1-9F3D-B24E145C471F', 'DF47BAB0-4664-422F-9B1D-0D1C3EE429C5', '4602242008514', '   -       .  1  15,0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('579C0F9B-9342-4E8A-B568-3A316D94F0EA', '2DFBD54F-E666-4009-ADC2-57A260C099F7', '4602242008521', '   -  .  1  15,0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8614E69-26D9-4A53-8FCE-CE9BBAD94838', 'B339D103-2DF7-498E-904F-CC96AED64D76', '4602242008538', '   -   .  1  15,0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB7AECDF-D24B-45C6-89AD-5869136DD3DC', '49ABC725-D7BB-45C3-A1B1-C9D3ADC43736', '4602242008545', '     .  1  24,0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A44D13FB-8D4A-42EF-996D-88AD99EEF42C', 'E1C6292C-6BB8-4460-A52E-6304F8D0ACB2', '4602242008552', '      .  1  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCE99E3E-A130-49B2-992F-E01E587C9F6B', '1F40F42D-B5D7-4872-9D67-98DA53FD23ED', '4602242008569', ' .     1  30.5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5081CED1-1395-447C-9055-2519D297A8A7', '0D753080-9117-43B2-877D-863662B8B9C8', '4602242008576', ' +. .170  510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8100F38F-17E1-40D0-9977-27BDA5EF6E79', '7D6CE2EE-0AD2-4368-9D1B-81BD84D71B40', '4602242008583', '   450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62A3AFC7-8FCD-4C66-826D-6DBF393F3941', '21FB3F8B-53D6-47C3-9B8E-7F0B009AA656', '4602242008590', '    1050 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE66AAF5-2D5F-4D5E-B43C-33F9298AEAA3', '49B1374E-2131-4204-B4D8-7DAD6AB37BA6', '4602242008613', '   200  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C918EB94-3C19-4621-A12F-BA7D1AE068CD', 'C5F2087F-77AE-4F04-A64E-26CFB8ED4084', '4602242008620', '  / 45+- 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35EDCFAE-78F8-4D19-9B61-CE91EAFC2D66', 'A43E0BA4-532A-4C6B-89BC-AF0A9E1CDF73', '4602242008644', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9984D284-46D5-4F68-BDDE-0B9F27B37654', 'DDB59542-07B0-4A6A-AA9D-634238260B96', '4602242008651', '    360 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAF0CEA2-8846-4DAB-B022-A9A7093B1E98', 'B21E70B8-736A-4D8C-9E58-6DCC17AD3511', '4602242008668', '  1200   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70AFC7C1-37BF-4E3D-BD9F-D19DC20B6F60', 'E788DD3B-3685-4BDE-8FA5-93529A174AA1', '4602242008675', ' 6 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28317047-10B6-4786-AA94-ECA4899D55ED', 'F2CD9898-8FF2-40D8-9D45-F99F02ADD2B6', '4602242008682', '   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D57A1C52-696E-40FF-908C-F150A6663BE8', '2CA87876-FEB6-4CA3-87CD-0E076645C046', '4602242008699', '   1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EC99CA3-C6E3-4E54-BAB4-0525E0215B73', '3691AF1A-7314-47B2-B329-43EE93908FA4', '4602242008705', ' - 220  60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A48DBFCF-1F36-4507-B561-D7C6068C69F9', '6DA7C79B-E655-41A9-8630-487206E54CC7', '4602242008712', '  0,5 /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49643358-37BB-4418-9872-2317CE8AC899', 'F4259371-85DC-4BEE-88A0-C54A3DFF962D', '4602242008736', ' / / 0,32  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC589098-D328-4D18-9A14-04B73778A0F9', 'FD6D123B-78AC-4D3D-8728-1E86F534DA81', '4602242008743', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43EBD21D-44BE-4BFC-9A66-1C2D6642CB7A', '9C99C7BB-CFBC-4352-B8B7-1330D621888B', '4602242008750', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA4B101E-5BB7-4A44-9D1F-EBA6B8BF4BFA', '49DC5ABE-AFC6-4E6B-92A7-035E021C1083', '4602242008767', ' . 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B77B12AB-4E04-4E59-A9B6-1EAA7210B295', '8596C5A6-228C-4403-894B-380132EF2697', '4602242008774', '  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32B4D7BE-0CDA-405A-84EC-924F3A49CEC3', 'A0B76F15-EF32-4D72-9ED0-98CFC572B329', '4602242008781', '    / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0D69159-82FF-4AC7-94E6-778A43A3E0B7', '5094F07D-28E3-45E1-B56C-91CEAC415E41', '4602242008798', ' " ".   250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18753C7D-BFDE-4C90-A87A-08C6F12A1457', 'DD880658-34E9-4C94-A5C6-17D930940200', '4602242008804', '   4  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE9574D0-0C81-44E7-89D4-01FBE4A5B9DA', '21662833-8BE1-4CFF-BF6C-5B33919AAF09', '4602242008828', '  100  . 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83F1FA1F-173D-42EE-B1B8-AF801C81A580', '79B397A7-7D54-46B2-A0FD-F637CA44D031', '4602242008835', ' R   . . 40  0.50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11EDE061-8151-49E9-BA2B-92279D1EA4A8', '699EDB65-3B11-4686-8359-5A0A442A8A5B', '4602242008842', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9282AD94-B629-41B7-9385-10B8928613F5', 'CE870099-4D68-4D07-8126-5BF0CD2B1814', '4602242008859', '   64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C2786AC-1AE1-4016-98D7-0BC2E6D8EF7D', '481847AC-9793-4182-AF7B-49F95CA022B1', '4602242008866', ' /// 0,65  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38FB9B0E-826C-4D80-9485-B81A20EC8639', 'A25B9881-6C1B-4373-8689-C736625E0CE1', '4602242008873', ' 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B55B5634-1669-4CB1-8A03-06D49890340B', '236B210F-4F26-47F5-AA82-5EA112BC960B', '4602242008897', '   1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('339CF4AB-ACA7-4159-BF51-C8D097B96571', 'FEB47A6A-854D-4368-8DF2-A1F30B13492D', '4602242008903', '  80 / / 0,5  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC9BC651-A1A5-43F2-8708-29401B91E1C3', 'F86EE505-9545-482D-A4A8-F42DC1CC5F2B', '4602242008910', '   15 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD1BDE94-0C59-40B7-BDB9-721C7F399E9C', '4D28B16F-6A30-4410-8DFB-DA81B2F2C6C7', '4602242008927', ' /// 0,53  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B81CE761-98E7-4693-A7E4-662909896038', '22F45BE9-C0AC-4CD3-8FDF-D6F460464CFF', '4602242008934', '     .. 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E527737-38AE-4A25-800C-0D4E5E3CCFE1', '057A104B-CE9C-42DF-BF2F-397A41FBFF7B', '4602242008941', '    21  11,0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB525ED3-ACF7-4567-9527-A515B754A379', '79AFD7FC-5685-4CC1-9D38-C6739C1C34A1', '4602242009054', '   .   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A133B7EC-0AE9-4615-B08B-79D2C06B77E9', '8106389D-540F-44E1-B2EE-05D1EE2281B0', '4602242009061', '    6  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A40CFA0A-3555-4EF5-A7BE-8F065B3C7D32', 'B4925634-5257-4B14-91BD-5A35A7E46AFB', '4602242009078', ' 5% "  ".  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33BD5909-2E50-4BBD-BF85-D5539C0A62F0', 'B5D0DA13-8B4D-49E0-9BE7-999E5EFCF7BA', '4602242009085', ' ?  .   30  2,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B563605-1605-4510-9721-11C820D9844B', '53859443-C824-4A6B-BED8-F66C126B6D39', '4602242009092', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D115FBAB-E4CC-4EF3-A789-A51807D04254', '30D99DD6-2485-4ED4-85C5-A1DD80DB309C', '4602242009108', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('096C13D5-6A30-4E29-8EE0-5C59D1231807', 'AE73D52E-68E9-41B8-B9CD-A777CC1555A4', '4602242009139', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC12F81B-D528-41CD-B9C0-4A984171688E', '63C93A3C-15AB-4A83-8D81-A28473AC5DD0', '4602242009153', '  10  6,0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69F12AFA-535D-4A85-923E-4BDF776A8403', 'D6D49211-E7C8-40AB-BC68-D04C6DD0A3A4', '4602242009160', ' 3-6-9 1200  45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2285DA69-8033-4E2A-9413-B7BB3291DD73', 'AF3EBA3A-4CC4-442D-9E29-710F3403705D', '4602242009184', '  500 . . 120  0,53 , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEFF2B48-6922-4B71-8B90-107AF0A95FB4', 'E98A5564-828D-46E4-AD1E-5955F8DC6EE0', '4602242009320', ' 0,3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4C7CB03-387A-4D8E-831F-85AB1A9DFFE9', 'D5E6BC48-6FC2-4319-BDC0-C4B89208B66F', '4602242009344', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8335ACF1-ED46-4AA2-A5A6-5A4BB8F270A3', 'C0CE9DC3-4374-4538-9EF4-CFFD6C6FA349', '4602242009351', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('618E524C-01B9-4404-9636-B500177783AD', 'FC596E7C-7E5B-4780-82C4-64FA0C600C9D', '4602242009382', ' .  1,2 12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E83B5CFA-D11B-452D-88AB-15ED30CE17EA', 'FA52C562-80EB-4093-92C8-3192ECDDD738', '4602242009399', ' // 0,75  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE5B9684-CE16-4C94-8CA0-B69D6FCEFCBA', '028F0702-9D60-453F-B468-F01106E3E502', '4602242009405', '  / / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADAA9F58-2033-4AD0-8C75-89CBB04D77E5', '86BE68C9-6EE2-42A4-A590-201B4BE8179E', '4602242009412', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2BBFDC4-A61F-40CB-838B-0A46317F2ECB', '02447BDF-A7A9-4D98-9DFC-F7F6CA7A7A95', '4602242009429', '     / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E303419-6398-4E4E-9DBF-E27366A8EE74', 'A5BBEAC0-FA43-42EA-AC51-26BC86535375', '4602242009436', '  1200   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73AC6435-5D27-4CB8-9018-8CDD304600E3', '75095EB1-3688-42D5-BEDF-D85522713715', '4602242009504', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE8AFC73-5C08-4060-8255-CF2BC8174FFC', '6931E817-CBA0-4158-AF5A-2760A2051178', '4602242009511', '   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2425CAE2-607B-451E-8C61-C7CE33E9A97B', '847DAA55-084E-4B19-8240-3E55EABF8C5D', '4602242009528', '    / 20  1,2  (24)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEB1A540-D6F8-423B-9F8E-49798129E77C', '3DA0E06D-75E6-4342-9640-C65FAD6827CC', '4602242009597', '   . / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E27C444B-11AE-440C-BDBD-627A1F3E99C2', '76D0B8D1-E4ED-449B-93A5-D5463375DC77', '4602242009603', '    . . 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3313366-A71E-4AAB-B720-B7066B7E8F4B', 'E774A96F-4418-44AC-8DED-F0D091253B91', '4602242009672', '   /. / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71E63870-2234-4E8B-81A0-1C725F44F133', '661B5E34-EDC8-4902-A8B4-38DC905B619B', '4602242009689', '   /./ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F33064A2-C3C7-43A0-90C6-A09BBEB961B8', '7094E835-BF07-448C-9E30-356946CBB168', '4602242009696', '   / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A0A452A-3A00-428C-804A-757A122595E5', '0D738287-2A7C-4FF6-859D-BDB5F465F956', '4602242009702', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47BFC157-923B-48A9-AA12-B4C070B76486', 'B21E70B8-736A-4D8C-9E58-6DCC17AD3511', '4602242009740', '  1200   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C896834-5E23-45EF-9A03-5C4A8A3F6161', 'C146CD5F-11F7-4933-92E1-BD341D81B967', '4602242009757', '  . 60  0,25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('322173DB-7E29-4DF2-AC72-7D5A5879E230', '09958E8A-05B3-4FE3-A048-CA35C9E90B08', '4602242009801', '+ . . 60  1,2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30D9B70F-EDE9-478B-B706-921A0D5873DC', 'BD35AFDA-2BC5-4315-A4BB-827A92094EFD', '4602242009818', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAB116B4-1FA9-4BCF-A54D-EBE01B70B7BA', 'F587950F-235E-4FEA-BC8E-5F819C098CB3', '4602242009894', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F76E7B79-6843-4310-B990-EA9294995117', '3D9BF911-1F93-47B1-9162-1EC038E63850', '4602242009917', '    1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21FF9DCE-2595-496C-8478-C5B576BC4B6C', '4A45A8FA-E594-4CFD-8A4D-BC1A122E3680', '4602242009924', '  500  20*', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DECA322-3D19-45B3-AEB9-FA63D59EE340', 'CB920983-7154-4859-A70F-7A409D730F38', '4602242009931', '  2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D0E1B57-8776-476D-ACCD-B4DF6C2EA3AB', 'B20C872D-8C8B-4C6A-A0DF-B36CF91B5A87', '4602242009948', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B3E0133-B985-454C-A86E-DA2B0177315C', 'AC8119A4-9BAB-4DD2-B063-E071142B8382', '4602242009955', '    1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1673BFBC-9817-4E6A-A2CD-DC15572201E0', '1760F5E2-CE8C-4C0E-8763-89CEB0A65D20', '4602242009962', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E81731AA-D21E-4F04-8A5A-C27E74DFF364', 'B431AA01-D8B1-43E1-950A-60C4BCE65AF7', '4602242009979', ' 0,4  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('743D7DA3-C8D1-4AAB-8B74-2CC558A0513B', '86BE68C9-6EE2-42A4-A590-201B4BE8179E', '4602242009986', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB108D8E-C049-47E7-8280-E46501DFEEEF', '9B41EA03-4A89-495C-B588-05E4C38AFC8E', '4602242010012', '  0,25 //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0F1FC53-6B2D-462A-9ABD-BE7993B3B6E4', '6C65C782-D267-4DA8-A2AE-84F4329D8F43', '4602242010036', ' 1%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('568E2EA8-EE0D-463E-9BAD-C9715ADB07C5', 'D6F47471-7276-4FFB-94E0-B19EB4966D8A', '4602242010067', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32AD990E-992F-4E03-95AA-35B0D4EBCB08', 'A4E59925-FAE5-4931-87A2-0575113871C8', '4602242010074', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A776D54B-7FE7-49DB-AF45-5FBF1907A9B4', '0E2B3B7A-2C7B-4269-B613-4161A5434620', '4602242010081', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E0CAA04-444F-443E-A3CB-2C4F10997DB4', '8F6EFF91-0B07-49E1-9D9C-1A8F0A1775F1', '4602242020042', '   . / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0CA3767-2D16-4EF7-9E7D-C4D0947F5201', '1B6F5769-75E0-4BF8-AA5D-6096E1FF711F', '4602242020059', '     1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52B56C03-56D3-4F35-98A2-50F6DEABA08B', 'DBF53FE8-5F77-4C35-8C6D-E88CA5ADB720', '4602242020066', '    3. .  30  1,0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BF27BB5-940B-49EE-96A5-ABDBB6DB8595', '761BD9F1-A326-44FE-9479-364EA4B15FD4', '4602242020073', '  3 950 . .  30  1,3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8398AF07-8593-411A-ACE0-01FD20919CB6', 'CF09EDF0-FDB4-4779-A606-6082FC39D065', '4602242020080', ' 0,58  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65B9893F-8AC3-4FD1-B6D0-2213FEB19E09', 'BFA54AC1-AD85-44CB-9CDE-1F208258801A', '4602242020097', ' q10 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB963A08-EBC4-4CFF-82D1-1A48FA48BB23', 'E28C2899-5B69-456E-8A53-408258DEFD33', '4602242020103', '  0,4  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('050794D8-A4E0-476B-A6E1-305904DC6828', '81237FE9-01A4-42EA-93FA-5659CCAE1E88', '4602242020110', '-  100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD4C1C64-D3FB-46CD-BE04-B64B4803A832', '98921D6B-CA29-4DC6-AC6B-8B4C734B6604', '4602242020127', ' -3 700  . 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('922E9FAA-5398-438B-90F6-2B07197DF687', '23E5D50C-A02D-43AB-AF78-D15BF7C61A47', '4602242020134', ' 250  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01F1BB0E-AE4A-4A9E-B4BB-D0E11A519BB3', '2DCFE4F8-5A69-44D7-A616-BE088A547EC3', '4602242020189', ' +.170  510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C20FB5F-8585-42C6-806A-E5EAC8F91C04', '4E707ED9-8EB5-4C68-BCA6-AB23373EC3F5', '4602242020257', '   . / 20  1,5  (24)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('165AF42B-3B8B-4D6D-90E8-0C01F2E31B19', '0CC0CC39-AB52-446A-8FDA-CB026017782C', '4602242020264', '   1,4  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B7203BD-5EB9-4D95-9BC4-0168A114D162', '5F70DA00-1D07-44DC-80C4-7BBD4A55FA40', '4602242020509', '   1,3  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0E42360-DDBB-46CD-8614-0CCE41A4760B', 'E98A5564-828D-46E4-AD1E-5955F8DC6EE0', '4602242020578', ' 0,3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57713486-63C4-4E58-A408-6B329C87FA80', 'F4BED4EA-9651-468A-A97C-32743D657839', '4602242020585', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53998177-1760-44AF-81FC-1FEDDE90C62A', '716FA0B2-6265-484F-ABDC-645D7360A114', '4602243000081', ' 2%  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83845EE8-9617-4AEF-A823-04681BE9AB20', 'A7DC5B06-E57E-4ACA-A375-ED77B186973F', '4602243000241', ' 2%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D485AC9-8270-4299-8268-18B34BB8DA9F', '1535B687-A12B-44A0-9320-6BB8036524E4', '4602243000401', ' 2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2A88323-7D52-48BD-ABE1-FCA05F182B3B', '37334974-1A84-4F69-B8BB-886D78C43BC6', '4602243000579', '- 150   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E0B2AF5-D803-4129-A8BD-CCD2EBAD6BE5', 'D525C31B-117E-45D1-A9B4-7F01D86C0A1D', '4602243001040', ' 0,02   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5919EDEB-4DE7-49E1-8363-D1273E8D125A', 'F51C8B44-FDBD-4F8A-8277-FF3C326D6E3D', '4602243001118', ' 20   //   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BBCFF51-29B8-4B11-B560-9081BEF43511', 'F396D8A9-2606-4700-B92B-4D281C1AFC6F', '4602243001163', ' 1 30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('513205D5-436D-44D2-AFEA-AC59C5BE3D35', '103C1A54-AEE0-4976-BF57-BCD1B992A0AD', '4602243001217', ' 100  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1971875A-12A5-4722-8F1E-F6B389B0E9EF', 'D71B87D1-5147-4E4D-90B0-9869202F4180', '4602243001309', ' 0,01 / -/  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BAD35AE-298F-4D48-BF06-26DEC41BD8D5', '61B120DC-B60D-4C4D-A2A8-4CF3C88636CB', '4602243001521', '   +20/24 150 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D192008-6AEA-41BB-B4A2-9B91A499B57B', 'AC830E14-876C-4FD6-9F7D-0143630C5DC7', '4602243002399', ' 25  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66C02DBC-52E3-4464-82E5-CD78C281DA8C', '749D94D6-D1F1-41AB-A61C-01D430163E75', '4602243002412', ' 50  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AD67AEF-BF11-4913-B171-320421CA1714', '0E08DA4B-565F-4D63-A2E2-F39D7D6D1CD0', '4602243003518', ' 10  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C25FD029-31EA-4AB9-B107-F1637FF458F9', '89541B17-E3BA-4248-B713-FB872A76CEC5', '4602329000042', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88AA5ADC-FC09-4AC8-A4EF-A14F4212573F', '24D4BA83-3B0E-44A3-97EE-BC43CEAA86A5', '4602329000066', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7FB3E37-1336-4E45-8A84-55E01D29968A', 'F9FDCCD5-9115-4C88-B52A-A921FF96587C', '4602329000578', ' 20   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('879B2003-2D08-49AD-A682-08BD36BD693D', '2AD94232-8847-4C63-A431-6D58822B7C8E', '4602329001049', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E3AA79C-6F21-4D0B-AD47-EB5568FEFB1E', '612C61BF-3773-4148-BB58-27B14A7CB4DD', '4602329001148', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89D8D45C-A0A9-49E5-9E18-F5F3951CEC95', '7A3F56B3-E55C-4AFF-BE56-1173500EEEAE', '4602329001155', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B3B23DC-B288-4293-A680-1450CD566429', '3734AA2F-A557-44A9-BF99-B2143F7F2B2B', '4602329001247', ' /.  .  0,2%  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5B17A70-AC7D-452A-BC29-1DF65E781177', 'AF2BEFDB-C438-4156-A57A-918AAD72EA15', '4602329001339', ' 0,2% - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97857E3C-1199-46C1-9503-569F3B108C46', '89541B17-E3BA-4248-B713-FB872A76CEC5', '4602329001384', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E6BC407-DACC-42AD-94F3-AF7C48A358DB', '898F9475-8694-491D-9745-CE26D65A3091', '4602329001391', '   250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE1491C6-4D11-448D-945F-912D97CC2800', '908A10E6-5224-4306-BECB-71B21F60B4EA', '4602424000053', ' 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E005F27B-FA60-4E77-8F45-282C0350415E', '9A17E5BF-343E-483A-8F93-B27F8A98211D', '4602424000251', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DA001CD-5A93-4093-B7B3-4427F59B878E', 'ECFDCCEB-C5B7-4A5E-A3F7-0596FF56B558', '4602424000299', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E405A97-9E4A-4D80-8644-E3E3104FF635', 'FCECDB71-DDBA-4033-817A-B20E748941CB', '4602424000312', ' 20% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1E205B2-2FDC-46F2-9243-0565B6E9022B', 'E66C79EC-DB59-4932-BC8A-1155BB21FB26', '4602424000442', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9761BD6-49D8-4CA9-BCE1-C59DA89733EB', 'E24046D6-DE69-4B6D-ACF2-022DD1CFE5D1', '4602424000459', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C49A319-DDB6-4500-9030-1ACA377FEADC', 'F65D2D5A-4147-4562-AF84-E3375E6249E2', '4602424001005', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A671B52-B2BA-460D-B807-BA54E7291AF8', 'F9649F8F-E801-4478-9D1E-5425A3133F04', '4602424001067', ' / 2% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBFC3FF4-E523-4DBB-8663-D2DFC1C18986', 'CD4F275A-68F3-4EBF-AD8E-EB72C511FD3C', '4602424004501', ' / 10% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13BC63FA-52A4-44D3-975B-20C40452930F', 'C5F0BFE2-9EF9-49DB-AA02-C658B55D0E51', '4602424004778', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CE0E3FE-F2AB-454E-8877-22FDB3D94720', '8E8877B8-AC1F-472C-ADAB-3D14045F1A1C', '4602424005270', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86F0B112-810D-449D-A2D1-DACCD9B73C9F', 'DEEF506B-DE83-4CBB-8DAB-FDA810401698', '4602424005324', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('072DE0CA-E958-40FB-8305-BF7FFB7F1233', 'C712F775-BA9A-4A9F-9E92-EA7291F5E206', '4602424005430', ' 0,025 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BFEFC5C-8EBD-45C8-9963-35F1CECA4C12', 'EAABE21B-C9EB-4C05-AC33-1C4555D07091', '4602424005454', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02B5D228-2454-4FA1-B97C-4BC863D622AC', 'ECFDCCEB-C5B7-4A5E-A3F7-0596FF56B558', '4602424005645', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96E37876-2A19-471F-8571-A293988D6D5A', 'EF3FC955-9E67-4956-B8DB-72E5A6D8C87C', '4602424005683', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6D0493B-B969-4751-8D92-F7250271EDA2', '11BE1C5E-4A19-46E4-98BA-D4614CAB52AC', '4602424006079', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58044F65-08EE-4C54-8DBB-FC77A4EA88BC', 'D439117B-E4A2-4ECF-9614-543088EA3347', '4602424006222', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26962137-70E8-42E8-A784-2F883E55E6F0', 'CC6DC222-EE5A-4E23-8846-B8E22583897B', '4602424006956', ' 250  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D70CACE1-5903-43BD-8E66-4CE33A1FA512', '3DD91AE5-B567-416E-AF04-8E966A1C2CCC', '4602424007076', ' 300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2A9E979-193A-434A-ABD4-DC7813C851E9', '43F1A00F-34A3-4B28-AB8D-B86972F587CA', '4602424007175', ' 75  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E3A41EB-7A67-47F3-AC48-7342B803548C', 'CC6DC222-EE5A-4E23-8846-B8E22583897B', '4602424007199', ' 250  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC3DD3D7-BE94-4061-85A3-740BD6389881', 'F048FD91-863D-42DF-BC6A-0DCB408A1F6F', '4602424007212', ' 250  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1166C7C6-FD12-49F0-BD93-835D872F78D4', 'E0C3042A-F308-4C7C-BF3C-230E15C7FB4D', '4602424007946', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E794354-DD44-4C98-9195-1B9E4E819970', 'C1BB081D-4627-4C3F-9427-F86ACCF9211F', '4602435001063', '  5500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CCC586E-B733-4E4F-BE12-65D05D312595', 'FA10DD20-48B3-4229-9D48-D10F4D70D67A', '4602435001100', ' 1,25500    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5212996-9708-4002-85D8-EF299B5123F5', 'C2C1D1D6-E369-4CC4-9A7B-D43D05349B99', '4602435001117', '  2,5500 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B86FE08-8FD7-405C-B371-81B4B77BAA6F', '7B0CFB09-F87C-4010-8C84-083F25629973', '4602435001131', ' 1,25500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C381F0E-156F-4A04-BE5A-4E364121294C', '6945C83F-5A33-4341-A342-9CED7D97F2C4', '4602435001148', '-  2,5500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D285944D-F6EE-4DFF-A766-20F72E135689', 'D2228973-DE0D-42BD-95EB-0A62FF967E71', '4602435001186', '  5500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AC62655-CC4D-4ED6-88E3-12230647DE8D', '3397D4FB-5288-4F32-A924-F5791026C5C6', '4602435001636', '   10500/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35249E18-53E6-4B64-AA4A-065FBF568331', '547151A8-79C8-4D50-87E1-0837227CE0FC', '4602435002282', ' 1300   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D12F625-CB17-4FCB-B3A2-0E0AA77A40A1', 'F78F76A7-18EE-4343-9172-5A04DCB69C43', '4602435002329', ' 2300 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('146F7BEA-F5C8-4837-AE52-63BB72AEC2DE', 'E906E5D2-34FF-4986-9FAA-D3FED9324900', '4602435002343', ' 3*300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7E06C77-F545-4E86-9B88-553126ABFE45', 'EED52E21-BDFE-4A79-9EC8-3FA35FE2232F', '4602435002749', '  1,97,2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B2D74E3-5188-488B-A597-7E48A5E9128C', '2D357761-5513-47A5-AE48-D74AC9FE194F', '4602435002763', '   2,57,2   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7A25DFB-D44E-44F9-A094-1C581D05CF53', '55B6B1C2-DA75-4EBA-B3BC-3CB12323BBAF', '4602435002831', '    610 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CB4B8BC-AA54-4375-B454-F585FE545A9A', 'EE164F99-809F-4DBB-9029-4026F59EADE1', '4602435002862', '  610  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BD40016-C273-4C56-B376-0D1F0C7CAE6E', '20366D0F-42AA-4E8D-970D-845A11C886EE', '4602435002886', '/. 1,97,2 .  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BF44872-E361-4BCF-B31C-D3D49F8E2DEB', 'CFA9066C-D919-4BCD-9C35-89D1D7BC11B0', '4602435002909', '- 2,57,2    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('070FFCC2-C722-4E7D-A72F-2F205F1FDCA2', '4368FAF7-8F98-4C26-8B32-27D1C62C5E1D', '4602435002923', '/. 1,97,2 .  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C509E8CB-EA8A-4EF0-AB83-E8F59BE10E8F', 'B14D138F-1AAF-45BF-9B82-28BED26C9A01', '4602435002947', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('373272DE-AABE-4D5C-93A6-6AF68AF55EF1', 'EF2AA6EF-E0D2-4EA5-BAA4-3E96C8051CB0', '4602435002961', '     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5FC0CCA-D7D7-4285-81DD-B1E8AA048139', '7565A4CC-6958-4263-81EC-3328FAB9D734', '4602435002985', '  1,9*7,2 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAC3CEC6-BC39-4E64-9FDA-E8F2980144CF', 'C69038CC-5C3E-4CC5-92EE-3980036CF99D', '4602435003968', '/. 1,97,2 .   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('793829BD-DBD6-4B6E-A153-1CDCE24C2C0F', '2A0E84A1-750A-4836-8781-713F0AA11EB9', '4602435004002', '-  1,97,2   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFE9A555-5709-4F86-9AD8-66A1ED74C272', '50285C9E-BE38-44B4-8A54-15F29CF8021D', '4602435004286', '  1,25500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D40278C6-A499-4CA8-BAE3-89FB47D279EB', '7560D4D5-844F-423F-A409-49961738FAC0', '4602435004309', '  2,5500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B235F93-759E-427D-AEE0-3C40592D4876', '583CA912-6F45-4583-8A44-A578528C4824', '4602435004323', '   5500 / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39CF1F88-4F4F-4631-ABF1-E62684A023D1', 'E00E9E58-F992-42BA-91CE-4B90677B85C5', '4602435004439', '/. 1,25500 /  ./', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A392D05-652C-4C8D-B319-A4E060C04557', 'EF3C9974-3C76-4462-BFE1-573EB37306A6', '4602435004453', '  2,5500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6B09656-A7D5-4EE1-8D50-FCA4045D28B4', '6D15701D-E9A5-45A0-9954-5DE006FC636F', '4602435004477', '   5500/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9D75BEA-2C4B-4971-89AA-0359F33D388F', '37DEC231-51DF-4D17-89A0-932D909F2E17', '4602435005719', '  1,97,2 .8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0662B6AF-556E-43B0-A8DF-6D167FAEBB51', '5FDBC17A-717C-40BC-AE9F-48B6266D8FEF', '4602435005733', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BE80F6A-C471-4A17-9A5A-21A57CF6637C', '0BE08E03-4744-4A62-8E3F-6099E6E1D2C5', '4602435005887', ' 1,25500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B85DC05D-63C4-467E-ABBB-D7220762249E', '96C201A0-B1A7-42AD-9C6B-0A87ED1ABE0A', '4602435005924', ' 2500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB1C27BA-7029-4558-8580-6387A7387BB6', '4CBF1CFD-7D56-46AD-B59C-9675F30D8563', '4602435006006', ' 3500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0107BEB5-3926-4F20-9E9F-00B87A6A5C69', '55EB217F-A060-4B26-B0E2-AEA4AF81D0BF', '4602435006044', '  .20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94D1348C-A86F-453B-A6B6-AE6B717D1FAA', '742CA25D-CD70-4365-AA94-6BDCBE070EAF', '4602435006211', '   . 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59AE23AE-402C-40EF-AA9F-0802DCD70789', 'FA7CE7F9-5EE5-4149-B7D3-A5E0CB22EDEE', '4602435006747', ' 1500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC40C785-6AE4-4CE5-89BB-CF915D54DBE7', '50CF70A4-0B1C-43D3-A35C-D3BB46A508C7', '4602435007072', '    1,97,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61E34DF8-5BFD-48C5-B9E0-4671A3B24AA4', 'E1F24A55-E97D-4237-AA8C-53C1EDABE49C', '4602435007133', '    2,57,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2A684C0-E6F5-47A6-9452-B2406F206A4C', '9EDEE437-4855-4A3D-B468-5B65A6C69E64', '4602435007393', '     44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7F103F5-BBFD-43A9-98A3-371B1BFB6C29', 'B511BE4E-69FD-4EBB-92F4-7CBFDB64401B', '4602435007416', '      55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ED9553F-DCD7-434D-8421-2DE56669B79F', 'CC922A5D-4975-4253-9859-6F44DA409439', '4602435007669', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09F7C5EE-0077-4E90-89CC-29AFB180EF9D', 'DB33751E-DC6B-436E-80B8-9E46E0F26261', '4602435007676', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A621D62-6A67-4281-ACCE-6868246E9FB5', '932F3F25-1A5A-44A7-A5F5-E572EED17B43', '4602435007683', '        20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7EEE48A-3F31-4384-BEEB-AE1E982B48B7', 'A83C6F50-96F6-4633-88CB-B8C113F2ABBB', '4602435007690', '     / . 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68B52C6D-D75E-48A2-BF2F-7302262FC650', '2A54A527-AB98-4DB8-976F-3ACF757C03FE', '4602435007713', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EA7B7CB-152C-4090-A939-9534E12CA9D8', '53E82DF5-0349-4839-AA94-925691B19BF1', '4602435007751', ' . ven Lab  .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAEA6057-E1CD-43BE-8FFF-C062547253EE', 'DA1CE521-5D2E-476C-A3E4-6F1CF8E4D637', '4602450000041', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB824806-704F-4E5A-8A65-04F2FA23DFDE', '263DE21F-12A3-4FE1-88F5-4AA87B477610', '4602453002790', ' 0,5%  -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D8F11FC-6BCF-4E0D-807D-6D96E243B590', 'AAA759CF-4CC8-4487-9066-7F2F983CE88B', '4602453004268', '      141200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EF2E67B-53D9-46E9-B12F-96EA01F1F70F', '8FA382B7-D731-40F1-A834-784BDC00B22E', '4602480000899', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A054343-D896-4481-AFF9-B28EFC21750A', '6524E7F8-4089-49ED-8382-5866BC388C31', '4602505001481', ' 0,02  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B00F8BE9-7C62-4623-8ED2-CB22A4294F93', '74CD925E-6B56-4EA2-BFAB-E81B664F46F7', '4602505007421', ' 0,5 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F5988C1-711F-47CF-90FE-C3FC40945316', 'AD2B8725-0501-4ABD-BC76-7F9E3B7490EA', '4602505007469', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('176675E8-059C-45BF-A2F2-8DE078BEC376', 'F723074F-547D-4B1A-A708-142123FB152A', '4602505007476', '   8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDD88DF7-8C8A-4AFF-9061-E8E3067680D0', 'F1B9DF65-689B-4824-9C5E-25A7679B0142', '4602505007650', ' 500   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6A49E5A-59A1-466E-8409-9C823D41908F', 'AAB2503B-F0AF-4710-8A52-860169201E43', '4602505007735', ' 2,5  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF08E13D-1EB5-4D43-B238-8719420A742D', 'E527FC44-587F-4CB7-949A-C8689BC7B84A', '4602505007773', ' 0,0025 //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A792FC5-CDE5-4AC8-9CF2-7563EAD314A6', 'D84A0F7A-050B-4A9D-8180-0C4F38759013', '4602505007988', ' 0,005 //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5308F1B2-F6CC-4065-A1D2-17E92731B148', 'D9F6B068-D6E2-4B40-A709-9C53A335B304', '4602505007995', ' 5  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08E4F8E5-C369-4454-B4AE-E2A5EA1D6215', '0BE74D08-7E3A-4C0A-B9AD-17C616B6A25E', '4602505008251', ' 80  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F93F8ED-F1CC-4F32-A7B1-9805BD12B649', 'CB88B626-70CD-44A5-B140-A03EECF45842', '4602505008268', ' 150   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67BB7721-D4EA-4D97-A663-103E3617B929', 'ADE1622C-6433-4808-AC31-D4F067E4F1DC', '4602505008275', ' 300   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7251F02C-11E7-4186-995B-D0EF086B85D5', 'CB88B626-70CD-44A5-B140-A03EECF45842', '4602505008411', ' 150   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E30DE685-CBEE-4CF6-8F7F-03617C8519BB', 'ADE1622C-6433-4808-AC31-D4F067E4F1DC', '4602505008428', ' 300   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06B3BB34-7A87-4566-AE12-4368C4388851', 'F1B9DF65-689B-4824-9C5E-25A7679B0142', '4602505008435', ' 500   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4060F2D-284C-4A28-ADF9-E51535482DB3', 'E059AD98-C4ED-48A8-BE94-F035FA273351', '4602505008442', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DCE7BB7-BA81-4DE4-9A11-970B5CD56EFC', '6E4A8618-F42A-42EE-9BC5-0B21EE0221B3', '4602505008466', ' 15 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4058BBA5-E36E-4BA9-9155-2A9628B18AB7', '31638A21-3540-4065-93B7-71572B32EDC3', '4602505008473', '   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4823CC89-D29D-40C2-A5F3-96051686ADB5', '06096B1A-3142-49E8-B587-C00242DA98F5', '4602505008480', '   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BEACFDC-26D8-484D-A064-82CC6ADBA913', '9F074024-2EC3-4A43-B8B5-6374E3961425', '4602505008497', ' /   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B925C10-E925-4332-87B9-53A98AAA6B65', '495CBD0C-5FFF-4CB1-B34A-730510FFFB7E', '4602505008992', ' 0,015 //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF4F7A14-EC66-444C-A80E-08AD850F9168', 'E65DF0F0-41AC-4103-800E-0FA3C865DCC6', '4602505009012', ' /  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('438877DC-5AF3-4D39-9B4C-182FAF08E9A2', 'EBEBCD7F-59DD-483B-A53A-95666AA53364', '4602505009029', ' /   12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D38B609-BC93-4563-B580-645F796E98A6', 'A20D7BA0-677D-4CBA-B72F-41697A535950', '4602505009036', '       4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D56F2D5-E42B-4C56-AD27-B0C5D309964C', '4E1DA2C6-734B-4440-A984-699417367FA2', '4602505009043', '  /-     12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C10AE9F-96D2-4A4C-B904-3AC1D17C1FEE', '6C2E82C5-76AD-4B2B-9467-AD956A7AF9D4', '4602509000282', ' 6% 400 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55CB3855-D6CD-455C-BD64-ECBF326ED8EB', 'D5316770-0703-40EA-A668-F31DB81A4C1A', '4602509000305', ' 10% 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEF2648C-A65A-48E4-B6C3-32E29B09B012', 'D54C84F5-3B61-4E0C-A719-8EF3F04F7EBE', '4602509000312', ' 10% - 200 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99C3A636-95BD-475B-B826-E5445FC8C862', '6AFE6F38-83E4-43EE-B7B3-463A0B408F3A', '4602509000329', ' 10% 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF46DF53-A60B-49AC-B9FB-2AEF72A7ABEE', '64230AFA-0F09-4E81-9D2B-7E3BD08A4B6C', '4602509001166', '   1% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75CD9B8A-C066-4D7A-9766-155E9421B1C5', 'E5A42E2C-E784-4C54-B24D-06C146DB2A3D', '4602509001227', ' 100. / 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEF24045-9A45-461A-8CD0-E71E0EC9A0DB', 'D54E0678-93D1-4678-BD0F-93DAA01D0AA9', '4602509001258', ' 0,025%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('252ADE84-FCD6-4EE0-8520-D07E2A807ED6', 'F6E5A801-6F2F-4553-A51F-D5BB78AB0154', '4602509002064', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A423DFD-0D76-4926-A72C-FA05C4651CF1', '3FBED1BB-F155-4A1F-B0C0-834EC437D327', '4602509002088', ' 0,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DF79152-F7AD-4AE9-81DF-91F8B4AA4707', 'D588D9AD-5445-4B55-9972-7B5D60968DEE', '4602509002613', '  10% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4102833-C04C-4255-B733-30FD0A49D851', 'FC342286-453E-4E4D-A088-FDFF404648CD', '4602509002736', ' 2% 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B5AB491-E053-4DFA-8836-D312A15FE02A', '347D1996-074F-476A-952A-2F46C8728F46', '4602509002835', '  10% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DC3F72B-20BE-4791-84C5-11614DC22702', 'F9649F8F-E801-4478-9D1E-5425A3133F04', '4602509003191', ' / 2% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62FF2EE4-9B4C-4EE4-883C-65EDBA9CFB57', 'FFE18781-61EE-4C01-8E2D-3E942D63322B', '4602509003399', ' / 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0CEA110-8F54-4FE2-AA35-D0A8255C35BD', 'CD4F275A-68F3-4EBF-AD8E-EB72C511FD3C', '4602509003450', ' / 10% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A4E7BE1-AF7F-4BB3-B2B3-0D8D84F1B0A6', '41DE5EE3-B509-43C3-8C26-58C043C7F4E6', '4602509003993', ' 1 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D8C4346-8561-4354-9EA5-69B0332D91E6', '878BEBC9-8D43-4B55-86B8-2ECB1CF91D24', '4602509004006', ' 1  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED751144-6E4B-4D4B-BB1B-6B79B40107B0', 'EB3945EC-0FA2-4DC1-96FB-E7062105041B', '4602509004198', ' 1% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D7F6A20-4F78-4740-8885-68F91A329AC7', 'F1843F40-68A7-487E-A1F2-7649D91EE4D4', '4602509004334', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('370FEAB1-D0EB-4D49-8D19-97176E2B6B09', 'B9DB7647-9681-45EC-B0B2-C731CC44EAE6', '4602509004600', ' 1% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48EAAEB3-2A59-436C-BEC6-423CF59FE937', '5EA112A5-3920-4594-BD09-12C5C419A15F', '4602509005140', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80E1830A-6A06-4A63-A2EE-16DC8A4F0A9F', '92062739-E0E9-4161-849E-3498C429E180', '4602509005287', ' 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C2750A9-64D2-46FC-BB3A-C124C5B2DB9A', 'E66A6B11-DEB0-4E4C-BFEB-43CFC1428D7C', '4602509005294', ' 1  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F39C2D2-387D-4559-8751-BD734D9F54E2', 'E4CA84AB-C264-49A6-9739-C947C52E0A01', '4602509005386', ' 2% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4192FD0-EFEE-4F2D-A782-3F5A183DC0B9', 'FCECDB71-DDBA-4033-817A-B20E748941CB', '4602509005447', ' 20% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DD0E706-2274-4FAC-ACF2-36C3CF32C0CC', 'F81D7286-6BFB-45F6-937A-4314C8D14CC7', '4602509005768', '  25% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C51123BF-F710-45C5-B975-A225040EB32C', 'F2A5F6B6-51B4-41DB-87EA-2B095D29AD06', '4602509006420', ' 5/ . / - / 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98C48B2F-3A45-4E93-A031-E2691287CFC5', 'C46D34B3-5447-4604-A879-72790ED2AF95', '4602509006499', ' 2% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5A4173A-0D21-4C6C-8C76-10604E3DEAC3', 'A4FF1431-EDD2-4DDC-8743-FE9743EAFD0C', '4602509006628', ' 5%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18098AA7-82C7-4726-9534-47DD950EFD9C', 'B13C4E81-6E57-41DC-93A2-1B5A7C39A34A', '4602509007885', ' 1 1 /- / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78FFE5A2-E3B7-4DDC-A55F-C05E71DA06E9', 'D25BD6F6-EF38-4E8B-9A35-342BC349CFEA', '4602509008226', ' / 2% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C22A052-E0E5-487C-B794-31BEDB123646', 'D2AF3F39-4AB4-4D16-ACC1-9AA2222EE627', '4602509008264', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6F2B60C-0FF8-480A-8644-5AFB463ACEE3', '0539B1C3-16E7-4E6C-B831-C7307935D68D', '4602509008776', ' 200  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AC4C30D-63CA-4D82-84B9-F95C43853374', '55155EBE-17EF-42F7-A10A-D5152D35B2F7', '4602509008783', ' 400 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AFB22F7-486E-4DCA-B1E2-78E0729575C5', 'A35A5AA1-8611-4CBF-B781-F521C5CA5315', '4602509009797', ' 1 /- / /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('600333E3-1DA0-4E45-AA3C-C33159A6AE0B', 'E800D3FF-4463-4207-A7E3-930DE38C7966', '4602509011400', ' 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D83EBFD2-E493-4FA4-9B3A-574708A7C62C', 'D625B558-3250-43A6-A215-193B8BCA1C3E', '4602509011646', '  5% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCA1E8ED-B654-49D8-805B-AEBA38750B25', 'B418BBE7-1844-40E7-A3C8-188BEB6306EB', '4602509015033', '  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF0C6F3E-7E2E-47F3-9FB5-9875E7D47BD0', '11EFD288-CC46-4DA0-9790-8EA34DF41268', '4602509015057', ' 65+500 //.  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0576598-F0B0-4EDA-B424-30A4206F9D03', '90BE6146-C5F6-4B4B-96BF-0D3FBFD79E59', '4602509015293', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66CA6EBA-BB1A-42B3-B565-A18DEC1D86C6', '089E89A7-AB6F-4546-BD62-EA294BC415D4', '4602509015439', ' 0,008  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('169E0B16-DB3E-4453-A9E2-5483513D69FA', '328B84FB-510F-423E-98C5-EBD1A88894F2', '4602509015590', ' 0,1 10//   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E5A3E26-8E39-4481-8C45-90D4CD03D173', '8C2F8B55-9A4C-4E63-9B0A-7088E9A41AD9', '4602509015613', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ECA82D6-FBF7-439C-9718-6A4A99820CFC', '97AADB79-0576-4B6F-8D56-769589480907', '4602509015637', '  500 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C47F81D5-54F3-49AC-877F-4C1B307720DB', 'B878EA8A-0D4E-4231-9DF3-802B9D82771B', '4602509016146', ' 25/ - / 3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2B7F0BE-67CC-4F94-9040-7F9D7D4F04DE', 'C040541A-53AE-45C6-85E4-93B98C013EF6', '4602509016757', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC949735-74D4-47B1-A623-621BD5B53A77', 'DEEF506B-DE83-4CBB-8DAB-FDA810401698', '4602509016788', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D130C07B-3BC1-40A0-969F-C815E7123628', 'B4F9A642-B072-44A3-B29E-C36D7C15FAE6', '4602509016818', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E45B23D-C9E9-4D4F-9DA8-5275B6D4DB76', 'EAABE21B-C9EB-4C05-AC33-1C4555D07091', '4602509016856', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5311122-1AE0-4C02-9392-8BD689B68015', 'AE5BD1C6-FBB1-4BE0-B83A-607DD4440BBC', '4602509016870', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F285772C-5DCD-4163-8B84-888B9719AB67', 'BDDF1D1A-2B0E-442B-8511-E1D8675D097D', '4602509016900', ' 50 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1685274D-5D15-40DE-AA85-17797B10ABD3', '732188E9-456B-46C8-A366-BDB6D4F05564', '4602509017204', ' 0,0015  //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('735DFF04-70EC-44BA-B274-0B1DB9D1117B', 'C20827CD-B26F-4655-95AD-13949276C558', '4602509017471', ' 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2209AA43-247F-414D-A2FC-4C4C3578C1BF', '17758D8B-227E-427F-AC4C-EE4B02164D34', '4602509017501', '   2% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A457463-D39A-487D-8622-E720351651AF', 'F0A32607-F27A-45F2-913C-1B8A3DD1A841', '4602509017709', ' 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9F11C20-0228-42C4-AB28-F284B7835737', 'C3E27556-7F65-4576-A60B-CAAB568665CE', '4602509017747', ' 300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('942217B0-1153-4B59-B067-1225BB0422F3', '03034FBC-A44C-4F2D-9F8E-5AC109AB818E', '4602509018232', ' 0,1 // 5 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16728D06-9557-456E-8AF8-808C6AC1EDFD', 'FDC428E9-B0F5-45D5-A13B-AAF3794149CB', '4602509019321', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25D40DFF-1583-40DA-ADF2-635B6C94BF1D', 'EDE107EB-0D43-4973-A181-3C001627B3CF', '4602509019338', '  2,5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01C5A7B9-4A23-4109-BB50-75FC52B7340A', 'D72D9EEC-C7A2-493D-AA48-CCDEC38CBC91', '4602509019420', ' 30/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C49E9892-A84D-4D42-B166-54821BA68061', 'D7D71C35-861D-453B-88B6-4C6D34E360AB', '4602509019819', ' 1,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99D38D12-854A-4A1F-974C-1C4B1D907517', 'AD881563-8B70-42A4-9DA6-43B306BE4AA6', '4602509019901', '   25 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D4A15E9-71A0-453E-9514-B9F937D57C2D', 'B1223618-E317-4F66-9F84-ABD6AFEFABF1', '4602509020082', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('521B9D0B-E293-4E58-A9AA-2FE914EB1280', 'EFAE4D1F-EB8E-4393-AE59-F2850DD5C1E2', '4602509020211', ' 0,5 /// / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A71E2B1F-A4B6-445D-8C9F-5E2661B9071D', '281EB0A0-77F3-4A38-B11B-A4E71FC743B2', '4602509020297', ' /- 1 / /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('011C3F34-8083-4F92-9C79-40F642EADF28', 'DC330F30-4584-4A58-90EB-22689571A5AD', '4602521000451', '  0,9% 200 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD2FDC34-99B7-4591-B596-00B650CDE9C3', '27FEEB21-DE8A-4D10-B472-52BDEA49212D', '4602521001052', '  500  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D32C25CD-6DFA-411B-BED7-AA41900A8E73', 'F704327F-1E32-4005-844D-31F889A9A205', '4602521001076', ' 500 / /  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60181D6A-2EB0-4ED0-98AA-268672DC527F', 'F126C3CA-494A-4D2A-A551-199C0501BB72', '4602521001847', ' 200 - / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D39C4B88-0F4B-4F1F-BBC6-25072E25B463', 'F126C3CA-494A-4D2A-A551-199C0501BB72', '4602521001854', ' 200 - / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAC5F882-F3CE-4251-8CA2-C21C6A055A5F', '6312D94F-B6BC-4E21-9A4E-567A8D09DFFA', '4602521001885', ' 400 - / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A44E7024-1D6A-43A3-B4CE-E17045455545', 'F1CE0542-1A45-49EC-8A14-CAD0E28F1153', '4602521002530', ' 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE2812B1-1D28-4C02-B362-14D378FF953B', 'E66A6B11-DEB0-4E4C-BFEB-43CFC1428D7C', '4602521003964', ' 1  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7619C42-F931-4A45-B6AE-25AD6806A4A3', '37D30AE5-DD6D-4B68-B302-6F1F865A3F1D', '4602521004510', '  5% 100 - / 48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65F52396-08BD-4F24-B901-91844B57F89C', 'ECC012A9-7375-4125-915C-65BC7E4F1838', '4602521004565', ' 5% 200 - 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C691B4B1-292C-46F5-B280-DCF37FD236B5', '71FC6DDB-79E3-48D5-91F5-595E8D65A660', '4602521004596', ' 400 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37BD76DE-E52C-4EE8-A5DA-DDEECA541A8D', '12D7E395-7C5F-4413-95B9-05AF824C444C', '4602521004749', '  0,9% 400 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79A643EB-711E-49EC-A619-FE0CDA44A529', '963F545F-78D1-429C-86B6-AFD0A2932C12', '4602521006163', '   1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC7046A5-5799-4AE5-B88B-B81B958E2E07', 'E7C4EB33-F144-44CC-94E0-5A3680922F30', '4602521006170', ' / -  / /  1 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D76ABCB8-5D9B-487C-BE7B-C1AB6D4864A0', '963F545F-78D1-429C-86B6-AFD0A2932C12', '4602521006316', '   1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E93C3932-6B19-434A-B611-F50A38A29E44', 'F179945C-37C9-402A-B014-8B2C083712C1', '4602525006015', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C34D9A3-8CEF-456F-A404-6B0E9B168E26', 'CB2E1A91-B2DE-43C9-A3C8-79CAD4DEA0F1', '4602546000184', ' 10%  - 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('808F28A0-E3F7-4786-8657-E19EBD103903', 'E2D8C62A-73F1-4067-9EA2-CEADF888A43B', '4602546002027', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7FAAF70-4FCB-4DF6-A794-9C382DCD39CB', '68DBAC7A-745D-4EE3-AAA5-F0AD643A1399', '4602546002058', '  30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E58B09F-1300-4719-B30D-C0F9DFCC3118', '72BAEFDF-26BE-4D2D-8B91-4374C37B974C', '4602546005554', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F2D827A-8E3D-454B-ADFA-D60E9DD6E28B', 'BF2C0017-AC70-47CA-B87C-42B1081F1D40', '4602546007466', ' 15/5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('781A877F-A86A-4F2B-9958-2A77281FBAD3', 'BBAD1E0D-EAF2-4CD6-9527-7B76EB95CAE2', '4602546008180', '  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F91270F-4ABD-41F9-AF04-6F8BD3BB00CC', 'D4B254B9-445B-4416-8FBE-68C2A6195209', '4602546009460', ' 0,1/5 100   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F157EDB3-F23B-4BC2-9B59-2721DB0D8CDC', '36639B9B-732B-421E-B0B3-D6D75BB7BC2E', '4602546010299', '   100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F334C89A-D443-4618-9091-8120471BC452', 'F283BC1A-BEAA-4A50-846C-DA98B6BE7B36', '4602546010305', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2DFEA55-BDDC-407F-AAB8-B12226CBF9C7', 'D6E70242-4532-4A97-B14D-5B5045C3827B', '4602546010312', ' /. .  / 40 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B226A9A-BBB7-4755-930A-E22F172CC724', 'FFB827DE-93B3-44DA-9852-D9C7687FB0C8', '4602546010336', '     50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F7E6792-1FC4-4D85-B086-043B164FD112', 'C689B254-1295-466B-AED2-CFFE2ACEA27E', '4602546010404', ' /   -  -/ 50 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82CDC522-0EDD-449D-BDCB-2A52B59A3887', 'A98A3762-B40D-43F9-B338-E6A6002ED9A0', '4602546010411', '  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9BEC650-D8E8-4CC0-BEFF-EA3C40A7042B', 'E2D8C62A-73F1-4067-9EA2-CEADF888A43B', '4602546010541', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D6CECAF-DF7E-4782-A21C-14915A763156', 'E2D8C62A-73F1-4067-9EA2-CEADF888A43B', '4602546010558', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF54AA90-B975-479B-B3D6-A2EAFDAD6D26', 'C6845EE5-41DC-474E-9D60-A6E67DEF11FF', '4602546010565', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCEB8DB7-94DF-4CEC-8F37-E50022816C2D', '98BAFCED-8829-4700-AFAF-1E6B9813E9E7', '4602546010589', ' 100 /5  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E77F827-8FEC-4525-ACAF-6A172E2C233A', 'BF2C0017-AC70-47CA-B87C-42B1081F1D40', '4602546010787', ' 15/5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED13259D-E9E5-47C0-B358-7BC1C2A03930', 'EF494027-68EC-46A7-84AD-D845BD7168D1', '4602565000097', '  50000  / - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D5AE9AC-28FD-41FC-BFFF-72583F3771E0', 'A0CED7AB-F3A1-43DE-BC41-7B627168D38A', '4602565000554', '  1  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EDEE78B-6FB1-41C6-A9E1-82967BB85465', '4A63C811-4350-4CAA-9B66-5EB119E1BA39', '4602565003142', ' 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09DABFAF-B606-4FFA-81F4-BAF6E2B53125', 'D2B40C1C-AD0F-42D8-9DA3-3973FF172D19', '4602565004323', ' 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9435910C-F703-4D66-A9DE-BDEFD535E223', '1FAB3BBE-C7BC-4DAE-AA83-DAEDB9D41507', '4602565006419', ' 200  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98E1D7E9-5458-4FFB-826A-F052C2572971', 'D9DDCDF0-DBDA-4B2F-9C6E-6E1EAA697604', '4602565007249', '   3% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97B89E86-E5BF-427F-90A5-E0E71C8645D2', 'B2C36F15-7AAA-4451-BD5A-D7D270201A8B', '4602565007300', ' 0,25% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2B7348F-2C43-477D-A514-10C7FCCD9169', 'CDCF25AB-84D5-49B7-B6E4-E3F6F7B46BA8', '4602565007317', ' 0,5% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0266309F-DA7D-4D3D-BD5E-C6F982D0334E', '963F545F-78D1-429C-86B6-AFD0A2932C12', '4602565007928', '   1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91B67396-1C88-4220-A507-8D70A3C00B4B', 'CDDED6DE-3218-4255-89EE-E2A290D54597', '4602565008369', ' 5% - / 250 /', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C0C96F0-D0A3-48E8-9747-FE600827DEF7', 'BA01E427-2FA9-432A-AF79-AFBF8A9E1B10', '4602565009038', ' 3% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D679A72A-A8F0-40BA-86B4-89D14885BF8C', '881E460A-6AD2-4EE5-BBC4-EA7EA5BB8EFF', '4602565009557', ' ( )6,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0B02170-DD08-47BC-AC6E-79C61B5D9ACC', '549155D1-F728-4B05-9DA1-F16C50052E5E', '4602565009588', ' 12,5 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87DC19C5-1483-44A7-9B5F-219D5A9E0FB7', 'DF873B57-4D3F-40F7-BA0A-2A647DA3C596', '4602565009762', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D965BC83-E92E-478F-9BB1-A9E1411CF05F', '95428C1E-02DD-45A1-99E4-E31FAEBAB0F8', '4602565009779', ' 15 //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7C81444-C807-4E8B-8DB0-A02E40573624', 'A2F8F24B-D218-409D-84D7-CBFF1B6D61C1', '4602565010072', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A76F34C9-9E40-4645-AE91-7B1C9B030719', '4131D314-B296-42B3-95E6-8B9689C01CA7', '4602565011338', ' 0,05 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6926E63D-3CA0-4421-AC9B-461949EAD3DB', 'C5E68877-8C85-48AF-BA6C-45050456945C', '4602565011345', ' 0,1 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA731CF4-3E62-4C3F-9BC5-AA613FECE519', '9B88FCCC-570C-4978-A225-455BC9202222', '4602565012069', '   0,5% 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FEF55F3-89E4-4856-867C-72216A73CA6F', '92AD66BC-0D69-4AD4-9427-B4CCDD326ACE', '4602565012076', ' 3/  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('209C218C-BEEC-41E2-91B6-6C3965964826', 'E5E761C0-19B3-4744-B006-9043D89462A2', '4602565012182', '  1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94F8A267-C4CC-4430-B1B5-0F0C0EC9E4EB', '9DE8139D-7096-4B39-BCF4-669A9DCD39CC', '4602565012540', ' 0,125 1,5  /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('578CF7F6-0503-470E-BE29-36D8A91DBE3B', '573DBE15-3EED-4D3C-9793-F1F0D4DA71EB', '4602565012601', ' 250 /  / 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22596A9E-0226-43B2-8670-E4D8B9EE4A83', '1C441EF1-195A-40D5-BE99-0A33DB5ECBBE', '4602565012663', ' 0,5  /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('027C64EA-86B9-43CE-86FC-D94255DB1082', 'A02C8EE4-ECEF-49D1-B76E-349EAE882009', '4602565013110', '  0,05% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DF01191-27C9-47D2-A74F-4B2EB601D1E9', '63F73F57-6544-4A1E-A8F6-D9A20FD9EE1C', '4602565013288', ' 1%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF62A13A-5A2F-4836-BA81-2D0B00C2341D', '77323914-FB6B-46B1-8399-09E457E9C650', '4602565013936', '  250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A4AE838-C053-4CF5-BDA9-50CA51D5A5C5', '3035E7B3-AA6E-4937-A193-CF7D6CEA2286', '4602565013974', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A24A81CC-2D53-4783-8B51-6DD4BD9ABBD3', '92062739-E0E9-4161-849E-3498C429E180', '4602565014209', ' 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3639FC3-0048-480E-A353-20588B497100', '9BA6164F-3A4C-4820-BFB3-EBDA387497C6', '4602565014285', ' / -    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8376CEDF-13CE-4886-86C3-5CA14B8ACB31', '9E7F012C-7FCF-41F9-A9F7-F5E1BE59B713', '4602565014292', ' / - /.   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E17740A-FA51-4102-A804-A4A4F1C527C0', 'D3AA3590-D05C-47AF-827E-3105854294F8', '4602565014308', ' 4% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA06AC14-DE3F-466F-AD63-90F7CA0BDE8D', '54F424E3-093F-4957-896D-F7D178B78B30', '4602565014322', ' / 1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('111F306C-77CF-4B29-9C8D-9AD088E0B2C4', '2B0DE94C-9058-4C6D-8EB9-3FA7456F6458', '4602565014414', '  0,05% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('974C1BE2-6B0B-4FDE-B172-166B8D1E1ABA', '00C764DD-A9DE-4DB5-9DB9-8DEC63FEAAFC', '4602565014476', ' 0,4  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E1A603B-DBA6-43D9-9A39-37D1B037FFD9', 'BCA3F056-F914-4513-8385-DEAF4F8B8114', '4602565014742', ' 400+25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('900A3096-285A-40EE-B0D0-19B2F8083496', '2363D3BF-9B0B-4359-BD2A-58BCC43D317C', '4602565014780', '*  500  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87AAB2FE-09CF-43DD-8EA8-2FD91942FF4C', '9107AA5F-96A9-457C-A73C-A7B52D80AC32', '4602565014797', '  250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1380725A-BBB3-4414-ABAE-E0AD9F93F4D8', '0096641E-CA1D-4B9B-98BA-4BC93E8E3094', '4602565015268', ' 2%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97968502-9515-47CE-B9F2-715D2491D882', '7515ED62-B3F8-47ED-8898-EDF8CBBD18DB', '4602565015473', ' 100 2 /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD902CAA-F1F4-4881-875B-5FBAF10A45E8', 'E401D8E9-AAD5-41EB-84A3-6B0F8BA1D4CB', '4602565015497', ' 100 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4AC830B-EF48-4587-80A8-2DD1D38E816F', 'E4C5B43B-BA90-41D9-A590-8BB6969070CE', '4602565015664', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B3E24D3-CB68-493A-9501-45161C777B03', '462C28D9-CA7E-4B7E-89CC-DD45C3FE3B6D', '4602565015763', '  1000/ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BBF3BFA-EF75-473E-B79E-6ACAF0D1DE08', '00AC95BB-D499-4C40-9A2B-967673BECB44', '4602565016036', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DD94B9E-539F-4B97-9177-5F2AF112B7CE', '7180B3C6-FFB8-4E84-8EB8-4A1DF88D7CCE', '4602565016111', ' 25/ - / 3  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDA31341-6A40-4A56-85E2-222DC8C46BB6', '31C5A1C3-94EC-42C0-8810-946535069679', '4602565016166', ' 300  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C627F4D8-7B60-40B9-94F9-12905355D3EF', '9157F315-BFF0-4C23-84E8-9EDDA1DE0C89', '4602565016340', '  10000/ 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61FB6B38-0E89-4532-8B2E-1468B46C9542', '6CA90E08-4D70-4F7B-9BCD-3DCF23C8ED9F', '4602565016470', ' 20  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('446B435D-779D-4BAC-8C03-1DF077E42680', 'EA7C5695-9725-4864-9674-7543449549DB', '4602565016494', ' 40  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3B5BCC5-DB94-4092-948E-64B1BB7C7E11', 'EA622E99-A980-4B89-B4C1-0DBD9832D2E0', '4602565016777', ' 0,05 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E1CD61B-841D-49B7-AD9A-C1CA4DBB143D', '6E5F37B3-4F87-41AB-B084-9B8B2E524B43', '4602565016791', ' 0,1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EE05D1E-DDE8-4242-A484-0D1835868C3B', 'F3F4C819-1332-4437-9651-E73D4C4A3D55', '4602565016814', ' // 30  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BF991CB-C869-46EA-9196-980BDF0B7E29', 'F85B0BDA-31A9-4923-8922-4DE50E165E20', '4602565017248', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BB6BBE2-2C49-4128-AF0E-B2ADFC1D3AB5', '9094F99F-56FA-41DC-AFC5-9F1ACA5139B9', '4602565017255', ' 120/5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A41E5E23-C4F9-4349-98F7-71FDA8AC1F17', '3F88B374-0284-4CC0-B6F8-4E6867EC4262', '4602565017262', '  2,4% 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A42D3D8-D7AA-4526-8EA3-F9372C2A5C8C', 'C819FFE3-E218-4457-98FB-6768041F0E0A', '4602565017446', ' 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC032AAE-B91D-491B-BCE2-3006BECFF0A5', '390F3282-AABB-45DB-A14D-C38EC007A951', '4602565017514', ' 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7543BBBE-5030-41EA-B699-842123FCA5BB', 'BECE11F4-7C0A-496D-9C95-8DEBB6D89C20', '4602565017545', ' 1   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9BC8CAA-1389-4105-AA50-0605A2461D3D', 'BC5CF39F-6951-4B8F-8FB3-852CC62F4DBF', '4602565017781', ' 200  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20F15882-9347-4A73-B2AA-1CE5A896A857', '61286D8F-F32C-407E-8DE0-CBC864BE2E1C', '4602565017798', ' 400  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1145C7E-CF0F-46CD-88D7-A5DACE1F80F8', '27FEEB21-DE8A-4D10-B472-52BDEA49212D', '4602565017835', '  500  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4BCE28E-C202-4766-9123-E89B066B411C', '8BB1ADEA-6864-4443-A6E4-E3DA85987545', '4602565018153', '  30  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('607C5ADA-F2D8-4C2F-AEF7-C2D287D5AD31', '281EB0A0-77F3-4A38-B11B-A4E71FC743B2', '4602565018313', ' /- 1 / /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1FE5750-6A7A-4DA3-81E6-DFDB74AF973F', 'B0931E2A-9AF1-420D-ACFE-CF82A413C19C', '4602565018481', ' 0,3% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0179F10-8CF8-49FC-8880-2AB6F9E5101E', 'D3B095AF-D74D-486A-AC8E-381BFF0A75D5', '4602565018580', ' 5/1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('994DB8AF-2639-4E5E-8267-BBA1DABB3C1A', '1CA55379-20E3-4694-AB26-D99F3FF33C25', '4602565018597', ' 10 1,5 //  -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12558FE0-552A-49B2-B664-D68048EC6A5B', '95187C02-F1FC-45AF-B4A5-AF073836EBDF', '4602565018603', ' // 10 / . 1,5 -  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F7DCB3E-75E5-45A7-8E1D-D99585A29117', 'BBFB8FC7-E737-4C30-980B-E9AF895CA476', '4602565018665', '-3 0,6. ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F09885B-C96F-49C1-A223-37074A301443', '4C05504A-CD85-4B2F-9F3C-E80A7778933E', '4602565018672', '-3 1,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AC7DDD6-FD77-4ECF-9C5E-B9A9D72CAAC5', '6D94A77E-2CD5-4FC7-9CD5-83315E5D28C9', '4602565018733', '-5 1,5  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D55E4B62-0C87-4A7E-8EC0-C7CB3DC2A0AC', 'EBD30EE2-0813-44A7-969D-2BF3DDC0F12E', '4602565018818', ' 3%   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80594049-1F6C-401F-BD30-3F8D4D887CA1', '9238DD3E-9305-4628-B82C-19E636B03734', '4602565019310', ' 2,5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9ABBD86F-C666-497F-9FB1-2BBC014236EB', 'B22C4831-54F6-4DE4-A891-86E7BBBB74F9', '4602565019327', ' 30  5%', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D8192B8-7880-4E1D-9A93-D3B576AFF768', '629F4E40-2B07-44DC-8A92-400D67B0E17D', '4602565019556', '  10000 / 1 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('556B7F97-294B-4C0E-88CA-6B621F8DF325', '122E5757-3901-4A58-8108-323EF1E76FEC', '4602565019587', ' 0,05% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1A35382-2910-4125-88EF-53EEEB12A3CC', '89B40569-6A1A-4A35-9919-962ADF5C9813', '4602565019594', ' 0,05%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAE8365D-2749-4E86-A5F0-917820923A22', 'FFDBC734-DD3F-43FC-94BC-F460FBD0BD55', '4602565019600', ' 0,1% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7617974-E346-4E20-A1EE-636B17DE6476', 'B878EA8A-0D4E-4231-9DF3-802B9D82771B', '4602565020071', ' 25/ - / 3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC2B6668-385A-47B6-9B13-A7B515CFB4CF', 'FCECDB71-DDBA-4033-817A-B20E748941CB', '4602565020095', ' 20% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16D160C1-EFE5-4474-B7FE-CD619CFF92F4', '8CEA05F4-C96C-4007-B9D0-86CEB65E4148', '4602565020149', ' 10  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F886F89-378E-4E58-9653-DAA38AFF1633', 'B9F17734-908B-47EB-AC98-5877A36392B6', '4602565020156', ' 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10F0F599-5278-48B3-9E11-D370672B0E87', '518FCFCD-E83A-4F17-A143-3824E50B4CA5', '4602565020279', ' 250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A914728C-D292-47C4-892A-E482B12CA24F', 'C7E57717-5B7C-4302-AA94-AE538E5FF99A', '4602565020484', '   1000.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E65CBD56-67BA-4BE4-AB29-63AD9F3FA444', '328970F3-EC92-4395-9A35-5E0939AF78D7', '4602565020491', '   1.  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D01A532-B930-4FAB-8F38-6B020BA8B565', 'F2F31688-4299-4E2C-A84D-B67B8AD41B44', '4602565020866', ' / 30% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14CE149A-59AD-4D86-8615-6288C6E10F03', '88A2D4EA-A0D3-4DC2-87B2-E4593A1DF0C3', '4602565021351', ' 2% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBE00934-E6EB-40B1-A564-E3BC359164B2', 'A30589C7-5446-4304-8FEC-BAED313FFB00', '4602565022556', ' 1000  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('441A2F50-D700-4D35-BE24-04E446C09E82', '9B1936C7-29FA-42DE-A9F0-5FD7146E138E', '4602565022891', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F4BC821-0238-44AF-B8FF-B2A956AB3194', '7B4A4A8A-6111-437B-858C-C879679E8D16', '4602565022907', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21704E06-31BA-4994-BA9D-116B73A32651', '81A3346D-6373-4C2E-9C00-39B82636162E', '4602565023119', ' 50  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9233D538-629D-48D2-B4D3-E144ED358D55', '2C6D505D-A4BE-401A-AF09-6D5C212EC5A3', '4602565023164', ' 50 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B05AB8D-B573-4716-BA70-05E71BA66304', '437215BD-F9A0-423F-A6BE-296D3897988B', '4602565023263', ' 0,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74926BDB-730F-4C33-9A03-849F7B4FD221', '8AD45809-CBEF-44EC-84B1-F011D634B3F8', '4602565023669', ' 0,5%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3A13ED8-B7AA-4150-A12D-E6EC9BE9447C', 'B7E68329-E641-4871-93BC-36602400F080', '4602565024239', '  1% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40B29249-512D-4889-A744-E968D2F4B0F7', 'E19B1D87-045F-45CC-820C-AC86C01C8A27', '4602565025106', ' 0,1% 15   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D09F0D1B-4EFA-484A-B905-C1E28BFEBF5F', '6CCFA8B7-415C-4DDA-8D1F-BB0E01BFEAFC', '4602565025298', ' //  100  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C559220D-9040-4A6C-AA13-C49365D0290E', 'DEB3274A-6560-44F2-94D1-ABDCACDD7B45', '4602565025304', '  100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E66A35B-8493-4F2E-840D-C656052703BD', '186E3118-697B-4964-974E-DF0A70640371', '4602565025427', '   50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2A36C0B-D1CE-44DC-8D23-040F63FE1E02', '221B03DF-41CB-4D98-B035-B57760925854', '4602565025434', '   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6D6FD0E-E551-4349-9538-C842F2138B3C', '6590C873-6A90-4D04-89DF-2F9303C29500', '4602565025465', '  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30F45C11-9091-4AB9-9ECF-A19EFAE9F0CC', '7FA501E2-B3EE-465C-810B-FA40C533408B', '4602565027148', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99147BE2-0C6A-4303-9AB1-8E7BFB86D07E', '9D17292E-7EB5-4B9B-BF67-3C9A2E5260B1', '4602565029074', '   1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D0A7031-A782-4C3C-B6B1-8364FAFF4438', '4D6C097C-1ECE-43EB-A414-3ECDEF24D79A', '4602565029500', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7A54953-5018-456D-8785-EB39FA49DABE', '55EED59F-41E7-4B69-AE61-471AA97ED922', '4602565029524', ' 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('495C23D8-F734-474B-88D1-3B8AE767A5BD', '455C6E1B-B751-47AA-A031-851F79736BCD', '4602656000319', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('362F8294-3D05-4ED6-BD45-DBB26D8714CA', '54B2EB91-D5F2-45C7-94D6-D7618945E139', '4602656000500', ' 25  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97D4BDEF-2A81-4B69-8BD0-EB8A47106537', '5966022A-2657-4072-B635-56718AA3D0B2', '4602656000616', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F77AEB69-8212-4935-A34C-B4ABD7D40832', '5BCC2868-779C-4CA6-9113-4C7ABAF7953B', '4602656000906', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C428BC60-7E2E-4210-83B0-6911AD775320', '234E550C-2CCD-4BE1-A4AD-34527949A31B', '4602656000913', '  / 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F18F7D8-95AA-49A4-A0D4-1C3F663AD512', '25844B0E-EA5C-4664-A394-21E42257976C', '4602656001293', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1168764-2B92-4C00-B01E-3D9B865B78F1', 'F3933304-E5B4-4F35-832B-16A453B26B31', '4602656001309', ' / / 5 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2151EDFD-4382-4A11-9D09-D48CCFADDF32', '3C5F29F9-D5F3-48F2-B045-9598739CB06F', '4602656001453', ' 10  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE92E833-F135-4B95-8FFA-559B642E3DD5', '8B462F99-4BC5-4066-AE61-C3726042DAB8', '4602656001460', '    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF15F76C-A870-4A92-B295-C4F90026891B', '265944A9-4D73-4AE8-9704-E693DAC8651E', '4602656001583', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3261140-9607-434A-942F-81BD3E1CEAB5', '9701BBCB-4F3D-481F-BF9C-2FCD5A4B82E7', '4602656001965', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48886762-4B30-4D98-AAE1-92416EF90CDA', 'B3DAB604-2C9D-498D-ADE7-BA63252115E1', '4602656002269', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E971176-EA8B-4C24-9951-CC5FC62166F1', '89AE1306-ED9B-4D97-B4A4-DBC9AE8008E6', '4602656003358', '  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('857B0327-3DFB-487F-BBD4-5EF3F06633BB', 'C7042CBE-367B-457A-87D0-506698833DB6', '4602666700704', '   150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E03FAEB-680A-4A36-9A98-CAFA8BEB8E13', '66D091F1-F3CD-49EC-BC39-2AF04FC5BF17', '4602666702708', '  ,    31 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42DD3500-0F87-4EB0-A290-E6F8761167CA', '9019C09E-098C-4350-B260-30CDCE3EB005', '4602666704504', ' - / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5C3A6A7-AB7A-4D9F-A5CF-E407A99E9CD2', '2227563A-D450-419A-9A41-4D6CB21118DB', '4602666704603', '  -   .10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F49E472C-8720-47F6-AD48-B0E2F063EC8C', 'D53B38C2-2AD5-4E5E-8508-B5495DA1C0CD', '4602666704702', '      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B84881F-0627-4906-8622-C4489EF60837', '6376FF21-F805-4A08-AA13-FCED6AD30188', '4602666705709', '   // 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C3BBAC6-18F3-40D0-BDCD-073A080586A0', 'EDB9E692-6BE7-4D03-A057-92FC75D994D5', '4602666706706', '   75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41E029F7-645B-4378-8989-1224016EB0D1', '8117040A-E91D-446A-8C71-0F83FCB49666', '4602666707703', '   / 125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D9485F7-4910-49FE-BB93-2E0BCA820198', 'FF59A6A8-F535-4813-9DFD-698B5AA70E19', '4602666707802', '   , 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D30F34AE-0080-49F0-92F1-1C071855CC56', '6FDF2771-910C-4EBE-B92D-FE355120F4E6', '4602666708700', '   2  1 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4EF61F3-49A1-4984-9159-9F29E14C52F4', '7EC53619-AA32-431C-A890-421A79DE876B', '4602666711700', '      1,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD785BF0-A58F-4C27-AD8B-B37B56D686CD', 'AB9F1E23-F58F-4F67-B31A-448D554A058E', '4602666711809', '   -  2-  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B866E19-C5BA-49EA-88B0-CCADC5BCF47B', 'DA03070F-B1B9-458E-AA56-43FCF6539BAC', '4602666712806', '-  aqua  21     /806/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50BCFB2F-B0C0-4F02-B207-E819C19ED0F0', 'BDE2C7B9-7B79-4F87-A7EB-AE2A0A4F0FD8', '4602666730404', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36600AB9-FA7A-44F6-8422-0EA1DD1ECADE', 'BCFB00B7-04AD-4D62-8B83-D49FE7401A7D', '4602666731401', '    2-  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52DC70DC-DA30-4BDA-97E0-0EA1F617A748', '24880D4A-F4B0-47D5-8572-698ABC9150AA', '4602666731708', '    125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EED7F04E-AC46-487D-B00A-93D0336F897B', 'BC9A52C8-46F7-4122-B18E-CC2ABDA24F43', '4602666740106', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('030E9422-8831-4BE0-BA3C-3EFEBB50F34D', 'D923192E-D223-4AFB-B57B-002CA2C21E1B', '4602666740403', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A4767F2-6ADE-4A9F-A8BA-CBF14EAE5423', '299D967C-DBAE-4D01-8A57-E3EA1A465C81', '4602666760906', '    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5ADC8A1-783C-41FC-A826-0D857A208913', '7CC842EE-F1C0-44BB-95B1-A7CB0BB1BDC1', '4602666780805', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56CC1359-97CB-46C6-9083-FDFD9770A987', '4B398CF9-FC66-41F6-9946-47EA072B211A', '4602666790507', '  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A29557A6-39D6-4310-BA01-0CD311892F3A', 'C6DC7330-02E2-4FC7-958F-6E69443468D7', '4602676000030', '  500  / 5 +-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E724665-34D5-478D-8EDD-6A050EA46681', '26E8A6AB-6D2A-46BC-8D6D-9C6593215053', '4602676000054', '  1000  /. - // 5+- 5 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB506D1B-C23F-40E5-B5BA-3818B4D966F2', '283FEEBA-5B96-4B37-A7EF-40A8AFE69999', '4602676000696', ' 2% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D0C30B2-B908-4679-8CD9-DD779A780316', '6EE05845-DC94-4DAE-B7E3-091C34E924E3', '4602676001747', ' 5/ 1 - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0822B525-F6FA-40F0-8B39-3ED16C6AE95F', 'F0AA6BE4-04B5-4DB8-BEDD-E3C7AD0A9AAE', '4602676003390', ' 25  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9779CD91-94B3-4588-8E9A-D2BCFFD0A831', '832481BC-DF56-4FC5-824B-5D6CF5E6B929', '4602676003475', ' 0,01  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A67A2BB-57DE-4DE4-9401-29900C6FD503', 'B20FD616-0F9A-48BF-A99E-A1E35F6413F5', '4602676004069', ' 0,05/ 5 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E460D67-05A6-46A9-8F44-F491F9CD3CD8', 'DAA48248-E0C5-44C4-A275-8159DF251127', '4602676004502', '   - 1,5.  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66298EF4-ACD3-44DF-836B-883A0CB09F9A', 'E2606A1C-7E44-45F2-877D-687B044F9A49', '4602676005097', ' / 5 1% 1,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08EF8467-CBFA-4096-A0D7-560AC2857485', '54F424E3-093F-4957-896D-F7D178B78B30', '4602676005165', ' / 1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('579F576F-A0B3-414A-807A-D9A8B8FDF8C6', 'F3E1D961-9F8F-4E94-B021-318690596AB0', '4602676005615', ' 5 /. 5 1   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F097F85-3A9A-4D29-A598-8D91CBFB93DE', 'D867208F-6656-4288-9275-501B44E20235', '4602676005714', ' 5000/ 5 - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66542EF9-3F0B-4FA8-A3B0-EEA8964A6840', '3A81BCAB-E1C8-41D5-81BD-7BCBF3A3C02E', '4602676006698', '  0,1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('847A2FFF-2843-4401-8083-0166F250F702', '770C34C4-9019-4B60-87A7-07744AFB5329', '4602676006889', ' 0,1% 10   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4AAE536-A1E3-4886-B837-41347A392681', 'EAABE21B-C9EB-4C05-AC33-1C4555D07091', '4602676006964', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('769ACA15-FAD5-49A4-B4CC-204A5FB51183', 'AE5BD1C6-FBB1-4BE0-B83A-607DD4440BBC', '4602676007008', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BD4063A-D3AB-4D0F-90E7-DEA443937E65', 'C01B631E-AB4D-435F-8C94-4F6E0DD3A3BA', '4602676007350', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70387557-61CF-4A38-B1E9-2F2605CF9F36', '3D41AC51-01D9-4BEE-AA71-CFDF3CA0B6BD', '4602676007381', ' 1% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB7E9D97-01D2-4D20-9179-2F23CF910CBA', 'F0BD2D85-8F92-4BE3-B4CE-C3481EAB1805', '4602676007572', ' 100 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE498A5F-DD67-445C-A342-291B003F1419', '500E9A23-050B-461D-8AD9-B2B860700928', '4602676007701', ' 0,1% 1 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DB9FC57-98AC-40B2-B7A9-B95E67BEA74D', 'E5164140-029B-4F69-8EBB-57052DA95BFC', '4602676008067', '  0,1% 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85B65A89-74AF-42A5-B829-7D50ADD98A63', 'AA20327E-CF18-472D-AE8B-1A43E6F92004', '4602689000041', '   5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('968E2F73-E82D-4E1B-AAB0-D995FB9F2D28', 'D3585E53-6B25-4B84-9B0F-E3966829CF90', '4602689000188', ' 1% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00810071-BB6B-445A-972D-7AB79E1A3821', 'A59AEB41-F01D-42D1-BD50-2ADABA01E9D2', '4602689000423', ' 4  / 5  5  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA5452FD-E931-4397-9D6A-C6411335DE3A', 'BCA29C96-B745-4065-8B84-206B5C2AE903', '4602689000560', ' 1% 10  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C15975F1-620B-4C0E-873C-BDA2ACE29538', 'D1BF5FF4-3C37-44CE-B48F-0C11336667C7', '4602689000577', ' 5% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21D1FADD-B47F-4779-970C-A6863DDDD23D', 'ECD1FC13-DE75-4D14-8E94-0ED81C52D08F', '4602715000441', ' 0,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09B5096A-CA98-4B98-8C7D-54CA9EE30913', 'ECD1FC13-DE75-4D14-8E94-0ED81C52D08F', '4602715001202', ' 0,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5420BF88-C315-4656-9005-4BC8B8B6D6A6', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4602737000160', ' 714 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('206ECA06-11CE-4A0C-B817-EEF72448DB82', '8F45ABD7-02F2-4EBF-AB43-08F2E86CF370', '4602737000191', '  45  29 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2CCF7D5-B468-407B-86D4-819BA540BB18', '28308178-45E3-45EB-A408-09E27BB6E08E', '4602737001419', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF858968-6E04-4A8C-8845-6FC54901AECB', '2DB0F24C-AA1E-431F-B4FB-A9C96F84F7A3', '4602737003512', ' 510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABF89329-74B9-42F6-BCF2-30D8589A7CA6', 'C0DC9890-02DF-4262-913F-D6973A54B16E', '4602758000545', '+ 0,35  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDE3098A-EBD4-471C-A3F8-F638EB209604', 'D400506E-D6C2-4A43-9982-D355089D6A0D', '4602779000029', ' 4  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7372B8DD-8054-4682-A2F1-96BF5835FABC', '735B797F-832E-4557-9F17-69F61B65F89F', '4602779001460', ' 0,0002  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3C2E004-6F23-4719-83EE-1735EEB8D221', '50A4A54D-EFA6-4FE5-86C9-C7A8B83498BD', '4602779003723', ' 10 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('294099C5-FA5A-4EB9-BF7E-01E11B9381F0', 'ED05C63D-786D-4B47-A536-3D49DFFC174F', '4602779003747', ' 0,01 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26656942-AEF9-4DCF-BFE6-ABC7674C6FCA', 'FE520A29-434E-432C-890C-D56CCE9450AC', '4602779003952', ' 0,4  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('218AECD2-4A51-4C71-8998-9580C4C75EB0', '628F7E91-54CA-4B2B-B7FF-E442C8C8D96C', '4602784000120', '  20 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B31A8BB3-9E6C-4A80-85D9-79F1BF83C2F7', 'D1301D22-93F6-4534-AB63-A8107DA672BF', '4602784000168', ' 64  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7310F35E-92BD-4630-B48E-CAA8CCA98590', '31328CB5-CF9A-423F-A717-843794A11CEA', '4602784000175', ' / 50  /+ - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('257ADAE4-B2D6-4862-8282-CD466DE4386D', '015BFD03-261F-442D-B497-B5B530AE0A9F', '4602784000397', '   20 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('140B0B65-F26D-4C3F-9674-995C631DFA81', '90B398C0-ED8A-4C30-BD2C-5A2C04415323', '4602784002322', '  20 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('118D5865-42C9-4B5A-A0CD-0F69D13D374F', '65313446-08C7-499B-9020-8AC9AA7CFBA1', '4602784002612', ' //  20 4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A90C9499-B453-4DB6-8E1F-C53DDE9232D2', '0CEDDEA1-421F-4E8F-99B2-859E48B6F187', '4602784003268', '- 20  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F6A9657-B694-448B-9724-BDDCEE5584E1', 'FF820343-EEE0-4CA6-A011-0AFB30B6D8CA', '4602784003435', '    / 1,5 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E81FB1A9-4898-41B1-B2BD-9DACFCE25A35', 'D050EE3A-D415-481D-9CD3-B94ABE40136D', '4602784003480', ' 20% 100 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53F2C174-8CC4-4813-89AC-2EE8C114C213', '9F3FAD53-68A5-4B79-9F93-FEF903AD62C5', '4602784003497', '*   /  100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('001D068C-F51E-4C11-914B-D03F5EE8F474', 'C682E142-B4F1-4014-9BF2-A10666670895', '4602784003756', ' 1000   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4E39272-8CE8-416A-8798-90F88D349182', 'F8EAB2B3-4875-4AAD-AD73-9A4CCD55ACBD', '4602784003954', '- 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B56B9280-FA2B-4864-B103-ECA7C98A9016', 'F205E825-4B12-4E65-9A6A-823A89B4190C', '4602784003978', ' 5   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D226E0D0-6ADA-4505-BB8C-74BF5E5E66A0', 'F9F1FB00-DF28-472C-B80A-0B64E00F7246', '4602784004159', ' 5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6737028-9D5D-48EC-B8FC-E2395DE76F54', 'F205E825-4B12-4E65-9A6A-823A89B4190C', '4602789002013', ' 5   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93E56C6A-F461-401F-AAC8-464156BC385F', '7D4472B2-8534-4279-AAD2-9DE19A7FB3F9', '4602789002082', ' 0,004 5 +- 5 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62BA3F4C-E7D4-4F9C-9D1E-13C23BE39ECB', 'A62830F4-75A7-4F21-9474-248335DC5239', '4602808000105', '-1  0,5     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B3DAD6B-1D8B-4CE4-8073-80A27A5C96DF', '3F6E99FA-82E4-4C7E-98F7-23DD5573B262', '4602808000129', '-2   0,5 /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B0D6E6A-1E25-4C19-AA14-BFA091655510', 'A45A609D-DD93-44F6-83EF-671D4EA655CA', '4602808000143', '-3   0,5   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58057E5D-AC62-403B-90E7-C50D2BBBCA57', 'E7B70BB5-F53B-4FDC-9399-51E30202CAA2', '4602809006052', ' 25  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50F2FC0F-3382-4FFA-8E44-EF5C307820EB', 'FD4DA183-1004-4F0E-B5BD-089F524009D9', '4602809006229', ' 0,25 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('610FB4D4-17A8-4DD6-834B-685A2EFCFE22', 'DAB4FC83-73B0-41AA-8677-C193D44194F1', '4602809006243', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABBCAB38-72EA-4FE2-BB8B-B77F6467465E', '4D462113-71E7-417E-B647-A60E5D32332A', '4602809006304', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C518E0E4-880F-41DD-89D1-74D8B09833AB', 'A9FA2EDE-C748-4B01-ABA4-4A1488E4E95F', '4602809006328', ' 80  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A660B1B9-8513-4516-BD5B-C2BEE4999B35', 'C0170722-8F8E-4B87-A868-9CDAC3E62AF4', '4602809006359', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('348C2A7A-520E-4DDB-925E-33527E11C4E9', 'D7871D5D-0746-4A24-9693-341F246CE1DB', '4602809006403', '  500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('567AFEE5-C95E-49CD-A531-14D108B8AF84', 'E77EF07B-E290-4790-B0D5-8E43F6ADAAFD', '4602809006557', '  20 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('273F78B3-E32E-45D0-8F6A-F0996083F78D', '94EAB7A7-DC3C-477C-8C94-DD72CCD8E129', '4602809006625', ' 90  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('323E8828-17DD-4887-85A6-25828FD344E7', '05F58156-4062-4505-97A3-F6374F8536D4', '4602813000671', ' 0,25 / 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DECAC45-9D20-4342-9E79-9F015BE3960A', 'D40DE8F4-6E3A-44CE-9CF8-71989F033A69', '4602824000059', ' 40% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52615516-5CE7-4F7B-B0B8-70AD5AEEA4C9', 'FC963FB0-4CBF-4F38-88BF-B85EF7E4033B', '4602824000073', '  10% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('411E7920-4CE8-4EDD-8F37-C5C0EACA95DE', 'EA2EE66E-3EAF-4A9B-ADE7-FFAA4F5C708F', '4602824000097', '  25% 10   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32DFC96C-9ED0-4E49-B443-E5401AC77DD8', 'D7925444-4D18-43A8-93FB-1D34E54D03E6', '4602824000134', '   250 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDE641C7-A41D-4CA9-8C31-4EE8562590C0', 'B5567FB9-99C7-4E7F-8BC4-5E60E0F7718C', '4602824000189', ' 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EE04786-DC9A-4CFE-A110-659E80CA9DF2', '5FBB67D7-4C97-4DF2-A703-CDBEC62950DA', '4602824000196', ' 500   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19786CBF-5155-46D2-9455-F51A0A0F1DD0', '6B6ED69A-BC10-4846-BE85-62402C5B2B5E', '4602824000202', '-  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD9BA33E-9297-41C7-AAE9-DAB20E1B8769', 'DB73578F-238D-4DEB-8A9D-9AE5A8AB4F78', '4602824000226', '*  0,1 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73281DC9-8476-48F2-AE9A-76E42086E9EF', '4A031F9D-667C-4650-A631-8E34B20A3690', '4602824000264', ' 25% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('797347A4-C299-4F74-835A-C7B3ADF51C44', 'D4168718-AA05-49F7-B5BB-25300203BDCB', '4602824000356', ' 4% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E23FAC6C-34D4-4E3A-BD5F-E0B8B8A9684E', 'D299FF72-EA04-46E1-B028-1DF6081B4036', '4602824000370', ' / 2% 20/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6880EB63-EEB5-4863-BEBD-7E5F1A4E4108', '9933BD2F-8CF6-481F-A68D-140219F71BF3', '4602824000394', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0E4DDDD-3833-4B8E-A092-E610CA953F24', 'FF00E085-D9D7-4A7C-9FA7-77AA1FE2AD5D', '4602824000400', ' 2,5% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('006AA4AB-4556-4B4E-A12E-F1F589C80318', 'F2448497-F151-4326-A44F-3DF2A45BB689', '4602824000417', ' 0,1%  - 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5216024C-0052-4FC3-B944-FDBF71FA3EF8', 'C1977E0D-67A3-4114-A13A-34BCD1E20DC6', '4602824000448', ' 2,4% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E211D0C5-755A-418C-99C3-03F506E0A04B', '7719E91C-0164-4E34-B2AD-DB2095A4FE10', '4602824000486', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A28C8BA8-492F-48E1-88EB-011DE9E1279C', 'EDB1D0BD-882C-4A0F-97F8-E61B6AEF7D2D', '4602824000516', ' 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6D887A6-D81F-4056-A3C2-0271F0C54EC5', '99C46E90-B2E6-482C-B256-2E71C9D286B6', '4602824000578', '/ 12/ 500/ 1 - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7871ADE-7348-44AA-8125-9C0BDF03A0E2', 'DB1F4BC9-0CB7-4ECF-94BB-71B89993BC9D', '4602824000615', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFD43368-B6ED-4468-B26B-3C7C07FAFC1A', 'FA15C994-21A1-4F25-8940-BEF9A39F2B9D', '4602824001322', ' 2% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94EB4281-D113-414A-93AE-DAB596112BE5', 'ECFBE344-67EA-497E-872C-F059631D9E8C', '4602824001629', '  20  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77F58297-1025-4213-9184-D77B5D7AD631', 'B9DB7647-9681-45EC-B0B2-C731CC44EAE6', '4602824003098', ' 1% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DCCE408-746C-47D2-B545-AFE7F7F6D8AC', 'D48313AB-F339-4B9C-BF8F-62EE988BE1C2', '4602824005962', '  10% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E690A12F-9565-45C5-998B-1BF569F952C2', 'F81D7286-6BFB-45F6-937A-4314C8D14CC7', '4602824006020', '  25% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F59D4B3D-BCBE-4A17-83E4-D677F9B3F3A3', 'FCECDB71-DDBA-4033-817A-B20E748941CB', '4602824006105', ' 20% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8284D7E5-D98C-4927-BF23-7B0DA7E1F17C', 'E4CA84AB-C264-49A6-9739-C947C52E0A01', '4602824006129', ' 2% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B873778A-64E8-4F48-9E7F-E75CD581F433', 'E075309B-CCFE-4522-A71A-EAA345142CC3', '4602824006143', ' 2,4% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9529A3B9-7228-4DA4-8BD5-CED0D6A1F568', 'EC3B7B23-CF87-4AF6-BCD6-FBF5E6228035', '4602824006495', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('243C2FE6-B358-439E-B83C-BAFFE0CC7F18', 'A07A2091-65A2-47F3-B155-EFE28836B0A7', '4602824007218', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('160930E6-362C-403D-B604-E4BD5AFD2E68', 'D6933740-EFDB-46C8-9AA0-48F264234156', '4602824007553', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4CE75D2-94DC-4644-855B-C0C134EF2B55', '2F2BA96B-D31D-4691-ADD3-3A9176E3D7A1', '4602824007676', ' 0,015  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E1265BC-188B-416B-8008-086641ADC322', '4542DD8B-4393-4F14-BCFA-21D073568AFD', '4602824011420', ' 0,05 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EC4023C-4010-489A-875D-A8EAF7710917', '5865C196-1A18-4AD6-8609-3BA3D5870A95', '4602824013530', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D151EE4-8E63-4992-9C70-D253CDE3DF41', 'FEFD7BEE-4E15-46E4-AEA6-6E1511A20F4E', '4602824015053', ' 5 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18742277-50AA-4287-A111-A1C18721E162', 'E474DF38-0BF9-482C-8581-8F12A2E77E13', '4602824015077', ' 500   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BAE3404-7944-4CA9-B151-098448EF1CB1', 'EB3945EC-0FA2-4DC1-96FB-E7062105041B', '4602824015664', ' 1% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A39B114-8B71-4687-A007-DDE1433460D7', '7692BB50-60C1-4640-9CC5-C56ECFE6A3AF', '4602824016135', ' 0,02% 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('769ED3F9-84E9-4F44-B181-D9FF4CAF89AA', '1842FF2A-64E8-42F0-AFC1-35657F0B60C0', '4602824016142', ' 0,02% 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF854FC5-96F0-4604-8AE4-D65F7426F8D2', 'F723737C-C104-48EA-BB4D-533F006E61D8', '4602824016203', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6121496E-2663-4DC8-99C6-65E359B2EBD2', 'E800D3FF-4463-4207-A7E3-930DE38C7966', '4602824016210', ' 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9664F214-C33F-411E-85FC-A3EFD587F824', 'E3E4FE67-8FAF-4031-B48F-41C974A71C18', '4602824016401', ' 0,25  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('058A16B3-2377-44F5-8674-25205119E06E', '45C29B22-E5F7-4A4F-93E5-BF3D3833E594', '4602824017248', '  0,9% 100 - 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6BB9757-B397-4809-A8A2-2E3DC5444C41', 'DC7128E6-F00C-4599-8E40-2973DD17C2B2', '4602824017255', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C74D757-D542-4261-803C-75F6FF384990', 'AAFF4912-81FC-455D-80E0-DB8E7D017C82', '4602824017606', '  20  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('051450B6-7069-4831-B144-D31DEA53B976', 'EC17DA47-3F3E-4A69-99A2-4A90D9884228', '4602824018795', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15E12C43-AE28-4BF5-8954-D4F0B1EEFAB3', '989F9A52-7DCB-4372-88FA-8E75C0770047', '4602824018801', ' 300/ 1  N 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BA76BC8-A5E0-4CDC-B6B6-79B08D3288B7', '45161907-51F6-404E-927E-ECC99A987766', '4602824019570', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F0C4CBA-E252-486C-9143-4155CB77CAA0', 'A7286499-1A98-40A3-885E-91030F323439', '4602824019617', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FCA7F62-8178-470B-A025-2CABB72993D0', '4D213694-2080-432B-A33A-D123E14CBFF4', '4602824019815', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB421AF1-E3A5-4123-AB2F-FCA284ABCD85', '7392DBF3-880B-4673-BA1A-AF41A0999215', '4602824020606', ' 0,2% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BC3F63B-EF06-4E25-8ABD-37B31FB6A4E1', 'ADE74AD8-0155-4B21-863D-7037037B774F', '4602824020798', '  1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B9BE171-CF43-4AFB-A438-6B7CE3D426B8', '77102916-6714-4A9D-AF87-BCDDAA9BF434', '4602824020859', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D9A8F0D-77D9-43BA-842E-C52E78C433EB', '655F8E21-049F-4B77-87F8-2B4BD575B8DA', '4602824020941', '  40 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2E5CE4A-C8AE-4891-B4BC-E2C1FD0DA02E', '9D36BCBD-D59A-40D0-9802-8463B2C01850', '4602824021054', '  200 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24C1106C-2DE3-430E-AE75-DE04350E209F', '2386A825-6608-43A5-B4EC-B63C984CB66F', '4602824021184', ' 100    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1D69F6E-839E-4229-8035-E7B37FF8F44E', 'EC17DA47-3F3E-4A69-99A2-4A90D9884228', '4602824021320', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A93862A-B995-4588-99B5-4FEE8803F836', '4A031F9D-667C-4650-A631-8E34B20A3690', '4602824021344', ' 25% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B704832A-B475-4D83-B27A-973623525B95', 'D51C9BF4-DC21-4038-9786-BA83FCD73FF8', '4602824021351', ' 25% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C8BA9F2-CF7E-4A10-9DFF-983E1B933C52', 'E052140C-4C13-44DE-ACAE-00E1A2EACB2C', '4602824021962', '  15% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4057485C-8F15-4D01-A57D-7CBC8344DBEE', 'FF00E085-D9D7-4A7C-9FA7-77AA1FE2AD5D', '4602824022518', ' 2,5% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90D2A559-4468-4167-A431-990F6D456214', '9933BD2F-8CF6-481F-A68D-140219F71BF3', '4602824022525', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7E8A0A0-B0E6-4391-B260-5D0C50457C04', 'E0C3042A-F308-4C7C-BF3C-230E15C7FB4D', '4602824022822', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FACA695-F5E7-4567-A98F-026ABA9D6939', 'A1CDF363-D5FB-4292-A93F-CC5CDCA153FE', '4602824022877', '  500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F9EEB17-04AF-4441-8819-EE1AA2B204A2', 'FA15C994-21A1-4F25-8940-BEF9A39F2B9D', '4602824023195', ' 2% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('957F12CD-4F89-4CDB-9079-62D61615E67B', '81F134A8-B25D-416F-B2C8-09A0ED99EAFA', '4602824023614', '  30% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB546E2F-C105-45F2-A5ED-29DBBD79E4A6', '93278EA0-F2D3-41AF-94B5-E5486B482E61', '4602832000072', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0147BF7F-E776-4B01-A96E-CB2050F45E12', 'F6A93A58-6EA1-4490-9DEF-421DA407C646', '4602866000208', '    l 5 -1443', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A0ECA55-5D1E-4726-9915-7DDA2EF79C6A', 'C5C97CB4-3DDC-4A90-B9B8-9D6F47AAB0D2', '4602866000352', '  1114  4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68CE5C4B-7617-4F30-A03F-68FA9483F7DE', '0303AC30-D885-4084-B7C4-C67EE94598DA', '4602866000505', '  1331 / 3 (S)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6F5E9F0-E17F-4FF1-96D4-049CE2D5992E', '88C0A513-7134-449E-83EA-6A8215CDE32F', '4602866000536', '  1331 / 6 (XL)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('301253CE-B995-4FD9-9CE9-EEE8A62A06B8', '536AFED5-F41F-4E44-A932-DF1C0AB38C6E', '4602866000598', '  1333 / 4 (M)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71DFB792-2B0B-4EE3-AA15-2DAC93D4E92F', '7EC1282E-35D5-43A3-9BDF-A81CBC24BC07', '4602866000604', '  1333 / 5 (L)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A4106B2-8F7B-4086-ABB6-507186659A78', 'A28900AC-A3A9-4948-97D8-B968E953E228', '4602866000802', '  1551  5 (L)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DFC72DE-F3C8-46A3-917B-62CCFDD439F6', '60C5C577-8FDB-4EF6-88C3-BA31C3D95296', '4602866000840', ' /-1552/  /4  ., 21/ /l/ 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80A6CCBF-8E7B-4C22-97B4-37AFB248C74A', 'C3A0BCBE-0E41-4EA2-B9E4-15CEAFE13B45', '4602866000963', '  1555  5 (L)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EF3CD33-1CAB-4154-B24C-0A86D51DEC29', '6999F641-041F-4E17-97CD-CD35ECF752DC', '4602866000970', '  1555  6 (XL)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9AA1705-DA58-466C-A17F-DA3D7216DF5A', 'CE954149-39E5-4BFD-88E1-E55FFC1F062F', '4602866021043', '  004/10 /...', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF3268F6-0E96-430F-B314-7C834C4012B7', '608C3E37-E507-4979-8B28-AC50CDFAE241', '4602866022699', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E21D08D-8480-46F4-81E9-1F7814C9C509', 'D6D4B7ED-A136-4260-838F-EC62FA61F2F0', '4602866042581', '  8302 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('502AEF7B-C551-48F9-99F9-E3E2BFC062B1', 'D6E9EA74-EAC7-43F9-B6F0-9F9B86DBC65F', '4602866042789', '  8511    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('937AB8F9-BD4B-4FD5-A16C-23FBE11C95B6', '9454AE62-720F-45EA-AB02-CD4A3EE46C87', '4602866072991', '  003/9 /...', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('199E5C6E-F30D-43C8-B10C-3C3300DE6532', '9454AE62-720F-45EA-AB02-CD4A3EE46C87', '4602866073028', '  003/9 /...', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89B4E9DE-9D92-4B0D-96D0-0D14E0F9E040', 'BEADE3CF-F54E-4C3F-BF34-2A9DBC712E6F', '4602866073653', ' /-104-s/ .  .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3689100E-AB17-49FA-80D1-53D988EF4645', '5CE892EA-31C2-4FFE-9660-87FB181C3D60', '4602876000120', ' - 0,025  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1100AA2-F270-4530-8D54-D69D223245B9', '8AF83E29-F63D-47FD-BCDF-206643A59977', '4602876000908', ' - 0,1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('501BD4AF-9F70-43CC-8DFA-368D0C9E1720', '8AF83E29-F63D-47FD-BCDF-206643A59977', '4602876000915', ' - 0,1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9FE32D1-D4AC-4037-8F2C-7840D75C3FD0', 'D824B725-6800-4CEF-8116-3863BE8B6073', '4602876000991', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6A25EF8-4F05-4CF6-BFF0-1DF3AF6EBDEB', 'D707D92F-2ED1-4C96-AF93-7B789D05D1DA', '4602876001233', '        250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C521441-9EB9-4ADE-9DCD-5C64E0EFBE2A', 'E4D69347-F1CF-4746-9C9A-2CFAAD7B15A6', '4602876001615', '  / / 10%  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98A98F23-6264-4209-A86A-1B694593C18F', 'AEEEFD22-3D1D-463E-8BE4-788A9427C8F9', '4602876001622', '   30%  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF1EB0B7-A33F-49BA-9647-8C15FF9F44A3', 'E802BDBB-52F2-48DB-9D0A-2387991C1832', '4602876001653', '  12  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7CF1AF2-7DA2-451B-9FF6-4B0CBBB4CBD2', 'CED98BD1-79A8-48FC-B191-F0F6CD18B8E5', '4602876001660', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('231EBEB4-2E38-44F5-8C3D-FDA817B9D9B2', 'D1B6B48F-F0E5-4910-8EA8-BCDDA707E8D6', '4602876001677', '  33.  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA36A140-B31E-492B-9CFF-7E9AA520DEEE', 'C46A5D85-3C21-4DE9-9513-3DA422184F9E', '4602876002346', '  /./  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('602B5C97-B00A-4155-9CF8-3D080452AE74', '4AF4122E-0A68-47CF-8C4C-F4048398BBF4', '4602876002711', '  / / 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('547508BD-0DE1-4B6B-B8E2-F83A5C843102', '4F412C5D-1E44-4923-8737-FC111FB814B4', '4602876002780', '  //  13 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67C245E8-76FD-44CF-B2A4-DBBEFD5FF67A', '8E3E477E-3DEC-4C0A-B3A9-DD4AA0BEEF1E', '4602876003367', '    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D0754C9-937A-4B5E-B52D-8EF198FF2F57', '43DBD515-CDC3-41C7-9CE7-E404393F248C', '4602876004388', ' 100 / -   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17126511-A1C5-4D4A-AFF9-D79B9FB71469', 'EBA59590-12FC-41F6-B8A0-0400E2152E15', '4602876004401', ' 200 / -   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('021B00E7-0798-4CC3-9043-8352316F77E7', '1D8B5BBB-E00F-4DED-BEA7-0737F49F635B', '4602876004425', '  3,44%   - 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B62CE35-DAF4-455A-BCAA-5ED929D327D8', 'EAABE21B-C9EB-4C05-AC33-1C4555D07091', '4602876004500', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('842F431F-AF4D-400A-A83C-46300341A71E', '83528BB6-FA1B-4F80-9AF0-2E895C0E9820', '4602876004616', '     13 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA88A2E0-6EF6-49E0-8D76-DB4DD4975B53', '655F02B7-164F-426A-AB4D-9D189EDBEC23', '4602876004623', '   13 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32D4B03A-FEEA-4D99-9938-0C02DCB2CFF6', 'E5352466-DD56-4B04-8BD1-E5CA68E27C79', '4602876004845', ' 250  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8456D09B-2ACE-4580-BAB0-A7265F557FB8', 'A1D13D74-F7CF-4746-A4A8-E7833D20F85A', '4602876005217', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F32C050-CC32-4929-9418-C4A94C30070F', '22D13690-086F-454C-BA88-D942FDA034D4', '4602876005255', ' 100   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A21363A-B1FA-44C8-B195-6077FAD037EC', '3974F504-298C-4B62-8890-910BD2105773', '4602876005491', '* 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E234D391-A724-4B76-907D-8482DD9280FE', '4129DEA1-0A21-4638-A5EF-EAEF6D98A3A6', '4602876005590', '  50  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D1AB306-CF3D-45CB-934C-B3A8AAE59EDF', 'E5AF47AF-3402-4416-897A-F21C124B6BE1', '4602884000051', ' 200  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A95F74A1-1683-4251-98EB-765F77238E8A', 'C042F94D-B419-4FE8-9D92-001AA78DEF00', '4602884000198', ' 0,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCF0D634-E057-44CC-A18C-9B92A2F16E6F', 'F6869845-B447-431F-9204-75641839944B', '4602884000204', ' 125  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('577BEED1-4256-481A-BE21-1694DA1D1560', '3E0F790E-BF13-4E29-B4A1-D90BF3B2DE2A', '4602884000273', '  10. / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68C04AD6-9966-40C6-8851-C0255AAB64BF', 'DC4B21ED-E700-42D6-9D28-3C2757A00ECE', '4602884000419', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B968B52-0D0A-44DE-B302-B4651EDE4BF2', 'ACF23BB5-B384-46D9-BF24-673E93BF2AF8', '4602884000426', ' 10%  25*', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3589E6D-3F01-4579-9E5F-4D19941C1C04', '5BBC4282-F251-4EF4-A147-87FCDEC6E5B5', '4602884000686', '  100000 /. 1 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A610AAE5-ED06-4B9F-8B70-165C81845B5F', '56E9F86C-6015-4A61-9015-98051695C16D', '4602884001423', ' 250000   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E536269-6E31-4F74-8C43-F731A7CBD09C', 'C278C3F1-6F29-45D7-A650-5EF5E896E2F9', '4602884001430', ' 500000   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22DAA3EA-E259-4D8A-9E40-C9DAB018FF94', 'C1B7A181-E890-467D-864E-8BFDC53BDDA7', '4602884001447', '   100 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9956A1CD-1490-47F9-8AFF-EED079565DAD', '7ABEDCD0-9555-4FE7-A499-75C2EFD3B76D', '4602884002512', '   0,25% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCBC953D-93AA-4909-A5DF-BBFCDA4792C9', '991422E3-83BD-44C0-971E-801C16A0A902', '4602884003090', ' 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C34F37B9-4523-4E3D-B050-EDBCCF3BD1A1', '8614516E-F0BF-4EDF-89ED-66B748E71579', '4602884003182', ' 250000   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10D05FD1-6A7F-4839-9F47-7958A1F342BD', '9E8D58B9-9EBF-4FEF-B0A4-70C606F35913', '4602884003199', ' 500 .   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E54CCC6-F606-4C10-8E61-040FF0046120', '8066739D-270D-4905-8A2B-1E72E9D3622B', '4602884003243', ' 40  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EABFB81-F185-4EAB-A86B-2C44256E521F', '9107AA5F-96A9-457C-A73C-A7B52D80AC32', '4602884003564', '  250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCD9924D-4723-4630-A343-E89B83BB11E1', 'E6AF3613-5DB0-4348-94EC-57DA799AE575', '4602884005001', ' 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF699E37-4493-4D47-8498-D2443722D41D', 'B0CF804F-E3CE-4C9F-9F4A-0A9685469357', '4602884005568', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06E7B3C0-7603-4A49-8576-B01789E2AA7D', 'DA5CB872-D840-4A42-BED7-8F05CE3CCD4B', '4602884006022', ' 10%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDE313CB-84CF-4432-A86E-2CFF3B67FF33', 'DB6FB4F2-F611-4C5E-A997-F72D662D9549', '4602884006466', ' 25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8138EE2D-5C56-4EAB-8CB1-EF2F8A19142D', 'C7627530-717C-453E-80E0-CB2AA7BA8E39', '4602884007883', ' 300  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD0F6B40-7597-41AE-BD82-69434D6A622B', 'AD8A3F5E-FF1E-4E3A-A25B-77FF79373E48', '4602884008163', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CD41BB1-EF34-4360-B6C6-738D7CB2CDC3', 'B9C17363-740C-4D02-8B86-23BC405857D5', '4602884008385', ' 1 %   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8D42316-81A1-4A56-BCDC-51F2540140D1', '64292FE9-1F6E-46BF-B43D-21C3E68B8A03', '4602884008651', ' 500   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFEC2126-9CE2-4905-9FA2-35916DFF4A2E', 'F723737C-C104-48EA-BB4D-533F006E61D8', '4602884008798', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AFCDA09-D163-4851-A00A-13300760E313', 'BE363822-1149-435A-93D9-5BE102211195', '4602884009108', '  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DD6B23C-51A0-4568-9335-D2DD6A619247', 'AE36455A-6678-4B09-9EB2-080CFAA370E5', '4602884009290', ' /; /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A86F0269-0787-4203-BC7C-9A0D6DFF77DD', '6ED63115-234B-431C-92BE-13C56A31503C', '4602884010333', ' 0,1  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E26E563-9CB6-4372-86EE-A295C539B802', '450AA512-5A49-467C-BA33-274D15C00007', '4602884010364', '  100000  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9D36F5E-2197-451F-A1CC-39DF0AA66DD8', '82491B95-3F02-463A-A844-A9DA8810F1EF', '4602884010418', ' 47,5+77,5  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('608BF117-A0EF-4438-9FEF-5533C45AAE54', '5EAA9CB7-A99F-4248-AA06-EFB60DF0F968', '4602884010913', '  /  2,5% 30 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('055C7C78-D503-4EC3-8608-B4FFE15B5B20', '9286C3D3-9BDD-464B-B697-A79DCD19C663', '4602884010937', ' 2,5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA2D451D-0C03-42DD-9492-20D38CB4BCBA', 'DD9D74C9-B1F5-4375-BBD2-BD3547BD5DFD', '4602884010944', ' 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A62BC106-1E7C-4857-BC3F-3E9EBD7C25AD', '9E8BB9D0-1E3C-4979-9B8A-24309BA40B02', '4602884011309', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F436A165-151A-46D1-995B-B16DAB2238D1', 'F9B53EE6-539C-4A2F-ABA4-C35D52CD29C4', '4602884012467', ' 250  /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA825F4C-AC73-42EF-B18A-FFB0ACC6FB4B', 'FAB51128-9A21-4395-B629-5AEB6E709AED', '4602884013433', '  100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E705DEE9-FBE7-49B6-BDAD-EFBE4741E4D3', 'F9649F8F-E801-4478-9D1E-5425A3133F04', '4602884013631', ' / 2% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D04BE697-78FB-4E80-9552-9A6D0DF9F0E6', 'FBC2B143-7D55-4D7A-BB6F-0CA0AE9195D9', '4602884013938', ' 50  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82FF4DD4-8BB4-4672-A4F9-EBB22B023288', '7E537EC9-BD2D-4E8B-8C59-551E41B95BFC', '4602884014072', ' 12,5% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D8B2EE2-BAA4-4869-89B5-71E715D5402C', '77102916-6714-4A9D-AF87-BCDDAA9BF434', '4602884014096', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D90BB8E-2A4F-45F8-933F-5BF626B95CC1', '02773E79-42E1-46C6-8887-4D12D5A1CB99', '4602884014171', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB9C0B03-11EC-454E-B898-02F14DFBC392', '61085DE0-1601-422A-AB49-54B856BF727A', '4602884014225', ' 50 2 / / -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0096F26A-61B6-4DB1-99B5-6BA17535C956', 'FA15C994-21A1-4F25-8940-BEF9A39F2B9D', '4602884015666', ' 2% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1915609B-26B1-4026-96F7-B61CA58A853A', 'B5499D2A-2FC5-49EE-A606-5D3FC595F297', '4602884015727', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DF78F3A-57EB-46EE-9286-505996CA0738', 'DCEC745C-5089-4E69-82B5-CEECDF57DFC6', '4602884016083', ' 0,5% 10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7DBAC58-DBB0-4C76-AC33-28D41FD7B6BA', '78B24F1E-A7F4-488E-8975-A1B44AD1CDFB', '4602884016090', ' 3% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70CC5A71-DF25-49A5-9F7C-EDDE061CE82A', '686AE6EC-89C5-4470-8EEC-FA43B6081FDA', '4602884016151', ' 1 / / / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39615E7C-3896-4484-8574-245C62AC6C18', '8AD45809-CBEF-44EC-84B1-F011D634B3F8', '4602884016410', ' 0,5%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8E1E762-06BB-4AC2-A9E9-875239D94904', 'C8335160-84DD-4AF2-A19B-ACFAB0041CA5', '4602884017080', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70702E1D-23DD-4FCE-B1B6-7A43D10AE244', 'FF2A6465-C1B1-4DE1-AC5D-B96BC6DDD816', '4602884017110', ' 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E079A11A-3413-4E74-958D-0DADC296B731', 'BB1CC96B-C435-4A9B-823F-3D343C5CB808', '4602902000216', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFB004DE-02AE-47B8-9FA5-2BF9FC1B71D3', '38405230-C8C7-4FF3-B050-CF90E05501B0', '4602902000391', '   / 57 // /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFEFB29E-52CA-4518-BE55-56DEB7620FBD', 'EC6CD614-CBBB-434F-A938-FF2BA4EA76C8', '4602902000483', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E16CDC2-C27B-4335-9590-C18F6AFB5D88', 'A2EADBBC-3042-433B-A532-4A17986F38A7', '4602902000520', '   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8EADBA1-1CDA-4275-836A-3B36140938A2', '8E98FE0A-348B-4397-8CAC-EF0770718AEB', '4602902000872', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('909ACE96-927D-4E76-8CC9-71DE237C5D25', 'E0B787DC-A877-4E78-8265-1E0E81E431E7', '4602902000926', ' / 57', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7078AC63-E8BB-4D77-AFA6-B1C92F688D2F', '8B1AC026-C8E1-4C16-B24C-B5E8501E7A2A', '4602902001404', ' //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47D004B8-56AE-4EFE-A069-A2E4A7EFADA4', '8B1AC026-C8E1-4C16-B24C-B5E8501E7A2A', '4602902001473', ' //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('762B5749-4B8E-492F-A58F-9E9AA77654FE', 'F9968FCD-7BC2-4221-8823-6BE79295498E', '4602902002012', '     130*180 / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('543DBC85-4C16-444D-89E1-4D61E872A9BA', '7176914D-414E-405B-A794-AB74B47DA631', '4602930005184', ' 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B6325CF-1E30-4069-99E3-2791CE0A2768', '29800B83-4572-47D9-93B7-6118DC28CC3F', '4602930005214', ' 100  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7233D087-91C3-4577-AB73-B4732840DB73', '4F8977C0-9918-43ED-8052-E3A7BF532C5B', '4602930006396', ' 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F51B67DC-6E7D-437B-AA85-B3ECC3834723', '6CA577D2-6B0D-43E3-B671-C44D953B5595', '4602930006686', ' 50  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E52F2C0-F4D8-41EF-8C74-9F9E682C0C88', '0F039235-2E37-401D-B5E7-9BE57212B140', '4602930007140', ' 50  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ADFE01E-513C-4D5D-A5D7-83CE383A9F01', '4B2E8846-9E46-4223-AF15-04C0AA8E296C', '4602930007799', ' 100  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CF0DCE4-94FB-423D-A572-7AC2D76D5FBF', '0C3715A2-549B-4F9B-B2BA-854C2200256C', '4602930007836', ' 100  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66BB0D7C-9700-4B94-A6C0-D8BD43DB25EE', '202A601F-6F42-47C9-A034-945BD160AFA7', '4602930007928', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60F5F93D-F22F-4DB4-8661-BD721A9795B0', '3C3E8646-A117-4B84-B6A8-E77D2847BCF8', '4602930007942', ' 0,04  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('072E67F0-CDCA-4FC9-8D45-AF942BB3F8FA', '2D51D5BA-35B6-4B9A-AB73-ABF74FF576B6', '4602930008024', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B03B1405-4234-4982-BBA1-CB9338A0BFD5', 'A4C011FE-E90A-4FF9-AA21-876918210477', '4602930008567', ' 320  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B35ECB9-2515-456E-AFBD-C19992805C95', '7D2DDEC8-3A4E-4A69-BE33-AD5CB54C7432', '4602930008574', ' 320  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('964C977D-B54A-47C9-83E1-4B7F4DB584A2', '1793964C-0FDD-4E68-8AF9-26A4637AE91D', '4602932000088', '  2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D392243B-C9D8-4004-A9BB-436C7410B594', '4C778376-4672-4553-9F63-FC4C9AB09947', '4602932000361', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('931E3C7E-76E4-44B6-AB36-798CC513F768', 'AE90631E-DFB5-4905-B9D0-522F34CAFB74', '4602932004772', ' 450  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F50390A-300C-44B7-AD5F-792765D30C4A', '3310242C-B481-4E5F-A7F9-2F17E9898532', '4602932004789', ' 450  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C71F32C-66E4-442A-9D23-F1B0A3976F0E', '33F8DE06-0BBE-4002-82AC-A48595F17697', '4602932005359', ' 450  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C85B956-06E8-4F1A-B091-B476BD190C6B', '3FCA33C6-2755-4924-B3B6-BEBDD2D2EC7B', '4602943000893', ' 0,25/2 2 / -  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C11FFC08-3A6D-46D5-9E5F-A0F2B318404D', '55D04226-0D95-4817-AB6F-1D7E5C9CBDD7', '4602943000985', ' 12,5% 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6511ABD4-4D4B-4995-8B68-AA2B1DE596C7', 'C76A23CC-B2FA-43B0-8F75-358DA33B3391', '4602957000049', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('927C7D98-56BF-414C-83A9-A2FAAC02D326', 'EFE41C09-A2DA-4A0C-92E2-9F11B5580EBD', '4602957000063', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8882E17C-DEEE-46B6-909E-AEBB1A5D661B', '40ABF607-1E66-4788-BD7D-955598EDEFE3', '4602957000070', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3D048C8-957D-411A-B987-343615524F0B', '338EE07B-EAA8-4969-B008-080BB3052AC5', '4602957000094', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B3C16B2-5E91-4E7A-BF8A-4A22090D0872', '56576E91-554A-4561-A227-7EA4486697B8', '4602957000100', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73A5B60D-9A92-4122-B2A9-B74A268C8673', '0B66276D-445C-4F4B-91E5-13B1967F5373', '4602957000483', ' 3  .  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9D05050-8061-4E55-93F8-98C8D9339EFC', 'D2903262-FA62-4258-94C4-B766A720D380', '4602957000520', '  2,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C196D8EA-20F6-4F5B-9536-D4D07EA91F27', '786C3403-93DD-45F3-A4A7-411CAD8F39D3', '4602957000544', '  100    10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4F7F5D1-D681-466D-9772-DA49A4939507', '818515EE-5668-465C-AA8D-3D46D08DBCD2', '4602957000599', ' 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A8D47EF-3A1F-45D4-B9AA-ACD104BAD575', 'FF999380-73F1-4A48-BE81-21947EEFBB72', '4602957000612', '  33000  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B01D0C7-AB0C-4DE0-B1D2-829BA5752116', '7ED5609B-9905-4711-A247-ECCF91CDF522', '4602957000636', '  2,5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85BE8A12-409E-4CD4-99A2-CF245CBCE4DB', 'C0423A3E-0FAB-4414-A281-4DB20D5A8519', '4602957000643', ' 200  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C52EF37B-26FB-4708-B24C-270076E7DA91', 'F9615CE7-3330-4AD1-B0BE-D54BF3F7AE67', '4602957000650', '  /  / 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9509109B-11A4-4CA9-8481-12DF792F7A04', 'C0423A3E-0FAB-4414-A281-4DB20D5A8519', '4602957000667', ' 200  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1E2A514-01B8-4CD5-A719-D875BF38E1EB', 'FDA0AD07-EFC6-4470-80F0-1A9DEA4EAA48', '4602957000698', '      1,47 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44A5458C-D7CE-4598-8D8C-BD89039F5372', 'F9615CE7-3330-4AD1-B0BE-D54BF3F7AE67', '4602957000728', '  /  / 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B8DFBD1-AC24-4759-A9C7-D4064B3A4BD0', '5BC76AEB-1863-4D3C-80A8-E7C47C82D082', '4602957000759', '   200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('360D4E48-AD7B-46BB-9FAF-AFB2F10B5168', '818515EE-5668-465C-AA8D-3D46D08DBCD2', '4602957000896', ' 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB73EA8-A6D0-4141-87F6-8790BB92ED71', '22D7936D-4B7B-4231-B916-BA8F9101214C', '4602957000902', ' . 50  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D2E7AEC-C9E5-4902-85C6-14FE5FBC54DB', 'A8821A48-47D2-403D-8000-50576AA7F78B', '4602957000940', '  2,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86938FAC-7C55-4073-AFD9-99C7BE967A97', 'EE372204-7ECF-4762-A12C-694773651D99', '4602957000957', '  life ascorbic acid 2,5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D7FF584-FB55-48D9-99A0-057B7F932CA3', '6EA7887F-4542-4C94-BA2E-3016ED450C63', '4603014001009', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9C454DE-812F-41E2-93E6-EBCDEC6436AE', '3DC70EDD-6752-4C6C-996D-9CD94241DB9C', '4603014001016', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADE59454-E214-4B2C-9C8E-6CBDC3426186', '1BF6BF6D-135B-4EC0-891A-ABCAE9A13D43', '4603014001061', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6E5A024-E8A7-40C0-9E35-D46BDCEE94CB', 'D8CB6A50-41D4-47C6-B29F-3AC9F6A383B8', '4603014001078', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31FE439D-9652-4E91-BFAD-26E20B636804', 'CA9F787D-63BB-4A78-BA81-AB1BF6A5E080', '4603014001085', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58158DE3-6CC4-421D-A31B-C74C4C76D4DD', 'EA1181EE-CC6B-426A-9FA1-58003035DB38', '4603014001092', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('392506FF-5E1A-4F99-BB28-973A06E4529E', '3E6953D6-7512-472D-B116-F710082718C4', '4603014001108', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('149D5187-808F-4BEC-9F73-8633FBA3A42B', '4AB0AC39-A901-485B-84AB-29D5435F4D07', '4603014001115', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8E9F304-D171-40C6-B177-F82435422E94', 'F168C1A4-9925-4D81-824C-49577B014CAC', '4603014001122', '    - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5B8CD29-D2ED-4E97-9E31-36A73B846159', '7D1F554C-1246-4012-A0D1-CA82ABF923CB', '4603014001139', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0083BCA8-F409-4ABA-840E-9E40FA5B9FA5', '9C791A17-426E-444B-AD38-C7051829930D', '4603014001283', '   / /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60D4C245-7550-4925-A90E-DEB110C495CA', '3E6953D6-7512-472D-B116-F710082718C4', '4603014001320', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('220927CC-B5CC-48F0-9464-9981E6E7EEE5', '4C4A94A1-51E3-49F5-BFD5-CFC68237159E', '4603014001573', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89C0A3E5-BD73-40AC-A605-49704233982F', '7B98F3A3-0617-47B2-99EC-D9BC3476D8EE', '4603014001733', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BFFE856-74D8-4D12-8CEB-0EC02F9DB857', '4FE29E78-E079-43AA-82B3-20B04665FD37', '4603014001757', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3780BAE5-C729-4C9C-BE8E-5469517CC8DF', 'FEC732A1-F266-49D3-8CF7-9CB7E3616B5F', '4603014001771', '     / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E30A5BE-9B99-45D5-91BE-F864BDD3EC4C', '54AEDA42-B3EC-4384-89CF-B6926F0FF502', '4603014001795', '     / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F697D541-214E-4C8B-81AD-E41970B677FD', '2842265B-5713-4232-9676-634E4B6E1109', '4603014002037', '  /   2  1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('257E2860-5EB9-46C4-9C01-F9C525050303', '3C9D82F8-9FC4-4DA3-9B81-E98375D8C79A', '4603014002433', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('450887D3-2D92-4D33-B930-7B3D28FABBDA', '2E0A1D1B-EC2C-4D0B-A69E-A4EDFE14A3EC', '4603014002457', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD65029A-2E44-4DEC-823F-1C20D56FDDAB', '4ED683B3-C50D-49E8-B7CF-8739DC617EE6', '4603014002488', '  splat professional   /.  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35DED6F9-B9FD-41EF-8B33-F5A299FE685D', '8991E7C2-5DE0-4F87-92F5-B0BF52626C30', '4603014002549', '  splat professional   /.  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48EF29B6-89A1-4630-B97B-3D86D41E0356', '2E0A1D1B-EC2C-4D0B-A69E-A4EDFE14A3EC', '4603014002693', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83AA9180-2F16-465A-9646-888925439641', '7EFCE057-5060-42D9-948A-09ED8DFDE6A7', '4603014002990', '         75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50F9C4C1-D352-4246-BBEA-34EEDED77935', '8D45BD8C-2C94-45B5-A731-C3BD9868B387', '4603014003805', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F97F435-7403-4814-855B-F1A4D7AC7FA1', '6D979E28-DC16-452A-8CDB-E66996040983', '4603014004789', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D86E770-6CA5-43CD-83B8-CA02E7F39E18', '7DD3063D-39F3-4173-905F-7104AFEDE9D9', '4603014005106', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9119845C-5471-47FE-BEE7-02717B5A731D', 'A3615096-3220-49F4-87C5-3863EDE722F8', '4603014005526', ' /    comple 275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AE28E55-F331-407B-B0B4-259533617F58', '03187AC1-D73A-4457-89A8-F9C03880C6FF', '4603014005878', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B99161F-14C5-4772-BBFD-7CC305D8E390', '01F66932-CB22-4E02-A00E-7CEBF8EDB754', '4603014006233', '      0-3  +  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2674FE17-5852-4E32-BBC3-996C742E3816', '3FA4586E-94F0-4A04-AD68-E63AB788BBF9', '4603014006257', '    0-3    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFBB612B-F05C-4ACA-BDEE-E4819D9168D9', 'C3DBCC69-1352-444B-B386-F3FE3EFD2DB9', '4603014006295', '     2  6    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48CA5680-76CA-40F3-A663-0A61D633163E', '84D1626D-C2B4-4907-9249-5EB1286C300F', '4603014006318', '     2  6  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3FC4F76-66A8-4EC7-BCEE-4878A4482A67', 'E361A56D-816C-480D-B588-AD756B5784A7', '4603014007247', '   .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EEF14D6-91AD-4E42-A688-BD1C663458FD', '4ED683B3-C50D-49E8-B7CF-8739DC617EE6', '4603014007278', '  splat professional   /.  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73EAB6D3-3486-447F-999A-5FE23AF99984', '74E1ED23-600F-446E-8D5E-2F2ED71B7769', '4603014007285', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C099CB5-DFB7-43EA-AEB5-D781DEF55CB5', '8991E7C2-5DE0-4F87-92F5-B0BF52626C30', '4603014007292', '  splat professional   /.  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('566194DD-BC23-4086-8C70-67CF678D116D', 'A7D7CBEA-B1AA-422C-8F05-5509B75F3FE4', '4603041000020', ' /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5660E717-00FB-47E5-9F07-E69DB77784C6', 'AC44234D-0396-4467-BE3F-04EFA9EB339B', '4603149000106', ' 10  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61F3F727-433A-4A6C-87D7-EB256E4E7AFE', '4B4647A5-5C5D-4B60-8A88-1117C60D22B8', '4603149000229', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53C3D6FD-C52E-4BA3-8D6B-419396548E17', 'C95E0B1B-EECE-4D5B-A8F3-AF4557801DE3', '4603149000274', ' 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BBFCF4E-E059-4C94-A02A-C1A32BB06735', 'B63AA690-8403-4B69-B441-C1E04B9B1D52', '4603149000298', ' 250  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0242B3A4-C5A7-4D84-9AD6-66A108CD88ED', 'BEB157A6-611B-423E-91E4-212297F6BAB6', '4603149000304', ' 500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D89EE67-513B-4166-BF9C-B1E851BA87AF', 'B35609A9-9A0A-420E-8081-90EB2BBE46C5', '4603149000380', ' 200 125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('096561BB-853F-4630-A384-8BCDCEEF6D3E', '64FBFD6B-9381-4DE7-A023-30CE501EA0E8', '4603149000410', ' 800  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F62DA33B-B5E5-46BB-8AE9-FC18C2C34B52', '9C764BFA-5572-49A5-B4A8-6660F9AB8000', '4603149000427', ' 1200  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1862FB63-E584-42A5-A68B-346527836E8D', '6013D988-51D2-45CF-930C-C7C4C14DEB54', '4603149000465', ' 5  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1691E782-087D-42F4-865F-111857BACE2C', 'C95E0B1B-EECE-4D5B-A8F3-AF4557801DE3', '4603149000472', ' 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF2E83C0-0C3F-4DEC-9AF3-D7C936C46B98', 'C5111988-2463-46CD-A431-D8C089234D75', '4603149000533', ' 5 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D9485A4-A50F-4AA3-A51E-84C73E7A7EE6', 'D66E168A-30B5-4548-962D-7995EB57D784', '4603149000557', ' 20% 5  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49F90F3F-BC6B-450D-9FE5-B2428B3B3DB0', 'B63AA690-8403-4B69-B441-C1E04B9B1D52', '4603149000571', ' 250  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B82A2A79-566F-4AB6-9CE6-D9184EC04617', 'BEB157A6-611B-423E-91E4-212297F6BAB6', '4603149000588', ' 500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5324007-28F1-4FD8-BAF1-13B2BF48D02E', '4B4647A5-5C5D-4B60-8A88-1117C60D22B8', '4603149000595', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6357FF0E-EB26-40D7-BEFD-23B52B69CB79', 'B63AA690-8403-4B69-B441-C1E04B9B1D52', '4603149000618', ' 250  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8A52E0F-37A0-4419-96CA-E4EB9DD1E75A', '46676851-7578-440F-93FF-24282A5DC784', '4603149000656', ' 10  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B97EAF6-C9C2-421B-BA7D-A6ECFB34B91A', '949B4B14-D5C4-4CF5-9D7A-577FA54FC253', '4603164000143', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D01E257-3EF8-4E04-947B-ED34D03A26FE', 'E7081063-306D-452F-940A-16D97201CF18', '4603164000181', ' 0,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56BDFCF1-9751-4DA9-95DD-795CF52C4D07', 'D9724BD8-2806-4E63-917C-977FA9BBB536', '4603164000204', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB46100C-C2E0-44E0-A673-5405F8C487E8', '41EC1E1D-6D47-4F23-BC81-08BBD2CE625B', '4603164000648', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22A8BF17-45A9-4CE3-BE2C-7CBA15409E63', 'E52F9B9E-FF3B-4D0A-845C-4A24D3475306', '4603173000240', '   / 3 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DF3352D-EC36-4BCB-AF99-4AFAB73F1E46', 'FBC2B143-7D55-4D7A-BB6F-0CA0AE9195D9', '4603179000107', ' 50  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91738E63-3884-43BD-93CA-48B11FFE24EF', 'FDEB511C-43F6-4EBE-A2D8-D6B4E791DF14', '4603179000367', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B70D06F-02B1-427B-9A0D-E85C4F145F81', '9FC6AC3C-B6CB-4B22-88C7-328A781B1CE1', '4603179000718', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B177C5B2-D9E8-4E03-AE21-4A08B7341CD2', 'ECFDCCEB-C5B7-4A5E-A3F7-0596FF56B558', '4603179002774', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98D1BADB-539A-4E77-AC4D-6A45184C284F', '4AC2FE54-B3B0-41C6-B67B-45E9D6B646A4', '4603179003214', ' 50  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54290586-4F35-4FCC-B528-DA4A1AE72455', '28A58FAC-AEAF-4E47-AA0B-5ACC5E61EA57', '4603179003368', ' - 25  . 50  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53C412CE-A273-46AB-9A54-FB5C1FF0B164', '9EE81E35-E422-4489-AD98-712AF68B41D3', '4603179003696', '    6  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29202772-D1C3-4081-B9BA-45A7FD4C96D4', 'B6303C1B-951D-484C-A900-11276716F17F', '4603179003702', '  3  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('018A4116-B363-473B-A487-0B0D7612349F', 'E7FE26DB-DC7C-415D-9E86-497CC36C2D6F', '4603179003719', '  /-  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71D20AE6-158C-419D-AAFC-E2B291DF336C', 'E52FBF9F-A621-4CF6-855D-A82A1F6EE63C', '4603179003726', '   0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32298C80-A1E6-43DB-9B25-626C7D74492E', '19DB5F9D-1D89-4FF1-B40F-9D1202D2B096', '4603179004150', '   / 5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4BDBBF6-9ADC-4380-8C80-9BE15B6D764E', '9CA2F1FD-9D9F-47AC-89D0-E5A895528D0D', '4603179004167', '  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06027F59-8716-476A-BD25-D8119C44AA57', 'E0C3042A-F308-4C7C-BF3C-230E15C7FB4D', '4603179004211', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFED700E-2D53-49F4-BB7F-568F8E25C6FE', '7E119281-F9EE-4DE0-B85A-D5ECA3B3304F', '4603179004396', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8192266E-201C-4858-9059-C1BAF8FC88D1', 'EFD609FE-391C-4399-B884-7BBEED8A7C6A', '4603179004402', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59D61C13-5912-4D11-9C21-43300E7E308A', 'D78E698E-2555-4BD9-A065-2E97E5FC0053', '4603179004587', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09F7E75D-2276-4CDD-BB6B-CED6831133EB', 'F16DF62E-6679-4BFE-989D-AB39652DCB17', '4603179004631', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2AD0583-E74A-434E-9BEF-F761FE302E51', 'C8D5B542-BE6A-4C4B-ACFD-E87C0F918ABB', '4603179004686', '  / - /. .  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C62EAFE6-8BF9-43C5-AC50-C5F2275C345A', 'C115FB8E-56D7-4E10-9A7F-DB995A6BB8A3', '4603182001092', '-  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62E39195-60F9-4660-9B65-1CAAD72E6B7E', 'DCA08CFB-90DB-4112-ABBD-ACD8B37D1736', '4603182001221', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50E3C2E7-CAD2-4249-B0C6-2FE182C65EA2', '78DC1FA6-F78D-40D8-891B-ABC62B0424E8', '4603182002020', ' 0,04 ///  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3627D276-3872-4FD7-B25A-0BFE62CD6A5B', 'F6E5A801-6F2F-4553-A51F-D5BB78AB0154', '4603182002051', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E33CB793-3D48-4A47-8F8D-89B6B28AC3CE', 'D7871D5D-0746-4A24-9693-341F246CE1DB', '4603182002181', '  500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AD21537-B662-45C9-8237-AC5A38255F7F', '003EF781-5203-476A-9CCF-8897F29E21ED', '4603182002228', ' 0,05  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0043866F-A1B3-4B63-BF8C-DF09B7C89B6F', '5B72CD12-5F60-4B1D-9ECC-A3B7FBBFEDB7', '4603182002235', '  250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6074D41-5C8B-4D18-9467-3719D5AB6E07', 'C11F83D0-62A8-4025-A781-604CAA8BDAC7', '4603182002280', ' 110  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DE0A25E-FF93-4378-847C-6EC65F92783A', 'E3509CA9-FFAA-4666-92E4-23E66A19C967', '4603182002303', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27678A9C-2A38-4E60-A703-B49DAE1A1992', 'BB075934-B648-42EF-BD90-6E370B8CAC9D', '4603182002310', ' 15  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A7D287C-B52B-4DEC-A8AB-BB3EF011EE59', '9EF4DD36-015F-48B1-AB8E-95EE7983DD75', '4603182002389', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF58CE75-9E82-4ADB-A545-1A3CB02E2CC5', 'F7B33774-9759-4851-B09E-43B78732F1AE', '4603182002402', ' 150  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EABC3118-2EEC-440F-B4AF-2E13C4000CBF', 'C040541A-53AE-45C6-85E4-93B98C013EF6', '4603182002433', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('352847CC-EECB-456C-9452-01A1CF4BBAFF', '7196AD34-DBC4-4241-BA4F-89E079749217', '4603182002495', ' 40  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8EFEDD4-E28C-478D-AA21-0406581EA709', '67C17336-0B20-4E45-87ED-506ADC774238', '4603182002570', '  100    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8B47484-4977-46C8-AD0A-D2C3D884EC2C', 'D69EEB5C-3059-40F2-8293-3FD1F9D8420A', '4603182002587', '- 0,1  // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F5CD29F-CE0C-4FAD-9E85-4576AE688F11', '8A58AAF6-77E7-4620-90FA-861A9736550D', '4603182002600', ' 250  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('794AED51-C9E1-4470-A07F-2FF78DBFE80A', '2B2AC0E4-29C8-4206-A552-306D3A383D8B', '4603182002617', ' 0,005  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3EFCD6C-09AE-4868-A424-BAE57A7BE7D2', '95B00D99-B1D1-463D-BACB-34E4A183DD3F', '4603182002624', ' 0,01  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D294CAC-9F8F-4778-B2DA-E5615450FB87', '2F8B4900-9628-445C-8577-01D6E64E7E4E', '4603182002631', ' 0,2  10', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83931230-4F04-4B58-BBAC-30E6E4DB8E5E', '969DBCF2-E921-4E45-9EFE-2ECB99C36589', '4603182002648', ' 0,2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C15065A8-0CF8-4E5F-BD70-BA8C7C1CAC7E', 'DEEF506B-DE83-4CBB-8DAB-FDA810401698', '4603182002655', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55045020-980C-4019-A336-495F7B973E26', 'B4F9A642-B072-44A3-B29E-C36D7C15FAE6', '4603182002662', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21EA2287-D6E6-4CDF-A62B-8A9B2BD0B1D8', 'FBE9A8D5-3120-462C-A12A-D942003431CE', '4603182002679', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97E3DE4B-2E44-453F-91D9-40C7A39711B6', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '4603182002709', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EFDBDBB-983B-4F86-87EC-A44A876469EF', '8F70342A-4DDA-4D44-A423-CCE29B27DF6B', '4603182002730', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88234A30-15F6-460C-B669-ECE7D4DB9CEF', 'F42CBA39-7E48-4B3D-A5DC-F09449585BDA', '4603182002761', '  0,04  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E93812F6-C5B9-4C53-B399-E23F71E0357A', '79965663-7DAA-45BA-9A90-44E3B23E8B4A', '4603182002778', ' 80  // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E860006A-CD6B-4B49-A0AB-82FF72852D57', 'DFA51B68-FA5C-42B5-8906-68ABC3A0C9A4', '4603182002808', ' 160  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('194C3D42-4818-4EA3-AE9E-3D4472036090', 'EB65956B-2F8C-4E0A-BC24-508B79BB6A51', '4603182002815', ' 0,15  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('291239F4-A945-401A-9418-5214FD610BFD', '1712E8B5-D123-43A7-BFD1-98CB0EE81C4B', '4603182005403', ' 0,5  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F587547D-1BCF-4418-AB9D-1796A149278B', 'DDE89BEA-FA0D-4165-9001-164B322F1C92', '4603182205261', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DEF7D10-AD14-4AC5-8E48-3ACCD66D4DAC', 'DDE89BEA-FA0D-4165-9001-164B322F1C92', '4603182205278', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2C9BA0F-EFCA-4881-BB4A-6F1ACD5E8DCF', '75AB940A-098A-48C3-A93A-0B8CFFEC6C1D', '4603182205285', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACED572B-B62E-405A-A22C-B03A03E3F640', 'E1833923-38BB-487A-AF22-5CF856DD3E0F', '4603182205292', '  3   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7F6DA6A-F976-42AD-A40D-5E672903B314', 'EB54B967-9F8E-4A81-A109-1B031986F77B', '4603184000079', ' 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8528748D-5374-4CDE-A006-8C31B7C0BA71', '98982169-BDD4-42BF-BE9F-2120D5200795', '4603184000093', '  1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE827014-8FC7-4B79-8E4B-D864F7166533', 'EAE284D7-A057-493B-B14B-2CEC079AD9D3', '4603184002295', ' - 3%  - 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59000554-1E7E-4454-AB59-671BD2545CD7', 'FA136A79-7429-42A0-9D2E-AC5173D39F42', '4603184003476', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F15000A-B51A-49B8-9C62-24025F33D851', 'DBB856BD-7D93-4618-B5FA-D9E139BDD3A7', '4603184003742', ' 3%  - 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19249271-CD3B-4E88-B79E-24838B9EF4D1', 'B8151DB6-B7C2-4C73-9AAE-7B85592FF6F2', '4603184003926', ' - ///// 1% 40 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51D305F0-F673-4BAA-B95D-B6785C6536F4', '38DC0189-FCE0-467D-9626-0D33AD382E98', '4603184003995', '  3% 100 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1EBEE24-60BF-4EB7-B469-83798396EBFD', '3FFE0FC4-8A57-4425-B1C9-A6E1B974B7CA', '4603184004084', '  1% 25 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB0943DC-94E5-4E0C-AB08-B3C6DAFBDE9B', 'BA129B1D-FBD1-41BE-A1D4-A5D690CD8741', '4603184004114', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EC8E292-C28C-41E6-8CA7-F35EFEC038CC', 'D22F119E-60BD-488B-A6AF-76DCE116ECC5', '4603184004176', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3D11E04-E79A-40BA-8D49-7B0EE520347E', '9015A993-23EB-4FD8-BA3B-29D1A44657C6', '4603184004244', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75254885-EF8F-4F78-AE16-27F3381C3AAA', 'F3BC84E9-6A8F-4916-9DFF-7D743587985E', '4603184004251', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B43F935E-2DBF-4210-A454-CFCA85D24ADB', 'BECF40A3-ED16-4E0F-91AC-5984D195BE4A', '4603184004299', ' 10% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA367624-2F41-4AEB-825E-AA6AA2143F64', 'E607A2BB-E2DE-4F50-B63C-78C73E83905E', '4603184004350', ' / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52B8AA3D-6D1A-43D3-8F59-4044D286DEFC', 'D381F4AF-D8BA-4183-9E47-5F35455C84F1', '4603184004497', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B59D609-AE1A-45FE-B2D6-606C7982AB51', 'DFEE6CC6-2267-46C8-BAAF-327A4D1ACDAF', '4603184004510', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C56CFE2-1D9A-4733-8E07-86DE880FBD6E', '92F3D310-9943-42A5-9433-81E2AB00C6A7', '4603188000297', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14A4A8AD-7EB9-4195-9275-8669441E6412', '40967FB6-D41C-4C12-9754-684EAE9B7992', '4603188000334', '    () 1 -4 (', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D1C8287-7AE3-4778-B659-907A9B2A5E02', 'B9388EB3-46BB-4796-B01A-2024A78B74FA', '4603188000433', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FDC4415-6F88-4800-BD86-FCD7EA05B032', '8D1E3356-7C0A-458A-AD19-E5880EE8AFA9', '4603188000457', '    4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67334114-63F0-430D-950D-5FCFF6CE157B', '500F0A94-0916-4132-A208-0B5829FC2F35', '4603188000471', '    1 -5 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('222F2A8C-5967-472E-B3A5-F1CA681A8742', 'F77B2952-D311-49ED-A6B9-02E981E36FBC', '4603188000518', '     -1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69F2CFF1-D7A8-4E47-B11A-84745C7AD718', '116BE98E-79FC-4701-A6CC-616E0BAA3848', '4603188000556', ' .   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('362A117F-3081-46BF-A21C-73EB16EE5F22', '14D61B64-A481-4AF5-8E7A-4885877D5F17', '4603188001331', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA0A2D95-B4E8-40FD-9A8F-B07DA890AE66', 'A2EADBBC-3042-433B-A532-4A17986F38A7', '4603188001355', '   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA649F42-4A71-48A1-AF54-4CD9756EEC91', 'E6C2EF89-9659-4A65-9128-B73F875B530A', '4603191000123', ' 1,5% 400 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60B69650-2A82-438D-BC24-EC9A4BC2EDE6', '68EC9033-1385-474E-BD51-11627EFC6507', '4603191000208', ' 150  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B054205D-BF00-4B1D-BF1E-3F49047972A5', 'A914C77F-49C0-4C12-96B3-8B02A6EA724E', '4603191000253', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8A1A765-5F80-45AF-8BAB-67D016A2DE81', '2DC7F670-147F-474B-8C40-C2FE4C63F797', '4603191000291', '  5% 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9306527E-93FC-4846-9F86-A19E6B15A8E8', '6178E468-2712-4EA3-B26C-A40C56EBD5ED', '4603191000307', ' 400 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26FCC51A-E8F8-4A99-912F-43429346C72F', '5A4AE5EA-1773-4738-A434-46530D510471', '4603191000604', ' 1,5% 200 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7A495F2-5E7C-4065-A290-921B078BA7B2', 'B3C2B031-5ECC-40D8-B3A5-E52F099ADEAC', '4603191000635', ' 150  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9991C697-CC11-4372-B5AE-8EC49A6936CF', '3F2ECBD6-442B-43EB-B408-FA7F8CBB6E79', '4603191000734', '    5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26E94994-43E1-46F5-90B1-3CF15BA0675C', 'DCDE06E4-342E-44DB-B413-A11FFDB4ABB1', '4603191000840', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAFA6B6F-C5C8-4E82-AD49-B413C8C07358', 'DCDE06E4-342E-44DB-B413-A11FFDB4ABB1', '4603191000857', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15370686-8526-42D9-8BA5-026F1F253A31', '42F15795-4D11-4477-AE3E-8AB354D1C395', '4603191000895', ' 0,15 //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB6322A2-D6E0-406E-9ED6-6BA6F10EF6AA', '0B2EC0FA-E8E3-4B42-AC1F-54E7F9D86F70', '4603191000956', '  1,5% 250 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2DD099D-415A-4605-A542-372AA5831C1B', '3E51E760-4939-4E52-8011-E103D2BF42DE', '4603191000963', '  1,5% 500 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('097AC56A-F3F8-4E99-912E-6CB9B6FA22CF', '0A77854D-0C46-49D8-80C3-067F33591917', '4603191001045', ' 12,5% 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CA7619A-0E76-462E-B661-DB0532CF919E', '9C47C6EB-B7F4-4DB0-A4F1-146CA1ED0A04', '4603191001434', ' 0,05 / / 5 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('607A7836-94F6-4631-9DD1-F61540EECC84', 'E60426B5-3E42-463F-9586-3D671F0564E9', '4603191001441', '  50 5 15 / / - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('156C11E3-8D88-41DC-9CF9-ABB91CDB9894', '994587A1-D640-4C75-8CF7-50010761B297', '4603231002186', ' - 0,5  . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF75FA81-6BD2-4F10-86CE-5371C7A21E32', 'E7C96DCD-767E-418C-ACA1-7A7D7BC6535F', '4603231002445', '.-     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A2EAFD8-D207-40DC-8C6A-8EA56D196BE6', '73BAE6EF-D2B6-4320-BAF1-9703C2F99892', '4603256000426', '  - 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D87A6232-B11F-45A8-9D67-E3547E133893', '924011C1-CF19-4F2E-92AB-002F6D5D963B', '4603256000815', '- 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E64A96F9-CAFE-499D-9238-743C68D6D34F', 'A135082D-976E-4D37-8E1F-C9381A5A4419', '4603256000891', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17922837-1CE1-4209-B466-30325B22B098', 'D381F4AF-D8BA-4183-9E47-5F35455C84F1', '4603256001478', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9DDB509-BB46-42FA-9B4C-7AB396D4020A', 'D310AFDD-5DEE-42CB-9755-1E8408813581', '4603256002307', ' 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA54F412-47F9-47AB-85DF-517B309A668C', '4664183F-2A28-4710-8B75-A42C1630F30E', '4603256003069', '  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99D90A87-0127-4007-BFC0-5727339ED41B', '7273BB5D-BF0B-47B5-BD2A-E0EE6080029A', '4603256005360', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0BDE7E5-16F3-4DBB-B7DB-F0615FFA6BF7', 'DE830E02-D2ED-490C-A935-EFC5D8846384', '4603256005643', ' 25  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4B7AEE7-D8C3-413A-A873-1D05BE9F0C8B', '4D65DF53-7FBA-49CE-93F8-51F835A8BAB2', '4603256009177', ' 0,2 / +- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3B01718-33C2-4277-8A63-BD10D263DA59', 'D78E698E-2555-4BD9-A065-2E97E5FC0053', '4603276000314', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8659AEFC-2814-4BD5-9219-1657C3F4EA50', 'E66C79EC-DB59-4932-BC8A-1155BB21FB26', '4603276000918', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E1083C1-643A-44C2-B99B-63A8ABC6858B', 'FD4DA183-1004-4F0E-B5BD-089F524009D9', '4603276001335', ' 0,25 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71DCA421-5C4D-4F4C-9D4B-9F6C3A0BFA34', 'F6E5A801-6F2F-4553-A51F-D5BB78AB0154', '4603276002523', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83D338D6-DB34-4FB1-9D9B-644FB4704290', 'B0CF804F-E3CE-4C9F-9F4A-0A9685469357', '4603276003032', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75507EC5-D1EA-4EBB-A650-1226C560CF38', 'DE588381-9539-4DF0-BD04-9AAD7C36ADFF', '4603276003094', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8EEE2FE-A12E-43F1-9A4F-1F4E8CDC8769', '957C8582-8708-46F2-A376-6D765A366EE3', '4603276003391', ' 40  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A06260C3-5628-4763-AD75-C4E78EFE1A34', '821DB938-2B70-40AD-A306-CE67AA477A4D', '4603276003407', ' 80  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55D8FE8D-BDC0-4B87-8411-67F1596F8442', 'E7AD194D-D645-4D53-9D6E-558FD7136A4C', '4603276004688', ' 50  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27060198-8115-4898-B29D-954F7B418663', '9A2F1AD0-3B0D-47F9-9EFF-CF5775906CC0', '4603276004961', ' 1,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E02A3E70-5AC2-490C-B777-E51C06995A0D', 'AD8A3F5E-FF1E-4E3A-A25B-77FF79373E48', '4603276005449', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B6593F7-6259-42FA-9051-4575B22D94DD', 'E24046D6-DE69-4B6D-ACF2-022DD1CFE5D1', '4603276005609', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18C95956-AFE2-484B-BA42-EB4169DE5949', 'E66C79EC-DB59-4932-BC8A-1155BB21FB26', '4603276005616', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACBE16DC-56E8-4A97-A19D-6B25FEBD919B', '87A67B06-434C-4DA2-9897-B3E4FE098271', '4603276005852', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FED2EB3E-009D-485D-B5D6-601E919E9B23', 'FBC2B143-7D55-4D7A-BB6F-0CA0AE9195D9', '4603276006439', ' 50  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CE9B689-3714-46AB-A27F-592BD07D8DEB', '15F2AA50-A34F-4EE0-B534-95E4730CD33D', '4603276006613', ' 1 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D80194D3-28CF-4F65-B79B-D4C60A4290FC', 'C774C8C3-7B93-4791-A2DE-DC449B3DFA55', '4603276006644', ' - 0,05  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B506AF6-0FF2-463D-AD95-28DDF25BD640', '8066739D-270D-4905-8A2B-1E72E9D3622B', '4603276006835', ' 40  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6517E88-D01F-43F8-AE5D-5B83D8DFB426', 'D5416C87-1AF1-4324-800C-7B3535322852', '4603276007054', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25F2E372-0558-44B0-A32F-2D52D562F4FE', '9574DC87-5178-4C28-A6EB-F3D375D53CC7', '4603276007115', ' 0,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84336432-824D-452C-B53B-300630652B4A', 'DB1F4BC9-0CB7-4ECF-94BB-71B89993BC9D', '4603276007139', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08A695C8-3C31-42E5-A0EF-82F4F6FC9BBA', 'DE588381-9539-4DF0-BD04-9AAD7C36ADFF', '4603276007153', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C68F2228-415E-402B-9AC5-F005D499A55A', 'E61F1AE5-2796-4651-BC0B-E10ACE7E46C5', '4603276007245', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C2F3157-5DBA-41BB-8269-B5955D824BFC', 'E61F1AE5-2796-4651-BC0B-E10ACE7E46C5', '4603276007252', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25583045-6D03-4025-96D8-A761764B7AF8', 'F759FB14-5962-4472-8B0B-46CF4B9FAC48', '4603276008082', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3EB673B-A47D-48F0-9670-CA37BB243DE3', '9574DC87-5178-4C28-A6EB-F3D375D53CC7', '4603276008112', ' 0,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9CC3C9E-396A-43AF-AD0F-1214606FB3D3', '5E9794A7-6865-418D-9D9D-9EE65177874A', '4603276008167', ' 250  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2F801CF-9F02-46EB-A571-C32C18316184', 'BB075934-B648-42EF-BD90-6E370B8CAC9D', '4603276008242', ' 15  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB089069-3C52-4327-909C-6216F334C9AB', '5A9CDDEA-C185-45A6-B45E-F4BC92A9E2D0', '4603276008563', '   56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FBDBCF3-EE5C-435E-8B04-D9981782EDB8', '86876A28-6FE9-4173-B5DE-919377CC3F17', '4603276008655', '  0,15  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62D232DB-B161-4FE1-9C27-2EE51CB971C3', '0A38747E-806E-4495-982A-1E4D6B5F4DBB', '4603276009256', '  20  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F54A50D-D93F-4A6D-8B77-A977806D2693', 'B01F0077-0EA3-4644-ABAA-DDF3EC47A987', '4603276009263', '  0,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9603F829-D75D-4749-BEC4-C550276C3212', '76F2B168-26B8-4FCD-9B97-3889F4BDDB76', '4603276009270', '  500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A583B1AC-7E09-48D2-AC7F-636DAA8DABA7', 'C0A502DF-EF2D-4E52-AB43-49DF98DE0EEC', '4603276009645', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12D2CDBA-2200-4105-9751-2C73FB7C1B9C', '569BB0FC-466B-4EA3-B5BA-3443A59C6470', '4603276009720', ' 10  // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('676B9F8C-C358-4D0F-A390-926B73185A36', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '4603276009744', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E661167-1705-425A-89A5-2F7368BDED5E', 'E464B6F6-E7AA-41FC-8105-4CDC10046A01', '4603276009850', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCD1A320-6D75-4531-8534-5A39DDF66CFD', 'E11D23F1-A698-48EB-A0AF-18C1FF8E2AB4', '4603290003667', '     5+ 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66A44811-B477-4D98-A677-1B198316C5F0', '8D68C5A9-5C82-4872-9ABF-61923DF209C4', '4603290003674', '     5+ 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C88960E4-FEA6-46CB-A910-FCF402C5F5A6', '897268ED-33C3-4E1E-AC24-1D9F142391ED', '4603290003681', '     5+ 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BF21576-D70F-4957-9694-F8D9B5F1E892', '5D418700-2AF8-4B09-ADE8-BA61EE46D6F1', '4603331000020', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD73D266-29D7-4407-9D42-F3F1B82AC94A', '1AFBF86B-BD34-4FBC-9765-291C99C23332', '4603331000037', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED871A41-41F4-4ADD-83FF-464FA621B686', 'DFAFD853-7BF4-422D-A5F8-E86488B9BDC0', '4603334001499', '   0,5    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84D3FE54-7564-4547-816F-DCCE65CEA124', '4D20167A-7EF8-475A-B5A7-291971FFCDD7', '4603334001529', '   0,5    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ABD0956-3EED-41EE-B2A1-0FCEA2154F85', '65726490-169A-410D-829C-70FA3DD5C1DA', '4603337000024', '   ()  /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('623C11C1-C39E-4FDB-8A06-DFD4BB4BB92D', '24248597-D77B-4669-9D98-8151C4328598', '4603341000232', '    220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97965795-7B0B-46D8-8B55-A95F3B99DC19', '3EE78172-2BDE-4F36-8564-869DCBB7679C', '4603341000294', '     8+220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25DEF1FF-F298-41D5-9A1E-26E974A39A12', '13A95953-5B53-4C67-AC95-BFDDE7739E67', '4603341000317', '     220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74F6F987-75A0-46B5-BF51-65827D543FBA', '4D5240BD-C3CE-49A1-A34C-EB9958882C34', '4603341000416', '    220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('053550D4-9295-4C03-A7DB-F6920EB27440', '17C3959B-C853-4A6C-9AD2-C9AE3DF14D8A', '4603341000492', '       220 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B77C052A-D1DD-4E0E-9EB0-9D84A3BDCE9A', 'A19C578A-28CB-4B27-A74C-F3DA65520438', '4603365000010', ' 0,1% 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('605A027B-3E6A-44DB-B5DB-F50A55F4412D', 'E4C49348-BBD2-48B1-A7EE-551E0CAECE86', '4603365000065', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAE65115-623E-4C01-B71E-509F8137B430', 'F10CCE27-0162-4307-8FA6-E56B80CD4D68', '4603365000089', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEA64CD6-00AD-4149-A801-3EBF82C84E98', 'C5172DE6-91E2-4B20-9844-179A399A3B37', '4603365000218', '  0,06919 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D380BB6A-705E-42D2-9D39-D60296223D70', 'D381F4AF-D8BA-4183-9E47-5F35455C84F1', '4603373000095', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DA53EA6-37AF-4B77-8A13-DC77EED335CD', '8831AA73-EB2C-4481-851E-F510EF96578A', '4603373000255', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24E6B67C-EF17-41C1-B2C9-FE9EF3DBAA65', '40D1DDD1-9C74-4D66-8ACC-44DFC6094D06', '4603373000354', '   25 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EAAD4CA-C723-48BB-B5B5-8E3EB5566875', 'CB2E1A91-B2DE-43C9-A3C8-79CAD4DEA0F1', '4603373000453', ' 10%  - 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDA4FF3A-4CA3-4CEE-891E-C30505B40C70', '902C666B-56E0-475C-B88D-58782F248DF0', '4603373000835', '-  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A62B3C52-64E3-439D-8AE4-B53F30DDB47C', 'FC2468C4-6F35-4CE0-A832-9DC9316ED4F5', '4603373001795', '    20% 30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('458808A0-E040-471B-9073-6923A7B3ECD2', 'DBB856BD-7D93-4618-B5FA-D9E139BDD3A7', '4603373001818', ' 3%  - 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06B9F4BA-1BA9-4382-976E-72F70DC26CF5', 'F932F350-7E62-4C46-8152-4B53DA0AFA92', '4603373001931', '  25% 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8465DDDE-B207-42D4-A883-E8E89FAA7FBC', '63374C66-DB45-42A2-9DEB-F525572994AD', '4603373002013', '  ( ) 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCD8564E-D24F-46CB-BC5D-84C73F7941B2', 'CD0424DD-AF6D-4B1C-A0FD-EB9718C7EB8A', '4603373002655', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A644E90F-B016-4A00-83D6-78FBBFD332C3', 'D2AF3F39-4AB4-4D16-ACC1-9AA2222EE627', '4603373002662', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A49A0D9-E131-4FBD-920F-EC5077B7AE14', '44EDFA26-C4E4-4385-8C0C-E636C394D893', '4603373002679', ' 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3441352-73FF-4623-8ECD-FD8C6B68B377', 'AD8C9BE8-79CB-410B-B5B2-9E9F72E2618B', '4603373002815', ' 25  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('279F617D-F90E-4AC9-8772-CBC0253D883C', '924011C1-CF19-4F2E-92AB-002F6D5D963B', '4603373003034', '- 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('812297A8-2458-491D-BD55-5C24410748F6', 'C1432C53-8DC9-49C0-8CAB-5010CD6FE1F4', '4603373003652', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B407FA4F-139B-40D6-A3A1-837D37BAA52B', '7273BB5D-BF0B-47B5-BD2A-E0EE6080029A', '4603373003683', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11871043-54C2-414B-A9FE-BC92528D5394', 'FA136A79-7429-42A0-9D2E-AC5173D39F42', '4603373003713', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEEEFD33-A3F1-443C-ABD5-10DD776321AA', '992993DE-66AE-4B37-B541-1ECC9D80AD24', '4603373003874', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35DF8045-0EBE-494F-BC0C-E10251821570', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4603373003881', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC631587-348F-4DA9-947F-2CA0A5D9CD85', '31244103-C5CE-4C33-A30C-E60C6DCB4ADA', '4603373003911', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('382423F0-B4D6-4161-A62D-7BB45FE4955D', 'A2EEB6F8-6C72-421A-8503-88894E93D683', '4603373004741', '*  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3B2E1C0-9736-423A-BC54-3CD705F73043', 'EAFBAFA8-00FD-4892-B386-C43EF74798F8', '4603373004772', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('958E1665-DAF6-4E13-9952-88E6D618C0CF', '650BBD76-8EE8-4882-A177-3D99305DBB40', '4603373005328', '  10% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6804B765-45D8-416E-B735-EC13F7A498EA', 'DDD84842-F12C-4A7A-9423-6DB06487D11F', '4603380000293', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA6B5FA6-060F-4637-8909-3A95F6022BC8', 'E2D8C62A-73F1-4067-9EA2-CEADF888A43B', '4603380000439', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D84C2FA-91FE-45B5-B748-6981013B2EBB', '789E3947-EA95-40E1-8114-23424FFEF2DC', '4603380000491', ' 125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('557F6DE7-35FF-4989-AE40-2C0E0EDDAE61', 'CABC57F5-F238-4463-8CB4-94F547C1C0F5', '4603380000576', ' 25  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF6376C5-605E-4220-AB8A-8D535F79CA32', '63374C66-DB45-42A2-9DEB-F525572994AD', '4603380000590', '  ( ) 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17DDFB86-FEFB-457A-8B45-D9F350E4C4B8', 'D3A14D57-0CD3-4AB2-9ADB-FE646AF0BC4F', '4603380000613', ' 5% 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B267C329-F798-44ED-8A88-66BE9A9C407A', '8917334C-6BC0-4FCD-AB1C-41D5CE7C0CEB', '4603380000699', '   25 / / 33,3%', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B93B519-3614-4690-92BC-70D4FE98332C', '650BBD76-8EE8-4882-A177-3D99305DBB40', '4603380000736', '  10% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65278335-CA18-4DF7-BE28-0BF8FF0A0790', '4E3C0358-EE23-436D-A983-8921F5900ADE', '4603380000750', '   /  10%-25,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AD2A7B7-3CAD-4E7F-A31B-F4F5B384A2F8', 'A6468A16-E9D9-48B7-A57C-3D12831AA837', '4603380000811', '  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE7254B1-71C4-4F6C-ADC0-035024A3FA9C', 'FC2468C4-6F35-4CE0-A832-9DC9316ED4F5', '4603380000965', '    20% 30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F6D7544-44DC-416E-AF2A-5CBAFC84BCC7', 'E04B19A8-47A9-4284-8B06-5FECE3E652E2', '4603380000989', ' 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86130B75-F6D6-40FD-A695-7DEFA2EC60EE', '7C8E22D6-EDA0-4D4A-BFDA-5201EEE8C59A', '4603380001221', '  2% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C2DC409-E113-43F4-9E8D-64FA91E4D602', 'C6738AB8-F325-4D13-9BF5-5CF99FAD57A3', '4603380002204', '  40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('406A98BF-D313-4B40-8C54-B2DD009AA5CC', 'AD8C9BE8-79CB-410B-B5B2-9E9F72E2618B', '4603380003218', ' 25  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3AEFDC9-3D95-4B40-9A60-9DA6E26F5FD8', 'DDD84842-F12C-4A7A-9423-6DB06487D11F', '4603380003317', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34CA19D6-3AF3-49C5-9646-0A0C66B5934A', '63374C66-DB45-42A2-9DEB-F525572994AD', '4603380003386', '  ( ) 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('862BAFA4-2C52-4911-A850-8EB351A22E84', 'FD7D59F2-3B9B-4D2B-9C07-8BD02241A1EB', '4603380003430', '  2% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35A966C0-4E79-46B9-91B8-12520E0FF490', '992993DE-66AE-4B37-B541-1ECC9D80AD24', '4603380004352', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAE15859-3EC2-4C5D-BB5F-AC9AE1DA5F1A', '73F9BF23-2E64-4A32-B6F2-621362419EF4', '4603380004642', '  0,2% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47099CB6-E20D-47FF-95BB-1FBA29503561', '3FD0E293-0A08-426B-8E57-E7DD2F66E52A', '4603380004680', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5215FDBA-EBD6-4369-BBBD-949C6014E2C8', 'DE830E02-D2ED-490C-A935-EFC5D8846384', '4603380004741', ' 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E14404E4-D4C5-4D63-9B2D-93F5F227AC6D', 'FA136A79-7429-42A0-9D2E-AC5173D39F42', '4603380005045', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2759592-6DFE-409E-8584-C05EE5A826E7', '243464CF-30E1-4825-A761-6AC5E4204012', '4603380005267', '  10% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCEA24D0-F70B-4FC8-BFA1-DB79718FC12B', 'FD7D59F2-3B9B-4D2B-9C07-8BD02241A1EB', '4603380005335', '  2% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F542674-4775-4AB1-A45A-F62F437A7CFA', '73F9BF23-2E64-4A32-B6F2-621362419EF4', '4603380005434', '  0,2% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7CCB035-EAD8-4D78-8330-88C505A9ECF9', 'FE9C52EB-E1AE-4477-AED5-D7224A3A3CDF', '4603423000082', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B38761C6-FB85-4CE6-B3C6-4E705F5D189A', 'BD459C84-F841-4729-A747-2F890711180E', '4603423000105', '  / / / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6CB5338-60CC-47C1-BDBF-ACF12AEB155F', 'BD459C84-F841-4729-A747-2F890711180E', '4603423000112', '  / / / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FF1D71F-AD1E-46DF-A2B2-689EB645E9CB', '755B8E61-416A-4944-A70B-E72E0BF01E2E', '4603423000334', '  /    35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25296074-C326-4B1F-ADC5-3AFA992A0E74', '7ADD2A75-7602-4C0B-9B11-805CC9A79B7E', '4603423000501', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02FD3BA0-8610-426F-8AA8-754079C1EF11', '559BE0BF-788A-41E2-93ED-AAFFCF897F3A', '4603423000778', '    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9DD40D5-8873-4676-98AC-549134C280D5', '5DCCC9A6-8DE5-4A0D-A651-DEBB208227C9', '4603423001058', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60CA64AE-E54B-494F-9177-BE1B7680C568', '49A62C56-BBD3-4224-BBEE-B342A6AED1CC', '4603423001126', '  - 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6288A490-2712-4939-87D2-9499FE435104', '3422C893-F70F-4F33-9633-22679BA84737', '4603423001287', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18E6EF4D-25EB-4834-A25B-56DA34B2246F', '251B083F-5C4B-4145-B01E-7B5CFACA63DA', '4603423001294', '  /  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77868AB4-DF5E-40C9-8934-667F4FA55BF2', '1D86045F-0161-4169-AE01-809B2D733270', '4603423001317', '  /  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8554FD7A-F0D0-488D-8F22-284B6FD8E63A', '0D054820-8634-4AC9-9EF1-55F15B99E8C7', '4603423001454', '   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C88862A-5201-4243-A93D-DDEE978AD242', '2FC52F24-DFEC-426E-B899-ACF585940CB8', '4603423001508', ' // /  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBF38F37-FD1F-4614-97F8-875F7DEACA6B', '5B48D05A-CAD2-463E-BFE0-B8663FE0E87A', '4603423002048', '   /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBBA1D38-B7E6-42D7-B274-EBC19022D2DF', '02411C90-38EF-46F5-BEE1-4AB2C26A69E9', '4603423002772', '     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B50370A-EE92-4145-905D-920EB7EA9878', 'B4987814-CB82-4818-A793-025F7DC2759F', '4603423002819', ' // /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75F5A8D7-089E-4092-8B0A-5CDE8BA3B13C', 'A0FE513C-30AD-48E8-A531-10AB4A28548A', '4603423003014', '      . 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D4DCFBA-BBA3-4D5C-B9EB-D1CD57A109AA', 'E192AA2A-B808-40ED-84C4-BFB1EC141B3A', '4603423003090', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37E36299-D0B6-44DD-B528-456F09BE952B', '00BF9F25-23A3-4465-AA13-CA385436A61F', '4603423003144', ' // /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56A7696F-0899-4C1E-A2C1-4C0DD5EBD609', 'A44B1D41-AA0B-4754-8F90-D30E824ED1E2', '4603423003151', '  /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3BC2EB7-DCF8-41D9-B245-1DEF8C463AD5', '86918F23-24E3-4344-8157-82C8EFDBE70F', '4603423003267', '  /  4  1    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C772F5A-5BC8-4256-97E3-EA9782F2D102', '6A434989-9B25-40C2-82F7-A163062E0FF4', '4603423003335', '   /  35 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D910E44E-A9D5-42CC-83B8-45793B95DEC7', 'E081FBCF-33B5-4618-8D77-6CEA4F1CFAD5', '4603423003526', '    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F3B9D9E-EBC6-4F3D-916A-CBD5B5ACF4A4', '44D44DF2-C94D-45CE-A71E-FE7FC9248DCB', '4603423003533', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC9E8B86-6201-4C84-B220-3B53A3947245', '355EA32F-ED6A-4226-826A-671BC52F2723', '4603423004004', '  /  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B663FE6-723C-4A74-A835-44EE10B5A1B4', 'B8ADF46A-88B8-47CC-9D14-25ADB218EEAE', '4603423004011', '  /  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D47A6DE-46BC-468D-B7D0-EA6907DB99B7', '34C9399B-6CC4-4809-8397-B7CB854554A4', '4603423004264', '     95', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53F849ED-7CF7-4A67-8C27-196708AB812E', 'ABB06EC9-762A-4B94-880E-90D3554F4938', '4603423004271', '      400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4C06BFD-912B-4BD4-9FA1-E3BD365BFC44', '767AE6E3-36AC-4DF1-BB80-1DBBBCDEB864', '4603423004394', '    /-439/ 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B92C2F41-BAA9-4C88-A7D2-8315BBD52C65', '2937F4DF-19BE-493E-98F8-BAD4C25DBA0A', '4603423005162', '   / .. /-516/ 55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94520655-F1C7-4D3E-9518-AECC594D1FC3', '177E7059-7486-4047-A269-96E14A203F75', '4603423005599', '    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E763331F-51FD-42BD-8240-6BDAFAEF9297', '01F36B14-3EFD-4917-845F-9A8DEC77AAB8', '4603423006404', '  / //  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC0D13C8-DFB4-4DA4-AAC8-47F19C14BE69', '0F4A9B9E-9A5B-4AF9-8642-E3331B48E07D', '4603423006411', '  / / /  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E0A5F17-FCE8-4A2F-9C21-3BF48B3E88C4', '7642CCBE-B3B9-4545-A470-FBFCEC3C92CD', '4603423006602', '  // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACD28699-5BAE-4A83-9004-6C80099BEE16', '7BADA856-EDDA-4B4E-B69F-202C074F0945', '4603423006626', 'Spring easy go   / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('132BBDC6-F89A-408B-B3C7-61D7C075FF86', '18E9EAD7-576C-462B-A8F5-82EDA3255538', '4603423006633', 'Spring prolong   // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('485D5C61-4DFC-46EF-B4B0-98A3909A2AC9', '26E12827-6229-4F5C-B437-D691748362BE', '4603423008422', '-   /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('857D5CF1-4E39-41B0-A2A2-3D3F6460B808', 'BF33FE80-DB22-42D7-A48C-2E33DDBD600D', '4603469002101', '- 3,75  /    -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB91BC63-871D-434D-A846-C3CD98D857B1', '43CADEC3-1E2C-447F-AB98-0DA1BF624410', '4603500007799', ' /    /100-104/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4116920E-DB00-454C-9AFB-EA1EE00751B1', 'E2724E29-A2C2-4677-A08A-820F2E6842DC', '4603500007812', '   116-120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14340C2E-65DA-42F7-A53F-BF943C6EA505', '4160B09F-2A08-42B0-9DBB-DD9556B3489C', '4603500050351', ' /    /108-112/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B78ED0F3-2C25-4469-8D83-3BD5C40CB61D', 'A4FFFB31-89F3-4D79-A522-8B5989D06F7E', '4603500050368', ' /   /- /  / / . 96 / 1444/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14A3277A-7040-4E53-92E6-68B15EB0BA3C', 'D33439AB-3D14-485A-AB11-0151943ED712', '4603500050375', ' /   /- /  . 100-104 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7E069DD-5BE4-456A-B26D-CA826613F322', '6CD9B025-1ECB-4EB1-9D2E-ECA60325DB16', '4603500050382', ' /    /116-120/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4CBB0AB-35A2-4FBB-AD56-5C7362FCDDF8', '9C2B280F-EDF4-4386-B2B0-C9039CE3E1F7', '4603500068769', '  /./124-128 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B98FC0AF-FEFE-4CD0-8086-52270F31B6A0', 'F0F8D09F-5EF6-42C8-A5E7-5052AC0C8B15', '4603569020036', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46DD6F2E-0504-4608-90E0-1E9692C20B1E', 'FA33533F-7CE5-4194-99C9-943D9FFBAFB0', '4603569310021', ' 400  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('268FBC64-DC36-4F31-9566-4F65EBAEB676', '97465E94-EC99-4B0F-B448-55FC70790C1C', '4603569540022', ' 1000 4  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37B7D80D-2539-48F9-A259-D3C0A248E361', 'F47B37F9-B60C-4684-8027-03B609399003', '4603569720424', '   3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F5A763A-F4C3-4BCB-8AA2-5C55181BF4DC', '008303DC-E0F4-493C-AF59-B415A710E1FB', '4603569720448', '   3 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92419B2F-CA5E-47C2-AE3A-B44CA17E2350', '2184D89F-395B-46EB-9624-9826D0B1965A', '4603569720509', '  30  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DB0210B-D798-4596-BA26-6708DB15BC5C', 'F80BC2AB-C44F-4A65-BB9F-CE1F29129280', '4603569720677', ' 100   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FF16F19-AB1D-4A80-9426-9CF87C90FDCA', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '4603569720752', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB052B97-053B-4013-974A-287961236C1D', '958BA8C1-7BAB-4B47-B8FE-F9F1C6848EB2', '4603569720783', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('525C85FE-62E1-4F89-B012-16C173F702F0', '1B52A28F-F864-43A3-93F5-AB6E0CB4FA5B', '4603569720851', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22BA9B1A-8544-4109-888C-455FBEE45DD0', 'D22D74CD-8F63-4231-BB30-94A158BAABD8', '4603569720868', ' . 600/2 2 / / - 10 / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DC86C0D-032C-4C13-91ED-5C4A0DC33AC2', 'F0F0334A-5DC4-4F5F-8D40-611CA809948B', '4603569720899', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27C7CCF6-78BA-4E1F-A40A-766D7DAA8F44', 'C08CA67F-F12F-4211-A973-AB876C736D7C', '4603569720967', '  200/  2,5 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('472C0FDA-14D4-428E-B1BB-ABD95C2E37D0', 'C0B370DF-5FD7-43AA-BFA5-57F64B2FC4E5', '4603569721544', '-  0,32  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EC80A20-6301-428A-A993-7D5AC8BAC591', '8F9B3237-9954-43C4-9C57-F4B808A89F56', '4603569721551', '-  0,32  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14AAD1DF-43DE-4870-8114-879F832D60DB', '8F9B3237-9954-43C4-9C57-F4B808A89F56', '4603569721575', '-  0,32  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06619988-7482-4107-9D9F-D3B6D7F7C4B3', 'E2E9A921-5363-4C2D-9EAE-84F5BEC18D36', '4603569721605', '-  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('935D6852-9AC4-492F-8BB2-A4E14C935ABF', 'FA9F953B-DB68-4703-980E-7C4026A62E74', '4603569721681', '  1,5 / - /   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6AA5318-E3BB-49A3-8D75-993253C0D436', '77E234E4-BE5A-4E5B-B120-E9431910A99C', '4603583000175', ' 500   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15010928-A133-495A-9C77-87D42000ECA8', '018472AF-B9CA-40B9-A6EA-E782BD079329', '4603583000205', ' -  45 - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3D3ADB3-F664-4979-9D5D-06C79EBA7B6C', '7F85D550-3910-41BA-AE32-99E533596A62', '4603583000427', ' 1   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B422BEA1-B52C-4AB9-B019-A008DC512621', 'C11EB72B-5D4B-4EDD-B0A5-A394E0E087CD', '4603583000618', ' 500  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA09A518-CE68-41DD-9D15-68D9BCACBACE', 'D9EE9AB1-58E7-43D2-8F9D-398291C53226', '4603586006754', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88A30598-7916-4A41-8B22-765F1C8FCFF3', '0C3EDFDE-716E-4E2B-933A-DBABBD15FAF9', '4603586008871', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1B2E92A-F9DB-4711-A423-00C7CF56C858', 'A1C4CF2D-1514-4C54-8467-DD347E46350A', '4603619000025', ' 10% 3  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF53E9ED-F74D-40FA-ABA8-578B228149B2', 'FFB45720-3800-4C2A-AD95-9C3777605B7E', '4603619000063', '   500 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4D967B7-E402-4A61-8CE8-E29BCB1BCFAE', 'C8D91546-6908-4BE5-ABA4-37FA34763B7D', '4603619000070', ' 25   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ABDF7E6-BF6F-40C8-ACE3-B393F8104456', '85046E31-7F82-4DFB-9698-99ECD359B3BB', '4603619000124', ' 200  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBBB0B8C-F64B-4DFB-BF06-4D244E9F2778', 'A7BF85C1-BFC6-4C8B-8DDF-CD3172742747', '4603619000131', ' 600   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F68DCC5-6B45-4807-BA75-9FE75DB049E9', 'C3E412FB-70ED-441B-A419-484ED3690139', '4603619000148', '  / -  3 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FC150A3-6D08-4A14-A05A-7ABFE4CF063F', '7C5CFC97-E4F2-4E81-90AA-4692390C2AB3', '4603619000179', '  2 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECEEE340-0DE2-4A90-83FE-1C21334E8FBE', 'F630EFE4-898A-49A3-9C38-F94B3E0590AA', '4603619000513', ' 400  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAA1A7E6-47B4-4860-9F39-B9AF0A3D55A5', 'E38A8613-8852-44F0-9870-BBC2B5743E1C', '4603619000568', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E69609EE-7B62-4AF0-877B-18C24EB325F6', 'C9A6FF19-6AC5-4C6E-B059-FCB5F43D31F8', '4603619000575', ' 0,02  100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EA408C7-01DC-4945-B919-6200D543659C', '1FB0A66A-487B-4A51-A883-12256F77DD6F', '4603619000612', ' 0,04  200 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C91B09E-B737-4636-ADD9-2329A70A9D92', 'B87908E9-25DE-4EA6-8CC7-98271796E34F', '4603619000636', ' 600   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('288ED7A6-B3FF-4977-AD6E-403CA5D6A54D', 'ACBFF139-0A36-4BFB-8FB9-6D8BBE2A9FF8', '4603671001442', ' 0,25% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72EDA364-0A7A-40F7-A89A-F89885AB0BB8', 'D3D68CC4-0EC7-4E8F-A872-B974C66D4233', '4603671001565', ' 0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A73FA92-1DE0-4932-A75F-882F56ABB06C', '37CFB113-991F-41B7-A3A9-70C4D6B19DE1', '4603671001589', '  0,05% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AE9FCBC-A52D-42A4-9D53-C583B585DC43', '42027986-1AE3-4FE1-AF48-1769CDB3E5DC', '4603671001831', ' 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD8B4CE9-9269-48BE-8856-41A41CAD6CDF', 'EBACE3D2-EAD6-4CB2-BF63-8BD4C9E262AC', '4603671002302', ' / / 300  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0F5706E-AC90-47EC-A125-E0AA542AC9D3', 'AD275A61-27D7-403E-A648-7B0DE1ABE429', '4603671002364', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38326395-B702-4D65-97FE-E76D32DC2CDF', '89BBA343-27A0-43B9-8CC8-5CB0C00D22FC', '4603671002395', ' 4% 5   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F679CB08-CBE6-46E8-A364-712D2A67CA7A', '4E7FCA76-20FA-4107-BC70-821704C05FC6', '4603671002562', ' 50  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6D8D4D8-99C0-41DC-8A3C-F837B76B6AC9', '80BBC26E-93C2-4877-B151-43B64A2B3E99', '4603671002579', ' 50  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1D06C06-E4FC-440B-AF29-AF415ACBE3AC', '36ACE009-D75C-4549-BB0E-F89534DE7AE8', '4603671002661', ' 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DE8A022-E282-4450-82F1-9327D82CADB1', 'D8AD953C-F835-4258-B863-4848B058E9F4', '4603671002678', ' 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('398B6CEA-CA4A-4F6A-9298-01F73B1286FB', 'F1CE0542-1A45-49EC-8A14-CAD0E28F1153', '4603671002685', ' 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5F496D1-23BE-42DE-BEF8-270CAAAA3D10', '742155D3-147E-4FD6-8E0F-2F29CCFA0A17', '4603671002692', '   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72253833-0C67-4C15-9960-7CDB89039226', '5297F173-765F-40D0-B69E-420C2343B900', '4603671002791', ' 0,1%  15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEEA28BF-1D5C-49C3-BEC0-87B75BA02BAE', 'E2ECE793-45E3-44B7-8A36-13EDCEE8C3A0', '4603671003057', ' 1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E0EFA60-4A9D-4348-AFD2-78CA16408A23', '87162FC8-AAE1-4AEC-A47F-43CF0FB23788', '4603671003064', '   0,2% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5791B617-B820-442B-8836-289E9DE84317', '9C526D1F-ADF9-4097-AB69-745AC91BED7D', '4603671003071', '  /. . 0,2% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F654DB4-3695-4551-B756-586D61E00BD7', '3E32C24C-08A2-405D-8AE9-B691BDAA01AF', '4603671003095', '   15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63F869BF-9148-4AF3-875A-63691D143BC4', '74E7313B-994F-4D7B-B889-F3E381DCA4D4', '4603671003125', ' 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3310C939-C958-44C8-9757-F3B9485CB41E', '1269C8D5-2857-4815-8E6C-3096D8EBA775', '4603671003163', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('885F6826-0094-43AF-8190-CC92BE1A9223', 'DDF2D631-06F4-48C2-B24B-673D30366C33', '4603671003170', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C9A8570-FBDA-47D9-BF3D-522C48AFAA44', '5F8F26CA-0A23-4AC3-B530-843503EDC239', '4603671003200', '  0,01% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37990ECD-8A9E-4B07-BAE2-77F99C5A0A89', 'F65AA321-5484-4A19-A2A1-33284CED7DAA', '4603671003217', '  0,025% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8643DDF4-5A24-4A0A-B3F2-1E70D37F4F2A', 'CD648468-615E-4E4D-9199-186B2F1A48BD', '4603671003224', '   0,05% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B810366-9388-4FD9-82E3-523CEC8F2714', '2A1D1777-7DBA-4856-98FA-047F0E11AAD3', '4603671003309', '  20% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9620B033-F1B0-4E51-8250-D6172B880169', '43876A78-EE8D-442D-8550-98E4A7C4E15C', '4603679000041', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('752EF055-F5FB-44CC-BEA9-363F3DDE0CC8', '4EC7BC33-86D5-4AB3-9487-EB1DDB721729', '4603679000164', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('262308A1-4EC2-4268-92AB-494A6C1399C9', 'C4F7DFD5-D072-49E0-9F99-B87EB6E1CA43', '4603679000171', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2741A771-AA8D-4710-944D-BF898129574C', '76A2205E-56A1-4CEA-A090-D3381908544C', '4603679000362', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5A0B6C2-DE57-4D96-BC54-7F2DFD0EA765', '7A551576-75D6-45B6-9660-1662A35ACA72', '4603679000904', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('444C4677-B64D-4AE1-A3D6-EBCFC1B651B4', 'D177CA60-C1DA-4F49-9E9E-D3DD92E72141', '4603679000928', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B4384D1-5321-4CF1-95FE-C2C19ACB0D5F', 'EE0F8732-2910-46BD-AE66-C37C66C032AB', '4603679000935', '  140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('086685F9-87E9-4A3E-8F39-8C09AAB89192', 'F59E7CFD-8A9E-43E8-992F-3101505C8D92', '4603679001024', ' 20%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92816179-CB13-48BE-A535-69D800607A21', '41AC9D10-3AF2-4AF4-A729-D7DB7659F107', '4603679001055', ' 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93C1F410-54AA-42AE-A367-704F98BB9F5F', '944CB770-F251-42B8-983B-1B1B55FFDE51', '4603679001062', '  0,2  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0CA4B1E-A114-4EE9-A314-DE274899E64E', 'AEAE148D-4D18-4B2D-92AA-3C6FB11116C0', '4603679001086', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82263F03-60F6-4D05-A8D2-98F33B3CAE68', '1E58F49A-20A7-41A3-9502-658EDF3ECA35', '4603679001345', ' 80 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32A63DB7-24CD-4E0D-BECB-1A7F50079318', '6EA3BCDF-BA8A-4F92-B412-1AEDD7E5FF52', '4603679001437', '  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A31B5410-4C54-48B0-A584-74719C8CBA23', '09F17B98-6623-4EA1-9111-43D19EBF3F18', '4603679002540', '      300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DCC1957-1DC8-4F35-8900-D6350DBBB18D', '1B3EA320-6419-461F-9A5E-591292EBB87F', '4603679002816', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F6076ED-68BC-46F0-8FF6-6749EB908143', '4F475E72-7E20-443D-BEDF-D3468834A6EC', '4603679002854', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB052D9C-FC1E-4CBF-ADA4-2639E46C4CEC', 'C69D16DF-8EF2-4BC7-A623-CF6545DC1D5C', '4603679003516', ' /L-/ 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79D80292-5280-4621-B6AB-EDE2D2C49DD4', '2950043A-79C9-4770-A00B-95741504D971', '4603679003530', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A87E9265-B8C2-40F6-90D2-C7EC0F9F21E6', '03AC0A9F-42FD-49E5-9B91-01BD66441A24', '4603679003639', ' 100 .   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B6CC1AB-71E2-4DA2-86BA-8FB6FC25C662', '04A21DBB-D8F2-42B3-9E36-24DB446585E3', '4603679003660', ' 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA5048A3-848D-4F53-B0F9-42A10250FECE', '02C8E688-72A2-4C5E-8272-DF5F4CB94EF4', '4603679003721', '  1% 30,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DF3ABA9-079D-485A-AF14-8ED25ED71D64', 'E3509CA9-FFAA-4666-92E4-23E66A19C967', '4603679003769', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE360837-0BF1-4B71-9DCC-E67256CA7BAC', 'BB075934-B648-42EF-BD90-6E370B8CAC9D', '4603679003776', ' 15  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AF014C1-3508-4A94-9DD7-5DAF7AD56206', '818515EE-5668-465C-AA8D-3D46D08DBCD2', '4603679003882', ' 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8F32E8E-221B-44D1-9EF5-8D3F614A6590', 'C1B84891-B857-4FAC-AE9E-A3DDF7D3840D', '4603679003943', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('015FB9B4-42E2-4F29-8526-15DCB564E68C', 'EF3FC955-9E67-4956-B8DB-72E5A6D8C87C', '4603679005466', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B3F2BAE-0240-46BD-999C-48C3682622CD', 'AFA64D89-F43A-4C42-BE99-42FA27880D74', '4603679005923', '  100/ 300 11   /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6932EED-E4B5-47D2-BDCB-8F14547AC9BC', 'C4F7DFD5-D072-49E0-9F99-B87EB6E1CA43', '4603679006043', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB479852-2C3A-42EA-8F86-193A88DD7F13', '85EB334A-B8C8-4030-A901-327C5E8E48FB', '4603679006470', '  / / 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C12E41D8-E3B9-4F68-B5B0-E5FAC4F47EE6', 'BF506AC1-96B6-479B-8AFE-37DC56111014', '4603679006517', ' /   / /70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AC6E939-9A98-42AD-A5BF-D585F7103ADE', '2BD76055-47EC-4AB3-8B45-1DF41E38439E', '4603679006630', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E655B14-4E85-4B05-BD02-E7B9D70441E4', 'B1A9FCF9-A507-497C-965F-8EC175DD8241', '4603679006784', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F1E4ED7-5E79-46F5-B4C6-3704A197EC33', 'FC3E48AE-0948-4B3A-B4CD-B5008B255120', '4603679006791', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFB05423-A959-4C87-B0F4-DCAFE318F315', 'C1B84891-B857-4FAC-AE9E-A3DDF7D3840D', '4603679006845', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1B1FE44-7FEC-4AA4-8D98-44CEE615D10E', '59906113-6060-48DD-88F4-9709EC71189D', '4603679007187', ' +  80 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A04B94D-AB27-46FA-8183-D8363E8C4B8C', 'F904E220-40D9-4975-94D9-10A514560915', '4603679007309', ' 100/ 200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCB1DFC4-9ACF-4862-A010-33FCE4B73319', '0EF0A7B1-D944-45FC-9CF0-1DCAE9345C7D', '4603679007330', '  / / 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4728182-4B6F-4552-BD14-465D4B514C7A', 'C6B45D01-84C4-475C-B24F-8AE13D7C54C9', '4603679007347', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('141BB632-8A5F-4463-A841-2CBFF1A00BAE', '467E520B-AA04-424C-87CB-D25B849F4E44', '4603695000056', ' 25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37958384-1B7F-4A52-A1E0-A3E3550CBD5C', '40FCD67F-701A-48B6-8A2E-51531EB38A87', '4603695000063', '  50 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D05CDEF-6150-41A9-83A1-67041E7DD614', 'E13A7CAF-B4C2-4087-B23A-11C6D29184A3', '4603695000353', ' 0,05% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A78B5264-D0DF-407B-95A0-204728F0052D', 'A1F3B022-EC79-4ED7-825E-CA996D18B581', '4603695000483', '  6  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0CC6D8C-94B8-4645-B173-4C768EC6C00A', 'FF9FD80A-ED9A-49D4-BE9C-BE1230E8A3B4', '4603695000568', ' 150  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA5B3B20-B592-4459-9A1D-F93BE1B6AADF', 'BB95A660-699C-4D19-895D-38DFB41E7238', '4603695000773', ' 5+80  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7BE12CD-A563-4B3C-BC5C-0914920D22B2', 'FB841F0F-69F0-4ABA-BBA4-AB3FB508D593', '4603695000780', ' 5+160  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33B181B5-449B-408D-AB91-FC3CAB1AC34E', '2F1824C5-FBB4-437C-95A6-92EA567ED6D9', '4603695000803', ' 10+160  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9B7D886-80FA-41DF-ABBD-2DD297A9715A', '6BB36D2F-9007-4AF6-8040-64DF0D94030D', '4603695000964', ' 12  /+- /  /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55D3289D-6A72-4ABC-A339-8EC86396D7C6', '668E9614-8FDC-41BA-9D21-806DB1061667', '4603695001121', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60EE543E-BD9A-4C83-B483-8E15184CDE45', '8371D380-7C48-4485-820C-44190630085C', '4603695001480', '  50+1000 //.  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4A9DC56-723B-42BF-8941-62EE778401A5', '05D03EF3-2495-494C-AC72-5E2921557AB1', '4603695001572', ' 50  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC6618C0-B9BE-412B-8F71-326BA1439871', '8169434E-2A34-4854-8034-C6358EE935C1', '4603695001831', '- 5+160+12,5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6B3486B-D8F8-4B93-8201-4396501DDCE9', 'AA658644-9981-4A45-AF9A-F185BF0F212B', '4603695001909', '- 10+160+12,5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05248692-80EB-4997-8661-2FBCC900092C', 'C89919EF-BF26-4218-A8BE-F28DF0E8D3AD', '4603695002203', '  12/200 /  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('727FC18D-070C-47C7-BAAE-22D10B90B739', 'A39C9218-0133-4415-ABCA-45D50764F8F3', '4603695002210', '  12/400 /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4EB6ABA-831B-43F1-A2AC-850D99990F0B', '0375BE06-E5F2-4145-90A7-EDB9F04A2339', '4603695002999', '  150   /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD71B837-6E4A-41F2-B057-E9A2AE4E0913', '9DE4C1C2-E11A-46E5-A051-F5A6465FAA66', '4603695003019', '   300 30+ m 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB7CAC41-742C-498B-BF79-7768CDB3F6F7', '369127D0-996B-4526-AB0C-B936881D80B0', '4603695003828', '  75  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3C6EFCF-2913-4F86-BF7D-761BF419E40D', '29F36268-CD14-4461-B625-C722B0F0D35C', '4603695004023', '  50+110 30  /+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21C852D7-6A93-4864-BEB9-43DEF61E29C7', '5C8CD3A5-6A47-44A9-A8C2-FA67892F3447', '4603695005204', ' 50  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90A48CB3-F065-48EF-AE87-B73A7F3C0C5B', '315A1ED6-FA63-478E-ACE3-FD2E46F8D09F', '4603695005211', ' 100  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6A9F48C-1204-490E-BDFC-401474958307', '4080199C-7F85-4949-8E20-99F8576FB2D7', '4603695005389', '  50  /  30+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C311C9AB-4148-4D28-AB26-16B107177720', '52E48D61-ABAB-4D0F-B682-5ECCCC357038', '4603699000045', '  /   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16614853-7FFB-403B-9B5E-DBB9114D4AA9', '4DBBFAAC-7778-4891-9F68-E95CE57A4597', '4603699000069', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2AD4E25-65DC-496B-A648-7D420812EE55', '124B735D-DC90-4840-B244-94C96C0A61BE', '4603699000083', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5171479D-23B0-4534-92D3-F9D778113EDD', 'B8C0D7B9-71F6-4F96-B8E1-2B516E2D5510', '4603699000175', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8639C6B1-FAD2-4AB8-9729-EF4E68E84F5C', 'E8476365-3A09-45A8-986F-B596226FBF8A', '4603699000182', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7734569-5EF5-4E0C-A4AC-01E70BE0DBFD', 'E713B721-BF1C-4000-ABB8-686F99253899', '4603713000051', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D0391CF-65DC-42AB-803A-4E2CF9C4AFE8', 'BC9B4B13-75C1-462F-BC8A-366DEAEED35D', '4603713000167', ' . / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49B20685-BD70-4829-BF59-EE417E55345E', 'A22C184C-C1BD-4C6A-84E5-4A630773EE8F', '4603713000280', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('454DFCCD-4CF5-463F-A754-02D25614E5C4', 'FE3600A3-A194-4598-ABC4-D1862EB1F6E1', '4603713000365', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A759CB58-730E-47C2-B11A-FC5392A41B3F', '90A45A0F-4BB4-4D0E-82B1-16B50DBD9881', '4603713000389', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE2D5763-A835-4EE6-BE34-D84F96D3EF73', 'F05DF5DF-2A00-4010-9EDC-036432EC3D36', '4603713000570', '  100//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50520E1C-9897-48A1-8A39-0ACF94ECDAB3', 'A9083BB0-AC95-4A99-B234-C2AD7462EC41', '4603713000587', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15420E59-36D5-4875-8D0A-67F7DA2B54E1', 'FA136A79-7429-42A0-9D2E-AC5173D39F42', '4603713000693', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DA6DADF-ED8F-42C2-A0B6-32B43EF2B36E', '55342DA6-1C82-4A71-ADBE-521EFC852FCC', '4603713000754', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BA123BF-DE43-40C8-9D89-D60FB6982B6F', '7283B910-F4CB-4001-8AC4-EC5F296C1D33', '4603713000907', '  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A31745F-86B2-4354-897D-596366EFFF02', '683174B5-A592-4A52-8B32-F653D49EE6C7', '4603720177029', ' /. 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C50D5C69-BAAB-4456-A7E6-61C34584EE67', 'A5000B13-8C38-4272-9658-E150DE9BC358', '4603720177067', '    6      1,5 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('687A471D-5668-4403-B927-7502A9FDF42C', 'AF668B74-E08A-4490-8CA1-C080FCE1B9E8', '4603720177098', ' /-. 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66702015-E759-4C7E-981B-40AA6AC72E94', '19334641-4F58-4277-9C1E-70D33A177E91', '4603720177104', ' /.. 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05BBDBAD-1BD8-41F8-9C31-A5BEAD43D7B5', 'E4F99805-4615-4D1F-90A2-25883FC79AA7', '4603720177128', ' /.. 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C54A586-2F0B-4B0B-9172-0F35F2158C94', 'E6A8FE78-B385-4784-B9E3-D0A214E8BB23', '4603720177210', '  21  .   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39A2FF59-3F4B-4547-A56A-7B1B538344BA', 'F955C652-E49B-451A-8DA0-92C97DCBBC5A', '4603720177241', '    24     1,5 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41A4152F-31B8-4743-85E1-1F6A3F4F324E', '3C53B3C1-0FD9-4978-9841-AD1297CCBB0E', '4603720177258', '   20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E11F972-E75A-4A45-96DE-A93E1FF5408A', '40B9EB88-8295-453F-A415-19F360696C80', '4603720177296', ' /.. 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('258D3B9F-6B6A-49FC-8378-54E6357194A8', '76A310BF-6BCA-4592-91D9-1AF00A17CAB8', '4603720177302', ' /. 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0115954-C80E-492F-81AC-A042610C2BFA', 'F85FAB52-21C5-4984-B2B9-5B57576EC8C4', '4603720177340', ' / 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CD7DAE0-D2C1-429D-B9E9-CC7587F6E390', '7809AA5F-5AFA-4DE7-A1A5-5B62F8FA7C8D', '4603720177395', ' /. 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DCC54E3-BFD1-4E49-AD0B-EAEE5FEB20D0', '88609F84-DDCD-489F-AFF6-89A2D3A79E36', '4603720177616', '  / 1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21DAB5DE-52BA-4A9A-A794-6BF8871FA1ED', '47BFB72F-8B1F-4224-88CB-EF75C0733EE2', '4603720251118', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8232E2F8-A413-4358-AA9C-8992642E8EFB', 'F94917DF-8BD7-43E3-B76E-9FEBB31EA7E8', '4603720251996', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F74C9E2-C3D2-4FF9-964D-4ACF6179156B', '6E9A1529-7880-4D1C-9BBB-4CC20A9872B4', '4603720587248', 'L-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DC6711E-80C4-4CEB-9A93-2D60972AE341', 'EEAEBABC-FE82-4E6F-B43A-9B575A515C26', '4603720937067', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ADF4355-E950-41E4-A77A-CE714952CCA6', 'AEAE148D-4D18-4B2D-92AA-3C6FB11116C0', '4603720937081', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3376B68E-E0AF-4058-BE4E-8577C247AE8B', '1150A538-B8E7-4128-A007-27B8A6FCE7D5', '4603720937173', ' 10% 40 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD14505C-C2EC-405B-A4D4-11049C64F260', 'BECF40A3-ED16-4E0F-91AC-5984D195BE4A', '4603720937180', ' 10% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC4B7E4B-CB63-45C2-9C38-F7112F4570C0', 'EFF5A3A0-F842-477F-ABDB-FF4BA7109FCA', '4603725521360', 'Vivo   0,5 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B59F33DC-741D-40C8-A781-3B47D1F23340', 'BEF5A5EE-F4BA-4115-90F6-AD7427F92B92', '4603725521377', 'Vivo  fit- 0,5 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DE0A10C-63A1-4E17-A006-8913E0B64E96', '4159312D-EB42-489A-89A2-E8813130C275', '4603725521407', 'Vivo   0,5 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6D3F3CE-0D00-4675-8684-83D2610FA34C', 'A0CB881E-21EB-43EF-85DE-92A424EE3EBA', '4603726175043', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A09131D-F2CF-488E-AA38-4C5DF6284732', '9F25EDBE-2230-4ED2-B9F1-99BA185D208C', '4603726175067', '-   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('257309F8-6F8E-4E7F-83FD-74882F9813F4', '202775C7-749B-4C28-90CC-3B9E8F380FCC', '4603726175074', '-   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7E06FEE-338E-4BBB-A9AA-8D2FCFA8FCF4', 'BF1B793C-7D96-4FFB-9766-8174CDA83DA0', '4603726763028', ' -  /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('768C29BA-217D-425D-93ED-B3C004281361', 'E792A607-FB31-40B7-BB07-8DB2FB813CE3', '4603726763080', '-   /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28F7C53D-1A21-40BB-9754-16043128DD45', '0EC7781C-E02B-49A9-8D8A-72147B097DC4', '4603726763189', '-  / /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4BFE55B-127E-41E9-BBA8-5FF03135AAFC', '801B9CD4-5F41-4BFE-B6B0-9C8618F717AE', '4603726763202', '-  / /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('344D613A-0B32-4F8A-B739-4A49BD47E45E', 'D4BE9D3A-A663-4CF7-9D77-10B3846D7E69', '4603726763349', '-    /   spf50 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F0E65EF-F5EB-41FC-B43A-60DFA8F44155', '39ABC494-4707-429D-93BC-DDB81EDDFDD5', '4603728946016', '    //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D01638B-DDA3-48C2-AC15-17DA8C59D6BD', '9DD671B0-1FD9-420F-92BA-FEC068893A7A', '4603728946023', ' achromin   //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92AD2388-CD3A-461E-ACF0-0BB4E9C79DAA', 'FB4B76D9-DD0B-448F-9423-E543CDD302FD', '4603730001314', ' 10/ 1,5 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('449E9854-A076-40FB-BEE9-20ADBF3A8351', 'D2B0406D-7619-414C-893A-9D67A927D258', '4603732052383', '   /   - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EEEFC0E-5C5E-439F-8048-379BE31BFFC6', 'E9E21A68-F409-42F2-99C5-A460DD221468', '4603734159011', ' // 10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC2F496F-AECA-43AB-8557-9E1DAECA7126', '75B2044B-5E1C-4693-AA34-204022F5E8D1', '4603738388004', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CFC7826-59AB-43FD-BE88-24112F61724F', 'EE53572E-458D-4A99-AAA2-4AB2EF0C8B0C', '4603738771288', ' 1,97,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F0BD823-84A6-485C-A5AA-0419A74A59E3', 'EFFEFFD8-AE2B-42D9-82E2-CE645F39FF86', '4603738771646', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B9B5D14-179F-4011-8347-25612FD6A06B', 'F2E13526-213F-47F9-8149-BF986C3538E3', '4603742000596', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBC8B392-F0B0-49D0-B0AE-2C42596CAE09', 'F2E13526-213F-47F9-8149-BF986C3538E3', '4603742000619', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8988FBC8-AAAC-45D1-BFDF-E5B5D4BA1FD5', 'C846090A-28A6-4B90-AAB5-E9594C8E5247', '4603742000640', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8CF1646-9FBA-4851-AB51-DFD954647189', '931FB522-F594-444C-9D6B-97D5C5EB0F32', '4603742000657', '    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DCAE768-9B7C-4C3F-A9B2-3D02CE173F5F', 'DA056F85-3289-429A-9710-E2DBAF7FFF5C', '4603742000695', '   /. / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52E2AADE-F6FA-47A6-820F-7C7A90BFF735', 'A6AA7931-A388-4AB0-9E18-FE6C309F46D1', '4603750000267', '  10  10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74C3CF31-96F2-40BD-8168-C01099631D8B', 'E779F550-0CE8-446B-9799-A90A148535E8', '4603761000140', ' 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B8DE47B-0E45-4335-BFBA-EBCFF6288082', '6584C4F1-B854-4476-B4EF-A71AABDCD24A', '4603761000225', ' 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('413A09C5-F434-4725-B98D-9C513321B2C1', 'C555BD43-3626-4EA4-BC31-F1E613F52B00', '4603761000393', '   6660  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C48B7E9-29DE-4060-86EE-1E3EF264548A', '95D7099B-B608-4F30-8BEF-E21DE0E17A63', '4603761000409', '   3060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75C3FF4A-5EB4-4554-8C9A-8AB26716D99F', '8161FE8E-0718-4124-9271-ADEB97706968', '4603761000775', '  / 0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80359567-45ED-4F5F-B404-82C6C99B2567', 'E1E699D0-B21D-48E4-882F-169AA244DA0E', '4603761000799', '   0,05% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE3F5C1A-2DE3-42DF-A8CC-C35D2ADA284B', 'C1ED956C-5678-4EE9-9E6E-ED0B0691A4CF', '4603761000836', '   0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A4A5685-3A7F-4F3A-A7F5-68D290AE3280', 'FFC4EB26-2427-4E2C-A80E-E222FAE1D26C', '4603761001048', ' 10%  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7C8FF59-63C9-4F0B-9CE6-4D035B63496E', '63AF8EDD-A26D-4448-AD96-70E584D9A42A', '4603761001246', '  6060', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2209AE64-F6A2-40B9-89F2-182B2FB970CA', '63AF8EDD-A26D-4448-AD96-70E584D9A42A', '4603761001253', '  6060', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F471889D-41AE-4214-B656-8D5696CD60C0', '3365479A-4F78-412C-92FB-251287419C1B', '4603761001284', '- 0,9% 20   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB4C3FCD-C116-4886-81C5-79EB28A9DE36', '7CDAFBE8-8C20-4CD1-AC39-DCD7AEDB094D', '4603761001413', '  1% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1052D964-5A66-4E48-AC63-39188A3A3CF1', 'DB2FC475-34C1-4270-A042-09191304A8D1', '4603762000040', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('922734D8-91E4-4E73-8810-2E72BC1CB718', 'F0BD4526-605C-43F2-B775-2468C9A55D85', '4603762000101', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6243E0C4-0765-4A2C-9193-037470C077AD', 'FD1F9052-B926-4CE2-9D71-4D561037ADEC', '4603762000149', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDD31EAE-70AF-4399-AEF8-B9FE20252758', 'FFB79E56-8CDF-4160-B87A-0E4969F9D804', '4603762000163', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6216A35D-5974-4B2D-9E41-71212E325E4D', 'F67C88E0-3CBE-4C9D-A312-81941E6C2398', '4603762000187', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D30BA60-5091-4D58-A05C-0264743C263B', 'F2F3C922-1687-49B8-8BFC-60B51081ABAB', '4603762000255', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABEEA276-2ACB-480A-9B81-5F73866EF92B', '78453FA8-812A-4FD8-8FB8-A8A4FA76B362', '4603762000484', '  3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('595D4B3D-4C5E-4F9F-AD09-42832E6137FA', 'A769DC2A-BE04-42FC-9775-DE0AF2E65DA6', '4603762000675', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26686BBC-4D89-449B-9302-5044FBC5C644', 'C923DCC0-F8AC-449E-A946-09929741D1C4', '4603762000729', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21923C7B-DA17-49A7-B26C-80141AFAE909', 'E80CD40C-DE82-4C7B-925C-B1959A17E642', '4603762000798', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5467D41-C992-4E7B-B67A-B6D3FED051E0', 'CA3D7845-88E0-4D43-8C9C-7FAE83D31D23', '4603762000941', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E5FEE50-B084-4B96-9FAF-591F9C94976D', '7E13AA03-DD13-426C-AEFA-A2FD998FA101', '4603762001030', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DC17CDE-9B71-45E2-9ED4-8B876C299385', 'B3DD5DBB-2D02-4DE6-9AC1-9C629BA9BE64', '4603762001269', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4861B1C9-85AF-42B5-8509-1D1364A59BFE', '80E05CDA-95FA-474E-8C6F-6364F19794B8', '4603762001382', '  4 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB1CECCF-E539-44DC-BDAE-AE9CD929E114', '371BDB49-4533-4CD1-A12A-89B29D6D09A7', '4603762001412', '  4 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4790C6D-C02B-499C-A4D0-BE03C8678174', '54F30F42-E078-4AA1-B0EF-8710381CF6AD', '4603762001429', '   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2826B2E0-F9DA-4844-A934-750DACB272B2', 'E1A6880A-04B0-4891-8F92-206AB17C7C24', '4603762001832', '  // 3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCB23E12-99ED-4372-86A1-5A0EF2ABF4BA', 'DF35B059-874B-486E-9E16-B8A2D3903CC1', '4603762001863', '  // 3 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89081C1E-0F9B-44BE-85CA-063D07EF85E2', 'CFFF73D9-112B-4ED2-99D6-E5CE326C7E01', '4603762001917', '  // 3 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85D933FA-61D3-4E65-A108-FEA2CE2DC430', '1C549674-6BEE-493B-916C-79E2B3F9C1BC', '4603762002006', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28C8FAD3-61E3-4435-8CAF-DCEAF8C70721', 'D1E429A8-95ED-4DEA-AA6C-A1C670368A59', '4603762002082', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D0FE200-932B-4A31-B69F-BF09118624CB', 'F6B2C78D-1942-4852-8D9B-0B0F35CE321C', '4603762002181', '  / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AA2A130-B484-40BF-8E2F-EDE65272103E', 'ED51CA63-C277-4CA3-8ED3-2D8C65944591', '4603762002211', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB5722BC-D34B-446E-AB06-39715AC4370E', 'DF8E27AE-2944-4C05-A2F1-5057EC2D5F8F', '4603762002297', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('926FEE18-5D63-4260-A453-D13E433305BC', 'AA50B6A6-FC46-433E-9DB3-6994E687BC6E', '4603762002365', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FDD117B-65A7-4B05-A948-B5C5A35ABA0F', 'ECC1EAB4-BF04-4A3C-918F-E4A1AF4175F4', '4603762002372', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6512F0FC-95B6-462A-B033-AC364A9B2888', '43B2DD00-2B2F-4DF3-9252-5E1B7BAD3C93', '4603762002655', '-  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C11E2037-DE12-4CBD-A440-8807F2D82320', 'A997152F-7290-466B-974B-522C3D95CB22', '4603762002686', '- 2,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CDB11E9-8872-41BB-90A2-0B6404D43126', '60412416-EA97-4C8C-9112-5AD9E426CF46', '4603762002709', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('104CCFB1-C98A-4B64-A92D-13B1A9D93C38', 'F08B2BB9-2C0C-4682-A2E3-F2B7DAF65422', '4603762002723', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06F5399B-D51C-4C89-ACD9-F3945382A47A', 'AF8C6543-BC5F-4B03-8E59-89AE0AA9E019', '4603762002754', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0530FF90-903D-4D0B-AE04-90C6C3B7FBE5', 'ADF4BEF2-90B7-4ED0-8510-2909F4843156', '4603762002778', '  / / / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2662165-6A7B-4B67-AC0C-60C89507AFB0', 'D1BB2DC4-2B5F-42B2-BDDF-553530D0C9BE', '4603762004376', '   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6FA2671-3926-430A-91AA-4D194914651E', '712A6783-9AB0-4C6A-9BA4-A6EFD10511F7', '4603762004413', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('172038E7-9FCA-4AF8-A9A6-0D5C8C1FBCA6', 'AA2E326D-27EB-4F2D-8B37-AABC818B1294', '4603762004604', '  //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E55512C1-9704-438D-B981-A592E88404F0', 'E7AB6940-680A-4A2B-B12B-66F8C3BFADCF', '4603762004697', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FF3B1E4-645D-4366-AC0E-4284A6255720', 'F76E3854-F7B3-444C-AA0A-CD8756A14620', '4603762004734', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73A3ADF4-D7ED-4D84-B0BC-C46C56A85217', '343EBCAD-3277-48F9-9625-06F61169BB47', '4603762004765', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3AE4D17-B12B-4801-93E3-3DDAF518224E', '6CC740E0-540D-46A1-9E3D-D87C7F5AC3C8', '4603762005793', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41B4460D-51E8-4CA4-A7A3-D0ADE1224AFD', 'F929A27F-04EB-4310-84A0-346D77C371EC', '4603762005915', '    / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEBBEBDD-72BD-4AFE-A763-F4DFA26865A1', 'B47E3BC7-9EB4-45AA-9B85-4675A12D6833', '4603762005939', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53137506-DEE2-4FF1-AC10-FE86AE9C616C', 'A9BA4798-D38F-496F-A867-EBC93DDD7817', '4603762005953', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24202DE5-C270-4CAF-8203-FD61FDECA897', 'CC3590F1-019A-4ED0-BE64-99DC56099456', '4603762005977', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C03D70FB-F969-45F9-9009-E4B65FEF9D1B', '508CD502-1D9D-455F-AC3B-C0E820CDC8A2', '4603779008459', ' 50   / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F48ACE4-3539-4087-91FA-C92CB412B14C', 'D4540DCE-301E-4A65-B54F-A9A5F0870FED', '4603780000015', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2357C27C-AD21-403F-AE1B-C3BEE68DEDFC', 'A1893DA9-F838-443C-9C76-35B12EA5FD7A', '4603780000022', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('430829F8-8D46-4541-88D4-86E4C11291DB', 'EC713951-F037-45B2-98DC-0968D78BAACB', '4603787000414', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3F12D58-604F-4F21-9B16-FEA0A330588B', '05C25EAD-601A-4E79-85E3-0F222ADBA156', '4603788000048', '   tvy-120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C52D67AA-61A1-4D69-81EB-B6DE1B6FFBC8', '920EF304-D070-477A-9A46-8CC1518AB0FF', '4603788005005', ' / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E8B8F74-E8C0-48E9-8A16-BB73A90CD6AD', '7771D5ED-6F11-4CBB-8770-D2C7FCD18EB3', '4603827001203', ' 1/  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFDC658C-7CE7-4BA9-BEF9-36FA7B00171C', 'A17F46AC-437C-4E86-AFE3-8E58CA055BF3', '4603852000028', ' 0,44  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB946E9C-4FC7-47FF-8591-EACC1C89859C', '914FB29E-945B-4CFF-B927-D6CC9C2EEC1C', '4603860000010', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC1AC98F-0137-4C73-942C-C3D51D4A8884', 'BCDCFA4B-8A1C-4C00-942E-5EBC9CC1482D', '4603860000065', ' 10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F8B9A54-63DF-4836-98B0-E7DFDE0DB90E', '581BDDD4-1973-4F93-88C8-AB884050E6F5', '4603860000157', ' /.   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27846ACC-5FAC-4972-9BC7-99F04BF371AC', 'E8DC8A40-66FD-4B48-82EB-05161ACFA9B6', '4603860000348', ' 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D56E99CC-44D7-49C4-AFBA-6B2F445BFDCE', '581BDDD4-1973-4F93-88C8-AB884050E6F5', '4603860000935', ' /.   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF4508CB-E53C-46F1-ACC1-458E05E41C55', '724DA2DB-0F97-4BBB-9F21-22B21156E2D3', '4603860001208', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE547E50-A5C5-48BD-85EF-DDBD672F1551', '1121BD36-7FDF-4910-9C05-4408D57679BB', '4603860001635', '  0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82A9233B-F50E-4E59-A56C-DCB07C890E8D', 'E607A2BB-E2DE-4F50-B63C-78C73E83905E', '4603901000115', ' / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('102C6344-BC2C-4AA7-8E04-DDE85C4B2159', 'BF3E3886-8012-4F44-B441-1D7D349E9AE6', '4603901000122', ' / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('883E684E-E4BB-48EE-A1F8-E06042B734DE', '6705E277-8E00-40A4-A9BA-866B8731DD9D', '4603905000173', ' - 1%  - 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6780A4A-B6CE-4DE8-94F1-F8D7ED755243', '8831AA73-EB2C-4481-851E-F510EF96578A', '4603905000197', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C23B572-0435-42BC-8B6D-D311DD41DA9D', '40D1DDD1-9C74-4D66-8ACC-44DFC6094D06', '4603905000272', '   25 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD7031AA-CD28-4A27-9B3A-28DA06C5F031', '44EDFA26-C4E4-4385-8C0C-E636C394D893', '4603905000357', ' 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('284E39E7-AEC4-44FE-8D30-730F8F4936C5', 'A6468A16-E9D9-48B7-A57C-3D12831AA837', '4603905000371', '  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9849A942-7545-4526-A427-8E5594C6CB0D', '099E5694-7ABB-4397-9715-FC0FCED54F9C', '4603905000395', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9573D6A-20C9-465E-882E-5EAF5C81ADC3', 'EB4BD1F9-E9E1-4241-B4D9-477794AF711B', '4603905000708', '    -/ / 20% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBF8FA55-3BA9-419A-A336-BAFF49338172', '2A5DCD5C-0C53-447E-A38F-8EEF7525E9E6', '4603905000852', '  10% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5AD9685-7279-49D5-8133-F4BDDCC0AD1A', '080AFD45-1A4B-423F-BD95-7DC1EDA014E4', '4603905000920', ' /   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E004B18-9753-4832-93EB-357DDB1E6240', '20FFCDE2-1462-4641-87E7-18AAF1444373', '4603905000937', '  1%  - 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63FF3A9E-D78B-4BA5-8FB5-B9FBD7758C43', '9A64E2DE-B2EE-4A34-AFAD-F08E70F8BBBE', '4603905002108', ' 10%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13087CDA-A57F-4ADA-A37A-9012D0C661A1', 'B0F4D662-87AD-44D3-A0F6-DC57EFFE1836', '4603905002122', ' 20%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA208298-EA7C-47CB-8C67-145F2737C558', 'CD0424DD-AF6D-4B1C-A0FD-EB9718C7EB8A', '4603905002238', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9A9010E-87AA-427D-A4CC-319E0E02E256', 'B6564B46-C8AA-403D-A21B-6D6261AA0B63', '4603905002252', '-  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2533BEBB-E6A8-4EBA-864E-841041033F3E', 'D2AF3F39-4AB4-4D16-ACC1-9AA2222EE627', '4603905002337', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB1D38B3-677F-4178-839E-F3468EEB5004', '650BBD76-8EE8-4882-A177-3D99305DBB40', '4603905002375', '  10% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B70019C-1115-4053-BC56-BD5AE640FCF2', '78162489-C1F4-4A55-9CBF-F2F123E53977', '4603905002733', '  10% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA45EA36-41CA-4584-A0C5-8686A9928CC2', '99867ECA-6EAB-43AE-983D-90536F3D9C92', '4603905002757', ' 20%  25*', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF5BF5EF-182A-48FC-B72E-D21035ABB430', '41876F39-2403-4E68-AFB8-BFA5F3C0F957', '4603905002795', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99C05551-4FDD-4B35-887E-B09A1143B163', 'FB586F30-AB90-4664-B98D-6ED211890930', '4603905003198', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49871E45-E82C-420E-87BB-6D84F9080E96', 'F3BC84E9-6A8F-4916-9DFF-7D743587985E', '4603905003327', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9825407-6183-4047-96E5-C59B284491E7', 'AEAE148D-4D18-4B2D-92AA-3C6FB11116C0', '4603905003358', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DA7A68D-B3F8-45E8-999B-0B8B35C3A988', 'DBA710B3-7A11-4235-9D20-661222CBDF12', '4603905003372', '  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E63B78C-2C92-4003-AC8A-D488F58BEC45', 'F4CEAA72-2104-41A9-B27C-A240D0C0B6AD', '4603905003440', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EC3CB90-D21B-4BA9-BB90-10664D48576B', '902C666B-56E0-475C-B88D-58782F248DF0', '4603905003792', '-  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DBC6E18-1116-464E-BE31-D567B5850BF2', 'F489B350-249B-4009-9C96-6034B1E63DD7', '4603905003990', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11099453-85EB-4B61-8C82-D9CB9B20D6AC', 'E6125861-7E3E-4542-9C22-5B7A3B8BCA49', '4603905004119', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B820E501-EA0F-46A9-9D68-056810DEC528', 'CE9D260E-D318-4C15-889B-C9636C4240C0', '4603905004140', '  / -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5FBE15C-4ED7-4989-B10B-99B08B729EF2', '992993DE-66AE-4B37-B541-1ECC9D80AD24', '4603905004195', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('775DB8E1-04E4-4DA5-A144-B2037C3E7318', 'FE3600A3-A194-4598-ABC4-D1862EB1F6E1', '4603905004218', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDD58C00-DF88-4CF5-AC6A-08268FC40D7A', '9A9B12EE-05F1-4F27-9ADD-D9EB20A82012', '4603905004287', '  50', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A31AF8E-5AEF-456E-859C-EF2288795F22', '789E3947-EA95-40E1-8114-23424FFEF2DC', '4603905004546', ' 125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19A410D8-BDDB-4D9E-92FE-D82EA385289D', 'EB54B967-9F8E-4A81-A109-1B031986F77B', '4603905004584', ' 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD90E821-5FA5-4204-997C-519F27E18AFE', 'D3FC1CE5-B0C8-4A74-801A-66FA0ABD82FD', '4603905004614', '  20 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D6949EA-8188-4EAF-B1CD-4BE9D1092C8B', 'D22F119E-60BD-488B-A6AF-76DCE116ECC5', '4603905004621', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD41C347-C8AA-4F5F-AF91-CCA7DF19DAF6', 'F489B350-249B-4009-9C96-6034B1E63DD7', '4603905004720', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('508EA50A-D0BE-4279-A22A-4B1C63499506', '687A7344-7EC9-456F-B793-7F3D4A7510AC', '4603905004942', ' 0,25 /  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40AE07FB-BA86-49C1-9ADB-8D30B4EB329C', 'BA129B1D-FBD1-41BE-A1D4-A5D690CD8741', '4603905005642', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8ECA55A-B683-44D9-81AD-F65518A0DF71', 'BF3E3886-8012-4F44-B441-1D7D349E9AE6', '4603905005673', ' / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B81CF936-A439-4929-8AA9-0465F1A530B9', 'C4B3A1CF-AB39-48B5-BEAB-32ED387B79C6', '4603905006021', '   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('699EAE55-4E7C-48F0-A451-C5766BA188BE', 'DCBC585B-C2BA-4A72-948C-A24DF786FC5C', '4603905006137', '  /  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57CF278F-22DC-4C27-A623-0DB112889C0F', 'AE10DF07-0971-448E-9DC0-C1232CEA5413', '4603905006144', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E21A4C84-F7F2-4961-BC57-FFAA0DAB4EA5', 'EBE9AB82-60B0-4ADE-A662-22FF64B482F9', '4603905006151', '  12,5 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A54EFFE4-6CDE-4948-96A4-416DF4177E96', '8B3B7C75-499D-45D1-9AE8-EF2D6BE6F2EA', '4603905006274', '  3   /.-/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9FC7529-A63D-4C8E-9866-F1F5D6E40379', '8E1AB7E8-71A9-4AC7-A7C7-4A251ED9D02E', '4603905006731', ' 0,067%  - 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE54BBF3-D7CD-4287-86FC-A3C9F9F978C1', 'DDD84842-F12C-4A7A-9423-6DB06487D11F', '4603905006984', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1D28496-26E9-47B1-834A-B086D8C30D72', 'F7ADC961-134A-4175-B2B9-CB1F1D2E79CF', '4603905007059', ' 40 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B555010D-C658-47D8-9387-D3A3695CB4AB', 'E88D5CF7-9DFC-4E7A-8E11-DD9835ABE88A', '4603905007431', '  0,25% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B15427C-2047-4486-8440-23989E045986', '784E81B1-E501-47FB-99E5-CE387C027385', '4603905007462', '  0,25% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8A1443F-C2DD-4C5D-A093-38BDC7911164', 'D588D9AD-5445-4B55-9972-7B5D60968DEE', '4603905007981', '  10% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40234C14-8378-4BA2-9565-874A7A4D7A16', 'C1432C53-8DC9-49C0-8CAB-5010CD6FE1F4', '4603905008162', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('726303E2-E83B-4F31-9ED7-A99A5F308EC6', '8459E49D-2789-415F-A9AB-8FB858921013', '4603905008520', '  2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00C22849-E9B5-4B88-BEEB-4FF6164EF511', 'DBC31588-1F01-4825-B812-581F83DC33EE', '4603905009817', '  1% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0842CF5E-440D-4DDF-B6D7-C3D5D94DC314', '4C21A8E8-BAA5-4242-B223-8FDF66757AF7', '4603905009886', ' 5%  - 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF5447AE-D20A-4798-A72F-D8F4FDE52D4F', 'F25EA392-F022-44EA-B882-EBD57C1C0592', '4603905010226', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDB54C7B-A808-4444-9894-9A4118792EE8', '961F0E41-58ED-432B-8AED-3DB95DA05A07', '4603905010684', '  / / 30%  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EF8C293-C8CD-4016-AAFC-CACE0ECC1007', 'EB54B967-9F8E-4A81-A109-1B031986F77B', '4603905011094', ' 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('190401E7-F229-427B-9C20-720CDB2AAB5E', 'D32A7E57-C986-4ED0-A12C-129608FCA4F3', '4603905012732', '  -6 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77C51525-AD22-438E-A7CD-C0FAABE00F18', '26287A79-3167-46C0-B7A3-565214F50BD4', '4603905012756', ' -6 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1B66245-D3C4-4338-862A-0B76F8C73C9A', 'D987B1EA-23AA-444D-9558-D871D54F1944', '4603905012893', ' -  2,5 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ADDE577-D254-48C5-8735-DC13EF723F4B', 'FDC886FB-9A6F-4E26-8668-79C67EF99675', '4603905013111', '  3% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D95D279-15FC-463C-B0F8-5664430B96F0', 'C4CDA4E7-42C2-4F4C-A460-308C01C93022', '4603905013166', '  / / 30%  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30C2ECF3-5DEE-484A-BDE9-889A95CD3607', 'E4D69347-F1CF-4746-9C9A-2CFAAD7B15A6', '4603905013180', '  / / 10%  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E75BFF09-A9A6-406B-973E-D03AD04E318A', '9D36BCBD-D59A-40D0-9802-8463B2C01850', '4603905013197', '  200 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E176D6CF-7960-4128-A545-B3631D045C3A', 'DFEE6CC6-2267-46C8-BAAF-327A4D1ACDAF', '4603905013296', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAAF8871-02BB-4D81-91F0-3F2326EC2DB0', '73720610-E9E7-48A0-BED1-C9801EC8A155', '4603905013302', '  2% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('996D9D26-CB60-4170-AC21-602E275D21C2', '1CC4E506-41AD-4EAA-9B5B-91FF495ED1A3', '4603907002052', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33DE5850-0B84-4E7D-91D7-4C69B2389D86', '0B0529D0-61C9-42D0-AD51-1A122BE3E4CF', '4603907002069', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF921804-45E6-4C8E-9210-2F913B52C59E', 'E49A6100-9B14-4F6C-A8F3-6888C99CB267', '4603907002076', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FDCE14C-2963-47CF-8450-BB53DA74B81A', 'BB7274DF-5ACF-4173-AFE1-890282898B96', '4603907002083', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C93A476-E058-4D78-95B1-1C4BF1A69830', '0A2D1F94-7C52-496C-B3EE-BA80F8111A3D', '4603907002090', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42C288EA-20FE-4764-B36C-579D44441D24', 'B3BA998B-EB6C-4352-B237-1C4D3E5D0FA4', '4603907002106', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCFE04E8-F23E-4C5B-ADC2-797916EF6893', '51F7EC2F-3962-4872-B64F-2BEF61EAB942', '4603907002113', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94E193E5-51D8-4C9A-83E2-D8C8F1B9FD1A', '38387E16-D08A-4797-95CB-8A751F03FE64', '4603907002120', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CBC8155-5E2C-4B30-872C-00DA36DC2369', '79814C3C-3D57-4B00-AFAC-9402614BDF71', '4603907002144', '    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC0E3382-4476-4B58-B21A-AB66AA33167A', 'EF4C81B5-CC05-466C-A736-F20995DF2B36', '4603907002311', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05341642-D8AF-4D40-9501-63022AC57802', '80C55359-3C79-4834-8981-710DBA2CD171', '4603907002953', '  13  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4690594-FDA3-487A-B3C2-C96FAFEE0CAB', 'B6A6B1AB-8874-4A87-8F2D-52AC66999F58', '4603907003028', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED61CF4C-F5EE-4A9B-952D-F71F0D04E70A', '51F7EC2F-3962-4872-B64F-2BEF61EAB942', '4603907003073', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98B4FF9C-4E7F-43A2-9C8B-A7202BDA64A9', 'BB7274DF-5ACF-4173-AFE1-890282898B96', '4603907003080', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E0C082C-1C24-4D68-8310-365D515D3C98', 'B3BA998B-EB6C-4352-B237-1C4D3E5D0FA4', '4603907003097', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B12D86BA-36BC-4955-AA54-0A8B7BB5D453', 'AF363F1B-7E29-45D0-B858-C88893099EFB', '4603907003103', '  /    / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D48E8143-CEDA-4D2C-B7EA-3C3C37D47673', 'ED10CE74-F873-406C-A6C5-3CE3B8A7C02D', '4603907003141', '   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3CBDA63-F924-4C59-BDB4-7135D980CD6B', '2888A1D1-E9B2-4949-A916-2129841CA217', '4603907003226', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A0E0C13-AC96-4760-8608-F85372036D65', '75B2044B-5E1C-4693-AA34-204022F5E8D1', '4603907003400', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('646E67D2-7D25-4389-843D-267EAFE3BBCD', 'A9B85E3C-0199-47B4-917A-1F4DB140E5F9', '4603907003455', '     // 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DD45C57-3153-431E-89E4-388E7250D04D', '567A4360-B773-4A89-A8C4-464FAC2EAA99', '4603907003523', '-   2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5C1DD43-ADFA-4819-A3E2-A83120625364', '74EAAACE-603D-4C1E-9065-E8346BA1DA67', '4603907003547', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('521F2822-FF0A-4225-9C30-A7EF75737A00', '687385BA-7607-4321-ABDD-C3733D4E6A02', '4603907003646', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C50B742-C61F-4696-B2D5-041102A474E4', '24CEBEC7-312C-4723-92C6-149DC7E64B01', '4603907003981', '     200,0/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FF11F61-682D-41A9-A655-C26878D3BA0D', 'D06175BB-5458-4ECB-BDC5-09E439A2C3DC', '4603907003998', '     180,0/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B1F2CEF-53C4-47B6-AA70-B198B63FDCE4', 'DCB771DF-2BD1-49ED-AB1E-BA54FDCF665E', '4603907004001', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08BCF28A-44A6-4030-BABE-C9D4DDE2976E', 'D4660357-D169-4591-8660-AD9D4F729847', '4603907004049', ' /++/ 0,18  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('384676DC-EC19-4FE2-81DC-B581BAD14FB6', '92A614F2-3815-4F6F-8244-E4E27CD2CDB6', '4603907004063', ' /++/ 0,18  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B8C761B-6864-421F-AA51-633E98810E69', '60C1BCF1-EA28-48D7-8171-84D4976BF141', '4603907004087', '  +  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FC2BFB8-6513-40D0-9D02-D1A4E774CED4', '17AD3095-7014-4819-A002-90F0EA8CC852', '4603907004100', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C8DFDD2-37D6-4215-934E-5A5D6F131F35', '3B8F65F5-FB2C-45A4-B8F3-166790CC0343', '4603907004124', '   0,18 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E422EDE8-52A5-4AC2-83DB-05C9BCFA3AC4', 'A804094A-8EF2-43A8-B590-6F6B2FCF134C', '4603907004285', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('759F909B-5BE8-4A5F-AD18-189CB933A285', 'E5F1EF77-B2EB-4962-AFBB-2D5FC73BE431', '4603907004445', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA725828-E8A5-43E5-BD21-F72890355889', 'E5F1EF77-B2EB-4962-AFBB-2D5FC73BE431', '4603907004452', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5C0C0BB-D647-42C9-A027-B5F656C96FB7', 'B0B84E55-813E-42E5-AA0F-BCA2999A7F48', '4603907004476', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1015818A-5731-4D38-B9E4-F45025C9EA1E', 'ACE04A02-4C01-4689-968B-55DE004706AC', '4603907004483', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BD8773F-23D6-454E-B1E6-A10E63ACE0C4', 'D900CEF4-3F69-48B9-B882-5A2A35EB336C', '4603907004490', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B90D919-04F8-4601-9293-296F8F14386B', 'A5CAFA03-576F-45BE-B3D3-4AF94353E3C2', '4603907004605', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57AC0390-EC36-4CA5-90E0-1C73B87B1D7D', 'E5F1EF77-B2EB-4962-AFBB-2D5FC73BE431', '4603907005336', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F2A4455-5F9E-491C-9A69-E357CC3EECDE', '86DA88DA-7747-450D-BEE3-9AC24F068452', '4603922000026', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C740E28-437E-4C26-885A-ECC94CA95E32', '3FFE0FC4-8A57-4425-B1C9-A6E1B974B7CA', '4603933001418', '  1% 25 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04CB38A7-76E8-404D-AC93-E90B381AA063', 'F4E14138-CC71-432E-BEAC-0DA737184271', '4603933001814', '   5  - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('469097A6-01A1-4375-950E-638D84888399', '543198A7-7BC3-41F3-9642-08232FADC36A', '4603933002088', '    1%  - 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CBCEA50-6815-465F-A6D6-EEC0C190D9C8', 'FC2468C4-6F35-4CE0-A832-9DC9316ED4F5', '4603933002798', '    20% 30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABC73616-B5BE-4603-BA49-6F591697ACDD', 'BA129B1D-FBD1-41BE-A1D4-A5D690CD8741', '4603933002811', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5374B37-4951-4D5A-92DC-8B966AF0BFCC', 'F4CEAA72-2104-41A9-B27C-A240D0C0B6AD', '4603933002828', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5773707B-57BC-4AA9-909E-627952A1E915', 'EB54B967-9F8E-4A81-A109-1B031986F77B', '4603933002859', ' 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74E0E34E-F8DA-478E-B35C-0D3D63267433', 'F94917DF-8BD7-43E3-B76E-9FEBB31EA7E8', '4603933003320', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('847DB242-441D-49AA-A9CD-68AD19995EA9', '89BDF070-A4F1-4F7B-AF30-B5ADD3C4E472', '4603933003337', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8788A4A1-4AB2-4B24-9D36-E91819C9BC71', 'F8A8AB8D-FFFE-43D7-B67A-E0226CF4DC1F', '4603933003344', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84EE0DED-427C-4B23-8AD3-8B18D13B46D0', '3216397E-F09A-4BB0-98E6-B1430B596B47', '4603933003412', ' 10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D815C5A-656A-4077-A364-1F7CA1B64DC9', 'EB17AB67-FEF1-4BF4-B660-0785D4769CDA', '4603933003474', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D44AA9A7-4E56-4F9A-B306-75E0C002CA7B', '14705364-113D-48D4-B3CA-28978F1B68A4', '4603933003559', ' 5%  - 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A81358CF-EC97-4584-AFEB-98B8F5E84EBC', 'EBE9AB82-60B0-4ADE-A662-22FF64B482F9', '4603933003566', '  12,5 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8CE859A-E89B-4B02-B6B7-B1F0B9848DB9', 'C1B38D73-97B3-4BE0-8EFC-3B72CC60539D', '4603933003719', '  10% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33FDA97E-2E0E-4D8C-B940-784673C681D7', '573B6CEF-23D2-4324-A6FC-1F4A23AB1178', '4603933003818', ' 10% 100 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EABAA468-4D12-4BED-A6B7-D901B9B8C3BA', '7A551576-75D6-45B6-9660-1662A35ACA72', '4603933003887', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9110FB73-B905-40F3-89FA-AB48F485EEBB', 'EBE9AB82-60B0-4ADE-A662-22FF64B482F9', '4603933004037', '  12,5 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BCD3FF5-C533-4332-96E7-8762E927A100', '8516C87F-5266-4405-86E5-A32B3C1C3160', '4603933004167', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3A70A9C-15FE-4FAD-B664-4E6FA528021C', 'F25EA392-F022-44EA-B882-EBD57C1C0592', '4603933004204', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B7605DA-6097-4009-9255-7A203DA58F1D', 'B6564B46-C8AA-403D-A21B-6D6261AA0B63', '4603933004242', '-  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A84635DA-31A8-4AF1-8FF3-A41BB2311769', 'A135082D-976E-4D37-8E1F-C9381A5A4419', '4603933004259', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E87D503-ADAF-4E52-87C9-B22225CD2772', 'AEAE148D-4D18-4B2D-92AA-3C6FB11116C0', '4603933004396', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43819F94-46E9-489D-933A-E57F0AD94618', 'BF3E3886-8012-4F44-B441-1D7D349E9AE6', '4603933004402', ' / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CF5228A-D8DC-4B9D-A903-4DC2043200B2', '91A4C068-A55F-4AF6-B069-3D9A01B1BDEA', '4603933004600', '-  25 ////', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B52ADF80-C487-4BFE-B839-7F5628B26D53', 'C0CB5C96-855F-4C39-B64D-7B0B72BC70A0', '4603933004747', '  .  .- 50 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7553DCFE-7E04-4D77-B8B5-8EDC56C3DB29', '388536B4-586B-4003-B3CC-A75DF1A9E05D', '4603933004778', ' air more  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4D17C09-9134-47BD-A860-4CFA7B832A32', '40740B1B-9D5C-4F9E-8817-CF3776E66E75', '4603933004785', ' air more  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68AC4BEF-8ECB-471A-8C2C-F8CB2C0D72FE', '3DC10536-8319-4F75-8007-2D98D13748EB', '4603934000212', '   0,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('360A3FB4-F1D8-47A2-B453-DEC1DB737541', '71772FA9-96E8-46B6-9D35-8E4E3EAC422B', '4603934000755', '   0,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4C23055-789F-4C71-8FE8-CBACDB056293', '6BA359BB-B858-4D80-B06A-E7161A55FC3E', '4603934000762', '    0,33 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AC3B85F-FC10-4F90-91CA-6C43617E17D3', '792FC874-A3C0-4CE4-A5DF-CD22856B1451', '4603934000786', '   0,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95EEE1B0-CC80-4A0D-8F00-DFE4F7947B99', 'C737FFA2-6892-4D55-B608-AE00C8C261BB', '4603934000793', '    0,33 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DBE5A32-5934-4C3F-9B90-9ED52DD11F58', 'BA6CFADD-0B20-4698-9E78-DF7A7EE6D6CC', '4603934001219', '    0,33 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('232ED10D-C219-46FC-9905-70C36547DF62', 'A659C81E-2B78-475F-A813-1D3F6DAC6D39', '4603934001264', '   0,33 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BE9F815-3B73-4F61-BFC0-60D4BABD769C', '86AD6BA2-53F9-45FF-97BC-443DF3DAB522', '4603934001288', '     1,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BDD3639-D03E-4892-A1CE-A6DB998E3531', 'F77594C2-220B-41F8-A85C-C6E13D79774C', '4603934001455', '      0,33  disney', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46BBB929-C1AE-495A-926F-F0CEC08F5071', '792FC874-A3C0-4CE4-A5DF-CD22856B1451', '4603934001516', '   0,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('342E9576-C237-43D1-8347-C63F13BB8167', 'F84D444A-CFB5-47FE-9F88-E4A9DEAFF791', '4603988000091', ' 8  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('262161EE-7442-4E4E-80DD-6510BED762B0', 'DB1F4BC9-0CB7-4ECF-94BB-71B89993BC9D', '4603988001111', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF7C2230-FD16-468B-8E65-06778AD73B83', 'DE588381-9539-4DF0-BD04-9AAD7C36ADFF', '4603988001128', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27BAEC8C-9F65-4D43-8FA5-E7E052FBBA1E', 'C4E38696-C763-43CA-8612-B41CBB243596', '4603988001678', ' 500 renewal  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1C5D04F-5912-438D-B6DF-EE5A0E9DF951', 'F6E5A801-6F2F-4553-A51F-D5BB78AB0154', '4603988002231', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC3B6F44-F0A3-44C7-880F-236B79B8DB68', 'D466248A-88B9-499E-832B-8F4121FE80D6', '4603988002576', ' 5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('583AF51C-EFBE-4363-B8E2-7538DF464131', 'B01F0077-0EA3-4644-ABAA-DDF3EC47A987', '4603988003283', '  0,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB768853-C23B-41DB-915B-50E3FAFCE0B5', '67D42621-FE28-42A0-849C-1FAC8D368A51', '4603988003993', '  1,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D20E401-5749-49B7-AA9D-55B0A0DB0978', 'D7871D5D-0746-4A24-9693-341F246CE1DB', '4603988004051', '  500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3529D4D-C619-4DE0-8D1E-E7D6C702FF6D', '23FCC387-889A-446B-86A2-ABFA48FF196E', '4603988004600', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24DED0CF-6B0C-4B2D-B729-A6D62BCC42C1', 'CDD25BB7-4E7D-4FD4-AC19-5EB974C33730', '4603988005997', '  0,5 /renewal/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E8DA36A-A335-412B-85F6-FA1A64C8A7AC', 'E73A2730-E34E-4262-BE3E-D132C661F8E4', '4603988006604', '    renewal  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AA04D7D-81E8-40A1-A606-C20FF9979228', '3FBED1BB-F155-4A1F-B0C0-834EC437D327', '4603988007120', ' 0,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29519959-BF3B-4B89-8684-1B383810B948', '8F0822BD-E668-428C-86D3-5B488BCA11C9', '4603988007311', '  20% 2   2 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('354691BD-5645-45B1-AE04-7F4AC9E3614D', '4F4D27ED-19DB-4E7B-9AA4-0A8F5F2F7AE6', '4603988008394', ' -   0,1 / /renewal/  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29933EDA-4BC2-4177-8536-A657E70FFF49', 'EFE30C35-96BD-4677-B190-6D6A65097246', '4603988008516', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8818B620-FD83-4D25-BA6C-99329EA210BC', 'D3C3AC48-5F4F-4B1B-B34F-7F3094BD27DE', '4603988009230', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26D46F75-B83D-45D4-A455-65385AEC422D', 'E1496441-8D1A-46E2-9D95-72801AE10935', '4603988009278', ' 0,1 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D05E53B6-99D4-4090-A765-BAAD6622C987', '4CB4BCC6-635C-46E7-9F02-4D6DE5BDD5A1', '4603988009339', ' 400/ 10 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23DE2496-64A3-4697-B421-8E53F02B740B', 'FEFD7BEE-4E15-46E4-AEA6-6E1511A20F4E', '4603988009360', ' 5 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('471D773B-2FB2-4E15-B079-E39042E5672D', 'CC55F59F-5217-4DE1-AB80-FCB617FE3C8F', '4603988009384', '  2% 2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB356D5E-D1B3-4263-8D91-CFC22E1D1499', '6CACE344-B8FB-4278-845E-A474ACC55FE2', '4603988009391', '  10% 2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA0C2E4C-20A9-489D-BB8A-579B80198912', 'FA15C994-21A1-4F25-8940-BEF9A39F2B9D', '4603988009421', ' 2% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('370E291F-2E8D-457C-A4BE-24A3F316C574', '08131286-C3C5-4831-9553-D1F4C703D627', '4603988009445', ' 0,5% 10 - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFACE1AC-F9D9-44EB-A4D2-26C00263DE9D', '3FFE0FC4-8A57-4425-B1C9-A6E1B974B7CA', '4603988009452', '  1% 25 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('638423EE-1392-40E3-98C2-FFC3F3F364B2', 'FC342286-453E-4E4D-A088-FDFF404648CD', '4603988009506', ' 2% 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98DA7D4E-3D83-4593-82DB-7F5998EDBEC6', 'C5372F0C-1210-4E62-8CD9-E0054656F7FB', '4603988010908', '  3% 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80E3C78A-1D03-4029-9600-58A0A5F8F5CA', 'EE699978-EA26-4372-8980-A2CE60DEA708', '4603988010960', ' 0,05% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52033693-804B-445D-A041-08E1B21719D4', '90085A69-F4DB-4875-9542-001108E9D541', '4603988010977', '  0,05% 15  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C806A877-3169-42D5-8C3A-02880E8F9DEA', 'BB06A4E6-93CA-4671-8117-0EF674A060B1', '4603988011080', ' 0,1% 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F715456-52E6-43D2-B142-4A6A4E2B328C', 'ED59EDE0-D614-411D-87D1-C461F128C077', '4603988011479', ' 0,1% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F62F2F26-24E7-4DF9-9652-1EAB2659FD93', '0EA8D116-E2D2-408D-B93D-0E05356FF6C8', '4603988011721', ' 0,5% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('226C2971-1776-483C-BE5E-153B4A9B6156', '883A14C8-638D-4777-B8AE-4EC783D7F713', '4603988011738', ' 0,5% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AD07C9B-2E8E-4F13-83DB-C83E787E1E81', 'FD8312B8-52AF-4323-BBA4-F2C88946F0F4', '4603988012018', ' 0,3% 5 / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3B9BDB2-2C92-46E6-B6EE-2EA5D9A979F9', '907567BA-0BC2-4E58-B594-BFE26A792794', '4603988012025', ' 0,3% 10  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FBDDC96-19CB-4C46-B4CF-1A05DDF81BCF', '70FAF42A-47D0-47D7-BB90-68E1CECE348A', '4603988012360', ' / 1% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DB54865-FC9C-467A-B520-571D1B7DFB3A', 'C78CB2B4-3019-4149-B367-DDACBE18FBEC', '4603988012414', '   3% 10 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8B7A095-22A0-4C2E-B557-098C61629CBA', '89BBA343-27A0-43B9-8CC8-5CB0C00D22FC', '4603988012537', ' 4% 5   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF0A9460-308C-4DBE-A292-9BB01D4C7BA1', 'F3231E76-1DDF-4DB9-A9EC-A59C8F7F6EF0', '4603988012544', ' 4% 10   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7427CAB-4A0E-457B-A10E-99D1BB4B5A2D', '0F038944-5321-4AA4-8BA7-072411BBCC15', '4603988012674', ' 30/1   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3092C1B8-C9D8-4F26-B62D-399F6192986A', '4D78FB35-A692-4B3D-AEEF-F29644820208', '4603988012834', ' 0,04  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DB026D8-2CFD-434B-9962-47FD1E830E5E', '8850C0D1-33C7-45C4-8172-9974383CB34C', '4603988012889', '  5   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0466D8A2-905E-4659-BBE6-8D7E7E9E54D0', '9655BCEB-E444-417A-8C73-13F50C976C40', '4603988012902', ' 0,01  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E9E16D4-9148-4480-ABC8-0E1117951B2D', 'FC266C99-4E89-4999-8021-1E7E015E7F0C', '4603988012926', ' 0,02  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBFCD347-E351-46E4-A8CD-5D7861FA3C55', '39B77FAF-C961-4BEA-8166-7630D1D81D29', '4603988013183', ' 0,008 /  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B528EBD7-73EF-4CC3-A0F6-EDEFF349CCA4', '970E1776-585D-470C-8470-1A76685B7B4F', '4603988013190', '  3 /- // / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E362DB8-0F75-4374-BF99-8BBB6C1B5D73', 'A2C5EABC-9FBD-4D92-8F03-8325509D731F', '4603988013206', '  5 /- // / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A34D008-061A-4CB7-A9DF-385E8B613512', 'E92210B9-EE60-4D3C-8A8A-7545CC014C5B', '4603988013480', '  100  112 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0DD2198-1EB8-4D26-8AB5-743BB7474C8A', '1EFD70F5-E983-44B5-B038-52241841D695', '4603988013503', '  200  112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F590DB9F-253C-40E1-BC86-8A50ADB620AD', '3FE7C31A-5089-47CE-A6FF-EF54E4A9F293', '4603988013510', ' 0,01 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB586199-3830-4A44-806B-2BA8D7495AF5', '4FAD3425-FB4B-4079-A9A0-C9D7C442D8BF', '4603988013527', ' 0,04  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('081A3316-B9F2-4191-B9CF-5CA04857B703', '542BE3E2-63D3-4C73-BE88-5B395CEA6B04', '4603988013534', ' 10  112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CE5C086-05F7-49A5-BBE0-05674E079A77', 'C6A13F9F-FBC5-46EC-A9BF-10E893F41A64', '4603988013541', ' 0,04  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9599BC7-D33E-4BF8-B61F-9AB10D73B444', '53D30EB6-163D-4F9D-A456-E9168031CAAE', '4603988013558', ' 0,01 / /renewal/  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FA475C8-4729-4BCF-A5B3-18C42E346CDA', '22F4D3D3-2317-41E1-A53C-B7C0AAB33C40', '4603988013572', ' 0,25 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D4A394E-38D5-425E-8621-449E9848B70F', '579372FB-52B4-4581-9E70-38FB2B72217E', '4603988013596', ' 0,0005 /  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEF9544D-7CC8-465E-B8EB-323B49E23C40', '212ECC3B-91CB-419A-B70C-7F85B0C0D904', '4603988013664', ' 25  56 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1033E5F1-97DD-4222-982B-26DA55468E1C', 'C8D9A2C1-0286-4BDA-8DAD-5BA09097AAFD', '4603988013671', '   56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC62507B-9594-4058-8E79-2F06530A365C', '623B282E-349B-4572-A421-5FE505103562', '4603988013688', ' 250  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD35076E-0D2D-493C-A00C-3AB942C5B194', '291E5036-C89D-458E-863D-AA879C1C6166', '4603988013701', ' 50  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9B93958-D876-4AB3-8C28-C472FF7C34C0', '370DE121-89D6-437C-9032-95718EBE8871', '4603988013947', '   0,025% 2   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5AAC446-35B6-41E8-86A7-BBDC24AD96AC', '1B43421B-48CF-4F61-AD2B-D35612703BD5', '4603988014050', '  10   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B76376E8-828A-4482-8594-347B17B4ADA0', '57FD6D3C-3DF9-48CD-A938-450485092334', '4603988014081', ' // /+-/ 2% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D237BD7-8065-4DD8-A6D1-4FC124D7D3BF', '10C49762-5F4A-4620-B2AE-B03E8DEA9280', '4603988014111', '   0,01% 1   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35E5071B-60D7-4E81-880E-776A523ACF4B', 'D2543C71-8100-418D-9AAD-0F81A6F0AC27', '4603988014128', '  /renewal/ 0,05% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D1CEF2F-1EC0-4CC1-B60C-992B75B8E968', '8A168D29-3142-4772-8E79-DBFF8C085A6A', '4603988014135', ' 60  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE3695C3-8D7C-41FC-8BF7-3935920535DA', 'D143A956-1720-4866-B9FA-C65120AC781F', '4603988014173', '   0,9% 5 -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38826544-4E0B-4248-8859-71F2F16CBFA9', '36FF7F24-8156-4262-B42D-BA0AF3AAF083', '4603988014180', '   - 0,9% 10  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87E90494-FDD0-4941-B886-C5F20EC2AD46', '47C7890B-8ECE-45EE-A248-01E87979361C', '4603988014364', '  - 10 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9EC0A1D-87C7-48C2-B43D-88A9DEAD441A', '69FD5E55-D1F7-4F26-815C-0B19F817066B', '4603988014388', '   20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFF8C188-1C90-4F78-9F80-C6E1DD9922FE', '7F976EC7-4EAA-4463-8090-999963C6157C', '4603988014395', '  0,1  20//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BE454DF-FD8B-4640-9C3E-959363D06EB4', '1F0B9ECC-B3B0-4394-ADC4-769CD2E9A009', '4603988014524', ' - / 5 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A208162-6758-4650-B44A-E4AF4FD16E79', 'EC3B0557-81D1-4FB7-896C-D7F27A1D8DC4', '4603988015194', ' 30  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49BF3CD7-662E-420B-90DC-D4250F55D12C', 'FF23FD51-F85A-4650-8936-BF859FB8BF8C', '4603988015293', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFFA50B5-88D3-40B2-8245-EC66F25E035E', '93E8BCA5-4EF4-4323-AC29-30D487A56E90', '4603988015361', '  60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CC11541-0B77-46E1-BEA0-7C389616888C', 'A96BDFC6-BDAC-4B3D-9BD8-E2C495F3759B', '4603988015477', ' 20 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43209D89-0B21-4C44-850D-664EDC9F69CB', 'DC6BBEEE-75C8-4B45-AF51-85DC55FCE529', '4604060000091', '  2,5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('056C12B2-E51A-4A45-8E67-718208330DB7', 'E6031524-9ACD-436F-A66D-F65B0DCE212F', '4604060000107', '  2,5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6596287-0887-4C37-A488-1B545ACFBDB5', 'F054CD80-4D4A-415F-9C9B-B575325C2F8F', '4604060000985', '-  0,1 //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78B62B06-605E-4FF7-838E-B1D3AD416E14', '99D048CE-FF35-41A5-B050-E2A2BE52B216', '4604060002019', ' 300  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77460B85-04E4-41AD-AC9D-E796F71DD4FE', '4B0133AC-1055-4616-8EB3-63B4BC25631B', '4604060002033', ' - / - /. . 99% 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D026B15-C0CC-4E77-9F51-D10246FEEE2C', 'E03BE0EB-56A1-4535-95EA-D855CAA03C27', '4604060002248', ' 1,5  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48DDAB94-2723-4B3C-9266-6647226D4DC4', 'F992E8CF-D990-41F5-A6E8-4049B2D5D0CF', '4604060002477', ' 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCCEED0D-AAEC-4BC5-9A9E-0A3A225557C3', 'F0913831-9666-48A8-86BB-4C7C6F3CADBA', '4604060002507', ' 60  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('292AD414-F63B-41C7-AD09-FA5A8CCDF9DD', 'FBC2B143-7D55-4D7A-BB6F-0CA0AE9195D9', '4604060003320', ' 50  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9DCEA4F-3EFA-4D9F-8BF6-958421835F87', 'FDE9AE69-A5F6-4AD9-9B4A-25D5F95F8D62', '4604060003665', ' 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0629E85-74FA-4699-BB72-24B9F7A4B518', 'EA396179-882A-4C60-A6C0-954CA6AA7365', '4604060003955', ' 15% 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A5EED92-522F-47EA-AFA6-BC9F169E97CF', 'ED397675-D882-46D0-9596-DC9DFBACA37F', '4604060005232', ' 150  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('533E8F01-B1E4-4C73-A62B-D3A77500A8D5', 'ECFBE344-67EA-497E-872C-F059631D9E8C', '4604060011097', '  20  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8F31691-0982-4906-A5E1-BE246A113D05', '99D048CE-FF35-41A5-B050-E2A2BE52B216', '4604060011202', ' 300  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F5E14E7-BF37-4269-B1FF-2BC01458894A', '414F6A20-52ED-4D1D-91A9-6F337AE520D5', '4604060011622', ' 0,025  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A34E9A0-2E9D-440A-9B50-12ECAF909B4B', 'ED397675-D882-46D0-9596-DC9DFBACA37F', '4604060061030', ' 150  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B88B0A4F-93B7-403F-8BA2-6D76898F4FFF', 'CB2E1A91-B2DE-43C9-A3C8-79CAD4DEA0F1', '4604060072074', ' 10%  - 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C544F2AF-21DD-4D6A-B167-BA8C97593DE0', '4D847526-8F26-4A5E-9621-37F33FC0C3D9', '4604060091013', '  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6E76FE2-735A-4DAC-B088-4CCC89DD1024', 'A07A2091-65A2-47F3-B155-EFE28836B0A7', '4604060091303', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8A99FB1-74AE-4794-9B63-A7F3EA5F7F9F', '84E3F762-0CD9-4505-B1B7-52A4FDC5EDF8', '4604060091334', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2646A8A3-FAF3-4641-814E-C9C8242563AA', '69B5940E-765B-413F-9F52-DBD3E9DA1288', '4604060092034', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3358EAD-752D-4CA7-A53A-148063E65570', 'F3BC84E9-6A8F-4916-9DFF-7D743587985E', '4604060093017', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75B0A12F-E865-4C9C-B47C-73B5B79413F9', '0900CD83-54B3-4646-9CD0-35BFC0D2DA76', '4604060173085', '  10% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75CC01B1-4BF9-4757-B6AD-F1DC0226D685', 'ACBFF139-0A36-4BFB-8FB9-6D8BBE2A9FF8', '4604060192130', ' 0,25% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C94ACFF-C3E3-479A-BE21-3EB7E0492386', 'FBC2B143-7D55-4D7A-BB6F-0CA0AE9195D9', '4604060201115', ' 50  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7949CF8-89EA-4FC9-8BDC-EAC09FA0CC66', 'F1028821-3CF9-433B-A0E8-2ED2ECA1636A', '4604060203058', ' . 10000/ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D873D6DA-75D1-4A12-9330-B576C2233041', 'FA8B4C87-652A-4A29-8DEF-BA43D138C865', '4604060203072', ' 0,5%   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5964497A-E980-4A37-A3A7-352D5DA2CF40', '4B37034A-322F-4EF0-8779-2FEC2EE0FDE8', '4604060231013', ' 0,05   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('095465D2-FA46-4400-B837-07BF9DB6AE1D', '5E999606-7AA3-416D-8FF0-76E525525373', '4604060233017', '   5% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E3345B6-DD06-4026-B7A3-FFCF5E90F8AB', '54D6E659-E5EF-482F-970A-B15E5764A536', '4604060251073', '  250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B163839-7B37-4D2E-8C06-5A8EFA88DEA7', '2919398E-355F-4D59-86F7-BCACDEF47043', '4604060252018', ' 15% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('658329E2-2ED8-4832-A15F-CD1919657852', '58416AC1-1056-4A8D-AE62-27A83662DB99', '4604060271019', ' 0,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF1AC78A-0FDD-4804-A120-37DC8EAE3D67', 'E03BE0EB-56A1-4535-95EA-D855CAA03C27', '4604060271095', ' 1,5  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AB55EA6-BD09-4463-90A1-1753A678F392', '57AFF134-9504-4976-A05F-2EEF3AB49757', '4604060991214', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A5A2D6A-A968-469F-B33E-282CE608A72E', 'B0CF804F-E3CE-4C9F-9F4A-0A9685469357', '4604060991412', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35902C95-1CA9-417A-920C-56C8BC581500', '3FE7C31A-5089-47CE-A6FF-EF54E4A9F293', '4604060991450', ' 0,01 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D12F5C09-10AE-48ED-BFEC-B5D4C16155F1', 'C6A13F9F-FBC5-46EC-A9BF-10E893F41A64', '4604060991474', ' 0,04  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A907B2ED-FBD2-4311-B662-C8A6DD88828B', 'ED397675-D882-46D0-9596-DC9DFBACA37F', '4604060991511', ' 150  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC3CCCF5-6BA5-4395-B8E1-60386B809C76', 'D26E9080-19D9-470C-B78A-214BD38D3A70', '4604060991849', ' 0,3% 3  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E42796CD-5C6B-4EC1-8175-21532FBD5583', 'BFD57777-CF28-47FC-8B76-4CFE8E9CE7F7', '4604060992013', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8721886-EBC2-43E5-BBC1-3B1E827FB278', 'F83FACB4-1B2B-473E-BD31-BF77576DE37C', '4604060992037', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13BC3E0E-8428-4CE1-AC1B-B95DC0C85C9B', 'FDF6B690-41B4-49DB-8D90-C94B493842ED', '4604060992051', '  3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('247D7185-7EB0-40C8-B05B-D03E3E7BC35D', 'B15357CB-EF74-4DC0-8FC4-7B243018CD87', '4604060992679', ' 5%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1C16149-6749-4237-93ED-666FBE9AF96A', 'E0846D8F-98A6-494C-BB60-77F459192FDA', '4604060992686', '* 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('914D5D45-5F8B-4406-952F-E3BAE90969C0', '78B212EE-3047-4AF4-AD8E-EA9913BCFF4A', '4604060992945', '  500 /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2885678-351E-43A3-AC68-5F9997BD58AF', 'ED75F2EB-0B9D-4BA1-9E2D-48A611BC587C', '4604060993447', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9824A143-F5CA-41BC-A2B3-A3A0FEC4D200', 'B141C470-ACBE-4646-89B9-658069B3CE28', '4604060994185', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('189526D5-95D4-4A88-B4AA-2F31AB6C2C6F', 'F992E8CF-D990-41F5-A6E8-4049B2D5D0CF', '4604060994321', ' 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECF1CEC3-922F-4C53-B8EF-BC461A3FF015', '8CEA05F4-C96C-4007-B9D0-86CEB65E4148', '4604060994406', ' 10  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECD6964C-5D9C-46D9-BE69-5090AE526F60', 'FA8B4C87-652A-4A29-8DEF-BA43D138C865', '4604060994444', ' 0,5%   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC413DDD-3419-492A-A21A-A49ECFE7DADF', 'E5A9E034-AE70-4D4C-8081-BA4AD17306A4', '4604060995090', '  1,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('049D8892-CE00-4E5D-AB46-16E2BCC0A1C6', 'C6688E2B-D9B5-4A25-B3B6-55D2AB538237', '4604060995755', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71466538-AD2E-4104-B265-0EF1635AD201', 'C76591F2-2B2A-43A2-AE23-7B2B9DCE098F', '4604060995823', ' 2,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2309ABCE-4EF1-4971-8998-6011987DC917', '4777135D-A35F-4187-98EE-F05A894BA7D7', '4604060995878', ' 0,005  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA8F8FED-916C-4268-8868-479FCB7FFCB5', 'F2CF2330-0D01-4636-A573-54AA0E7D7114', '4604060995922', ' 0,01  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06FFC35C-E050-47A6-9EC0-7BFC383EAA69', '2B996A9B-CA52-4CBB-823B-61B4C8EEBA51', '4604060996288', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E97F1368-EE0E-4A83-B665-BB814EBDD118', '8CCFDCE6-BA26-4781-87E9-FAAA43E73E86', '4604060996318', ' 1000   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A52E42B5-5AC2-45AD-8C76-06A553D3014E', 'C44A9777-1FD9-42E5-9BDF-D651DE395644', '4604060996561', '  0,035  //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B08F337-9AE1-4790-B4CB-0F954AB8B89B', 'E9AE1090-1666-454C-9EAA-3314920583A2', '4604060996578', '   35   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1D05FA7-D864-434D-885E-DD6AB3DD6FF6', 'E0C3042A-F308-4C7C-BF3C-230E15C7FB4D', '4604060997124', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F186250-F547-44DB-86F7-4B345F5FF400', '35108BF2-EA36-47FB-A638-8C20597AD419', '4604060997360', '  / /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB7B9E5D-4865-4CD2-98A5-97C7BD4E584D', 'C9AAA200-FDC5-417B-AC78-EE6AB0356741', '4604060997391', ' 25% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F5DAC14-863F-42AD-AA15-37A8DDF8CDA9', '777DB851-B069-4AC3-8939-ADF3B708E9DC', '4604060997995', '  100 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50F34404-ECB5-4B17-A2FA-D6F5CF9AA324', 'D588D9AD-5445-4B55-9972-7B5D60968DEE', '4604060998053', '  10% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('060C835C-ADEA-4449-8156-EC9A45C24F8E', 'BA129B1D-FBD1-41BE-A1D4-A5D690CD8741', '4604060998350', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEAE8045-5B88-420D-99AA-7CF08B1D7118', 'A8F600CF-FDAC-4BB3-BA2A-9DB0DD687182', '4604060998503', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09EB9EBE-F465-413A-B884-57E90253D2DF', 'F283BC1A-BEAA-4A50-846C-DA98B6BE7B36', '4604060998800', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB67A66-4B4D-4C58-8E3C-EEE45794E4A9', '69B5940E-765B-413F-9F52-DBD3E9DA1288', '4604060998947', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87750B83-0FB6-47AD-9C6A-4137FD84BC18', 'A07A2091-65A2-47F3-B155-EFE28836B0A7', '4604060998985', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41C31A08-4326-49DB-A616-4684A14994DD', '3C0DF36D-DED0-4C84-BEE7-13949242792A', '4604060999081', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E75E92D7-0567-4937-9E65-7E9FFA55ED6D', 'F1028821-3CF9-433B-A0E8-2ED2ECA1636A', '4604060999241', ' . 10000/ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('897BF518-25BE-4893-BC52-79D68788AAA6', '2AC4B6B1-D8B4-4854-BA66-712B2108543F', '4604060999784', ' 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39607BAA-C6E4-4587-BEB3-6D673EE3B9D7', 'D59E1344-221F-45B8-A055-6C3BD04AC1DB', '4604094017256', ' /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('326932FF-A717-49FD-9056-A3F6FA2DFA38', '9767F70B-387B-4D00-8BA1-AC32DCDCFF36', '4604094017287', ' / /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6940111A-A26C-4FD4-8136-CFF04A710EF5', '0D08FFDD-4D39-4975-A08B-231355A53010', '4604094019458', '  / /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('986530FF-779F-4B45-86DB-FD6003CC64EF', 'BF3E3886-8012-4F44-B441-1D7D349E9AE6', '4604171000195', ' / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCF907AF-F258-470A-AA97-AA41A10044B5', 'BA129B1D-FBD1-41BE-A1D4-A5D690CD8741', '4604171000201', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B9FD84A-B623-47C5-AEE2-203E5A127C4B', 'C1C4D162-C0A2-4B25-A705-226956DFCD39', '4604461001567', ' /   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5D2D95A-DCDB-43B3-8FC6-4B62C054C150', '54157231-897F-4417-B4E8-A16953C1CF9C', '4604461001727', ' /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D36C6031-34A2-41AE-88F7-DB3B99EBF347', 'D648104B-DAEB-4EC7-A46C-D3DEAC289EC3', '4605021000327', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76C3636D-D292-40F4-922E-16C26AC27CC5', 'DDC0BC7A-7009-49E7-A2ED-942D01C830C3', '4605021001645', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F5B4347-B625-41DE-8B56-693C40532DBD', 'D648104B-DAEB-4EC7-A46C-D3DEAC289EC3', '4605021001652', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('295DFBAF-FA29-43D7-84D7-618BF039B787', '8C1E48F6-5073-4A3E-B26C-286BF284E6D7', '4605021001690', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF686F50-7E39-4924-9395-F9710F5E8023', '7E554992-E687-48FE-A89E-23ADA674CD1F', '4605021001706', '- 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A4754E1-0151-494B-88B0-D4BB4FFCDEA1', '8C1E48F6-5073-4A3E-B26C-286BF284E6D7', '4605021002093', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCD0B3FD-7F10-48EC-8408-1568B82EEE71', 'B4CE5FE2-1D1E-49DB-BE10-D22F37AC943D', '4605021002680', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E1902A0-19C4-43BF-82AB-04346278D312', '9891D704-66D6-4C9C-A6B9-4F5D058209F1', '4605021002703', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77AA1202-85D9-44F7-BD9B-B6DB8B89C036', 'BE8E8D09-262B-41DF-BCA8-6E3DC83018F4', '4605021002994', ' 5   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63F5268D-CFAC-4D73-B6BD-EA7B346F8F54', 'F9F1FB00-DF28-472C-B80A-0B64E00F7246', '4605021003052', ' 5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FBBFED8-421C-451F-9F8F-3CFDE0F5A558', 'F9F1FB00-DF28-472C-B80A-0B64E00F7246', '4605021003076', ' 5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F94C863C-65E7-47C2-9C06-38624ECC2211', 'F1FA4294-1320-47CD-A72A-17C0C7A93823', '4605021003151', '  3 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('225BE0EF-4D48-496D-84C5-72B38EBFCA5D', 'F8EAB2B3-4875-4AAD-AD73-9A4CCD55ACBD', '4605021003182', '- 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF586E17-F553-4138-A003-425A82EBE89B', 'EABDEDEB-8ACD-4A3B-9BA9-CE6507F7197D', '4605048004421', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C9A20BA-3E6B-4EC3-A0FE-713D34EA18BA', '6894A790-D285-47B4-86FD-4F0DE78649C8', '4605048004865', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AA6B47D-1521-40C4-B625-5E1058209A39', 'B6DD2EBF-F1B7-4FF0-BF45-1BE2253397B4', '4605052000013', ' 1000 300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1A4E3F5-1C54-4B36-AA10-6D3DD4B33436', '9B4ADE1F-F412-428A-972F-B244E0AC2441', '4605052000051', '    0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D726E0B5-CA5E-4F61-955F-122ADE37F6BD', '3DC11A32-7A3B-4F51-B287-C4B554499FC9', '4605052000143', '    3  0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('506B7883-7D7F-4489-BA5E-3870C7393E1D', 'FF7F4C71-EFCF-4EFF-B742-73FD8961A30F', '4605052000150', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8E20106-6D2D-4CE1-855D-DBBD47C3EEAD', '1CE9ED5F-8767-4587-93B8-D6251A7B137D', '4605052000167', '   450  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEE2E52E-EF23-49DD-BC02-1F02DA288508', '299EA775-C614-47BF-ACC1-75927D955644', '4605052000280', '      0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B682FFA1-DB52-4B32-AD33-0B490CA33703', '5207EF6F-1B4E-400A-9FA4-A8C29D397E36', '4605052000419', '   500  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DC7A734-4EF0-4057-895E-43D8B0B9086C', '9B4ADE1F-F412-428A-972F-B244E0AC2441', '4605052000464', '    0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('308A6516-A785-486E-86C1-14A274EEDAFF', '4352199A-AEC4-46B8-BE2E-6F894CC4601F', '4605052000501', '  / 0,5  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43B18802-80E8-4D74-993C-705E699EE33D', '749166EC-2503-416A-AEE1-210D4322A771', '4605052000587', '  ++  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37EE8FF8-C069-4507-94C8-07C427E72E89', '11A952CE-5DA6-4BB6-9A9B-584E1E2E3C51', '4605052000747', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC92738E-581E-44F9-84E8-7BE14E81F1A7', '3DDFB3FD-1B5B-47CE-9C41-7E73B8468FF1', '4605052000754', '    450  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CF73EF8-4939-49AA-A66B-57D65F22ED93', 'C6DA9D8F-B198-4ED1-B2C8-C3D53717883B', '4605052000778', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07C6E808-F37A-4B61-8A17-65DBFE666480', 'B11ECED6-640D-49A1-B4BF-7EEB6B2A96E5', '4605052001034', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DB8FEB5-86A9-4EFB-993F-9599CE2F9868', 'EA7EC285-2113-4A49-A3EF-5F7049C08E26', '4605052001232', '   450  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0963A460-FCA0-47D4-8C87-50C711D99FC0', '20FA3C55-DDF4-4F62-8DAD-2AE738B2C458', '4605052001508', '    100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3126761-3C30-4068-A342-475D93BCE2B7', 'CABD061C-8492-4672-A6DC-777B70415F81', '4605052001751', '   0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C4A9991-7A17-498E-ADFC-A55618FAA9F2', 'C6DA9D8F-B198-4ED1-B2C8-C3D53717883B', '4605052001775', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48E56E01-08A8-4F5E-860D-C79519ED69CD', 'B11ECED6-640D-49A1-B4BF-7EEB6B2A96E5', '4605052002031', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4841D9B9-5766-4C08-92EE-E076118040A6', '8043FF27-93D9-4C9F-9324-E143B33724E7', '4605059001624', '5   /      1,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3782F4C3-04E3-45E3-91C6-DB154F5A75E0', '3FD57F25-4984-4FD9-8755-8DB7EA5D114D', '4605059010251', '5   /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03C33E5E-9ED0-41E2-8429-CA3617AAE4C5', '344280EB-495A-4F16-8CA8-CF56C1FCABEC', '4605059012583', '5   /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53418A35-91A0-4BFD-8242-DC35A7FD4207', '27E80BD0-552C-4C51-8860-DABB6FA13810', '4605059015225', ' 5  /   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24353B70-47E0-45E2-BB80-B46C670E7C1B', '8CE44DCF-F5A1-40FC-9203-E71AAB977913', '4605059016550', ' 5   /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BA446AB-7AA5-4AF8-8B15-1B15BDAEDAE6', '1245B914-9ED7-4DD1-8CF7-2E19DAB96C1A', '4605059019179', ' 5  /    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35ED8349-F872-4F36-BD71-FA21C46E9F37', 'A5677BB7-09EC-4060-AEF2-8828FEF152C4', '4605059019216', '5       / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A047141-A608-4FAC-8D59-E0B1AB380072', '749A40FD-037E-4B9A-8DF1-99CC4D17788B', '4605059019711', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2F6AC31-A81E-419D-B93D-28B6851EDD0F', '6C8FD4C8-7D02-4D53-9026-53B3C97309E0', '4605059020274', '5   /   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BEA23E6-303F-4639-BCC3-A7DA294C1624', '6C02FD93-3681-4E0B-92FE-9BF04F47049E', '4605059020304', '5   /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D819EF18-B781-48F1-94CB-ED86BF219117', '495ABBDE-059B-4795-A642-27F0AC77F7FD', '4605059020328', '5   /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BB14940-FC94-4ADB-9838-0CEE87AC5734', 'D0EE14DA-9CF9-41F6-AFB7-7CBAD2400839', '4605059020434', ' 5   /   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9553F7D7-0BC1-4766-B2B7-0BE2D77B889D', 'F5C526FC-EA53-4CF1-BFD8-8CBFF159FBFA', '4605077000319', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1C774C6-F822-46A0-ABFD-BDDFFA05E570', 'DAB4FC83-73B0-41AA-8677-C193D44194F1', '4605077000906', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEBB179B-E535-48BA-9344-7772D99FA279', '8DC98CB0-BA05-4CF0-A739-9A8682976F39', '4605077000999', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36659D09-4325-41A5-867B-88D322A39959', '7A521097-95D4-46FC-970A-68331A417D68', '4605077002184', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9354ED3-8D6E-4C8D-9D9B-2ADCEFB047A9', '9D1F110E-B429-4A92-932A-B273C72DC30C', '4605077002412', ' 50  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D659791-C7C5-46F3-A2CA-E2D7735BBE74', '52112402-1B1E-4FEE-8528-A8BAC087787C', '4605077002450', ' 0,05  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('011FD74B-FF74-45B7-A825-C206FFC17E39', 'FA9C0FD2-3981-4AB0-988E-FB710F7F5F08', '4605077002627', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E9E3BCB-6ED9-4E8B-BA8E-4550DA2BDA35', 'A440D979-05FF-4854-93F4-561F50136E28', '4605077002979', ' // 100  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B076BCC-8384-494C-A465-42725153AA95', 'F1E2DEBE-A850-4035-8F9A-A72F29D8F6D8', '4605077002986', ' 30  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BB3156A-0D66-4F3F-AEDE-6B0CC4A11DB5', '683C1D27-32DE-41B5-A6E8-9AAA3FF954B9', '4605077003303', '  100  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB20705C-4465-4656-BF3C-33402B96D900', '2C9CAEA6-E11F-4286-B3C1-FCB5729CC282', '4605077003372', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E00C7F11-F9EC-45F0-84DA-54FD6BCCFC91', '4C50D00A-7F44-4016-8877-FB50633B82B0', '4605077003785', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF3A9D1F-9828-44B8-ABF5-FD4C7172E4E6', '8B39F358-291B-4B0D-92C7-7A3600D3B5B0', '4605077003891', ' 10   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC913083-475E-40A7-83D3-BF205980FA14', '70F9B99E-46CC-449F-B34F-331BE1825BEF', '4605077003907', ' 10   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C50E40EA-09D3-4CE3-A842-976569268448', '6F867A70-2B9F-47CB-9126-23F03C5C1D18', '4605077004294', '- 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D05AFFEA-FDF5-4AD3-83F7-7252317439C0', '9630AA03-C190-4A57-8844-D6C052DECE86', '4605077004478', ' 0,01  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22F256BD-11D7-4EDA-BC64-25E28B3BFD79', 'E66C79EC-DB59-4932-BC8A-1155BB21FB26', '4605077004607', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('516751A7-7A8C-4835-A925-39952B4B993B', 'EAA10170-BB1C-4A5E-97F3-9EDFEEBDE720', '4605077004805', '  / ./   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3A05F66-F6D3-4C73-9CB7-2F6AB041FF40', '74E61D45-7701-484C-9AF8-BAA0E1AA038B', '4605077004812', '   / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C009FBC-7047-4D72-8442-FB31818B55AA', 'D3125849-8A88-4008-AD89-467CE389CB35', '4605077005086', ' 800  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FF782A2-9424-46AB-8E1B-376B4B688974', 'F5AAC351-A9DA-48AE-AE4E-CDE73D4133FA', '4605077005093', ' 25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90421B5A-1BC0-40F1-9444-8BF80A9948C2', 'E3DFA5F8-0097-459A-8D46-5928331DBAE7', '4605077005147', ' 0,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCE4007F-AA5F-487E-B81B-34E39749FF56', 'FADC955C-6DCF-4555-AEF5-97ABBC70D9CF', '4605077005154', ' 0,5   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DEC876C-CCB2-49CC-A383-3B8CD870A699', 'F5680C87-FD4F-4F02-89F8-85B47E1537A4', '4605077005543', '  5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD08D5D7-392C-4271-921D-B6E4370147CD', '44BE536A-34E3-4792-8D3A-0018BB50112C', '4605077005567', '  10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEE56166-2145-4F04-9591-5080CEFBF1FE', '973B4D2D-3FA3-46B9-B5FE-7A10EA833356', '4605077005574', ' 250  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BBD4D4B-646D-4D01-839F-2E229FBDED39', '59E00B1F-6C25-45DC-BE0A-7468CF2C4A4E', '4605077005581', ' // 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3915ADC1-E96B-4573-B2DA-44DDC6CE2B03', '99117497-F5AB-4A0C-9069-775ADE2BBF68', '4605077005598', ' // 150  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('076DE8FB-2B4F-4174-BD20-53EFAB92DF0B', 'FD462CD6-0BBE-4843-9E14-DDA4DA7AC30A', '4605077005871', ' 500  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74EBEEE0-81DB-4297-ADE9-06048EFDEDF1', 'A4402B4D-AAAF-48C3-A251-A11547C73DE0', '4605077006021', '-obl 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AFF5B26-CC76-4FE6-AA47-34FF6AF75429', 'A8685EEF-826B-4AA1-BB41-6CB810345E62', '4605077006038', ' 100  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03093009-FD62-4919-B095-FADF5DA3681C', '4AC4BB8E-68B8-451D-AF7D-8F1C597E0126', '4605077006090', '   0,4 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45D29239-8629-446B-AB98-9278202D064F', '32C7D125-2C3D-45CD-A1FD-E30B177FC9FB', '4605077006571', ' 150  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3B2CA14-1B12-4904-90C2-5D985B16E866', '6A9254EB-D8C2-4CBF-B73F-7828D4A2E9EA', '4605077006588', ' 150  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7845159D-F3EF-4EA1-9042-3CAAC89B5ACC', '103A9B92-CFC2-4AE5-8EB4-54CEA681E376', '4605077006663', ' 0,005  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4EFF99D-DB0E-4931-9F4B-09D88D8E50EA', 'F7B33774-9759-4851-B09E-43B78732F1AE', '4605077006687', ' 150  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B355A8D-F927-4FFB-96EB-920164330B63', '677CE0B8-FD80-43B7-B614-803019E02E24', '4605077006939', '  500  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE6F281C-F54F-4046-BAED-E91051F2B951', '0CFEF669-E228-4DBC-8289-C6123D6D2987', '4605077007820', ' 0,4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FF00103-2F36-4A4C-AC6D-8D596000D564', '8720D65C-3A0C-4069-9266-41834F20C270', '4605077008025', ' 2   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AAFF232-CD87-477E-A1B9-80FDB23A724F', 'F5AAC351-A9DA-48AE-AE4E-CDE73D4133FA', '4605077008483', ' 25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A9C7798-B217-41B9-B465-D61C50B88524', '8D0DB250-7AB8-48B5-B7E4-F988D5E10F52', '4605077008506', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D194E229-6290-417B-B1B0-4C1E7EAB09D9', 'C72241F9-439B-4178-97A7-0C394853FC3F', '4605077008803', '- 50  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3CE792C-3CAF-43F2-9CF2-6A162A79B6EC', '7AF908F3-CFDC-4C59-AE6C-79D979A2D5AD', '4605077009237', ' 0,025  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84EE56F9-096E-4BEE-A416-531D572626F6', '9599686A-8971-43E5-A6DA-3B4620E5D4ED', '4605077009251', ' 75  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E7CF892-106A-45FB-B9ED-967547CAA9C1', '56718230-BDAC-4FBF-BCD8-A5E54740B6D1', '4605077009411', ' 0,05  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4C9CA2B-1124-41DF-87FC-1A6BC4A0448E', '635BDCAD-C17A-46C1-B9B3-893CAEC61307', '4605077009435', ' 50  10 / 3 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD947FEB-3854-4FC6-A63D-07C321017587', 'B5BFF340-E1E2-4B6B-BB09-1A8E8B64B5A3', '4605077009442', ' 50  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2538180D-089E-4369-9F98-7E09E83DDCAF', '78C5D43D-A8FE-433B-B358-EFAD17383DEA', '4605077009619', ' 0,002  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B6C94A5-834C-4C10-94C5-B3E5351EE952', 'E07AFEE6-5CF4-4521-85D8-02B3CC26ACFD', '4605077009688', ' 15 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8316562F-B081-4BEC-B867-840F1922E745', 'F5C526FC-EA53-4CF1-BFD8-8CBFF159FBFA', '4605077009725', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('867C54D8-C49A-4D28-A41D-3B6FA4B06905', '7A521097-95D4-46FC-970A-68331A417D68', '4605077009732', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B7073F9-E830-4C01-B9DC-CF86A7F13500', 'E4E721E1-CA8F-4ACD-91B5-C2BC9A658CDB', '4605077010202', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6042A8CE-EA2C-44B9-9A45-748918640FB0', 'EB65956B-2F8C-4E0A-BC24-508B79BB6A51', '4605077010387', ' 0,15  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('252169FD-FEE9-4673-9C38-5F06782BF76B', '8AAC8418-C405-4062-8550-49C61830F31F', '4605077010431', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7F1D54F-0A49-4081-9468-62F24A7D9028', '4EF3DC81-AE7F-4673-888E-68A86C3CD735', '4605077011100', ' 50  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F984F1AA-D5A9-4CCF-B784-4E249A5279F8', '2E1EEC47-11F6-475D-A68F-54054A0D5A0C', '4605077011124', ' // 200 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B38C290A-DDAB-400A-ACE9-B3183ACBD637', '23E1BCE7-2290-4A0D-BED5-606F5F2806AA', '4605077011230', ' 0,003 //  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1A31B57-B3EC-4EE4-B1AE-C9AB0A559629', 'D2B950A9-A8CA-4908-9C50-F74BA91FB53D', '4605077011537', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('229B06B5-A0CC-40C2-A7AA-FF985832A077', '9599686A-8971-43E5-A6DA-3B4620E5D4ED', '4605077011667', ' 75  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A106A2EA-B5DA-4003-BD91-C7F63C95B31E', '94232B60-DAD3-408C-8DFC-B09CF7BA27E0', '4605077011698', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE5903A7-EE9C-4DB7-9ECB-517B5201D504', 'FA9C0FD2-3981-4AB0-988E-FB710F7F5F08', '4605077011711', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1A7CBD1-2F29-4C7D-B195-F99F86D22735', 'ACB5DFA6-CDF9-4FD7-9D38-31DEE873DD3A', '4605077011735', ' // 100 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('825C2271-D70D-49F9-8D76-DE21CF0C6EA9', '978C52E8-E2F8-4989-91BF-D2301FD40C68', '4605077012015', ' 3   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('169A91CA-AE6F-4827-9741-F12605E053EF', '89487627-68A7-4DE9-AEEC-79A91D24CB98', '4605077012046', '  800  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E754115C-CBA6-415F-BC64-1F1D52E7E6C3', '806F496A-8E58-41E7-ABF5-C99E44D51702', '4605077012077', ' 2,5  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49920AE5-A696-4C5A-B2EC-B0765C0BD694', '88C184F9-3658-49BC-972E-22607F5A3011', '4605077012190', ' 0,03  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BF5E268-E54A-453B-90E2-59C8490EFECB', '478B8309-D803-4CCD-91D7-F8CA08086E6D', '4605077012237', ' 25  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1989B650-C538-445F-9758-4B5A0BB5C6F7', '9B472F5F-18C8-407E-B455-48E5B301FC13', '4605077012299', ' 1 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FF3F6F7-84EF-46CD-A500-8A0415246CFB', 'E098196A-997B-40B7-AB45-2CD5624AB773', '4605077012336', ' 200  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7030BF2-85E7-4902-B6F6-5732DF3EDB85', '06CEF4D6-052D-4DBF-AEFE-DCCBC40DE506', '4605077012350', '   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32941A33-7480-4E9F-9D28-621F913615F2', 'ED97335D-855F-4F7F-8C44-3500FB16296F', '4605077012367', '  300  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B973EAB1-8F0C-4408-9DB7-670AE650DDC8', 'F605FF76-CE00-48BA-BEFF-36F848200E6B', '4605077012411', '  500 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('335E2B5A-33C6-49E0-8E67-9876E3894E39', '9FBB9AC7-A506-4C8E-AC21-9CEC70124B71', '4605077012480', ' 1000  /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61443A6B-57AA-4A5D-A266-F064DD4268C3', '936EF1A8-BFCF-4347-8D3F-F1A274A10BA9', '4605077012503', '  500+150  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4004947F-5B55-41B2-91EB-17D7BF610039', '70783878-ECDD-4F77-8A99-4DC870E315DC', '4605080000450', 'L- 20% 50 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CCB1C3A-203A-4147-A7AC-CE7861F7E89C', 'B41FDDD5-3BD6-4983-A293-9880CBE653D1', '4605080000580', ' //   0,2% 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D282D60-2B18-446B-B6AC-0DC1F2B6717F', '510B9C2A-CAA8-43F4-8212-43533F715EA1', '4605080000634', ' 0,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEF32D04-1E9A-4E21-8D2E-E41C6721888A', 'DE9935C8-B2C0-4E03-989D-C048F40134B3', '4605086000171', '  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89AFEB57-6F43-40DD-B70A-B070DB4DE043', '14102B10-AC87-46FD-862C-AA52DE2B6AAF', '4605086000188', ' 18     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4176DCB2-232A-4F29-B3E2-3A67F1D6DC54', '242D5084-E733-491A-8789-B2F9D4D74661', '4605086000195', ' 1,58   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC16D3DC-A7CA-4683-9F7A-19432F95000E', 'CC491E5D-8ECA-4F4D-A805-A92706F013EC', '4605086000201', ' 28     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFBA3893-C06B-4FB0-9190-8C16845B1633', '581BBCE9-E878-4219-947F-45413B9EBD5C', '4605086000218', ' 2,58     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9E18C76-59F6-46BD-B00F-87CA3ACA2A40', 'FD23FB9B-8DF6-47AF-8BBE-E88035F8A07C', '4605086000270', ' 1,510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8D849E6-C029-4CE3-90AA-545FE16DBD86', '973C83B0-6631-4861-8E17-0AAD02A00BD0', '4605086000287', ' 210     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('569AA422-CB54-4D82-A6C0-AFFD0F61C125', '5AFF3E96-5E17-4038-B45A-4201013E5355', '4605086000294', ' 2,510     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03142BA6-EBED-4B04-925C-3AFC06FB6478', '95F170BB-21D7-4313-A18D-DA8AAF69AE49', '4605086000300', '  310 -   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE9AA8C6-D115-498C-B082-3E4A212FADE9', '0C145474-3DB8-455E-A091-785020AB1157', '4605086000317', ' 3,510   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13266A02-3B1C-4267-820B-0B3DEE98809A', 'CA97BF13-C54B-4C85-BEEA-9A7B04B19EB1', '4605086000348', ' 510    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9980D0D-8147-4F18-A756-8C85846168DE', '973C83B0-6631-4861-8E17-0AAD02A00BD0', '4605086001253', ' 210     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8412729A-4DBC-4182-9F8E-1D05EEA6FE05', 'B985FB20-9668-457F-A17C-40BDBDDC1634', '4605086001345', ' 28  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9D689D5-18EE-4F5F-9D79-EBDE07B2E72A', 'C15FB4C9-3BE6-4088-9408-2CE0F7A7A274', '4605086001864', '   4  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE7ACB94-5B57-40C2-8C50-28E482D92AF5', '11C8C2EA-7BFE-4DD3-A026-D7C8C86AF757', '4605086001871', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('365369C2-37CE-465A-B12C-F21A6F2DEE1D', '4BC0E66B-5874-4935-AB70-63748DF2B7A9', '4605086002748', '  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0085E94E-C4F4-43D5-9D45-11845F542978', 'A5D4BADE-DAF4-4A5B-90DB-C705F016AFDB', '4605086002755', '  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6039A6E-5B4D-4ED8-A82E-16E1FCED31CB', 'C2BFBE12-D3CC-44A0-A65F-66EAACCE9D20', '4605086002762', '  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E17183F-0AB3-43D8-85DB-7033F92E9BE6', '63DA29A6-9CEE-4515-97E8-292761050E0A', '4605086002786', ' //    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7F78A2B-8FCA-4A54-8797-ABCDED85D6B2', '1A74274D-1DAC-46B7-88C8-1B399E84BC02', '4605086003752', ' 18    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('734EA623-4E6E-418B-A52D-078FC6E6F1F8', '62142A9B-3787-4956-A681-B581EC703CEA', '4605086003769', ' 1,58    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('678174FC-2CFF-4717-AD57-BB813B3A3A9A', '8B520130-B2DE-4AF0-8E5E-D8702356505F', '4605086003790', ' 38    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73FF56C9-947A-4E07-B1AC-43DAAE709B75', 'F3F8CEB1-0B7F-4BD4-AAF6-E97885F1DE4F', '4605086003806', '  3,58   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6A201DD-C578-4823-8CF0-7ED00B4BDE51', 'A15F1317-8D50-4ECA-8FA7-E28565E766DF', '4605086003837', ' 58     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('378F4E64-0B1F-4C57-8167-0A502247667E', '217320EA-CA9C-4EA3-9897-1E6678C4D4BF', '4605086003844', ' 110      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('164285B1-1813-4AF9-A0B4-704221788E78', '1040A6DA-CC17-44F5-B9E8-D52E5C82E5A1', '4605086003851', ' 1,510    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F9616D3-7E81-4B10-9999-AE10A81B2E48', 'B29824D8-2F78-49DD-A975-0C888A089C77', '4605086003882', ' 310  -   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EA42CBF-B1C8-441D-8C0A-65D997C5B702', 'EAF291F7-AE43-4A4F-B491-B5CBA307E009', '4605086003899', ' 3,510   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C64D434-C3F5-4292-B31D-298DA9F3482B', '30DBE896-3A88-4C17-B86C-AE1579B9BF63', '4605086003929', ' 510  - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EA31777-D482-4C3D-9631-19814006C09B', '8D00FA77-0A50-4011-B511-148315058607', '4605086011320', ' 1,58     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66047262-852F-4D83-B4C8-7070C075325D', 'F1F6623F-4AD8-41EC-B905-EBCF4B2A3D89', '4605086014420', ' 58    - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D9AA044-D84F-4A43-AD73-71F4FB29F426', '86CA4F7E-F4AB-4DB9-810A-5DD33D058275', '4605095006003', ' 100  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDB0789A-2140-48A1-9496-CBC66728EB42', '47B9E3F5-B0E0-49A2-B31F-8E9F9F3206F3', '4605095006027', ' 100   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3F96967-4D3D-47BB-B11F-E98470085F96', '8C10CB9F-3CFA-4F3C-B3E8-F24B00F587EB', '4605095009073', ' 0,05% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA52E22B-BD8C-45B7-9335-9B9426688CB7', '883A14C8-638D-4777-B8AE-4EC783D7F713', '4605095009431', ' 0,5% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB077A87-E9CA-4BCB-8A71-6D2B6A0CAA5D', 'F69D4AA8-15B3-402B-A005-550A956D8C17', '4605095009448', ' 0,05%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E2C90A6-94F2-4B06-92B1-1D1D04B891C5', '1C6F8B46-F3CE-4838-AA7F-C915506CF9C6', '4605095009486', '  0,1% 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0145E9E-EA83-4F6D-B7E2-435605EA9690', 'FC6B6FAD-1A5A-407F-87D8-892E33409489', '4605095009530', ' 400   / 5+-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5AE70BF-DBE5-4CB7-88D7-AAA9B0987615', '130F7EBA-E697-4B76-9FE1-DE52FAFB146E', '4605095011588', '  0,05% 10   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('907785E1-1602-4FE0-861A-FD7FE134B0F4', '756E8C4D-982F-4480-BBDE-888948040D4F', '4605095011656', '  0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94A85F86-1028-4AB2-9077-D47FA5AC847D', '6DD93E99-EC9B-487C-857D-D2F51019B563', '4605108000202', '   /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7529AF95-77A6-4CA1-A905-7FAD20834306', 'DBCE5C2C-94C2-4F40-B37A-AEC5D7F2ADB3', '4605108000653', '   8  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A007876-3ACD-4A66-8ECF-C776D854F526', 'ACD3689A-152E-4CAE-B5C5-01DEA7E84FC7', '4605108000660', '   / + 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACC42C5C-7D9F-43E8-9BC4-ADC1C7AD7CCF', 'BF72C2EC-A652-4CB2-A674-9CB9E54A8FDC', '4605108000813', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27D97EF3-604A-4510-8C82-F5C2E2487BB4', '3F1547D7-EB14-4718-9AE9-7502D56474ED', '4605108000820', '  75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFD45128-71ED-4514-BD6A-EC8E421B3FA6', '28FE9250-786D-46C5-8A66-3413BB67AD27', '4605108000967', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAF31216-4E22-4CE9-8621-F5F30CB66FAF', '701554C6-5A6C-4E49-85D9-DDF99620C260', '4605108001100', '   8   7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1FDCF97-0B2E-4CBB-ABC5-F5528308C80F', 'C422C3F6-084C-4AD8-9147-5E6376813273', '4605108001629', '   /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF0F5087-79E6-4333-8A1D-97E6B6BEF53F', '2E6CAA0F-0827-408C-98C6-4921AD9906A9', '4605108001698', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D7D9ABC-9ED4-464E-AEAF-770D95131D61', 'E46DA87F-3837-4BAC-A814-E6F7467C187B', '4605108001704', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9567D353-6EF0-4A5D-A89F-D17E6E539A79', '2D011BE2-1617-4109-BA17-BE9043B7CDAF', '4605108001711', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F386F2E0-735A-48CB-B61C-0FDDFC9B4DEC', 'D20EAAF1-91B5-4814-867F-5B897BA7FF3A', '4605108001735', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EB89EAE-8597-4E54-A886-946F2C9111E1', '573BAD6A-5102-4C2A-89BD-760171E46D53', '4605108001797', '   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18AB77F9-B22E-48A6-B4B6-E54351358D2A', 'D67D7BC1-30CE-4070-9CD6-E8C27BEDE7F1', '4605108001834', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CDF4F53-737B-4B91-9B06-2EE30D224447', '76AE6487-4BA8-46CF-B965-5E7CAB82627B', '4605108001841', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F956DDE-3FF9-4541-9E2E-EA2ECDDF53F3', 'DB790FCE-5738-4B50-8840-0E3243E83D23', '4605108001889', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AD5F75E-DBB9-483D-B61B-B7CC252C42A6', 'BDD20D99-7DF3-4448-838E-B848BFBB1D90', '4605108001896', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32D2C257-008D-4C6E-907A-DDAE960E001A', 'C41CDA4A-FDB8-4A2A-88DE-3402DB9DDF84', '4605108001902', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC53B746-ACA5-4ED1-A7F8-3B9B8E5D7CB2', 'B8136726-DD39-479F-AD0A-AC60C8B2BEFC', '4605108001919', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('920EE8CF-BBCC-46B8-BD19-0FEC3E90E281', '9FB5C094-B428-4CE0-AC95-88A2CAB17588', '4605108001933', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E85C3CF-D9E5-454C-B8B3-93722F1B159F', 'A0238B71-87AB-4256-8A3A-0BCB37666803', '4605108002152', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('079E8BEB-118A-4B9D-8FDE-0F17D5E789F0', 'EC373944-746D-4683-92BD-C15185456AA7', '4605108002282', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83A73E05-3E72-47BF-865B-D7D9F5C99D46', '5DE7B90F-56B9-4EBB-AC3B-22AA12CB0F52', '4605108002329', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAA7430A-4151-465D-A944-9F1C77F6CE4E', 'B3DC156F-154E-45A0-9241-36D4E2EDEB02', '4605108002398', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C36D7B1-6920-4E12-A170-1D9E70DC376E', 'EB9CF387-E2BB-45F8-AF9C-467119D0D5D7', '4605108002459', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FB3E11F-BF03-4C49-9B48-B82F0CB904A9', '11C61A81-91C7-4DCF-A163-0C78A58660BB', '4605108002633', '    /.    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('016AE00C-69E6-4AEB-BECF-76BDB29152F1', 'EB952113-43B7-4BBE-9733-132C9AB22AAD', '4605108002695', '    / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9309A4BE-E280-4283-A3C4-7D65FA965702', '2711F4F7-002D-4C93-9FDC-73F24F1B8FD6', '4605108002961', '     /60/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AC12BD5-0129-4EDE-B8E7-1998AE70B663', '430DB1BC-CC96-493B-A520-45AFD179F70C', '4605108003029', '     /152/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('114EF57A-35C0-454E-B867-DD323644A8B5', 'BABE5663-B144-4BC0-B685-BC7D203E342A', '4605108004224', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96DA096A-FA10-4C1A-860A-34481E5134A7', 'B45FB6BB-BEA9-491C-8ECC-BBCD1A0EEADB', '4605108004255', '   75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACEC4E98-7E77-453E-A91B-1F35105236E9', '8727C203-0257-4583-8930-0FD68C03B78A', '4605108004477', '    8 // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AB9CC2B-16B3-40B1-854B-8D8A0EF65D84', '7E7558F4-36A6-4A3D-B0F9-4B8AC1DC1E8A', '4605108004521', '  8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E09FE8B-36BC-4E07-A559-E45AA1215D38', 'A04F04E4-496D-4B3E-A71E-E242B5DF789D', '4605108004705', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('757CCD0C-DB22-4E2A-AF8F-D682CF9251DE', 'AABACBD3-5177-489F-A6E3-40FBB53F95BB', '4605108004712', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D343260-FB76-4F57-B451-B708011F8738', 'B9C23DFA-681C-4167-B7D3-AC815C50B2EA', '4605108004729', '       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6C466C5-603F-41E0-88AC-6BF850847C2C', 'BEA4BFF1-D14F-43A0-AF4C-5B099E3B953F', '4605108004736', '        250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BD71E4A-7A61-45F9-90F5-3E32672EC75C', '5F38E112-68F8-4DE7-8F5F-A608F2B675B2', '4605108004767', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBC1DD36-FC2A-4762-80BE-B917A0B794CD', '5C0DED6A-4156-49F3-8D54-3815EDAD9239', '4605108004774', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FE56733-2348-4371-AA7D-FB2AF452A83A', '0C731396-0326-4AA9-A0F5-93EE0348D378', '4605108004798', '      / 75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9971118F-E5D7-4F3C-86AA-D166339A9ACC', 'DAF49664-736A-4A20-AB3F-A1AE38687089', '4605108004842', ' - /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C3107B9-7C9F-4FAE-A742-735FF3ED772F', 'A720CF13-C867-4B0C-B30F-8D0662610974', '4605108004859', ' - /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20B8D019-3F32-4560-84B9-87D19A25DAFC', '146478AB-B089-4624-ACBB-3120AEF47B8E', '4605108004903', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BAD29EE-FFA4-4B51-A770-E70579747916', 'E1B97B61-5C54-41A0-B594-BFFE4408EB3C', '4605108004927', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F424202-5D0E-4DC8-911A-371DE9DF7023', '1BB296A3-1588-49E6-8704-7F062DED458B', '4605108004934', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D069EE17-40BB-44B0-A1B6-1517C14764A0', 'FAC73416-028F-42F1-82D1-0A9849701820', '4605108004941', ' /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C220039B-0710-49B0-AC49-B93241109E75', 'FDE0CCE0-0711-4F39-9E1E-1D89C95CCD29', '4605108004958', '    /384/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD46F74B-50A3-46F3-8A36-09C49002C8F5', 'A164166C-068C-4720-9DEB-AB08681DC2DC', '4605113000051', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B15268C4-E981-45CE-8AF9-014251FED5F6', 'BC4522E2-AE70-40D8-AE20-F09A7882D039', '4605113000082', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61258813-3D29-43A2-8BDE-A115BF19915E', 'DB2FC475-34C1-4270-A042-09191304A8D1', '4605113000105', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47040D72-1E6E-43B4-8A01-784A76DD388C', '53F44CB9-5048-426D-B10D-E7534DA99F90', '4605113000136', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DD605F5-8A37-4B51-9C61-B47C20E4A2E0', '80573107-752E-458D-978F-1DB52073F236', '4605113000143', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B23011B1-1041-4B47-B111-5705F315F64F', 'F9BD7430-31E2-4F1C-ACE6-A319D067C10C', '4605113000150', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34067D1F-BF5C-42DB-B28F-525FA8DC3247', '7314EA4A-3592-49E0-9B92-9E6FFBCF91A9', '4605113000167', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4229612A-FD4A-4958-B169-CB9BB96ACEAB', 'FF2DB31E-B9B8-40BA-AEFF-DA574263CAED', '4605113000181', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAAC3990-90A4-4859-9BC2-F95F4B759ACE', '590483DD-D86F-474C-B024-FF0C34405C6D', '4605113000198', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76992021-8C13-499A-AFDE-15B079F10F92', 'D7FF7774-6A3F-4CF0-AFFC-F9BF68D3E855', '4605113000204', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('371C94B4-1017-4AFE-8BE5-C932436BE3DC', 'EE4EE182-86C7-42BE-9CAC-C227F7FFF692', '4605113000235', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('917CC1CD-2151-4747-9956-AA6282FEBDAD', 'DF8E27AE-2944-4C05-A2F1-5057EC2D5F8F', '4605113000259', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('123E81F2-D82D-489C-AB29-626A4AB048D1', '6BEBAF0A-3CBB-477D-B34A-A1169CBC41B1', '4605113000273', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23D57A6B-E432-409E-9DCA-F6A8BE16E81B', 'FD1F9052-B926-4CE2-9D71-4D561037ADEC', '4605113000280', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A7FCAFD-111F-4936-B730-F161A594C0E7', 'C923DCC0-F8AC-449E-A946-09929741D1C4', '4605113000297', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7EA77EA-535B-4873-9FE5-42B9F2175C2D', 'FFB79E56-8CDF-4160-B87A-0E4969F9D804', '4605113000303', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B449FC6-32CA-4FDC-BF73-23CE7218F672', 'B47E3BC7-9EB4-45AA-9B85-4675A12D6833', '4605113000341', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE801A82-C04D-4E0A-B3FF-41EBA4D89F89', 'FE686EBB-8723-463D-B2DA-BF15DFF315BF', '4605113000365', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE5CD7DE-6222-401D-A18C-8FBD27BFC4A9', '7E13AA03-DD13-426C-AEFA-A2FD998FA101', '4605113000389', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BA04CB1-657C-4529-8070-2E7B0ABBC2C2', 'ED51CA63-C277-4CA3-8ED3-2D8C65944591', '4605113000426', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('837B7A9F-1479-41DA-9512-BB4E407925AA', '21A75E45-1165-4EF8-B8EE-B5D79E987863', '4605113000433', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C2AC19C-BDF7-4211-BD5C-1C9E6DEBA3C2', 'AA2E326D-27EB-4F2D-8B37-AABC818B1294', '4605113000464', '  //  50', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F90D43CF-758C-48E5-B0B3-78AAC708C7D3', 'F0BD4526-605C-43F2-B775-2468C9A55D85', '4605113000471', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6657CD4E-F2B6-4BCC-8044-F8E16FD31D1D', 'F76E3854-F7B3-444C-AA0A-CD8756A14620', '4605113000488', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EE0C377-BB1F-44E4-BF35-FD32A007AA56', '423AFAC2-3AC2-4C9F-8BD0-CA7DBA707A83', '4605113000495', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3402683-063C-459F-8406-34B45B030509', 'E7AB6940-680A-4A2B-B12B-66F8C3BFADCF', '4605113000518', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75B0EEE4-E2A2-453A-B390-B81FFD0C4069', 'F832CBDB-1091-4159-AF62-9C6A7ED1D5DF', '4605113000556', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06C63984-5988-41EA-9600-C3D6D351430F', 'E6F0C991-B0D3-4442-8299-820D8DF11F5D', '4605113000624', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDC273F8-AD41-45FB-82E7-2E62B30DDBC0', 'D141900D-FF41-4E3B-9979-E922F45AADB6', '4605113000648', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44F8B4F1-0764-47F8-A301-A2259B7FD7D6', 'D06EDCAD-7BDC-491F-B0E9-02A92F5A32AA', '4605113000723', '  2 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19225026-ADEF-4363-85D2-70DF561B77EF', '45FE6DBC-83ED-4B02-ABD4-F8454778E8E4', '4605113000730', '-   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52D4B565-ACEA-4C8F-A997-902F98967F42', '59458EDE-4EFF-47E7-BE7F-B16386CA3603', '4605113000754', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6AEEA18-CF9B-47AE-9DB8-529CE7407CCB', '063EE68C-DD5B-4434-B752-F0FCE971DA4F', '4605113000792', '-  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F51431C-AE1A-441A-A342-8A8A90320EC7', 'D1E429A8-95ED-4DEA-AA6C-A1C670368A59', '4605113000877', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DCC24A9-4E10-4984-9C05-31D72384E1C2', 'E05F5B6D-CFF5-40DF-973E-EEB5ACC900D6', '4605113000884', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('747273F5-6383-4797-AE66-8E69D8D4CC23', '17E87ED8-FC5B-4BE8-8D8C-BC40037AA8C7', '4605113000907', '- //  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FB75202-C693-40F4-87AB-7A5D3AE2AD96', 'FA604C1F-8D2D-4B0C-B85D-5950DB1A5E97', '4605113000921', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28683191-9DFB-4CA0-81C1-C1DBF596DCC7', 'EF82CC7D-0CFE-461A-9E0C-B04546511108', '4605113000938', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2FA5107-6594-4E32-A187-86312DFA50F1', 'A769DC2A-BE04-42FC-9775-DE0AF2E65DA6', '4605113000945', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('067573E5-6EE3-4676-833A-511E981B4C0D', '8D66323B-12AC-46FA-B1AD-E7AFAFE43DAA', '4605113000969', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85A8D34F-C84B-481B-8311-FD2AC0333577', '5498F981-CE6C-4D92-AB6F-C2BD66083AA7', '4605113000976', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32344F71-F49E-40AE-91F1-1E599B587C97', 'E17BD737-60A3-4087-858C-E736DF00C941', '4605113000983', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B249EF5-128A-40C3-9E00-BA3D501DFD71', '7217915B-995A-43D6-A199-E1559B0A9308', '4605113000990', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D36148BC-83C5-4108-9AF4-AED10B400B81', 'BD7D425C-7C62-4935-B1A8-2460DBABCB19', '4605113001010', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7249553-D858-44FF-A51B-E8B317ACC28E', '8D2FF5C5-1A52-49F3-9A75-C4A3B161A098', '4605113001034', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF947EB7-F97C-46E6-9FDA-3ADCED7FBB0F', 'E80CD40C-DE82-4C7B-925C-B1959A17E642', '4605113001072', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADC79BAD-658C-4AE1-A5A2-F33A8AC784AE', 'ACA364EB-812D-40A3-B95A-41A2C34D6362', '4605113001089', '  1 - 20 / 2,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC9F51EC-72E3-452F-98B5-E37BCD8A7E3A', 'D3267CE4-0067-4AAA-B7C2-76B1BA7CBF68', '4605113001096', '  /// 2 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42423CBB-C212-4E38-9AF1-8B838B4D2D41', 'E3F0A76F-D596-4279-91CA-5233E7351F5D', '4605113001119', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83BA02CC-4CF7-4B1D-9AF5-D0E06B6B6AF5', 'F570D7E7-70F0-4E99-886E-0C6BEE971E91', '4605113001126', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF690BD0-B225-4DEB-AD89-F6EC198D4217', 'A1F56594-05D8-4DFD-B722-3A0DED96B968', '4605113001157', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B44441E-DDF4-4F66-A71A-448B588D720E', '11C0D8C1-760E-4CDF-A743-1CB63FE8983E', '4605113001188', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5A8D4F2-E21A-4A4F-8672-62D1AD22642B', 'A997152F-7290-466B-974B-522C3D95CB22', '4605113001195', '- 2,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4FD7BCE-0598-415D-8731-9D0CCF4BCA99', 'ACC05EBF-5B7D-407B-8381-86EBAD789E51', '4605113001225', '    1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE0D11A2-840F-437B-8BF3-AE90C9F20E8E', 'A6CABD51-4E24-4A93-8574-5C6B049FBE99', '4605122000790', '  500 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C633D55A-52D6-4CFE-8269-479E834D74D9', '6EA14ABD-B189-4EF0-9217-E3E9BC1F3481', '4605122001377', ' 0,5 / 4+1/  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('896F9674-395E-4B67-982F-456E223EDCFD', 'F6B2C78D-1942-4852-8D9B-0B0F35CE321C', '4605126000178', '  / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('281E0253-A285-470C-8FB6-ACA8D8C7CE41', 'FC6F4DDC-47F9-4CED-A299-52BF373C8534', '4605126000376', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53EFB1DA-B466-472D-985F-9CF7ED5EB872', '237BF6E8-4E5E-40D3-93C7-BE8E5465EDAF', '4605126000529', '  50 /-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('323E61A5-639C-4010-BED7-D6455FAFB7CC', 'C785878F-008C-4C5E-9F28-FDF6E4106E67', '4605126000925', '   // 50 /-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E1E6192-75A8-47A0-95B1-D4215461AF2B', 'B31CFA86-9C57-47F0-945E-89CEFBD9079F', '4605126000949', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C98C4C4-C9E8-4DE5-977B-949AEC31C5A5', 'C366F192-8B5C-4BB8-A202-E3ADBA6CD4EB', '4605126001755', '  // 100 /-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E977667-D690-4F05-8F56-4DB13D12DE5C', '0C935623-9F93-4FDC-9773-4FADF2081E1F', '4605126002103', '  // 70 /-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C7686CE-8B13-4205-9CD1-67F5AFA34525', 'B956BA21-65FB-47B4-9DAA-9949B4D78DB4', '4605126002554', '  1,5 / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A4E5747-EBF1-4C7C-BC04-345E69F5A449', '2328F754-24AF-4B76-AB0E-2FCBC93BF334', '4605126002578', '   / 1,5 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31193917-01DB-4E12-8775-C4F2A9041C2E', '62378FA7-4BE5-458F-97B8-8F82EE8DFE59', '4605126003322', '   1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE6128FD-BD1F-4E15-AF09-B21F91D49502', '3CCE0649-7EA5-4C1B-A4FB-EBA47BB77829', '4605126003568', '  / / 1,5 /- / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90EB7F40-72D8-4694-AA3A-FB714C06B798', 'B82DC6B4-4F53-4B60-88B6-FC861A2AAE6F', '4605126003742', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF0D472E-82E5-473C-A296-4772452E5C12', '28BFDA90-9473-4E8E-AF83-BE587A112F32', '4605126003902', '  50 /-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4C05FBA-0E96-4783-9048-314CF475486E', '3CCE2962-8973-41CD-8F6C-74B86CA6D6B9', '4605126003971', '  /// / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38B3E66E-80EE-4509-9371-6F391F70C3B9', 'D06EDCAD-7BDC-491F-B0E9-02A92F5A32AA', '4605126004244', '  2 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6427E5E1-3F0F-4D0E-A15C-72407D4CB64E', '9D55B8D7-4170-407D-AB13-76CC0DAD2C7D', '4605126004404', '  50 /-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AB07672-DB0F-4098-B8FD-239B7474DA6E', 'A997152F-7290-466B-974B-522C3D95CB22', '4605126004749', '- 2,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('655FB0D5-E07C-425D-84ED-683349212BA9', '7BDE8363-0143-4036-A773-AD12B2E31F94', '4605126004763', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E08816B3-BFE7-4FE8-8BE9-6330A154A769', '5F85F86F-0F53-4BDE-B315-8FD3999BBD49', '4605126004794', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA91E55D-EB81-490C-8147-4354C90B98B3', '15FD5D88-66AE-468C-8D20-D34B15AEF5A0', '4605126004886', ' - // 2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B0DF833-F361-44B4-81B7-F4BAF81553D5', 'D1E429A8-95ED-4DEA-AA6C-A1C670368A59', '4605126004893', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C1F848A-4E64-4F85-8603-A312828AAED0', '5E8F103D-8B1D-4AB5-BD03-EA4B6226D2E2', '4605126005302', '   . 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC686945-170F-40D8-A63F-A6955F304D38', '9DA60AA9-05F3-41D4-898F-FBDD559DD4A2', '4605147000072', ' 714 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD3C88CE-42B3-49E6-8565-4F0118047F2F', '8A127BBC-3A97-4892-BCB7-F5D2331D1A2A', '4605169211135', '-     55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07F3828A-03A0-4A1B-BA9D-465E64C931DA', 'A597BB99-988D-45E5-B8CC-35B6F7D53B21', '4605169211159', '-       60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('139278CE-6E4C-403F-9320-6410C5C6D010', 'F06B43B2-9EF7-4706-ABF0-37DEF6DC51CC', '4605169211166', '-     55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3FBAA25-F5F5-4086-BFF6-91E5ABE13AB9', '5C0620EA-220E-4BC9-BCBA-49E624A047DF', '4605169211173', '-       55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B3F35A0-F3A9-4D79-90AC-A4137196AC09', 'B5987EE1-EDC0-42FB-9085-433B4B5DE39E', '4605176000142', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D58C609-6602-4596-9E85-37B90C19E5D5', '12EE3B8B-7E34-4F90-9AD3-ED95BC7FE974', '4605176000166', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C768B30D-7518-4E5F-ADF2-1CAB4FE0DEDC', 'F8584FD7-F4F4-4B44-B5BE-5BD5789D3AD7', '4605176000296', '  500  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73F0AF93-65BF-43F2-B883-27A5B7A77707', 'DAD8B5B6-D2B6-4DF7-9AB1-3FA104A54E01', '4605176000302', '  500  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BAADC66-E1E2-4C3F-B2EF-1BFCAB082446', '93D9FCCB-0737-4D65-BC32-1C01E24BB02B', '4605176000364', ' +  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1622F6F4-067D-4670-B4D5-FCF0C456B5C2', 'AE4ACCA8-C5E7-4346-B90C-512737EC652E', '4605180000084', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DBB52CB-093C-4061-B932-6CE6B88EA87C', 'DF7B0CAE-1B3C-4C9B-97AC-927CADFFEAE8', '4605180003535', ' 10   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F83785CC-D0CA-4903-8C0F-41AF7130EB18', 'EB5069AD-E54A-4AB0-AE43-B16994304AD2', '4605180004846', '  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06EE9A70-E5F8-41DC-89BC-F75662553354', 'EE0F8732-2910-46BD-AE66-C37C66C032AB', '4605180005072', '  140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEEF7A64-79BE-40EF-B923-B77D4F907F81', 'F4645767-B4ED-451D-986B-58B44670D7DD', '4605180005188', ' 350    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C53BB0E6-6159-4FCC-B70D-79764F2C630A', 'CD3BD7B1-757B-44D5-97C2-10952994F806', '4605180005270', '-  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B950E54-0BCF-4487-B867-BDD593D606C1', 'F283BC1A-BEAA-4A50-846C-DA98B6BE7B36', '4605180005348', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5EF6BBE-4834-4E35-8B27-6E831F86C832', '5F060DF6-017D-4B4F-8DBB-CEE1A3F35622', '4605180005355', '    1,38 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71B6FB57-EEDF-4220-9146-804839CEBC54', 'E713B721-BF1C-4000-ABB8-686F99253899', '4605180005379', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18D64ECE-AD7B-46BE-816F-B464803457E2', '7B4F003B-0D90-4D87-A793-B1ACC10505BE', '4605180005454', '   300  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('396F3B7D-BC49-4E7A-BC00-6158223F31BA', 'FE3600A3-A194-4598-ABC4-D1862EB1F6E1', '4605180005539', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA6C9A34-05A6-43FC-9C20-8B42B8B92493', 'FA136A79-7429-42A0-9D2E-AC5173D39F42', '4605180005560', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57B08FE3-757D-4BFC-ABAB-904B6A5EE23B', 'AE4ACCA8-C5E7-4346-B90C-512737EC652E', '4605180005607', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D611859-3C40-4A4E-AEEA-6FBEAA9E0CBD', '2FA2A982-494E-400F-B558-87A8AE924385', '4605180005621', '  0,1  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6A7A0F6-D159-432C-99EC-2B179C7D777E', 'D310AFDD-5DEE-42CB-9755-1E8408813581', '4605180005720', ' 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3831AA7-5CB1-4A83-A473-89488D8B903B', '84E3F762-0CD9-4505-B1B7-52A4FDC5EDF8', '4605180005768', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF9F20DF-8E44-4926-AA2C-320ACAE73991', 'AC0B7D70-83D9-4433-98D4-3C4D571992A3', '4605180005799', '   250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7FBC796-5551-4F03-AD6C-7A714C4B5398', '447554C2-A69F-4072-BA07-80D1255AE4EA', '4605180005805', '   2 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EFF6EEA-4C4E-47A5-B6B0-B885E117122F', 'F2711808-10BA-41DA-B3C9-D59F80BA0096', '4605180005829', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9138461-60DE-4C31-AF14-53DDCD3AF919', 'E7207135-4F6B-4CB5-9B04-F03D63724651', '4605180006000', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33F4344D-CF5F-4BC2-B053-14722BE64196', '69B5940E-765B-413F-9F52-DBD3E9DA1288', '4605180006062', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DDD3E7A-6F42-4F4F-92FC-2DA058508156', 'ADE74AD8-0155-4B21-863D-7037037B774F', '4605180006079', '  1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB2CF02F-0CCB-4D19-A5FC-D2BE5918498A', '7392DBF3-880B-4673-BA1A-AF41A0999215', '4605180006093', ' 0,2% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('967B6870-BC1B-4A24-98BC-43E196093B73', '5635BF15-38C7-421F-AB2D-0DC1580C5480', '4605180006123', ' //100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8B3E118-EE9D-4C58-A2A2-BEB80A3C0881', '83DA4AD3-F2D2-4BC1-B3E1-4EC68A858917', '4605180006178', '  150  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A71E1DAB-135A-4C72-A128-5F11D236021C', 'DF7B0CAE-1B3C-4C9B-97AC-927CADFFEAE8', '4605180006383', ' 10   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F47D799-1F6E-4260-B7DD-0AF46A1303B9', 'E515E6B2-4087-476F-9962-57528FDDFF50', '4605180006581', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C776A4F-0719-4AA5-B735-E65537FF4470', 'E8AE4BFB-35C9-4687-B763-4DB37E201C09', '4605180006642', ' 25   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3D95A23-655D-4D82-8C57-4CB80B4807FD', '2BCB062E-3D89-4409-9180-D054F2DC2F68', '4605180006659', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8575F62-F453-4171-BC5D-F9EE662CB7D4', '59D85B89-7D6D-4413-A6EF-1D170095BDB7', '4605180006673', '  120  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCBD6329-0F6A-408E-ADF6-6885BBFDF106', 'F3451443-4E7B-4680-B4CF-B3118D1A2E55', '4605180006697', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B49B073C-8809-4046-A964-98AB5475E637', 'C5F81D78-8439-4CFA-ABAA-FB22CD0AA9BA', '4605180006710', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F0A5B46-17A1-4C1C-B739-99A05DB066DC', '96BE6C32-E826-4EB6-8BB5-2344589E8988', '4605180006765', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7C114AF-014C-4876-8D70-241CF44ADC2F', '7BB9EA4D-DDF2-44C8-87E7-10261EFA149E', '4605180006802', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2C439E6-787F-4746-B2EA-E2152EE5E0A7', 'AE9F3F27-F163-4201-A9CD-45655657C465', '4605180006826', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88C3418B-DA1E-40E6-999B-BACF16A76028', '40A59F6B-79A5-4348-8879-BC361E0AF501', '4605180006864', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C02D8B1C-C524-43D9-8AE4-D927D742BEB4', 'E820D79D-40D1-40A3-9C20-A6278507DEF9', '4605180006888', '     /-   1,47', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1476EFC1-813C-469F-9A64-9F15E0D9B0DC', '898F9475-8694-491D-9745-CE26D65A3091', '4605180006925', '   250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A03978B-9456-493F-A93D-50E214050A75', 'AA13DDD1-FF63-41A3-BCED-B0DD129541CC', '4605180006932', '     /-   1,7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74496557-3D36-43BE-9280-E4AE65B61619', '50A0A838-8984-4377-844C-7DC0914448AC', '4605180006963', ' 1   /  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BD8E1C7-0CB9-45A1-BB2A-9ABD251F4BBE', 'ECF344A3-BE0F-4B03-82C9-89C4BEA41FAB', '4605185000157', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E0975C9-DB11-4D4F-8B9C-14F0FBC2F5EC', 'EAB94531-1D6E-4E85-BB66-3F8E6A5D73FA', '4605185000980', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06124D2A-AE3B-4647-81F6-A070CDBA9037', '629B9BE7-6BDF-4ADA-992D-57DB93B616AC', '4605185000997', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A94A129-510B-470B-9783-24FCBAB3E2A6', 'A5A06ED8-1325-4C29-B929-EB050ED6475C', '4605185001000', '   .  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C5F1828-A33A-44EA-948E-A09784214217', '1F3233E6-4DD2-4575-8301-FCE43335A198', '4605185001017', ' -  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D05AE4B1-340D-4DD9-9B16-FBDB3F13CD12', 'BFC71286-5D03-4167-AB3F-BDFB674BB585', '4605185001024', '  -  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1BB2633-0ECB-4443-803F-93D9AA04276C', 'D18DC729-1D42-455B-BE3E-6E187CB4C669', '4605185001277', '  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6AFE250-A91D-4E7E-B79F-3F128809A8CA', 'A035BAF3-F3E7-4A0C-9E1C-C9E8C91792A2', '4605185001321', ' 25  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD890440-BF2E-47C7-A999-77DF50CEBDE1', '1475863C-C79B-4FEB-A83B-0EFB41D7F40C', '4605234000978', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC8E3CEA-3DEC-4964-BDC0-71E37BCC75FE', '288C1FB8-6CC9-4D43-A68E-A96F23970159', '4605234001692', '     6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('753D9ABC-917E-47D7-A1BC-266B5E0B012F', 'CB4E93AB-22C3-4E60-8E31-C3DAF522FE75', '4605246005947', '  100    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DA3F5F9-D147-416A-966C-F652906883F8', '2C46AA59-E8D8-46C5-83A6-2097B82DAC97', '4605249000017', '  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE0169A4-03E5-44E5-9F6C-1FE8001BB641', '43F74DF0-1DF0-469C-9C8B-AD01EAB9DA74', '4605258001067', ' 5% - 250 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7916B69F-F459-4552-962B-7C13EDBB1A21', 'AD0C7ED0-6AE2-48E9-8CD0-023D09430909', '4605258001081', '    0,9% 250 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DDADF6C-628F-4A45-B190-1F44A8B96444', 'DBA9B569-CDA5-43C9-839C-1A185BB7D19B', '4605258001098', '  0,9% 500 - 1 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D85D99F-F0F4-4ADF-A534-8CE616BF0F88', '4737C251-2F9C-40BA-88AE-15ECEF32BC3A', '4605258001104', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B1F3833-56BB-4AE9-AE3C-F7AC1745DAB3', 'F66B2FB0-3038-46E9-A413-9740A04ECCD8', '4605258001111', ' 500 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1431A4A-F138-475D-BD52-269125019C00', 'B6B8FC7B-0BED-4CAC-82F1-5295BC8D9DC0', '4605258002118', ' 5% - / 250 2  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E777EDF-43F1-474D-A746-BF6B5F6494AD', '38881FD1-BBE5-4D3C-9029-2CB6BCE140B8', '4605258002644', '  0,9% 1000 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('913D999A-154E-4514-8039-611C628AE808', '99ACBF73-5912-448E-8FFD-7416DB6FB6AC', '4605258002668', '  0,9% 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C615F6DD-4CBB-4E53-A057-490CB8A1C386', 'DC330F30-4584-4A58-90EB-22689571A5AD', '4605258003788', '  0,9% 200 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB934089-190C-4F6D-A949-7A299476A8F6', 'D2FB6260-04F6-4012-AF06-86CB3804B97C', '4605260001871', ' 100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('159EB7F4-22A0-4762-965F-D5292DC9CEB7', 'ABF3EB33-C79C-42DD-9310-8C398B42D6E7', '4605260002793', ' 0,05  /- /+- /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8ED3223-3A0F-4909-9388-16EA2C1C6AF1', 'F1C62050-5F58-4872-9360-6AF6583D1049', '4605260003202', ' 0,1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82AECB98-F7A8-42E6-8B8D-44F65C61BBDD', 'F205E825-4B12-4E65-9A6A-823A89B4190C', '4605260003752', ' 5   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88902AB6-CF43-4AF3-B264-D2B15ED2238D', 'E7296CD7-265C-46E4-BB92-C5AC33F73E44', '4605260003783', '  25% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F99A14A6-107D-4C89-AD0C-68C158DB9A8F', 'F9F1FB00-DF28-472C-B80A-0B64E00F7246', '4605260003998', ' 5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D420AA6C-489E-47AC-9385-654E7504615B', 'DE7D7E37-BF3E-42D0-973C-32335D94C6C3', '4605286000124', '-3 1000000  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B9B1CB3-4678-46C3-9267-F42FDB4FD9FF', '24703634-99A7-46BE-AE49-8FE157AE9D5A', '4605286000131', '-4 3   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('285E900E-993B-4A06-81F3-479538B968A0', '7E7610D8-9B2D-49B9-881B-D5A4D3045571', '4605310000021', ' 300  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABCF6430-9CA0-46A1-AC5B-3B7706F3BF11', 'F322EC27-B161-4D16-ADF2-F15B1C6DF0DA', '4605310000502', ' 150  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D52AC08-1CDF-4660-BBBD-3ED4CC89BDCA', '9250727F-E736-4E9E-81CB-3951A62B0E34', '4605310010525', ' 2 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5180C00-4894-4B81-8B86-45C122557D4C', 'FEFD7BEE-4E15-46E4-AEA6-6E1511A20F4E', '4605310010549', ' 5 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5B107F9-06A1-4446-B153-65CDF7181777', '39821C0C-8AC9-44C0-BCC0-0D926E4DE2E4', '4605310010600', '  0,9% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAC40D21-7175-47AE-A81E-25BD263E33F7', '1BBE475A-0639-4071-8F54-31F9DF52EE41', '4605310014271', ' // 30  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFA37C12-C387-4FB8-9C83-39789D903BE3', 'AB662E31-D10B-4566-BBA9-97158AA5AFC2', '4605310014325', ' 45  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCD10780-9156-49C1-8176-1492A0929E80', '95C8777A-8E6F-4D58-9BF5-BC8FD09D8FA6', '4605310014387', ' //75  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67EDFF66-0290-43E2-80CE-981D620528DA', 'DCB3DE82-9215-4E54-96A6-BE4FD555DBDE', '4605310014462', ' 2% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ECE038F-6615-4801-872F-738240632E1C', '141D9A79-AD08-46AF-98B0-CF5408D82506', '4605319000510', '  -   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87DEDC70-89FB-4694-AFF6-5B6681C4D1E6', 'BEC83603-CD14-486D-92C3-C71E1A8FA4B8', '4605319000565', ' 105   / /  20/ /   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('932DC1A2-8ABB-4D36-953B-8ADCA47E0454', '2C54FDF2-FF26-4D68-8E59-1B4177B7589A', '4605319001265', ' /     25  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40338EBE-5A6B-439C-8CAC-AA4CEA17D1CE', '7A9AF426-9F6B-4FA9-A5F7-8166387F648E', '4605319001463', '-   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD198D5D-26A2-4BAB-816A-BA3DD2EABB3C', '8C4444AE-D279-4D95-8451-67667EC51033', '4605319001579', '   /   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8904BBB-7133-4A83-BA31-9050F8720140', '85947078-8389-4BD4-B971-D05BB6C2BC37', '4605319001586', '  - / / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C4582A9-DD4C-44C7-82CC-A6ED62395026', 'AEEE2F2F-3788-4A49-BD01-3F2FD41045D6', '4605319001593', '       150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('016BDFBA-38ED-4C91-B4AC-A549A58B36E5', 'DC7B85A7-B316-408A-9244-ACE6A2DA06AD', '4605319001920', ' 101 - /        125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3891042D-DB28-49C1-9E4F-BB084C4A915F', '5F7F2B17-99BC-4C91-AE04-D7143BF746ED', '4605319001982', '  -    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6DD2220-5C3E-4E84-959A-5559B6FAF721', '73727149-4216-4F44-AF5C-7E6D956429CC', '4605319002309', '  - - / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('474E87AE-1C6A-412F-9FBA-B58B1A30C2D5', '17A82D25-7370-4F0C-917B-571E2FD006B3', '4605319002316', '  -  /   / 171/ 500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('722EC202-C36D-4F34-99E9-737ED813857B', '726FBEC4-1975-473D-8ADB-79D76A1F0916', '4605319002583', '- -   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('863595C3-4C88-4703-8F00-CB18DD35D9CA', '762D2809-97AE-4A5B-9A24-F059D28DB95B', '4605319002590', '- -     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEA94461-4900-48CF-9B3C-AD52F92AACE4', '1BF7B492-F748-4F11-B40F-DF69305750AC', '4605319002675', '-      450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5FB39D1-653B-415B-A734-6E858C620683', 'D94322F6-644A-43F6-8946-842968F3CE5D', '4605319002705', '- -   /.  .  275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85EEED05-E591-47ED-8699-12F12CAC25CE', '84795624-AD0E-44D5-9D40-5590D5D9F328', '4605319002712', '-   - /. 275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8E69834-A3C8-4B26-B2D8-8D0496823D59', 'A5B30ACC-8C3E-4D34-AB0F-B041D04B53E7', '4605319002989', '    /-100/ 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3B89DAD-F18C-4264-B3E2-BE0FE993B886', '42DF85F0-364F-4FDD-BDAE-A5E75E632877', '4605319003955', '- -       275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('096F8B59-4761-4C70-9D96-B44B951B41EB', '65AE2C8B-8BB9-4C0C-BE34-4E3178610770', '4605319003993', '  -  170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8286582-114F-42E1-B481-844665A061E8', '3F564C10-5A6F-45D6-BEC4-BF10D16CD5DB', '4605319004952', '    /  500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5F62A8B-3550-4D9A-819E-2F81C54699C1', '66A520F1-7F0D-402B-AF64-B485A4932571', '4605319004983', '  - /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50556716-AD32-4897-91FB-2DB03B9762F2', '8FFEE923-8A08-4F17-9345-3318A5B1FAEB', '4605319004990', '    spf45 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50E38F91-32DA-4DF3-A427-1CA54EBEF731', '6F10C7F7-5E34-4F35-A08E-522DAA3A5C8B', '4605319005317', '    /      125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAEDEA75-11BD-4003-AD0C-40A0479BA5A4', '5DB45643-ADC8-48B3-B579-F075D707EA45', '4605319005324', '-   spf45 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3786797-FAA2-43ED-9349-FAE00E487D02', '2D4E95DC-B6DD-4953-989A-2B52403B8D69', '4605319005522', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6FE0E53-E2D9-41EB-8AF3-1DF5D0B3F8E1', 'A8CEA7B6-84E3-4659-9C26-C21BAC50E2D6', '4605319005539', ' - 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94166283-9049-4EB3-A906-F0F7A82AAEB4', '58540494-B199-4AEA-9518-42C00FE69DC1', '4605319005553', ' - -     100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9083B62-68F4-4942-86EF-37D1234F727A', '246257FE-F855-4DAA-91F4-2581476F4CE6', '4605319005560', '     /-84/ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8BDE27A-8653-463B-A167-0B073E9895FA', 'CDD64843-4EE1-44A1-B148-7FF339BA24EF', '4605319005904', '  /    - 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3597751E-225E-4985-BF7B-FAE4ED14D8E0', 'FDFE9AF5-4627-486A-9A88-FD8A0467C090', '4605319005935', '   /. ..spf50 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3D4C72F-DF2B-49F5-BA3D-2B76F65992F3', '682D3358-817A-498D-AF01-81965E0227AB', '4605319005942', '      spf 20 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42E9A1DD-03C5-4565-8CAC-4E6933CE6CA8', '268C7247-A7EE-4B78-BEB2-FF06EEE38863', '4605319005959', '  408  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56FF162B-8754-43E1-B858-A5FB5D77E578', 'A02295A7-08D1-47A0-AE9B-10FEBFB33BB9', '4605319006291', '    /   // 450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('767B67CE-EBCF-4F71-959C-6E2C41E388DD', '1476CF50-F6B1-415F-8A8B-2B621EE68481', '4605319006307', '    /   /     450 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41B3CF30-4E83-426C-8C02-0E68D762D8D3', 'CC4D01A4-6DE8-4214-876E-3DB8489C3F9E', '4605319006314', '   /   //  450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB1FC85C-2AFF-480D-A285-3950A40AB4E9', '551B47D0-7E83-4FFD-B9BB-54B7604E6272', '4605319006550', ' 40 / / / // 450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3084F3AB-D2E9-4F9F-B85B-3F33C870DB90', 'AD568168-3E4F-494D-B735-D2492DBB305E', '4605319006680', '    spf 30+ 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EBA7A04-6F72-412C-B287-834B9F06747B', '3CE9E494-209D-4A97-92D9-C1E48DA1A013', '4605319006697', '   ./  spf+45 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C0D5338-C017-4DF3-A508-34002E678748', 'F0A2E1A6-656E-4BBD-A212-C9EAAE32C338', '4605319006833', '314    /  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17FB8144-1457-4B60-98FD-99E3D4EC44E5', 'D63FFBBB-4E91-4117-879E-9406D4ED9B83', '4605319006840', '   spf 25  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A84B69A-35FC-404D-A1A8-1310F2A1E42E', '201CA45A-C689-4CCC-AE6C-64E9606B2C58', '4605319007274', '   // 450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B76F0365-3763-4D19-8893-C9AA26E45F1E', 'BB951DBC-8757-48CB-BD22-9B3327C7F3F9', '4605319007472', '   251  / spf24 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EC8F405-6ED2-4A5E-9930-696789711E69', '5CD6D563-0757-43C3-A0E2-BA7DF448C932', '4605319007861', '   / / /+/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE5FB6E3-2945-413D-8C9C-D8B1BFEC465B', '2A006328-9991-4FC9-B042-0BF785870549', '4605319008042', '   // 450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67696784-2CB6-44E6-8BEC-2B74BDFD5713', 'E6CF8FB2-1945-4CF8-927A-9F0A3327FC66', '4605319008202', '   spf 20  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6998ABBB-578B-45A3-9E5B-A9C8BBEA7824', 'F78551D3-25E1-4996-A182-5CB603E1030B', '4605319008226', ' /  spf 25 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D61105BC-58CF-4C8C-B83A-2AFB719B2240', '3F957E29-86C6-434C-A667-8D9922FFAE37', '4605319008264', '  / spf 15  170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B23CCFFB-C7A1-404A-9DA3-D0D9AF018748', '78CF6ABF-7FFD-4599-A5C4-AD603D54D3C5', '4605319008271', '- /  170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9AB26E9-0CB4-4E82-905D-7A96F0621C13', '425B534F-E69E-4634-B97A-35767EA5A1DB', '4605319008332', '  /  spf 25+ 170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F08A2EBB-5A54-4B2D-8043-EE208242A955', 'BB025FA9-C1C8-412E-BDD4-C7DE88FBB283', '4605319008349', '     170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A7921D9-CC06-411B-892A-0FD3C70834C1', 'EE37F4AB-0387-4490-92A0-0C232A0AD741', '4605319008554', ' 180    / spf20 65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('524879AB-0EAA-4555-B801-A756474E0929', 'F4F0B09C-7346-4D8A-A811-8CD7CF14BF55', '4605319008820', '   / . 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAB21C35-188C-4D27-B819-B00BD6B13335', '71C5027D-6659-4402-82EA-9796D68C8BF7', '4605319009407', '  - /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DE4C601-2831-4C79-A626-70E49010B0E8', '284D3BE4-9B2F-4BDE-9D5D-AEE86281D414', '4605319010830', '  / 450+/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98537026-89C1-458D-8FF5-AEF5EE0E93ED', 'E55A9BF9-D20E-4761-9EE4-7F10304C439B', '4605319011240', '      3-d  1 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24604E82-367B-4512-B87F-8E20584C285D', '10CBD05B-498A-4BF9-AD8E-9E404E365EEA', '4605319011318', '  178 /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF3BFF78-8231-476C-A823-03B22051BEBB', 'F0859700-C6E5-4BF8-A41E-6E28FDF8B718', '4605319011394', '   spf 60 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('799EA849-42F4-4DE5-860D-5E4A57A1C59E', 'A3D9CA2A-57E4-49B2-A564-765A2B14DF2A', '4605319011400', '    spf 80 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61A80709-700C-4084-97C0-8BF9182A8EA5', '8E752718-B482-48B8-9E15-DD70D731B8D0', '4605319011417', '    spf 100 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EE370F9-2959-40EC-BD59-DC44AE9382FD', '437114B7-B84A-4BC2-B464-62B2CD228B48', '4605319012049', ' 262  //  450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCD4C979-8A9C-4FFC-8603-17743A38DE67', '6D2F8FF5-19FB-41A9-AD1E-659F855F91A7', '4605331003308', '    4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E73AA51-7F91-4CCC-BA36-80B2C2986936', '8AD7870C-2F23-4906-B44F-97B9D4D5F8F7', '4605331030304', '    2-   4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCA85FA2-CEA9-4A7B-99B6-A11C761FA9C0', 'B0075BCE-EBFE-4BEC-82B8-285109ADDFC5', '4605342000150', '     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9AC9D1C-81F3-481D-83A6-C9153513A060', '36DC5674-D3B4-4147-9234-A24A4877C7A7', '4605342000327', '   - // 800', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6516E649-C5BD-4816-89CE-712EE7B7BBD9', 'BB189259-5D37-4BE6-84AB-D3EA43392219', '4605342000372', '     500 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73FCDF22-11CD-4AD7-8C59-B5616367F7E0', '1848E9BB-5685-4D98-94AC-0AF89F2583FC', '4605342000433', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA2F41CF-3ABC-4DF1-B620-A06B6A942A37', '831CB987-99FE-4396-9216-CF65D18F8F54', '4605342000587', '   /    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('913E75C3-BD4D-4CC1-9A4E-C1BBA0933901', '7EFFB234-1D4E-4613-A829-0E922057A454', '4605342000594', ' /    2 / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('284DC4B6-48AE-471B-9661-24E16D0BDAF1', 'F92EA51F-FACD-45D1-89A8-AD3685BECAB4', '4605342000839', ' /    250 3 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3F2AF26-EFE7-4703-89DD-22BD11E09BAF', '2B33011C-D9F2-41E4-9004-E943AAF7E432', '4605342001249', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4B96625-DC87-4423-B4E3-BFB6A3986388', '217473BC-269A-4C5A-AF71-8A9D39FEEB04', '4605342001850', '  /  + / 450 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A5B62AE-513B-4509-81EA-DE9409DC4520', '4D057913-A73F-4C1A-8960-01BB699AC0C5', '4605342001881', '   /  -  150 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24C57557-C24B-4262-B61C-EE5F167CA81B', '96410156-13A1-4356-9A1F-08AD5256B40B', '4605342001904', 'Dr.aqua  /   +0 / 450 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED078FF8-9F23-4C49-B2AB-12D27DD91C3A', '714C81AD-F22E-44D0-AED0-C11D3FAD17B4', '4605342002222', '     600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF1641D0-3698-4966-8D8A-6E75BFAAFD6D', '154AA238-90B2-45D6-8FF0-93AD11E24701', '4605342002246', ' 600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3F57359-F31C-4F07-86E9-1FDEC0292AB5', 'C4F7DFD5-D072-49E0-9F99-B87EB6E1CA43', '4605344000011', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E527D07E-40FD-4ACB-9F23-425756D3A8CD', '063A6DBB-B44B-4BA4-9D93-68BAB34D701B', '4605344000066', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA101CED-BF80-4390-8919-FABAC4D4CC68', 'E6125861-7E3E-4542-9C22-5B7A3B8BCA49', '4605370000160', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A54DA616-CB4E-4D16-B4C6-4917376D6212', 'E6125861-7E3E-4542-9C22-5B7A3B8BCA49', '4605370000221', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B672F5EF-339D-465C-9DF7-DE3EEAEF43DD', 'C68847FB-C4DE-4D46-93E7-52E7F65164C9', '4605370000764', ' 10%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CEA5825-DA57-4A99-B8B5-A4407796A1E2', '9637C93D-361F-4D8C-8C0B-BD204E5AA8DB', '4605370000849', ' / /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C207035-11A3-4898-BFF6-A846A543543A', 'B65DC5AC-6853-45A6-B2A1-94D79737E8CE', '4605370000870', '  1% 20,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56CD2BDB-E84A-4FAC-9B35-950C42D64BD2', '4C34EBC2-5C2A-4676-8739-8F2B9DE1C548', '4605370001204', ' 0,002%  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE4F5D10-69E3-4B17-9042-86A796ECCF51', 'DC4ACB44-FDDE-4138-822C-271CBC45C978', '4605370001778', '   / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F31918E3-102C-4ADB-9064-3D5A5886E7B7', '92BC9338-DFCD-485E-A839-590B918C4EBA', '4605370001945', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3917AB01-8C2A-44E4-B638-642A960E7432', 'B66D6651-3BC2-44E3-9F4C-D848EF8976B7', '4605370002348', ' 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D95C9B08-74B4-4005-8B27-015F108A02BE', 'EE1F61DE-11AA-46E9-AFA6-9367C8F65900', '4605370002355', '     75  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9C9A67C-B045-45FE-ADB5-8F21A34356E0', '7DA46571-A594-43A4-A6B2-67296993ADEB', '4605370002362', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC72C9F9-5BCF-438A-8894-70F2AED945B2', '91BA5ACD-BDD4-4E94-AD79-E175149A268A', '4605370002379', ' - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9C21378-1E74-4AFA-BAFC-B4D6006C8C54', 'E2669BD8-18F6-4AA0-954D-27E465AC26D7', '4605370002478', ' -    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('105B19ED-B84A-4CB8-BBD7-5B4D5A83BE23', '0D3F9F57-74BF-48A2-95EB-2171902DFED8', '4605370002485', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77FB96C4-564B-4745-B893-E5DDDA9CDE96', '1B8AA506-C56C-465F-A569-C30C0383571D', '4605370002522', ' 2%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DABF300-1C14-47C2-9586-5D331905B3E4', 'FCC26B1B-9C0A-42D6-B8A3-7CDFF881DDBF', '4605370002539', '   /, ,  / // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDC4F416-ECB1-441D-986E-E128239810CE', 'EA49A9E7-AAC5-4881-988F-3858833F81D0', '4605370002546', '    /, / / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5574CAE-8927-4536-B180-4F508E933F92', 'FCC26B1B-9C0A-42D6-B8A3-7CDFF881DDBF', '4605370002560', '   /, ,  / // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCE1A13F-B59C-464D-A91F-2EAB207FD0FD', '2765BE1B-0ABF-41D5-A0E8-ECEA07CF6B6A', '4605370002652', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76D3ACD5-238D-4F46-8548-D8ED9397DAC5', 'CFFB330F-5A9F-4296-8594-88BF1BC72A57', '4605370002843', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCEA21D8-FE7F-4FB9-80F6-484202D98394', 'D45D0F53-F0EE-44C0-9002-CAA815FA0870', '4605370002850', '  / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC0AB3F6-4597-4DD5-8F23-5298D83C7044', 'FD2DEC1A-9B6F-4BFD-91E3-9BA526466A6A', '4605370002881', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF346C74-2889-4CA6-B659-F01A1925D4E1', 'BABE77AA-3B61-432F-A2CB-0BC4709EBFB9', '4605370003031', '  / . 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7668BC46-EB8B-4653-B256-5262E1D67A72', 'BE3FA7A4-A467-4E5F-A0D7-7A96381050ED', '4605370003048', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F3015DC-2B00-4246-AF6C-6E3EA1679154', '159CDF77-6B01-4D73-B250-CFE082FD1229', '4605370003154', ' .   97*97', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29156F10-C72A-48EF-B23F-2C3F68DDE4CA', '4E310828-5E65-40B4-83EB-B2334F4B73AD', '4605370003536', '  55 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4D7D57E-CDE3-4FF0-92EC-03CAC01D81C0', '596F771A-8C1C-4F13-8973-7F8C42057E9B', '4605370003543', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89897854-18CA-4933-8F6B-C8B8A35DB740', 'F28A41D1-CF1A-4F3B-A384-0B2C3EF10BB2', '4605370003550', ' - 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E91BB69-3DE1-40C0-95D4-48F512A03967', 'F57997FA-D078-4AB5-A7A7-1D80B9D6C61A', '4605370003604', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B84631F3-977B-4704-A5A9-71966786EC7D', '3563AA16-DA1C-4ACE-9ED2-B1583B10EB9B', '4605370004090', '  / 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('999C7384-3EA4-4F18-8362-3244D4F88735', '830D4361-E335-4682-8C0C-734005E16E94', '4605370004137', '   ./  6  12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F03FEE3-A26D-4E3D-B0B5-26739970344B', '8FE49366-C161-4DAD-A01E-F5F70F08579C', '4605370004489', '- 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10688F49-55E7-42A9-89D8-EFAD2D23A484', '666FBC02-FCF3-403C-BD02-E4F249265B5A', '4605370004502', ' 250  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B40475AD-F06D-4F5A-8157-1F18A457B88D', '344CA6B4-78BE-4B7C-A66B-3FDBC805D178', '4605370004526', '   99', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EE6DEA5-1727-458A-B8DD-A71361CB9C6F', '4285B5EB-C82D-43D3-90C7-E45B38197F39', '4605370004571', ' 1    .    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B4783B3-AC19-4356-B9C1-A2904CC9F2AA', '1900DFE0-5F58-4F79-BBCD-ACC34C82FBEA', '4605370004588', ' 2        24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCA78B18-1419-4DC8-B593-1768540DA184', 'B432D44A-F63F-4395-84FF-FDB845F12201', '4605370004601', ' 3      24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0838585-0194-4D2C-8A51-2FB4D888180A', 'F273A2ED-A992-4385-B91C-657F762A2009', '4605370004830', '  / 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E783C38-AC88-4ABB-BA0F-E30531B9CDC9', 'B8A76D89-6742-4875-84F7-C1B6E88F4193', '4605370005387', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C770A0E5-C704-4F7E-B94E-5985E34D301C', '7B59DB2E-ABB6-4C49-B128-8D593E73A28D', '4605370006629', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F5D07B3-44D0-4F47-ABAB-A2B242CB209D', '52C7C84A-F531-46B4-BF9A-A8317209096C', '4605370006704', ' - 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D961B5BC-BD91-4522-8AB0-688C9A415286', '35A0BBFA-B5F3-4B8B-AD4B-B46B5CFF3493', '4605370007183', ' - 20  N 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('600A4EBC-088D-40B1-BBA8-F668561D84ED', 'A69FC30D-143E-4701-B622-6CFD8AB171B2', '4605370007206', '  //   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11EA943A-61A3-49FA-9740-7840F8460A48', '41876F39-2403-4E68-AFB8-BFA5F3C0F957', '4605370007329', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2336C31-9E00-48F0-B7C8-B5B51B9EA988', '00D32283-7978-443E-8FEE-E90EF39D9FEF', '4605370008517', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4C98F2E-E658-4FF4-88AB-C69078DC1BFE', '5E6002C4-FA7D-45AB-B562-AE98F3F3B348', '4605370008524', ' - /,  1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47EB0A5B-A7E0-4BC3-92E2-4510410F196B', 'B5E5C450-57B7-4E08-A98C-9BD2E9029552', '4605370008531', ' - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('147BE564-D5A7-4C89-B40C-B4021FFF80CB', '96852D72-756A-49C9-8878-7B35B25C4C70', '4605370008890', ' 10%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A470CD39-A695-4A00-8E91-8B64B2FF6672', '8CCFDCE6-BA26-4781-87E9-FAAA43E73E86', '4605370008913', ' 1000   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34F95B70-CA07-49FC-9FBA-5169C6361DA7', '19FC836A-2BE7-4327-A0EA-601E4BC97C08', '4605370009088', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7D8DCD6-907A-40F9-9220-FB61B0A2A838', 'CF18DAF0-7744-4270-B5F5-3F9D205E7679', '4605370009125', '  / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E661171-7E99-4E13-89CC-01A9565C9652', '67989B2E-CEA5-4B4A-97A1-FA8AF1674027', '4605370009712', '      / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('413B2DDC-41C6-4EDE-A123-75AF2B3016DA', 'F179945C-37C9-402A-B014-8B2C083712C1', '4605370010138', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59A0B154-9927-498E-8139-ACCCA0286709', '6E08245C-49AD-430F-ACA0-0E4E348543D6', '4605370011609', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22E7A720-B4D9-4644-BD59-FD8A4FC7B263', '20CDB0D3-03E7-4016-A899-3246A1C5AE5C', '4605370011623', '  / 200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B492DC9-D4BA-4DC9-89E3-B592D8C36B3F', '30172B18-9EFA-464A-BB48-DBB15764DA67', '4605370011647', '  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76185227-CC76-4243-9E5B-011E312E48CB', '321873AD-C5E8-4218-AE45-519B047D4BB4', '4605370012217', ' 2%  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A882DA64-4CCC-4797-A46A-29C00CCA064C', '333B45DC-B562-414F-8D89-50A93D992DAC', '4605370012248', '  5% /  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C19CFD9-9C78-4F3D-9CD8-466D82235322', 'B195D41D-C4DE-45FA-B859-6ECFD1B13659', '4605370012385', '  /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACC0C7DB-E8AA-49B0-970F-46D3A46B224B', '5D9A1B66-DBA1-4F3F-85B0-2AA97118F748', '4605370012620', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6484B11B-7888-4FF2-A964-4371A011CC40', '24E95FA6-9BC0-4091-9287-FBFF5B3F5F73', '4605370012668', '-      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77539DE5-0A0A-48B2-8C83-9C9B7D220DDD', '5963F475-9933-4207-ADE2-9B42183F030E', '4605370999990', '  zd  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC996E2F-3BF5-443C-930F-A6D2F15FC3A1', 'CCE66DCD-D00B-48C4-ACA4-DDF29458C02A', '4605379000048', ' 2000/1 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8153EBBE-816F-45D5-A67F-81D46F5BF104', 'D8AD953C-F835-4258-B863-4848B058E9F4', '4605391001320', ' 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B45FC79B-55D1-48CA-A0A0-3E48C2F35B0D', 'AE36455A-6678-4B09-9EB2-080CFAA370E5', '4605391001375', ' /; /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E31DD7D4-331F-43D3-B41C-B203889B96F8', '9CAB4C54-8385-48DC-B175-0746F3B681C3', '4605391001405', ' 1 // / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB4C39E5-95B6-4747-8FA1-79C7C91B32CB', 'ABF3EB33-C79C-42DD-9310-8C398B42D6E7', '4605391001511', ' 0,05  /- /+- /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AC7B831-75E8-40E3-A94A-B926722B056E', '9DF5D5C1-47A4-42D5-92AC-E9BF715750A9', '4605391001962', ' 0,02 / / 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46BD65D8-EF5D-471D-8A0E-65E4648FDEF4', '306A9237-224D-4AC6-9111-64AE40DEE934', '4605404000074', ' /  10% 10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D44C877-732F-4933-A10F-91E70081C1B4', 'F43EB291-95D5-4F24-B27D-BBB266B8D938', '4605404000098', ' 10% 100 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('017FDA33-3297-41AE-8AF5-DE3DA6BEFD09', '62688242-0436-4651-AD0F-41ABB17BB1D7', '4605404000173', '  1%  - 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2F7C53A-7FFC-4B90-B73D-78CE9F35BFC1', '9B3011E1-3AFA-4F83-92D3-2707B81346D8', '4605404000234', '  2%  - 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA334A6F-F648-41B3-8BB2-9B7EA414410B', '99158D8B-3BA0-46D7-9469-D497BDD6D93C', '4605404001927', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47B71398-56CA-4345-89E7-8732A0A037D3', 'E7265F1A-FFAB-4C9F-9398-73CC852DB7F4', '4605404002047', '  0,05% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05A7A0F6-FD7E-484D-8DCF-48E6BAED4654', '73C21D0C-BE6A-4615-AB48-801756FA804D', '4605404002085', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77CBF51D-2382-439C-A62D-75597467A196', '86B95A21-BAA9-4A7E-95ED-4A3E495B02D7', '4605404002153', '  30  .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DD31FB0-26B5-4EFF-B870-76F61CFECAF5', 'ACF41313-80FD-4F95-927C-39619E2A4FCA', '4605404002160', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC81BB2F-7143-4792-88AC-2094ECDE35E5', '348F212F-4A8F-4027-A93E-0E37A809DA2F', '4605404002245', '   -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E37C341-1A5E-4162-98B7-8E0B219E4DC4', '6B30DDA4-5B95-4209-8137-484E5D152387', '4605404002337', ' /   // 1,4% 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77B24E49-1263-4D77-BEA9-AF1037B86A4B', '90C3966D-B320-4C3E-B83A-032B246420A9', '4605404002344', '  40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E15AC03B-B99E-4E18-A3A0-B5B3AFD66223', 'CB2E1A91-B2DE-43C9-A3C8-79CAD4DEA0F1', '4605404002351', ' 10%  - 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('366DC841-DAFA-4DB7-A3A8-7B8ACE4B61FF', 'FC2468C4-6F35-4CE0-A832-9DC9316ED4F5', '4605404002443', '    20% 30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37331C07-4341-48E7-8995-EDDE12083FE9', 'E39B0214-D313-4EAD-BC20-2C1FC8A36A2D', '4605422000025', ' 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E67DCBC-0150-404F-81A3-CC181ECAF0C9', '86876A28-6FE9-4173-B5DE-919377CC3F17', '4605422000445', '  0,15  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE633CDD-D6D5-4ED9-B68A-B4E35127BA99', 'EFEFA8DC-504B-4300-A236-627142532363', '4605422000469', '-  100  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C5943A6-973C-4B65-9347-8DD16F119895', '2C7EEC32-9E8A-4D83-BEAB-73CD789A1099', '4605422005082', ' 0,2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FED2AD79-0338-44E3-8B75-0EBA2BEAC414', '51F35E15-7E73-4D4C-A498-F636D04F5662', '4605422005129', ' 0,2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9BADC36-F30F-491F-BA5B-E4E9B7F2F007', '87A67B06-434C-4DA2-9897-B3E4FE098271', '4605422008656', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3A043CA-6E26-44AE-A2A0-C57776A32801', 'E39B0214-D313-4EAD-BC20-2C1FC8A36A2D', '4605422009240', ' 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89AEC24F-C82C-42C2-AC48-3770105485AE', 'BF3E3886-8012-4F44-B441-1D7D349E9AE6', '4605422010345', ' / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37AC1E58-248B-4630-B838-480B52886F81', 'D44EF9AF-C4FD-4833-BD44-9873596AE54D', '4605422012059', ' 0,15  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83B03BD8-D6D9-4C36-8ABE-6172BE7432CD', '623550FA-3D1C-4B58-8992-8AFBA814980D', '4605422013643', ' 50  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47D3232A-BEE3-4A22-83F3-0EC02795807F', 'D96AAB80-6264-471F-A5A2-00CAFDFCB66E', '4605422013759', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5F70CE8-A4AF-47E9-AF97-98687F1564BD', 'EE155B44-97E9-4FDC-B416-177AAC7DF482', '4605422013766', ' 0,25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('714A68C4-BFC1-4325-B4DA-EBEB7CE3BD5A', '12ACBB60-769A-4C1F-826E-2F49697BEC8B', '4605446001183', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90764964-DDB1-4536-954E-7FA6EC770741', '30C16BD8-2DAF-405E-B8A8-6B875E66D312', '4605446001930', '  /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CB15199-4DA9-464B-AEE5-BE1009EBA741', 'B81E1DC6-EA9C-4AA4-9AE5-80F3AD388640', '4605453000025', '  0,9% - 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2313918E-4823-41C2-A08B-602BA8306FD8', '2C84AC49-2CFF-488A-8F7E-6B4B12697026', '4605453000124', ' 200 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04C7A3D2-A628-40C7-A887-E48A34846A7F', '4F125CB0-CD2E-4491-B8AD-98AB27D66137', '4605453000131', ' 200 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64F30364-F0C9-4893-9BE7-0D5A3797DF1C', 'D625B558-3250-43A6-A215-193B8BCA1C3E', '4605453000322', '  5% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84AF5756-A764-487F-90CD-F88CA9259FAE', 'DE9B912B-03D0-4A52-84DE-781F90BDFC71', '4605453000667', ' 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB52D4CB-CD04-4812-BAD1-0A75830B9A26', 'FF274725-1BE1-4088-9D33-268B22B436E7', '4605453001008', '  10% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CD1139D-AF93-4C6A-A8C3-EE23D92FD628', 'FCECDB71-DDBA-4033-817A-B20E748941CB', '4605453001121', ' 20% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9994A323-BE06-4A78-BC0B-5CF4900BF455', 'F81D7286-6BFB-45F6-937A-4314C8D14CC7', '4605453001169', '  25% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5038A30A-D43F-4BEE-AF11-F7C4A7B92D35', '8B9A6623-84F7-444A-AE5A-BA4FFDAB18EE', '4605453001220', ' 200 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCE255CE-9CD8-4AAB-B692-D66F29E6B210', 'E17CF4F1-B9D6-4691-A1D0-01091821C516', '4605453001237', '  400 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A5A832E-1060-489D-A248-8D70869343E3', 'FF274725-1BE1-4088-9D33-268B22B436E7', '4605453001329', '  10% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C8F4AFD-261E-4AF6-886D-6DF17C70F03C', '81F134A8-B25D-416F-B2C8-09A0ED99EAFA', '4605453001640', '  30% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F3CD056-C335-46A7-9A13-AC3E96D72ECF', '244CBA7B-B966-4647-994B-55D3BA8CF14B', '4605453001961', ' 2,5 200 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E4C9456-5CC5-4586-80D2-49557A87B60D', '81F134A8-B25D-416F-B2C8-09A0ED99EAFA', '4605453002036', '  30% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81F597DF-46DD-458B-823F-DD8EB9AEB128', 'E9C6E41A-765C-4093-9383-88BB3E275818', '4605453002166', '- . / 5% 100 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0DBEEBA-AF1C-45B7-9091-7F04C65B93D2', 'DF2BC770-11CE-4C58-8D11-CBD983B43813', '4605453002173', ' 5% - / 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B139860A-C499-4415-8490-1F383FB22F0E', 'A6E851C9-FF9C-4650-ADDD-D5A75568B117', '4605453002180', ' 5% - / 400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62A62309-9867-41B5-8CCF-E9674F858469', '3C5CA160-B51F-4A0E-8AF5-9B2C8B11BC86', '4605453002203', ' 10% - / 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB14AE55-8E0A-4B3D-BE2B-93BD49D0B190', '7E537EC9-BD2D-4E8B-8C59-551E41B95BFC', '4605453003453', ' 12,5% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66DD1BCE-CF1D-4043-A45D-E35E279F74A0', 'EF19AF55-4760-4385-8A39-C387538ABBED', '4605453004054', ' 0,05% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6E8B238-585D-443B-8A20-142CDAD50CBC', 'D466248A-88B9-499E-832B-8F4121FE80D6', '4605469000828', ' 5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5A6D1A0-3CAA-4EC1-BE27-9224FDF8A19F', '902A2645-C967-4D0A-A30B-55B98DA20BF0', '4605469000910', '  / 100 5  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79F57A44-590D-4106-A0E5-5494FD28CC7A', '4F873380-6F1D-40D6-8219-457DA2F93D9C', '4605469000965', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57034E43-4FB0-491E-8324-72B46C61796E', 'EAF0B2D2-CCA1-4848-9A98-8A8CF04CDCEB', '4605469000996', ' 20  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36814D71-6C8A-4AEC-9D52-3CB4E3DD6C54', '8AAC8418-C405-4062-8550-49C61830F31F', '4605469001016', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42B2F074-1601-4571-935A-2D29EDF4390E', '43A940F4-AA22-40BB-A049-AF12924340EE', '4605469001061', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92D478D5-C80D-48AF-91BA-F4B804C6CA56', '991B6056-0310-4321-9AD8-8B9EC108B0E0', '4605469001085', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E377B8A6-F3FA-48D5-A34D-A32E5D711335', 'C8335160-84DD-4AF2-A19B-ACFAB0041CA5', '4605469001320', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60E39B38-7836-466B-B26C-D80B955D0881', 'FBCD1B38-6F47-4F68-AD5E-EE276BD7FFAA', '4605469001375', ' 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18F70FCF-5FA6-44A0-8193-C8A69E90403A', '7F6BEB88-7FA0-4523-BF36-64766E690C1A', '4605469001467', ' 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3616180-C136-4120-91F1-BE00AF8965FC', 'D5771D09-169F-4643-85EA-C65780BB17EC', '4605469001474', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('571451A5-C131-4E6A-B6CD-C4020E4816F5', 'B378A98C-CEFD-46B2-8C53-777BBA64EEB5', '4605469001627', '  10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4BA95B6-A903-4594-B933-814085F9F4EF', 'D8F9A987-2991-4879-B8C9-CAF4C4D1C514', '4605469001658', ' 5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3868AAB-8634-4854-99BD-0C4931DD0C04', 'C342B58E-9F9F-49A1-810F-29D0B3661B54', '4605469001672', ' 10  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83DB9656-5FCC-4E8D-8BB4-FFF4B72DABF3', 'D4F4A3AB-FD48-410D-ABF4-9E1D5190CD2F', '4605469001702', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92A360F5-4444-47EB-8B5B-1F777A608637', 'E7BAA685-5D52-458A-9C7F-45F33E7C5D7D', '4605469002204', ' 5  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2C8BC9B-47B4-4357-B547-0513696CC180', '350C25B7-A8B2-430D-BECE-1D3A3C5AF19F', '4605469002211', ' 10  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('297665DD-76CA-4450-8619-851BC33F2059', 'B47FEA2A-B6A5-4C22-98AE-9FFEB1BD44DB', '4605469002228', ' 10  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('692B256E-16B0-4D5A-80A4-436F47FE5FF3', '5D0ECB73-814B-4608-9790-D9D36D4EA95A', '4605469002235', ' 5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47F3E609-D278-43A8-9B18-1BD2C80B0B3C', '33C797E9-ECD3-4B0F-B57E-449F38B84F56', '4605469002242', ' 10 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5854066-DF71-4319-8E4E-DD676A46A123', '3FE71D75-53F0-4E1A-92E3-4E8B26468D72', '4605469002518', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7D292E8-AF02-4E43-ACA8-0D20AC31CEB1', '37AFF758-BE4A-4FAE-BEFF-9CB2278D0912', '4605469002525', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9E47ED2-1C27-41F5-B8A4-DFE3A2457D62', '8D398556-7390-4122-ADC6-B071AF619227', '4605469002532', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D90AF2C1-69DB-466A-AE61-F8800EC93712', '52E0D3AC-72F1-409E-B534-D74173F6BA95', '4605469002556', ' 5  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05133B31-B675-4E00-A33F-ACF7F958F68A', 'BD7F2FAF-49E2-49BD-8CCF-C8878A1DE336', '4605469002563', ' 10  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9F4202E-8118-438F-9D72-EB82E3A040CC', '68306944-8532-4094-957C-E401C7540406', '4605469002570', ' 20  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99840343-9A8F-472B-9D33-C8FC42617551', '8856D41D-A105-4403-A30A-7F0EDB5531EF', '4605469002877', '  10  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8ADC284-E751-4C71-A413-085168269920', 'B378A98C-CEFD-46B2-8C53-777BBA64EEB5', '4605469002884', '  10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62858BB9-3657-435D-93EE-46AB337AF70C', 'E9B9512E-9C4F-4485-9832-4E3A219BEFF1', '4605469002891', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1073802B-8C42-4FB0-999B-2A2095A00773', '54C016E9-0E5B-46DC-B03C-547167E9B1D8', '4605469002945', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CF24CF0-8301-4E68-81E6-1EB52CD663E4', '52E0D3AC-72F1-409E-B534-D74173F6BA95', '4605469002952', ' 5  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A0ED23F-B776-4233-B5ED-E4D19E71AB3D', 'BD7F2FAF-49E2-49BD-8CCF-C8878A1DE336', '4605469002983', ' 10  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BD93D04-5FD1-48E2-9888-20D1A1F1B3D7', 'D4F4A3AB-FD48-410D-ABF4-9E1D5190CD2F', '4605469003003', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1384146-530A-40AE-9E9F-DBB6F029385E', '68306944-8532-4094-957C-E401C7540406', '4605469003010', ' 20  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5A2CDD5-1805-4653-B11E-B1D5AA7919C5', 'BB1E21C7-257B-439D-B08B-FFCE7F2E812B', '4605469003034', ' 0,15  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2214B4E3-544E-4E78-B5D5-1B04FDBF469B', '60FE8A28-122B-482B-A49E-04AE8D08B6E4', '4605469003041', ' 150  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('849833B6-0DB7-4626-81C6-86BB23B9D060', '8767480B-7E0A-4EDF-A74F-0879B0C41BE5', '4605469003249', '  2,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82341F69-3764-4CE9-908D-0DB6AB578FFF', 'AB64F2B6-7FE9-4E8E-BF89-39B8A27E0066', '4605469003256', '  2,5  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AAA2F78-A9EB-4126-B0DF-21DB039323D7', '8856D41D-A105-4403-A30A-7F0EDB5531EF', '4605469003546', '  10  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23B2006A-BAA2-4B6C-B2AF-F356E4A47A5F', 'E1F6F4BF-CB11-4AAF-ABA5-D7916E6D1600', '4605469003706', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28AE5011-6CC7-4600-B6CD-502D202886C8', 'AD4C182A-0468-43D9-9F2D-3A35BA8E5A4D', '4605469004055', ' 80   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C78F54B-AE67-474C-B3D7-5B8FB0320BA1', '3ADEBA2C-A523-490C-9E92-8590129C2F2F', '4605469004192', '  100   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6130AA92-F0A5-4901-A4E9-198467B1FD97', '86B7BBE1-B7DD-4364-8CAE-DA4986DB7C0F', '4605501000076', ' 5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3F6FDB2-1478-4D9D-94B4-F1538836248E', 'DE9B912B-03D0-4A52-84DE-781F90BDFC71', '4605526000013', ' 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCC2A29A-CD28-45B0-9514-89AB69BF8877', 'F3559AA1-B294-4FAD-B2B3-47F3476C5F6F', '4605526002598', '  0,9% 200 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69B7219E-3BC1-49E4-97CA-DCE92E5B16F1', '65E96FD1-4C60-4DE3-BFC1-19008CED115D', '4605526005759', ' 50  / /  / +- 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('432E212F-3147-476D-98CB-1C52A9996CCB', '0D6309A6-002E-4581-9F1C-A95F67C66A1D', '4605554000306', ' 0,01  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D08B149E-54A1-46D9-8E3F-C548582F1D63', 'FB184964-3BEB-46A1-B48B-C8332344BED8', '4605579004259', '   55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A3B08E4-5A33-4D95-B0D6-68A70B69385C', 'EFC232FD-4407-47E4-A0BF-7D6A36029C91', '4605579004266', '   55 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C263881-8B26-4173-BAAA-36DFBEC3EED3', 'A654D51B-D4A1-4875-9B0A-C498B80CFCFD', '4605605000057', ' 0,4  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55137BE8-0268-476E-9D76-2DA49BA5B764', 'B20B8967-67AE-4A07-B988-3441320A234A', '4605605000187', ' +  500  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16B5283A-9E29-4872-AC22-2AD8F7525EE5', '28AB15F0-C2EE-4F6D-B26A-5A1FD2129814', '4605632245636', ' - 130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7B279B1-90D3-4252-84B9-ACD08D69D99F', '58846792-887F-4901-85F7-0778F49F4850', '4605632245643', ' -  130 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6102DD13-855E-4859-B474-8E9E0E8A872B', 'A99C1331-79A5-442D-9D77-8BE114E997FA', '4605632246275', '  -     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD2B5D65-2365-40F5-8E42-81981D2D7F35', 'D9453E78-F43D-4941-893B-CD3DD617F58A', '4605635000027', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E99D44B-725A-4DF3-873B-54AFB6B32B08', '046E9C31-C311-4887-8F01-9659DEADBD82', '4605635000058', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C993F00-EFB7-4816-856E-3CF384730E43', 'A44DA078-A28B-4D5B-AA0E-69CC996B3C5C', '4605635000249', ' H 10/25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('460516B6-E616-4D84-8748-7314CB6A6650', 'BBB130E6-BAE6-4C0F-BBBB-AA4842EFB7F4', '4605635000263', ' HL 10/12,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C3DCB5C-966A-44EF-9C11-F2808334E9CA', '5E1EDC96-4FB8-4907-AF60-7686F62B0B47', '4605635000331', ' 500 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('338EC70A-3FC8-4751-80CE-08F89A7D2AC4', '8548EF5C-5CE1-43A2-8FDA-F6E703ACE49F', '4605635000829', ' 10  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73A5927B-4F54-4468-AD04-DA4FC80CE920', 'B4951086-696E-43D5-961E-FA62FE97E352', '4605635000836', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B742401-4D75-4F81-B4B4-E8F4A913DD7C', 'EB6AFCA6-D3E9-43DE-A215-51BBD46413E6', '4605635000850', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E8AD5EC-A487-44B1-908C-C8A298EA0759', '94232B60-DAD3-408C-8DFC-B09CF7BA27E0', '4605635001017', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0F76AC7-2B83-466A-A66A-83555FCE35D2', '9EF4DD36-015F-48B1-AB8E-95EE7983DD75', '4605635001413', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7C5DCFD-4AF2-4A9C-A23B-B74AB54BDAC6', '0596AD35-9794-42ED-A2FD-DF64C1647D71', '4605635001604', '- 3000000   /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3239A6CD-1BC0-4FA1-AE7B-F0C7AD175BD5', '0BD5D12B-F150-4793-9DAA-F20B75CC914A', '4605635001727', ' 200   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4EE64AC-EB12-4382-9C8C-749CA5723E7C', '94322DC9-E4F0-4351-8011-54F8ECA20252', '4605635001741', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('594D908B-6590-4E7D-B8FF-01FC61C547B3', 'CDBD8B1E-5EC8-4898-A1B9-387CC07D657C', '4605635001857', ' 25 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F61071B8-D404-4999-943F-CE808BE23914', 'DAE10591-B1F1-4D14-B090-5B673060EA1F', '4605635002205', ' 250  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('609FF429-5B62-40D4-B091-8DE5434301FB', 'E8034C07-42A1-4C1F-B52F-0AD91ADC1096', '4605635002700', ' 40  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AA3F585-3164-495B-9DEF-8BF3309BEACD', 'B668F97E-D115-447E-9390-71FF201A867A', '4605635002731', ' 4  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0397EEDD-56FF-4A10-9154-739EFF149C53', 'FA9C0FD2-3981-4AB0-988E-FB710F7F5F08', '4605635002748', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C4052BD-B849-4803-A951-2AD447CE6058', '3A177198-1384-449E-80A7-20B637DFF19F', '4605635002946', ' 2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9CA4945-1C72-4743-A89A-7188380E4DB3', '6B491121-5806-4AFB-A5F2-E1C708BDF38A', '4605635002984', ' 3  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDDD0951-F100-423D-B755-473352CCDB59', '1C6B5EF7-0564-4D9A-9BAC-9C1A51D5F076', '4605635002991', ' 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('634EC412-03A0-4B92-8D8E-4E731164FFE1', 'DE96C962-6022-49FD-8FFD-22D7CBFFB6D9', '4605635003141', ' 3  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B38F8FF0-3674-44CB-9436-363E87923E7C', '5DE18655-F40F-42D4-82B9-27EBEC32D7EB', '4605635003240', '-  500000   5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4921D1E-368F-4E3C-B8F4-37CB46A83432', 'A632E842-0512-4047-9A83-2252CB53FA7C', '4605635003493', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C6428D2-C08D-4F03-B53A-1308E088180C', 'C4765C07-44A9-48C6-AAA5-16B105E859D7', '4605635003516', ' 4+  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96001CFD-AC1B-4C9E-AF32-D794CBBA6FFB', 'FF7DCAB0-C2B3-4891-80D8-DC4728B6CDEB', '4605635003523', '  20000  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC209C5C-462A-4BFE-B986-0D650F7AE521', 'BAD2622E-9C13-43D6-B4BB-A1E4381C2D37', '4605635003530', ' 20000  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ABD1F95-6BA5-46E4-BC46-DC097B498196', 'F5B55211-BA8B-4E5A-971A-D83DF0DD7640', '4605635005152', '- 500 .  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('516594A5-EE36-49A6-AD19-8E2C6F39A552', '2D703957-184C-4A58-9576-B3F191434233', '4605655000113', ' 5    20   / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0F03FA4-2335-47F8-A2F0-73A7D3F87283', '5C1CFC20-F9F6-4034-BF1E-32FE92357F8A', '4605655000380', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92370651-77C5-48F9-A2CC-7233B7E613C5', 'E3DF49F5-89A9-4E53-A091-CE5E854A35EC', '4605655000434', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E4977FF-3B17-4F49-A5E4-389042D364A4', '914D6E30-A313-451D-A7F1-F56519F006AA', '4605655000670', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E8A9020-4108-45E0-90BE-A545C5357288', '8FE3EAAC-6DC5-4E96-921A-EBF290D42EFF', '4605655000939', ' 0,45  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6E7BACA-3D93-4C19-BCCD-7320E7711B0A', 'E72C6A20-6564-48DC-8075-393E59AE829C', '4605658011093', '       125 11109', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33ED7051-3DE8-4080-9882-C04BFEDC760E', 'BFCF65C3-F9E8-4083-951F-7D05817B1EC8', '4605658110000', '       6+125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5515AB47-D062-4F21-AB3C-D32447BE847D', '9D272F7F-FE00-434E-B572-8540C5215769', '4605658110017', '  /11001/  .   /.140/ 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF06A102-7011-426A-8EB4-A0E1CDEA477E', '544F285B-1BF2-4EEA-A360-58047981B2A1', '4605658110024', '    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B61AEED-5ECA-4BF1-89E4-12478BDB4452', '95E8EB5C-73C2-4153-B919-E19E098B17DD', '4605658110048', '    250/11004/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7055C6FD-CDB1-46E4-B79F-562E97282F9D', '6FC8F848-29BD-4109-AFD9-FF596397746B', '4605658110055', '       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('236F7BC7-892B-4DE6-AF65-3A7A596F4C53', 'E7C6E377-4489-45BA-8EB0-EAEC7631736D', '4605658110062', '        6+125 /11140/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59C02B3F-5AF3-4E9E-AF77-F007CDA7864B', '10BB1E9A-99B0-45B5-A800-13DB7B31DF04', '4605658110154', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70F1A1F4-3A75-4772-B664-B1B5CCFB8BCB', '647BFDC0-B045-4117-9872-53EB2809313A', '4605658110178', ' .   /11101/ 1 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E54D520-DE66-4475-A6E2-EE8C1BD38F16', 'CD7B2DD3-236C-4087-A498-2B4D392BD476', '4605658110208', '       6+125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18EF8B2A-60DA-409C-93EE-073B0FE2F08F', 'B955BCC3-C44C-4D2B-8750-BC8B6E35B11D', '4605658110499', '     2     250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A06D4209-2ADD-415A-AAC9-85BE28B47642', 'FDF35688-6F35-43F7-984E-883396045140', '4605658110857', '     125  0+ /11085/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E39DAA25-855C-49AB-8269-88FED324CED1', 'C7B0C830-7449-4E5E-AF15-AD097DF63839', '4605658110888', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34D24B9E-E950-46E6-990C-97316A54DDD9', '875491B0-2E60-46C6-A3B9-EF5E4E36DAEF', '4605658111014', '      240 11101', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('380492CF-4785-4CF2-91E3-39EE0549291D', 'ED9DE996-0C10-47E6-A775-990500B249DF', '4605658111021', '  /   0+125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F2104E9-93BF-43EE-933D-F2AA92E33410', '18E10DE6-020A-4CB7-A6AF-DC4392FC4AF5', '4605658111090', '   .   /  125 11109', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD472FC6-A01D-4C31-BA0F-D3BD13022286', 'C30EFBD3-4346-4006-BADC-7EEB41B4330D', '4605658111120', '  .   0+250 /11112/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C84D6CD-1504-4AD9-9E5E-91FD9F630BC3', 'B0EFC22D-A06C-418E-9F2D-3ED54EFD48A0', '4605658111137', '        250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C95B676-B1D5-4D73-A73C-1DDCF2408D05', 'ED9DE996-0C10-47E6-A775-990500B249DF', '4605658111144', '  /   0+125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('083D5CE5-C0CB-44DC-8D26-F258DFC3C7B4', 'B0823285-C2B3-4333-A7A9-10EC92202F8C', '4605658111212', '  .  240/11121/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A001B47-0364-47FE-97FA-F46D8E94C6BD', '607D5E43-1630-4395-A6E5-B889FEB27E83', '4605658111229', '  .   0+120 /11122/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('499AD282-8351-45BC-B3C1-88AD4A81C85E', 'FCB9AED5-608E-42E6-9BA1-9B466378B918', '4605658111298', '    0+125 /11129', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ED85CFF-2C36-4857-898B-D5A3122526B5', 'DC3B6DE3-F776-4C85-9267-D96F1FE9F717', '4605658111304', '    250 /11130/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4DFD0FF-9044-4E59-96C7-9C9240C2C08A', 'BDED253C-926C-4B3E-B704-0DF7FFCBD624', '4605658111328', '     /11132/ 125 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE4EEB4B-619D-40AB-870F-5834200CEA54', 'A29BDB9F-1C8D-4BF2-8AEA-43746BD44E81', '4605658111335', '      250 /11133/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE201E3B-6175-4576-867A-76C784A35EB7', '94C6F24B-8FEB-4CF4-A710-3A4C4C550176', '4605658111342', '      /11134/ 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72B5B392-2964-428E-9C34-747739846F1F', '86324C96-EECD-4712-B7C4-694B535D055F', '4605658111397', '       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54524147-532A-4967-839A-52C017A32A43', 'BFCF65C3-F9E8-4083-951F-7D05817B1EC8', '4605658111403', '       6+125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DDBD667-6F21-4FA6-BEA2-2C9B17381082', '40A27F12-5145-4D9A-A67D-418B4D0E8805', '4605658111410', '       250 /11141/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B60C201-4857-460E-A8A7-B0BEA2F99E7F', 'CF03C663-4A08-4F66-A347-26D04975ED0D', '4605658111427', '       125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81C56F2C-4852-4F2B-8BB6-7C3FC05F042F', 'C7B0C830-7449-4E5E-AF15-AD097DF63839', '4605658111434', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D3231C0-3082-4932-BC89-79A9A053AD40', 'F6033BB9-0C72-41D9-BDE2-705D07DF1E17', '4605658111441', '      0+ 125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E8E462C-076A-44D1-B786-3CC66E4B4927', 'B5D06288-A7E3-4944-8BF3-CDCADCDBD7C9', '4605658111458', '  /11145/   250 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC324742-F0D0-481D-907C-212BB3131A46', '8DAC3051-969F-4CBF-968B-9EA48ABEBBA0', '4605658111465', '    125 /11146/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48D9F963-F1F2-4125-8EA1-283942559407', '257E0430-18C4-4218-9A1B-7B57719BECD6', '4605658112080', '  .      0+150 /11208/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB563A5C-CCE2-40DA-AA09-59C22A770088', 'B9FC94F6-FB71-4BD3-ACC0-6173F35BD56B', '4605658112097', '  .      0+250 /11209/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C56CB1F1-5C7C-4F43-A506-8AA191F0AA6B', 'A22F7A68-A6E9-48E6-8BDC-75FE6261DB5E', '4605658112110', '  .250 0+ 11211', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58EFA0B5-ED95-4D42-9FA5-81347D7E9B1C', 'E08C4445-35A8-4B30-A8C1-EDBDD3E50B4E', '4605658120184', ' /12018/  .   6+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCC178A1-6979-499A-91FB-6D786C619B0A', '9600D814-023C-4295-8081-76496BAA63AA', '4605658120306', '     -  2 /12030/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B209C247-C2DC-465B-983F-90673A7CB0BA', '4B035A82-CA0D-4EB1-966C-497BEBB4D248', '4605658120313', '       2 12031', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2B4580B-56B8-4636-BD09-47E6E9080FC6', '2F96E323-1D11-4842-AD1C-4FCF9D654BB4', '4605658120320', '  .  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F51E71A5-6119-4D8A-B930-23BA6368799A', 'E1C8240A-43AE-4D72-9058-3D6018BA8AF5', '4605658120399', '    3 ./12039', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD020EB9-CD94-4171-A63F-A1B08DA24CE1', 'A5CAE153-0085-4560-9EFE-A756E7A2ABDF', '4605658120412', '    6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49C048E9-B80E-48F8-8D17-2128ED8D29F9', '1E5BAAA7-88BC-4979-8E9A-2D83C942EE35', '4605658120511', '  3      0+ 12051', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A72B6AA1-43C3-45AF-AA74-F683D6FB4FC9', 'D766DD2B-88E7-4CDA-AC00-A036A98629E5', '4605658120535', '       0  1 12053', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52B244A9-CE94-4E67-A825-FF1803BA1740', '42EBF5AE-1E61-4FCE-AF8F-02401A9696CC', '4605658120542', '       0  2 12054', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B229F68-BDF8-4A76-970C-ECC68C85184B', 'E7A6DE6A-7756-4C90-BCEB-0863E62B12D4', '4605658120559', '      3 0+/12055/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35C889D4-7225-4A17-9ACA-605425E18DFA', '3F3DE1E8-E5C9-4761-AF36-DBCB04FDE9F7', '4605658120566', '12056    .  6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B978161-1E55-4E33-9F5D-E31868B0CF65', '3944218F-8F36-4E99-99DA-E24AF259A6FE', '4605658120573', '       6  2 12057', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('133731BC-5A85-43E6-87F9-A9FAFF4FE706', 'DDE66105-B6E0-40BA-837F-78D90697F743', '4605658120702', '     -   6  2 12070', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAF828A3-FFE5-4902-A617-CED45F94857A', '4A39FDAA-859B-4A31-B5DA-779A9940553A', '4605658120719', '        3+/12071/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B4E2FB0-C91A-4537-9847-AFE545825AA6', '34625ABA-7C65-4E0E-A686-01621771A921', '4605658121235', '    -  6+  2  /12123/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76CAB8FB-2CB9-4D06-A4BB-D9493CB373E6', 'F20E6368-A148-4E25-96D5-1890F18CB4C4', '4605658121242', '        2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('606DE770-5478-41E8-984A-FA6869EEDC3E', '413BD6CB-6054-4844-B0E4-0423174B96BE', '4605658121259', '    2 0+ 12125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76CCEEC1-D538-447C-A06B-FFEAD51E7EE6', '6BAFEA77-A845-4AAF-9645-F0F785D3D611', '4605658130145', '   0+   /13014/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BDBFA67-089B-453D-9FAB-E4E34F163011', '2916CF58-2918-41D7-889C-DC21BA1F6ECB', '4605658130152', '   6+  /13015/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFCAA6C5-7225-4587-9A8D-EAE03B2996F9', '5AF133DA-9DA2-4F22-9D91-AC6761DDA8F6', '4605658130251', '        0+ 13025', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3E426FE-737B-4BFE-B0BB-9CA7BA09D5B1', '93B13E5B-D868-4AF3-80E2-AC2B694C5127', '4605658130268', '  ,  6+ 2 13026', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDF9E995-ACD5-441F-B0AA-580F7A3A04F0', '4820A879-C785-4C47-BDDC-CBF9434C391B', '4605658130275', '    6 2 13027', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38AE3988-D425-42AF-929F-3B50AC156CC8', 'FA514D66-67E6-4BB7-AFF4-5C98EF4A68D7', '4605658130442', '      /13044/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D664DB48-F216-420F-AC46-D4BB8D4FF091', '6873909C-27C0-4947-AE2E-1B77678B6636', '4605658130541', ' -  6+ 260 17043', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CADBE2C-C112-48CF-8061-1470A0EACA6E', '213100E0-891E-4C81-BE72-1459AA18E299', '4605658130640', '    0+ 1 /13064/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9E8376F-14CF-47EA-9205-1E4A9F65F9CB', '4FB5D911-4F95-42FC-B6BA-3F4BE7A7CD5B', '4605658130657', '     0+/13065/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89F4B1B4-A1FE-4930-8A2F-30DD658C692F', '265E29F2-1948-4759-B4AB-89D65C281686', '4605658131005', '     0+  13100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4DC8B0D-EF7A-47C7-8846-DFEDF5328C01', 'F0FC7AAB-6697-4E2C-9678-36196ED4A738', '4605658131012', '     6+ 1 13101', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B9100CE-9D60-48E0-AEDC-C55003A6809A', '5F5BE897-4DB9-42C4-9ABD-39F236010AE9', '4605658131029', '    0+ 13102', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03C574AF-FBA4-4ED1-9E4E-E2CDD54A5126', 'BDA88729-FAB7-4456-AEA2-BE0D57901B61', '4605658131036', '    0+ 2 13103', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A28CCECD-33DA-4899-84EA-3B3ACE9696B9', 'AF496FF6-B763-4504-B0CA-DF60735620D4', '4605658131043', '      3 13137/13104', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F29233B3-F248-4424-9975-E16729CBEAB5', '2F01FE72-AC93-47E3-AFEE-2D31FAC85F7B', '4605658131098', ' -     6+/13109/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9E456EB-EC86-4CB8-89A4-DD45226F9A4D', '9ECC51BC-DB9C-4051-B819-EDA9F73A5C78', '4605658131258', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A2502E4-0D9D-4FE7-95A1-8CD43DFBB173', '9E5B5F02-8689-453F-B872-59AF39A1B0E7', '4605658131265', '    0+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DBA996E-9BD3-4339-9CD9-6065AAA7B8CB', 'FFB3348E-D1F2-44A0-89A8-58122919EFFC', '4605658131272', '    2 6+ 13127', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F54C98C-8476-41DC-96C3-C9240CB99679', 'FF2D0CD1-CAD5-4943-894A-FD7B393238C2', '4605658131340', '      0+ 13134', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('890BA786-F713-4A44-B0E9-E3E79902494F', '05F84D71-3340-4627-87DF-15F3AF540270', '4605658131364', '    0+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F178980-4F5F-4421-BBA2-724115B8223B', '75E8CEA4-99E4-496C-B864-7DEC68F60F65', '4605658131401', '     6+ 13140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A74FE8AF-44F0-43A9-BDFB-CA6A119DD6EE', 'E1563955-321E-4F19-B533-ED08FE838331', '4605658131418', '    0+ /13141', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB590EC4-D0FE-459D-81EA-836CB8262AAC', 'AF161D4C-3916-4BD2-A000-C0BD41C7A695', '4605658131425', '13142   ..  6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72F43331-2E99-467E-A7CA-2B6D65BE9ABD', '50924CC9-67F7-48EA-9543-15F78F52109C', '4605658131432', '    0+ 2 /13143', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24F4277F-F8CC-4D66-A690-75F192B39E36', '1AA0C3AE-6AF4-404A-8B92-A246D4EEF6CF', '4605658131456', '       0+ 13145', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B4B06A6-5830-489F-AD0D-0984ADF0B892', 'CEA0EF44-8A6E-45C4-BA75-4BEA473D3103', '4605658131487', '   6+ /13148/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FD7B914-E721-4F67-BD36-FCD14F5E2524', '37BB1AA8-DFF5-48AD-BA40-8369AE505C22', '4605658131494', '   0+ /13149/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F597981-7B94-4316-A5CE-F3054F817ED0', 'EED4D478-FB95-4C52-A6B8-AC107DEA89CB', '4605658131531', ' -      3-/13153/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C066307-DCE8-4443-AC9F-1F69C65111F0', 'E9565155-BB3E-42B1-987B-2950354504AF', '4605658150020', '   3+/15002/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('608677BC-D133-49CC-93AC-7423FCCB5FA5', '8FAA7780-9CC2-4956-B8D3-4375F0F79127', '4605658150037', '      2022 3+/15003/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FC1BB30-158D-414F-8A70-4D9A34834390', '97B69175-43C8-49B1-AB44-F83F58C40A86', '4605658150051', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05EDACED-50CD-4EA4-9197-E84CF1F834BD', '5623EAF9-F5F4-4F28-A4FD-F24B0DB071D2', '4605658150297', '    /15029/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44F04468-2385-4452-8A7A-837A6611AAF6', '9B56B782-3597-4E51-9363-2E6E4571A398', '4605658150303', '   2 15030', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F99982A0-F74A-429A-AEC1-290170FA2223', 'B8B72146-024A-4363-B59F-750EEBFF4CC1', '4605658150426', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE8C3B8D-C1AA-4BC0-BC39-85DA7BA54E48', '94FC05F3-3411-4E48-B77E-99D54A1E3C25', '4605658150440', '   2 15044', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E36FB99-CC22-4BF3-BDE1-FE39E7D790C3', '09A7EF56-8629-4CF1-86D8-1301E66279ED', '4605658170004', '   12+200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('617A3E09-36F3-4D93-946F-9D234BCBAA73', '3B9BE64A-063E-4328-88D8-B7042960FDA5', '4605658170035', '     6+200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26FFA58F-532B-4CB1-A757-A754ACC21CD1', '6E567792-3A93-4A91-9D1C-B8E97E134561', '4605658170066', '     175', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CA7E2F5-78B0-407F-93C1-FC43A856A127', '62F24815-748B-436F-AD43-60003E2FEA5E', '4605658170097', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FA91AE9-3E47-40BF-AD03-C0F5728381EB', '08596680-800E-42C1-B765-7D92E2E6920B', '4605658170165', ' -   250 17016/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F30390AF-3261-47AA-B461-963ED0DC4437', '64EE9CD6-0B1B-48FA-819A-1D8A8A787D54', '4605658170219', '-    250 /17021/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E488820A-55B7-4883-B162-1A0E93FF78CD', '203980F9-A2D5-462F-80A0-3DD51F60FF0C', '4605658170271', '     200 /17027/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7EF6027-BF10-4C57-9608-78CD8593B1A0', 'DC7F6F5B-1A5E-4A5F-8941-9282D3772F57', '4605658170394', '   210', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('196D6492-74FD-471E-BE15-5A7863F9F702', 'C5501D5B-8E6E-4517-A0CF-78E0B9E15559', '4605658170424', '-    235 /17042/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DEB8208-FB1C-4441-8DC1-225F82A0CA5D', '6873909C-27C0-4947-AE2E-1B77678B6636', '4605658170431', ' -  6+ 260 17043', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FF0715F-8604-4C0E-8343-4A0C9B01D581', '3A18F127-1740-4510-92F2-C441E52B89ED', '4605658170455', '   125 /17045/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12E75152-95BA-4C1B-BCD8-DE695D172F09', '32F4DF56-086E-43EC-8B49-E36BCC747279', '4605658170998', '  270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F5879B2-3B78-470C-BC2D-A460C31042D0', '82AA3519-1D01-46D8-A1C6-46ECFC69ACD8', '4605658171117', ' -    +6  17111/ 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDB5DD0E-9E52-4321-8FB1-A5AB0BF1D01A', '466E7867-ADB2-4677-A997-59CC4D655780', '4605658173081', '    5+ 17308', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5E49390-F4B2-4609-A746-7A36D9FC03F0', '96ED7E34-7A17-467A-9D9A-86C6725CC5CF', '4605658173142', '      /17314/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FBA05C1-3240-4149-B17F-1F2B67091E76', '346BFADB-DE07-43C0-B57D-6AB3A33DC5C8', '4605658173197', '  /      /17319/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E594A86-6FA7-4659-A3D4-3D2BDB06202A', 'EF682886-A8E0-4CB1-93B4-53CDC4D3A85A', '4605658173623', '   /   4+ 17362', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B2EB758-10F9-4790-A65D-1B0AECE48766', '296695FC-308D-4C9C-BD13-198A7078EB6D', '4605658173654', '   /   17365', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C819B9A2-DF69-48A5-AF08-3F2DE7A51520', '2399E6D6-474B-4519-B044-88981B94AD4F', '4605658174088', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8009E00D-8EBE-4976-B162-E987C3D2D9B2', 'B6C167A8-DC6E-4827-8DE7-51D6FEE8DF8C', '4605658174200', '  /  2 17420', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECB21ACB-6C0B-476A-9B97-096B14CEFCC6', '2A467269-2BE4-43F2-A061-EC00B74263D8', '4605658174316', '     17431', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8831B83-1B9F-4103-9F85-008DD51D27F5', 'E06D6E04-64CA-411C-9BF8-A996199C48FA', '4605658174354', '      4 17435', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D03C9CEE-994F-40F7-9060-7475726EE862', 'D60F9830-AC16-4BB4-8A50-98212D9148B9', '4605658190019', ' /  /19001/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE5F2B07-7E32-4091-9897-DDEEF2851274', '228207AE-7CF4-4C1B-8323-F1750F3C0EC0', '4605658190026', '  /  19004/19002', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D94B93B-471F-4C32-B212-BFFEA5B49669', 'F353B8D2-A746-4B40-A5DB-0EBA0030A68C', '4605658190040', '  /  19004', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7DDB925-DB61-43E5-9235-6079D87D93D9', '6743AEC6-2C85-47E1-94AC-CDC41BCB6060', '4605658191115', '  /  19111', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74692456-931D-42AC-8232-64F5B645F13B', '799243D7-122D-4622-BED8-6C3172C21EC4', '4605658191122', '  /  19112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B67BAC2-4CAB-465D-8430-FCF98C123CC8', 'F0EF52DD-400C-4048-988E-E119130C3E04', '4605658191139', '  /  19113', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F68708E5-8714-4FAB-BAB3-92782F46D3BB', 'CAC1B3B9-E689-44DB-A01B-F8CF145719AA', '4605658192037', '    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F6DF0D0-BA43-4B37-8E48-B02B67E29304', '57BA91BD-CE71-47D7-904E-4D6FC6E37C9F', '4605658192044', '    /      150 /19204/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05CFE4A8-CB14-4BD3-9650-6099F222B35A', 'A180F592-E059-412C-95B9-AD16FD0DBE89', '4605658192051', '   / ( )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF5D0979-734E-45DA-A6F0-C6D4B8C85872', 'C9149CA9-F09A-4074-9B39-7C99BE45AD58', '4605658192068', '     / 19206', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88B053B9-F284-42C5-A5EB-7BDCDE80826A', '04855BD1-5577-4E8B-BBB2-F3C574CFAF8C', '4605658192075', ' 0+/19207/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19C30AB3-2FEF-4E8B-8838-97AAFB575FAB', 'E3161300-14CC-4294-B060-BD5BBA231AD7', '4605658192082', '   0+ 19208', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F72E11E6-983A-46B2-9AEE-BB4FA84AF0A7', 'D4E0AFE7-5223-4754-AC3B-4CD9AAF9F6EF', '4605658192112', '-  .  - /19211/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B124B14C-90A2-4183-A220-9E9855132504', '2F70DED5-05FD-4159-9DB2-AA8350E43F61', '4605658194109', '      4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('943C0379-F6D5-42B2-9528-64D28E68CE45', '1BF1251F-FD28-443C-9C56-ECD5967FF42C', '4605658195021', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('050ECFDA-6823-4C81-87CD-DF03C829C6A1', 'F0B6C589-EFA1-40DF-BE76-74B20347BA9E', '4605658195038', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('538F3C2B-F100-4E5E-916F-3BB477B66AA4', '0A077276-0A1A-4D82-92FA-E38A1315BA14', '4605658195045', ' / /19504/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('356956CD-09B1-4077-89D6-A7906B32634E', 'DF9C4834-B2A1-4889-B851-45798C4A07E0', '4605658195069', ' /    /19506/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('537998E8-C13D-4DD2-8AA4-B18AE6089401', '6F648527-2D7A-4100-AE59-6B2BAA657941', '4605658195113', '     19511', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9C6C018-B1FA-4C74-84BE-B53193489879', 'B57532EC-2D7B-4DD2-9720-FB6A7CFC73E3', '4605658195144', '  /   0+ 19514', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B761F242-768C-4851-9249-1DD62147353B', '979857BB-13A5-4847-B9AA-599C4933A5A2', '4605658195151', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A63CD3E-FD6F-433E-B78C-66866D4BDD4B', '675F2F31-5ADB-41AB-9CE9-D255994A2209', '4605658195182', '  /     19518', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AAB0647-10FC-4624-93F9-252A3C21AC64', 'E6EA5A15-ACC8-4B79-9B3F-941A45D85BEE', '4605658195243', '  c  /19524/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('266AFBB5-C389-4AA2-8F45-E455BDB5326F', 'B23C0E8D-C3E1-4DC9-8E95-9591474FA52C', '4605658195250', '        0 . /13025/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA960629-F5B4-471B-A792-57B89259667A', '119680A1-A4DC-460D-833A-932C653C52CD', '4605658195335', '   4868 /19533/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('486D865D-E69A-4821-9473-BC1235675AD7', '34299AAD-7715-4BBE-99CC-165EDF1DD587', '4605658195342', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EBA2DF0-3F4B-4D55-8D97-AD8DD0CE545A', 'DD71CFDC-E599-4108-81B4-46AB15AAECF9', '4605658195373', '   /   /19537/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DE9B0B8-BC59-4632-A4A3-56F7EF38696F', 'A093106D-D803-413F-B2A6-F1977A89124A', '4605658195403', '     /19540/ 0+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5024ACF-AC9A-411B-93BC-AC28A5823A36', 'F55092F7-9F0C-49E1-B73E-D8725A690F92', '4605658195502', ' /    /19550/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98B61B09-4D78-4419-A5C7-B745958EEA48', '7B6D87D4-DF4A-4EF1-A212-8E000E221163', '4605658195519', ' /    /19551/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('735A4C02-6E37-4DE0-8E04-CC50BBE9068D', '2C5CAB44-15F8-4222-B4CD-6D11268D30FA', '4605658195533', '  / 0+   19553', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F924D582-0D3D-450D-AEE3-32271D4E0AE2', 'AA1420BC-51B6-496A-8628-37C39853203F', '4605658195540', ' /    0+ 19554', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1352118-4886-4226-AA57-7437BCAE5E8A', 'F0B6C589-EFA1-40DF-BE76-74B20347BA9E', '4605658195762', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85A2446A-2F1E-4C7F-8431-B3DB6889D530', '0EB951A9-4082-476D-A551-91D7705484FC', '4605658230074', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5379B2EE-9669-47B8-8EC5-7765E5246983', '3EA5FB30-BF14-4CD9-BEE5-827CFDD568DE', '4605658230128', '     4+/23012/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A485BB8-D115-46F5-A2C8-3B49B5642F12', 'FBB88794-7514-4DBA-93F3-9C9522F97ABD', '4605658230173', '  -   23017', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F8E608D-4DEA-4F81-B345-74CC993138E1', '6870FD6E-8C6C-44CE-855E-BEB29C6E3E7A', '4605658230258', '      4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('475F16FF-D5DE-4ED0-B7BF-B6BF5F8CC878', 'FDED68B3-8CE0-45C4-9126-D718F0D58098', '4605658230272', '  4+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('323A4D5B-858D-4B46-BD51-D3276EE26B6D', 'B3321924-2C41-4FA9-8D61-8CDBE0CB0179', '4605658230425', '   / 4+ 23042', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('580A43EC-59C6-4A00-8528-E90476E967C0', '00E2DE64-3939-42BC-93A2-1E4593282DDA', '4605658230531', '-  - /23053/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5654006-E2BB-487F-8441-7E828750069A', '6EA7A544-DAEF-4994-A1E1-333BD1E8866F', '4605658230548', ' -   /23054/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D073E532-E530-47BD-8291-2A4892A9C6CD', '9263A5E5-FC26-499C-A238-6D073CD4848C', '4605658230746', '     4+/23074/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DC4DDCA-42AD-40BA-8E49-EAD449A1EEAC', 'D2C70E5C-63F6-41D5-A3A5-8F925413D0E2', '4605658230753', '      4+ 23075', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('001B1F82-4C49-48F2-A561-B4BE378DD47A', 'B93CC026-4F4E-4A2A-AB8A-25CBA4B17412', '4605658230760', '      4+/23076/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1669DF7-22E8-460E-A308-3D555CF3C090', 'E7FDD3B8-47FD-400D-819E-35C219AFB4C5', '4605658230807', '  -     4+ 23080', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E28F12A3-4316-4AFF-B9D6-8AAF5238829A', 'ECF73D6B-B316-4806-9566-D7E8892F0B81', '4605658230852', '      2 4+/23085/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F62DD529-8370-4273-BE92-C0E40C2E4636', '7E0CB21F-7976-48E2-AD30-6E812801894C', '4605658230869', '      2 4+/23086/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE3235BA-1D96-4A07-97C5-1410D67971EA', '43C11D9C-ABD7-47D4-97D9-3DCA2FD75E9E', '4605658250393', ' /   6+ 25039', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23C51597-4D7A-4280-838C-51B3E0807430', 'BADB47BD-2DE2-43C7-AC58-9FF2D09AF1F0', '4605658251307', '- / - /25130/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4BE39D8-541B-421D-AB4F-50C44BC46F7E', 'B9898CF4-AFFA-4E81-AD17-511BAD24A33E', '4605658251710', '  /   6+/25171/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCCED685-4291-40B3-8BB6-D5C263EEAB79', 'BC4FED0D-D76D-44DF-AE23-22B2600803E4', '4605658400132', '   / 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5607002-085E-4BF9-AF56-F162745D1459', 'D0A15280-3F79-4F47-9047-F43E326EF33E', '4605658400163', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C02EB9DB-F9DF-43CD-85DB-0D119B61D795', 'A1ADA102-3669-40A2-B71D-8FF54092E8A4', '4605658400170', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E2D950B-4DB6-4BEA-9AFF-3B3B5655C698', '4ECF0268-8276-4804-8F95-0602DFD9B8B5', '4605658400194', '    10 40019', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83B4E461-F785-477C-AB4E-06CC8E9C7850', '6F50F748-9684-4E9B-BC9F-02215988BE23', '4605658400248', '   / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6326A534-E96F-4402-B741-430171296056', '531109D2-096E-4B4C-8F23-2B496165A86C', '4605658400286', '     - 63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD7131E2-D4FB-4DB7-A793-AC8F4F8CB73F', '674C9648-F44C-49DE-B826-C87DD4C9C2E0', '4605658400347', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AE61295-FAB6-4149-8632-B558D2AAE180', '96F70B2E-C6AC-470E-BB43-AAB79C963BF9', '4605658400354', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DBDA1DE-D158-447B-98B8-2456D5EBE6ED', '0E8645DA-9C4D-4D2F-838D-C330D07C54CC', '4605658400408', '  / /40040/ 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA799223-C495-4B21-A0BA-69EC46021F69', 'E59A05B9-B499-478B-9553-A9314F7AC959', '4605658400439', ' .      0+ 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E874D95-6D39-4C99-AA1B-493EBF12D249', 'CB8F2360-5000-40C3-A355-5D6267C6487A', '4605658400460', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A279B6A-EFE6-4EE8-86FA-AEA71852DF84', 'AC38D3A3-7D25-4C69-9479-33521444CAF3', '4605658400484', ' . /. 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEC8D4F2-910F-4DD8-B077-506A60ED120A', '62CF73B7-96E7-463A-996A-55D5AC1AF9F9', '4605658400521', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F4CBCD8-04E0-441E-A513-4C3042A545EF', '924E51DD-A8FC-4EA6-9003-A0917A98CA83', '4605658400545', '  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A18030F-A219-4A91-8840-9D3853E6614C', '5378630D-1DB4-48AF-89A5-34ECE3F5FF8B', '4605658400606', '     40+20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD64ADCC-2C3C-4DC2-BEC9-C899BCB67CB2', 'D7CBA265-B859-4B4F-8793-A28832F687BF', '4605658400637', '    40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B96C27F2-95A4-43B3-9368-DAEFA9379AA0', 'A24D7CCB-97B7-4B7B-B3A5-D764E73BDCF4', '4605658404109', '      90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFD80666-AEE4-4688-BD23-0FD786BE676B', '891941C7-61F9-4FA4-B8AA-9856DEC1D844', '4605658405052', '     /40505/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEFDA8C6-B6C7-435B-9676-E874C1024A05', '4D46211E-5842-45A1-ADB0-BD687F2B12F9', '4605658405069', '  /  .40506', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93130C27-046F-4B4D-BB54-267174BC583C', '44E05C6F-9C00-46EB-9908-B3340C5EF7B0', '4605722871516', '  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81778A55-90FF-4737-A0AF-8900B4D78A01', 'C4F7DFD5-D072-49E0-9F99-B87EB6E1CA43', '4605738000054', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('775E72B7-CC05-4965-8ACA-5E7268F51A6C', '86DA88DA-7747-450D-BEE3-9AC24F068452', '4605738000214', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B82D911E-8F2C-4705-880E-DE17624CD59A', 'D47FB9AB-0236-4AEB-A4FE-BABA2E8DCC0B', '4605738001402', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45A49397-DB54-4F9D-A08C-B69A0B4E6160', '27E9A6FE-FF33-4DA3-8661-4CEAE35E81F3', '4605738001464', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3D1CA76-2B8C-476E-A658-641A7F52C79B', '24249A47-B623-4007-BFAC-9BAA32A0A0A9', '4605738001501', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('016C2217-2A75-4B10-99C8-A33D97FA4E4E', 'DBDB36E0-BF44-4147-81E6-C12A0A950FFD', '4605738001679', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C651D279-B093-4A80-B7A5-A916F6B0DC8E', 'C68835B3-38A3-436E-9E11-469E8E9CB991', '4605738001686', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4C36AB7-FDA7-477A-9A04-379B7CEE6BAB', 'D7804E26-B114-4EAE-A86A-F9EDACEA19DD', '4605738001709', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4232666-6A02-4BAE-8029-C98EC0007A1E', '860D9B2A-CB98-4CB6-BCFE-2F56443016B0', '4605738001716', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7E38126-B840-4343-B1AA-36A72B90BA3E', 'BEDA2779-B8A9-42C0-8FDD-87F207E79DF4', '4605738001730', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('427F0E4F-9070-4434-B638-0618050C9D51', '7F5A736A-F749-4704-84DB-474EB6D29AEF', '4605738001754', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('737CCD53-9FA4-453B-A241-D3A6D80E46E2', '7B35B45C-596C-4185-B86B-68575F27CC60', '4605738001761', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25321560-E02A-41D4-AA3B-7468B500C6E7', '850300AA-6944-4EF5-BCD1-3227DAA9ACE2', '4605738001778', '    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ED62F6F-9DBB-4970-A285-23864A0B423C', '2B0CDF98-BD76-4C91-BE9A-3FBC1B0A9A7D', '4605738002911', '   /.   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEDAF68E-A593-4BF9-9B36-89A42227A4A6', 'A31B4EB2-69D5-40E2-A570-45E9C27030EB', '4605738002928', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FE6CCF7-29C0-4940-BC81-C4905A034AEC', '66F32A70-3E52-45DB-9EC7-CE1A89DADA53', '4605738002980', '    200 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('082D4BE9-5740-447F-AFC2-75C6E9DD5C8B', 'EF0377AC-42BC-4EF8-A64C-AF630C777F0D', '4605738003512', '   /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A303E935-1863-4F14-9FA0-EBCEEEB28167', '0E07EDA1-8242-4590-8C22-6C3CDD9F5C08', '4605738003598', '   /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC50B65E-707C-4231-B485-216D2B6B46FE', 'F7B47EFC-14AB-41D7-95DC-9E93F5ED9039', '4605738005745', '     4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59869546-1733-4C61-A2C8-12701DB9C676', '90BC7DAB-A1FB-46E9-8F49-C6E1A36225D7', '4605738005936', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('075FBEE9-4E3B-4C6C-8AA5-E6E7241B4E65', '767F9436-6386-461B-9E1D-DA79EB900F34', '4605738005967', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B09083E7-D0D3-46DC-8F3C-543EEE627F17', '8489F471-C231-4F7E-ACCB-692FAD3579F7', '4605738006186', ' 20 0,37', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFC4404E-8E97-4302-B0EB-FFF5F2598398', 'C0BE12F8-AE82-438B-847F-A48E64D0AB98', '4605738006513', '  /   // 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('827A2AC5-3E58-49E1-9CD0-C0EDC45BD326', '15D28947-B6B1-4534-9988-F188996E42FB', '4605738006520', '    /    7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('535C1CB2-9AA4-40B2-BE1A-AAA85CF27421', '97F0FDE8-A9C1-4D9A-BE79-38CF98910183', '4605738006537', '    /    7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A612A33-BDAC-4A15-9D09-B58942DFAA78', 'AFF5B0B2-6297-499C-B3A7-12F2B5954BFB', '4605738006544', '    /     7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFD44528-FCFA-464C-B448-1F9D620F1AB8', '379D086D-A3A6-412F-9692-73BDAFAA4FD8', '4605738006636', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E75E4F47-9D87-4D6A-9269-55D4FC61C045', '8B08D503-BF85-48BD-8CBA-DACF7402E3D2', '4605738006667', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E98A823E-0CDB-4E52-B17B-DFCD5DFC1CDA', 'C45EBB42-6746-4886-8324-26A5E9D9BFF9', '4605738006759', '  - / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0A7B638-F0D9-4EEE-8FBB-502133BD487E', 'ADCCF616-490D-403A-8392-A2C3D32DBE75', '4605839000496', '   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB6DB14A-DAE3-47CF-B28B-AB84F126590C', 'D226FFDD-E50B-41EB-B326-ECB0751FEDEC', '4605839000502', '    14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DE01C05-D57E-417E-8607-CD19CEA67585', '800E29B8-39F6-4B6B-AF1A-3D773DB29D57', '4605847001805', '  5%  - 10   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B6E4565-1017-4D16-9F21-DC53EBCE7CAC', '66F5D3F9-C86B-4EE3-A7AD-17A3BCF21C34', '4605890000046', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('369052F6-4A2F-41C5-A896-E07F38B64219', '7B3092FA-DB63-42D7-874F-B64320384CAD', '4605890000053', '   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFE7C019-90A0-45C0-97F4-6760BDA7804D', 'F76E2A89-9B64-454F-9459-C90C374A563E', '4605890000060', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66013567-52AD-4CB2-A75B-FFCBF20D3ABC', '19502C88-1E70-43E4-8A3B-18B14C1F8E3B', '4605890000084', '  - 140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2282D972-74EE-47A0-9D29-6DDF90EA5027', 'D3259888-914D-436F-B064-C3D4E9D7ED87', '4605890000107', '-   140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02539903-EF77-4B3A-8F6D-AAF64D8F86BF', '65ADAEC6-AADE-42F2-B638-C7E6737C333F', '4605890000152', '  - 140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('809ABD48-56ED-4120-ACA4-517B0D799F8A', 'CDABE383-7498-44DD-B42D-E6F8D4F923FF', '4605890000176', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0B43CE6-5CB2-4B03-9B91-4F7C40462F40', 'BCD708A9-BDA3-4036-9EA1-95FAAECD29FE', '4605890000190', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3CE3D94-E958-4340-B2FF-2428E28C70AA', 'F20AC5B6-54A9-4E36-B407-388724E2B363', '4605890000213', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84AA8DD4-771A-42C3-91C9-D6C56F0FF2E3', 'ED6974FB-4594-48B9-952F-40952B44A29E', '4605890000251', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EBEF7DC-E709-4596-99DA-2ED5F09B84C2', 'D8F3EA71-940F-4B9B-A18C-1FB5A6302A48', '4605890000398', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC858A69-0915-4E45-B619-060AB57FE30E', 'DEA734A3-A948-4961-9FC1-BCC925EC5301', '4605894000141', ' 0,005 // 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BD80CE9-DCA1-4348-9103-204465D8ACDB', 'D551738E-F481-4398-8DB6-003BE57DC9CF', '4605894000158', ' 0,005 // 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('479F2237-C448-4CD6-BD3B-F8E6C9064F33', 'CDB0FE5B-7363-490E-B5DD-E564208F1F54', '4605894000172', ' / 0,02 / 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EE387F1-9A05-4B06-8DF2-2AFC463AC121', 'CDDA67E6-B1B4-479F-AB8A-825EBE7D85B6', '4605894000288', ' 0,1% 10    /-/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB25C4B7-F55E-4E32-9366-6C81B8D53B94', '2B930B3C-E759-46F8-AA4A-7281B6CAE1CC', '4605894000806', ' 4% 10   - //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('635FA22F-AC03-42D3-B801-C15E63C2913E', '415A17AA-3E87-47B5-AB62-6B33A3382218', '4605894000929', '  0,25 // // 10 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00E9FF7E-9992-430C-BD02-11207DA53DE9', 'DC2B429B-90FA-449A-A4BB-279A847D72C1', '4605894000936', '  4% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6744BDC3-F921-4FE0-8234-3045B8760A08', 'D48313AB-F339-4B9C-BF8F-62EE988BE1C2', '4605894000943', '  10% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56889974-9C71-4FB4-8367-6E7A138C2356', 'FC963FB0-4CBF-4F38-88BF-B85EF7E4033B', '4605894000950', '  10% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1700A911-8D5F-4232-B016-0D41EE21EC90', 'E075309B-CCFE-4522-A71A-EAA345142CC3', '4605894001001', ' 2,4% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F52B0126-9F84-4679-B585-2E5E75F691E4', 'FDB085E8-A9BA-4E47-99DD-432EF5043394', '4605894001025', ' 0,024 /// 10 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04FD8F07-D7DD-4F0E-B402-4D3C2A5D8EF2', 'F9649F8F-E801-4478-9D1E-5425A3133F04', '4605894001032', ' / 2% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20A0BB24-3C68-47C1-BE97-4D51BAD27AD0', 'CD4F275A-68F3-4EBF-AD8E-EB72C511FD3C', '4605894001049', ' / 10% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27F93E18-62BA-4199-A6B1-B0A8C3C2F118', '2C0B53AB-684A-4478-84C6-3890CDFB06A4', '4605894001094', '  0,1 //  // / 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E191CA40-6775-4CC8-B1A2-57C48D687416', '88E0DDB1-CC8D-4B70-ABCA-C46C49D3B552', '4605894001261', ' 20/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29D0FBEC-2FE0-4A22-857D-43C4657BB79D', '5882D524-00D6-4A98-ABEB-055735207EFF', '4605894001346', '  5 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50E1286F-B49E-4144-832E-31FCA8580C65', 'BB02085C-61E9-4D6D-8901-7EE678C708F9', '4605894001377', ' 0,05 / 5 -  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AD174BD-3760-4050-959B-B61F1071DA6E', 'B878EA8A-0D4E-4231-9DF3-802B9D82771B', '4605894001711', ' 25/ - / 3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CA8F067-21DF-4301-9242-189EA61CED8B', '3FDB6EB7-513A-422C-88AD-86024A48223D', '4605894001759', ' 0,4 /// 10 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D78CC2FE-359B-459B-966E-1E0C6B3C311B', '904E50EF-9AA7-4883-AA97-6AD5DECEB9EC', '4605894003746', '  0,9% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E63CD13-9A2D-46A4-B179-CD3385B2A2B5', '108ABE3B-1C0A-4590-8DD9-0757B9C9B057', '4605894006624', ' 0,1  /- /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EB4754D-6B08-4A9B-B62D-EF517CBF0CB8', 'CE398510-70C3-4522-AA15-8DA3CB27C08F', '4605894007287', ' 100 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A38FF231-AA6A-4E72-848D-72EAAC00F707', 'F2CFBF66-59E2-421D-8F3A-A886E422EA4A', '4605903000995', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA7CB594-9D34-4F0E-9444-BED3A2F612AD', 'E32D72AC-8C71-4F1C-A4A5-9A76FC474FD6', '4605903003002', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A9B7A52-DA9B-4470-AEBD-99262E38A8B7', 'EF24A2BD-A405-4E2B-AE03-DE707AF3C78C', '4605903003996', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('619581DB-2E2A-434E-A458-0B12DF0E4AF1', '9290514F-726F-4120-8C63-4D59787C3852', '4605903007437', '  3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F9EEC01-1345-4FF6-A4F1-5B298C1B1684', 'ACCDC08A-F07E-4EC1-93B3-663449015DA1', '4605903007932', ' 10% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0232C8C9-CAA2-40CC-9779-402F95B6846A', '93973185-7D33-4398-9D7E-9C6D9E2AF461', '4605920000138', '  200  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19D3236E-9F45-4AE3-ABCC-0E17852DDABC', 'A3FDF45B-9008-4FC4-855F-2263621D6154', '4605920000169', '  200  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26F2EC40-ED60-44FE-81AE-2168958C91B3', 'BD39BB0B-9E26-4BFC-8F02-CDF2587CAB42', '4605920000176', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBA50D3C-79F6-43A2-BDAC-CAD6AFEE6B51', '2AF5FD97-C91C-493D-ACC8-0096734EF24C', '4605920000220', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90423582-C465-4F87-9609-AFA1420D9CBD', '1FBE8C03-D474-4234-AFF4-2B8FD4550B14', '4605920000237', '  100  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('312C932D-3CB3-4973-A3FD-F8ECFB7C867C', 'F4F93710-BBCD-4E65-8433-C0FBF8F7AF27', '4605920000244', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3680C36-1445-49BE-9F21-BEFD8400415C', '6678E381-9A26-42B5-AB7F-9A2683ED1B70', '4605920000251', '  500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F24DDE0-3B66-4B0D-B393-3811D595B58D', '52C3D3B6-0DD0-4CC2-8DE5-7E5889D9C546', '4605920000282', '- 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B3FAE0B-F12F-4D3E-9C09-FE1035FFEEE4', 'CCCA1C19-414D-4182-847C-8D4C32168E5E', '4605920000299', '  0,205  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA360CEA-1361-49E0-9B63-DED9C655EF8F', '67CD44CE-BA40-48E0-B938-648E5FECE7DD', '4605920000312', '  205  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47CECE74-8030-47C9-99F0-32B2944D60DE', '55DBD3FF-6F6C-4A98-B2F3-B8030017D7C3', '4605920000336', '  200  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBA58B51-CACB-4D27-A814-70D41700728D', '3583DA75-2677-4F22-B6F9-BAC90B123CF3', '4605920000350', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2093E15-01B9-4B56-A6A8-8628009F808F', '7E2DB1EE-522B-4C88-996C-F50C2E2F2813', '4605920000435', ' /++/ 0,18  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B646AE75-6E49-4A10-A451-3E30C18A35A7', 'A600F90D-F6A8-4622-A66D-EB24021B2DFC', '4605920000442', ' /++/ 0,18  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD6799A0-05E3-4C98-828A-372E338B50DB', '2A7E4865-124E-44FB-B1A3-290C6F0BF3A9', '4605920000459', '  +  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE3B9E41-0A26-43C3-B5EE-1CB8F746C9C9', 'B51BE5A8-1956-49F0-A98F-F9B8CF771B87', '4605920000466', '  0,45  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71861303-361E-4A26-89B8-D0643D67DAC8', 'C30FCF16-8A53-48EC-9446-3B74CA51807A', '4605920000503', '  /+/  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('105438FF-0916-477B-BA4B-4B9297902716', '2ACB14EE-805B-456D-A566-8FD97B8864ED', '4605920000541', '- /  /  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A02308FB-1CE3-41C3-A230-55F6B23E1D8D', 'EF4C81B5-CC05-466C-A736-F20995DF2B36', '4605920000664', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC3CD29E-D9A5-41CC-9B60-F542332463E7', 'CEE5779D-2FB7-4788-8F20-9B61DEFE36CC', '4605920000671', '  +  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BE904E3-4F58-43C2-AD4E-89D7A0807DC8', 'D4660357-D169-4591-8660-AD9D4F729847', '4605920000688', ' /++/ 0,18  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF4207F8-D24E-476E-8D8E-C1AEF31B3105', '10DD5EC4-05E2-446B-9BF2-64B14159C248', '4605920000695', ' +/+/  60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9906D1F0-F23D-4299-BD7A-F716A4E4D89E', 'F9F4EEEC-463D-447C-BADF-CF84ABAE7311', '4605920000756', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FE50038-2996-4492-9238-A276370CEA5E', 'BC058CD9-BB16-4ABB-9E5D-426BC369A164', '4605920001593', '  200  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5562C91F-A1F3-45DB-B5EC-411E4F98B8CA', 'D67CBC35-05A1-437E-A657-07A29DCBD001', '4605922017455', '   /     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF1DD0C1-C364-4DDF-831E-AA1507438798', '0B84ACCE-1D98-4B36-BDBE-95F4CE48B1DE', '4605922017998', '  - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F407E7DB-6AE9-47B2-A246-A76F2A8F8D32', 'EC7C0A63-DDC5-4C5D-8EFC-9131C6AB7112', '4605922018001', '    -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B37054EC-A3A8-4AA1-9D3E-17DF98A15B30', 'E5D73967-2E25-4736-A563-CA75360835B0', '4605922323327', '   /   101 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97BA86EE-FBCA-4AF4-93B7-4ADE1C45DAAB', '787AD146-4D3F-4A88-9289-AE02254075B3', '4605922323495', '   /   101 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8098D9D8-1F85-473A-A06D-996C14BA32AF', 'AAA521E6-E64E-4B59-8F55-1B3E260025DD', '4605927000063', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED0746BC-ADD2-4594-B2AD-4C90B6AFEFB6', 'DFECCDC0-ACF0-4E80-892C-E253CC6CDDB9', '4605927000339', '    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6384773-5C26-489F-8267-61CCC8C905E9', 'EC7C5023-3C0A-4B14-9DC2-4837B8650B49', '4605927000438', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5DC6A2E-F1C0-4C8E-8368-7B614A2EBA0F', '5FEE782F-0B98-44B2-BD43-78C84B1C07C5', '4605927000445', ' // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78C5B809-461C-434D-9C43-FEA9BC225A60', '224CFF48-A046-447D-A2F6-254B42BF9678', '4605927000469', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCF44C36-0CAD-4180-8676-81B733158095', '5D161477-B923-478F-A392-6788FC55894C', '4605927000513', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC7D2D60-345F-49CA-8C97-C2E90129731F', '51C26073-C519-4A7B-9A11-644CDC906FFF', '4605927000520', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB335717-663E-416C-B296-A82EB89C9F81', 'EDA29891-9A88-45D0-A6E3-C61978DF86A3', '4605927000544', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E0056A9-7416-4D59-8C48-7C55EEAC928A', '7DEE5E98-8336-438C-8298-FD6E0A639692', '4605927000551', '       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEE8BDA2-A0E2-42DD-BA4F-FBEEF858EC63', '60EF62F6-5E35-4AFD-98BE-ADF9062E3E48', '4605927000568', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAE59B54-F4F5-48CA-964E-2EED9953BC1C', '88CE9495-7E63-4AD3-BAB0-8494BAEE9728', '4605927000605', '    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49554785-2CBF-4634-ACD8-498B2E471F16', '10258651-68E9-49B2-B8B3-BE47AF8ABAF8', '4605927000674', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4B294F9-9AAC-4263-8C99-3A3D8B44D2A4', '3F307207-BFCC-496A-A57E-65B2D64FFE7A', '4605927000728', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F82D329-92FC-45C8-A455-D6F3DC041CED', 'AAA521E6-E64E-4B59-8F55-1B3E260025DD', '4605927000742', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D83F3AEE-56BD-4211-9804-F59FFBA6524D', 'FD8BF25E-3A8B-47FA-A8FB-2C9D99798608', '4605927000797', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A23DEF2C-0F83-43E5-AF33-4F65C55996A9', '9747D863-7CA4-4575-90AF-5B8762A455B2', '4605927001312', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92B3059D-4422-42F2-B7C4-7D2B553E565E', 'B1D26141-FD4D-4F21-A3DF-F81E3F04A3C5', '4605927001329', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52D42A83-3323-4249-A3D9-C4A4345F799E', '752C9437-0AFA-4061-94C4-63A04D241704', '4605927001336', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7745C64-4C79-4D39-AFB8-8E57003A5CA2', '0C56AF90-74F0-49BD-8534-85395592A3EA', '4605927001374', ' // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4BE712D-9CB8-4FB3-9077-5CB593678141', '45A39D9B-82FF-4DD0-BB1E-2112E1DD17A4', '4605927001428', '    3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('532AE99A-312B-41B2-B749-E181ADB58EA8', '23C642F3-5D29-4B0D-B4E3-A62C13AA8ED8', '4605927001435', '     3  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98A17F30-847D-4A8C-A83A-D3767282CE6A', '7F399775-7FD2-4550-82B4-D6E88ED55501', '4605927001459', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB927D8C-7B21-40DA-A4DE-24B6870A64AF', 'B358E300-875C-43AA-8423-C058A34C7139', '4605927001510', '  / /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D44B8C1-6D53-4C5E-9EAC-49E8728B444F', '010B3AC8-49A4-4A9B-BEB9-E6EAA387231E', '4605927001596', '   3-  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62942D36-C4C0-4CA9-A0C5-2E58455DDD73', 'D4E64855-E8E5-49B0-B79A-6F5C915E69E7', '4605927001725', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19FCDD40-913E-40E9-9DCA-140DCDDD3479', '792B730F-4DDE-4033-A2C8-CD649490B3A5', '4605927001770', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FC9050C-E41C-4D9A-B096-6FF381B89EC6', 'F39094CA-19A8-49EC-AB71-79977706365C', '4605927001787', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97AE0212-D8EA-4104-958F-38D62F3C4218', '743A1696-4931-4AB7-80AC-29EF4C406FA3', '4605949000089', ' 0,02  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED42D7E4-5665-41AB-8E87-5366EE1D309E', 'EA7C5695-9725-4864-9674-7543449549DB', '4605949000119', ' 40  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48DE09F0-81B6-4978-AF41-AC35C0AA3B7F', 'EF1A9ADD-E06D-4DFF-9A64-5F6D19C4BBC4', '4605949000133', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C948D5C-3370-4200-A1B1-F2B8F04D1570', '9EF4DD36-015F-48B1-AB8E-95EE7983DD75', '4605949000164', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2F84DA3-4DF8-4E01-8BFA-71645B95BA25', 'C75645A4-CEBF-4B43-BB67-D93652D05D88', '4605949000256', ' 50  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6EA2ED7-C7EC-4D70-9B0D-36AE4E762CC6', 'E9ABFF26-DA98-416D-83F6-AB48FA73ABBC', '4605949000775', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDEC56E6-4A20-4A46-B263-B247AF0C6083', '4DCDCA3D-AD4E-4C2B-9701-C85EBAF64D69', '4605949000942', ' 35  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA6AAF9B-DEFA-4874-8EB5-451DD0701084', '1841280E-E0CA-4AC3-8808-081BA53AD576', '4605949001222', '  150  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58E3EEBA-0289-4EAF-9E45-9092AB22B835', '9A2F1AD0-3B0D-47F9-9EFF-CF5775906CC0', '4605949001277', ' 1,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD8EC85E-6F8C-496A-B35B-5258A14DEC51', 'AAD0356F-F10B-4F36-B29A-E91F52510CDB', '4605949001352', ' 0,005  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('546FEFA7-B27F-4269-B2F0-2ED4185F215B', '4A588138-BB2B-4FA9-8259-EB52D3CCCC06', '4605949001437', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85E5A4F7-C7FB-4EA3-BC29-D39D91E03772', 'F8B7485F-EEF4-4B1C-B47A-8EADB97857C3', '4605949001468', ' 500  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11A7C6E7-017F-457D-8B75-09EDBDDF25E4', 'ABB9962D-DE46-48C9-9C69-A8F2A8D498C1', '4605949001482', ' 100  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('995B4382-0903-4CD4-9662-0EEF40D10812', 'F992E8CF-D990-41F5-A6E8-4049B2D5D0CF', '4605949001529', ' 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('445818C9-4B77-45F4-B36D-84902829BF02', 'AC830E14-876C-4FD6-9F7D-0143630C5DC7', '4605949001567', ' 25  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA36BB0C-DE47-4FEB-8B42-5E8C45614DD3', '749D94D6-D1F1-41AB-A61C-01D430163E75', '4605949001581', ' 50  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0AD9F8E-F69B-4A86-A2DB-F71E261DE5D9', 'D890BB6D-6A48-4DF9-95FE-D6E1409EB285', '4605949001789', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AFD663C-5BA4-4726-BFE2-9CE7C88E6661', 'AE75AF0B-4021-4126-B5E3-889B517EA8B5', '4605949001796', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0D0495E-E82B-464A-A2E8-1F7A134B35C4', 'EB3D9BA0-7FAC-4D4D-9883-7F2D457117C5', '4605949001802', ' 12,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90B23EDD-3669-437A-87A2-A752B29CF715', 'CFA793E4-3699-41E4-8F2B-F0F6017194F1', '4605949001819', ' 0,025   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30592303-DA74-4DD5-AD22-AB053EAF57D1', 'E1F6F4BF-CB11-4AAF-ABA5-D7916E6D1600', '4605949001826', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB566BD8-D3A4-40B3-9C13-710C3FB06FC2', 'B59F9546-4571-4914-BE36-12A77A271AEC', '4605949001871', ' 0,005 //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6B2F677-B547-4BF6-ACB9-DE9DC049D9D1', '00A8D1AC-93CB-4C22-8F5A-0B1707F4B868', '4605962000165', ' 0,25% 10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E65AD62-56BB-474D-829A-B59B99DEA483', '4D05FD81-39F8-4850-AD49-656ED0221382', '4605962000349', ' 0,25% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF79127A-1A54-4D7B-BEA7-FB425CC6D045', 'B9423416-9CE0-49BC-8BA3-3C6A356E9394', '4605962000387', ' 1,5% 5 - / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA0686A9-119A-4342-9FA2-A590AB1B80EC', 'E2FD6883-DB3F-4B04-BE91-888614F3BA26', '4605964000378', ' 4  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CEAE00C-FCCD-4ADC-9D3D-A6CBD47EE883', 'EAB96D9C-8A06-491B-95C5-C3597EE1F5E1', '4605964000880', ' 500  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A9490E3-F1A9-4A2F-B80B-293AF91A4940', '38E776CB-C957-495C-B5D8-C5D04B32C3C3', '4605964001085', ' 25/ 3 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E69E12C-12C5-4984-A484-1E428DA3CF94', '9EA7E545-C41D-434E-8D6A-98CC27D91D69', '4605964001474', ' 2 - / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D41091E-A7B0-41D6-8ED2-E9C7DF9A5425', 'C75645A4-CEBF-4B43-BB67-D93652D05D88', '4605964001764', ' 50  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1421ED4B-3499-45EB-8243-BFA229B3972B', 'A54F153D-D731-4DE0-9764-94FB5343A75C', '4605964001924', ' 40/ 2  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7373E7D-D195-4319-BA7C-F153A2E65C00', '72173CBC-3C05-425B-B7A6-572851E1300D', '4605964002211', ' 25% 4 - / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9631FA3-CF9B-4A55-B907-A15E597800DE', '16466FF4-63ED-4107-B05F-FE815289BFE8', '4605964002259', ' 40/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1E95BA3-3EE6-44A9-A1AB-DD01E8F7F355', 'F0EAD5B3-581E-4C82-80FF-99A34FD76865', '4605964002686', ' 0,01 / 1,5 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD5B1D8D-135F-4313-B09B-365F1849B30E', '04E062CD-7BD2-4A43-AC10-5A6EBB2D9C4F', '4605964002747', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('182B1FE7-1277-4863-B0FA-77D7B9E4D960', '57FF7EB0-5378-4AF6-A42F-0B90249A8ABC', '4605964002785', ' 25% 4 - / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A940E785-11F9-4D10-82D8-F8CC5D435D53', 'B6434C0A-2B20-469A-9E9C-2832A285DD38', '4605964002884', '  2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('226B7727-4DC1-47A2-B2FE-2A1411F628E3', 'CF1BED4B-DE21-4B6A-8F1B-C2538A1BED6E', '4605964002891', '  2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AE19188-C480-4CD1-BB00-BB99DDF23779', 'F1D61D74-7C43-4A79-A55D-04BE629DACE6', '4605964002983', ' 50  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A6868DF-B51C-4091-B777-895166E1161C', '4F42C2B3-90CE-4357-8392-1E8241532FC7', '4605964002990', '  // 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1653BC16-7D9E-4D6C-867D-8E7D87B07C5C', '442208DE-6F46-4EEC-A334-754A8910B0E0', '4605964003003', '  2 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06DC7530-2F56-4528-A259-2004CBFB151F', '5B3921C6-1CE4-478A-AE29-31F14F261ED3', '4605964003010', '  2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0226BE5-E85C-43D2-A5BB-2C9BB25F78B6', '7C626A00-1D4B-436B-BB76-CEB8AB40411D', '4605964003041', ' 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45D8E6BC-76BE-4D50-8285-EAC0313F63F4', '6469B043-A377-49B3-BB85-539D3ABD4B97', '4605964003065', '  100 1    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ECC8116-0EE7-442D-ABD6-742A6B387798', 'A24678B3-1926-4FC5-9D96-9E02B41D9418', '4605964003096', ' 0,1 / 2 -  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD887DC7-6D4D-40E5-AB86-B899FEC620D5', 'D15DA236-8DB1-41DC-98E3-E8D67DC9A78C', '4605964003102', ' 400  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8028BE85-63A9-4CAE-BF24-77CAEB1CE753', '17B683DE-29C8-4B53-81CD-A26301BDC49F', '4605964003119', ' 400  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EEA9004-10B3-493A-BB67-04DCA34566D8', 'DBFB0845-9D5A-40E9-8ED7-FD1F7F2481F0', '4605964003126', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41878FF0-ED0A-4ECB-8EDB-17B97C1249C2', 'B5DB8E11-B252-4C5F-AFA4-A9C0F9958A95', '4605964003133', ' 15  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48498B91-E059-4ED3-A651-9E4ED38D4FDF', 'EC4F2A51-AAE1-4A10-9430-B7D22FB6BE46', '4605964003188', ' 15  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83AB41D5-4022-4329-A094-29371BC0DCFD', '2975883E-FE94-4FDC-8642-2C65FF4A233E', '4605964003195', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAC1A1A5-3DC8-4942-B157-7D920FAB35A9', '4565950F-1BD9-455A-9FB8-168DBF509579', '4605964003201', ' 50 5 / /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA5329C0-7C36-4B13-BA85-F25B8200AD4F', 'C0B036F7-CB5A-4E18-90EB-8E81C6BC3D15', '4605964003287', ' //100/ 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4FE81C0-04CA-427E-941E-B7CA9714889C', '122368C4-4AE6-4961-B39A-7283D26EFD37', '4605964003386', ' 100/ 5 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('016AA736-44A2-4783-9698-D17B70210244', '12C27D40-520E-47F2-8CC3-B9888CB0147B', '4605964003447', ' 0,1   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33F8F187-9A3A-428D-AFE6-82E33B4D1E5A', 'F55781B9-37DA-4667-AC4F-F3EF045C1FEE', '4605964003454', ' // 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ECC31BA-92D0-4C43-A175-E64F3A94EF05', '09F85EA9-D2EE-41F2-A5AA-C0F9CF4C398B', '4605964003485', ' 50 2 / / -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C86EEE8-91FA-4493-8D3D-6C3E046D4D0E', '8B6478A3-B136-443A-BA75-ABD332BAB3AB', '4605964003607', '  35  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3E0BBB4-67F4-48B8-B594-19961F4DE850', '48758B63-C8EF-4465-9D9A-81556D98E163', '4605964003645', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B92FF92-CEAB-49A2-B74D-744A7AD16969', '88EA8FBC-F2F8-49D5-98DC-EE5405E7B97C', '4605964003669', '   5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE0D9AB0-EBE8-423C-B673-810C50AF8E43', '9C3A297F-2559-4824-947D-0E3EC03C7E19', '4605964003676', '    5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71615733-EC18-4D21-8968-E9B6A28491B2', '9EE85B19-C4F1-4F73-9119-E81D2D6F06EE', '4605964003744', '  5 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F576B93-6646-4A44-AF4E-2882A4D90D28', '34590794-D0A8-42A4-9919-0B48A267AE1E', '4605964003751', ' -  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F58F5F6-4BA7-4878-99FE-70E2493809BD', 'D61601CE-FA8C-411D-9E43-A2431B5B087E', '4605964003829', ' / -  //   5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0248817-D709-4CD1-A7DD-8832FA08026C', '8826394F-9C18-475B-BE8E-256D83F841D1', '4605964003843', '  //   5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9D45263-724E-4FEC-8C7F-9C40002133E3', '9FFD1113-BAEF-4511-A7BD-B546CCBD9D2C', '4605964003850', ' / -  /./   5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E753172C-91E9-485D-B83D-32793EBAAF3C', 'D1549199-4A45-4CD8-B12C-D379E6E3694D', '4605964003881', '  5 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('131B6FAE-3727-432F-B07B-8704CF53C337', '8C76BA8B-A69E-4C60-ACCB-8BF47ED00B74', '4605964003898', ' / /  5 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14F1C2FF-AB83-4E16-A98B-BCB99897223C', '7A515A01-8948-4305-A06A-47093B63E1E0', '4605964003904', ' / -  //   5 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C034E6C2-39C3-4700-99F0-051C22C13975', '3A8DE467-396F-4A86-8ABC-9F6871A8920F', '4605964003911', ' / -  /-/   5 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F772AE92-3FDC-46B8-8D78-3A25A46F04AB', 'D1BFD4DF-687E-432A-ADA7-0D08DFAE7E82', '4605964003928', ' / -  //  5 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B15B8CB-F3A0-42DA-B773-B5DEC5F2D59E', '06A0A269-75E7-4431-AA14-5F2BCED80C68', '4605964003935', ' //  5 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E792FA39-9058-440B-A4CC-4788D1720BCF', 'F7B33774-9759-4851-B09E-43B78732F1AE', '4605964004215', ' 150  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABF5F449-D876-4D16-AEDE-BBB95448440B', 'EAB96D9C-8A06-491B-95C5-C3597EE1F5E1', '4605964004444', ' 500  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5549AD26-EFEB-46B5-A46D-7D6525183D30', '75B84631-FE58-4F72-8195-B2C97EE8307B', '4605964004611', '  //  5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DEE8479-CE79-4660-A93E-0BF6A1E157C4', '96BD1103-78E0-4FC3-B312-3F4EBE824C35', '4605964004628', '  //  5 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D08A6EAC-0A88-4787-9939-99870EF22C2D', 'E9BB88F0-FE49-462E-A5FA-F580989B59F7', '4605964004635', ' / -  //  5 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23265B3F-35B1-4B59-9226-CC1AA10AF16A', 'B198925E-882E-402F-BEC9-750928450BAD', '4605964004659', '   1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C081BA60-B64C-4669-8D1F-0824A6E72308', 'ABB1AC42-3B3C-47CE-A189-2339414E7E1B', '4605964004666', 'c   1% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90F0F31F-0F74-4D9D-99E6-FF3305790A98', '323B870C-5113-4408-AF2B-B25C806D24D9', '4605964004727', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ACB89A8-AC78-406A-9244-E907D8E91124', '83F43677-D51B-42C1-9448-4F4791BA9D78', '4605964004734', ' 10  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('363BE65C-77AD-4EDA-94F5-3739E7ED7994', 'CE8D4C52-16A6-4844-81A2-8BE38FA3DF55', '4605964004741', ' 10  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70B1B9F9-E9DB-437D-A53F-41DC0E190141', 'E2FD6883-DB3F-4B04-BE91-888614F3BA26', '4605964004864', ' 4  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A1C08C9-6290-460F-AF0A-CA71931D74B0', 'A3E205E3-D25F-4A91-8C24-F346219A5D2C', '4605964004871', ' 0,008 //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7234F7F-948E-4F78-86EB-83A42B7B3BE1', 'D7BB3A2E-BECC-40BC-BE8E-B88FA0BCF464', '4605964004895', ' 8  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AD52A86-39F4-4E6B-A989-9C0870168E4D', '976F306B-242A-4B7F-8366-AD8118E34411', '4605964004956', '  25 /2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('889A75E5-9634-47C2-BABB-E672E4CB7DA3', '652F3092-7028-4FA1-AB3F-F927493AEC65', '4605964004963', ' 7,5   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('989F1CFE-1437-4F23-8079-37EBB0E0BC1E', 'FF0D648C-7E52-4BF5-8B77-84E523B5B2C0', '4605964004970', ' 0,015  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13B00FDA-2BDB-472E-8D87-61FAFF98D47C', '245074AC-ED6E-4DCE-A4E6-3B8C2BC33CD6', '4605964005182', ' 125 4 - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D610240F-5D9C-480F-85DA-A98FF5F0815B', '1C795314-A05B-44B6-9407-C28295B7B87B', '4605964005212', ' 250 . 4 5 / / - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F73F02E1-DBF7-4F39-AF65-8AE3CE17FC96', 'FC664FF2-2B08-4ED3-9F3E-C2DEEBBE9352', '4605964005359', '  200 2 / /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DBB1609-344A-4B7F-9BDA-C05823C2D9CE', '357978A3-D7C5-4600-8EC0-B54DE66E6726', '4605964005366', '  25  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA5D646A-50D9-46DE-BC5F-31B54789230E', 'E10B3228-8252-4604-83BB-7D4FCA7DBC35', '4605964005625', ' 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDDA1F0E-7CF2-403E-854A-404B8272ACC7', '06AF283B-DC21-447F-879A-6CCA468E2EC3', '4605964005861', ' 0,4  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0235AC31-CE3A-4F94-AD54-CB480008C452', 'C0B036F7-CB5A-4E18-90EB-8E81C6BC3D15', '4605964005922', ' //100/ 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A9268AC-4DF6-4521-AD25-BC0A83E3E752', 'C4C7AD65-844D-430A-9C29-CB20FFAB5C8F', '4605964005984', ' // 0,0025/+0,1 / / 1 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59D1894E-57C6-4320-B29D-35D5DD8D1AA0', 'C4C7AD65-844D-430A-9C29-CB20FFAB5C8F', '4605964005991', ' // 0,0025/+0,1 / / 1 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76809E40-35A0-48B3-B1F3-BE86E5E01BF4', '83CAC658-FB58-4F1A-BE5C-44DA552B2188', '4605964006004', ' /  100 30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61BA0A9E-7A01-4F53-8A3F-43F18F0823A6', '9FD99132-FCA1-4F13-9BB1-96E10E3FB2F9', '4605964006158', ' 0,1   / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2225C1DB-0D36-4827-B71E-9BF2F9C2A237', 'DCCAFFCE-B7D7-446D-9F1B-B3DDEA002DF8', '4605964006172', ' 0,25  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C976868-B711-4D54-B589-C029E62A74C6', '8170CEF8-ACA8-4BD8-8BFD-53742DB4ED08', '4605964006196', ' 100/  - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66962C16-20C0-4B25-A333-529C1BBFAE53', '10FF636E-2F93-4334-A702-EFCC4CB94113', '4605964006387', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD5669B0-4B53-4600-B691-D6BE88CFF2AE', 'A0B6E0F7-0F7A-4A2F-BA85-FDB08B0E53CE', '4605964006394', ' //   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAD954AE-E036-40D1-8F8C-3FAFC56EA32A', 'FC664FF2-2B08-4ED3-9F3E-C2DEEBBE9352', '4605964006417', '  200 2 / /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA489177-4172-4313-9E09-626B65C12400', '83328E97-D6AD-4DB9-B131-19BB1CF789BA', '4605964006677', ' 100 2 / -  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BCD4CF2-0852-4ED0-8B34-5EED33B6F356', 'D0A10F76-9E54-4574-A916-58285064E9F5', '4605994029073', '      20% 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98B22505-CD81-4441-BFCC-C8AE33CFAF5F', 'CD81FDA2-14EF-448A-A4AB-A488C0979909', '4605994029080', '         30% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5D455D4-5510-46E1-8F26-F899687CCB2F', '5B8643E4-037E-4478-A28F-DE003B4902DD', '4605994029172', '        30% 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2A534C1-70BB-44B8-A992-F24286EF8E3C', '855B1EF4-D0E6-4C6B-BC72-9A09E3D15D38', '4605994029769', '    /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AC1EEBF-7895-4BAA-8B39-A04CDC7EF729', '2B893507-339F-4678-8A0D-7CFCDD23F346', '4605994029776', '        30% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD98C115-D762-4B04-85E1-8372AEFAE4E9', '57A4382F-E3F2-4530-82E0-C0A4395D9B4F', '4605994029783', '       /       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3697D303-FA94-4C5D-9094-BFD9FB870062', 'D6D979E9-FC4B-4EB9-89CD-42B7F8047F83', '4605994029790', '         /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3519F688-F0B2-46DD-BF52-D0ED221421E5', 'ED0A8BA7-7524-4FE9-8557-25673A589A53', '4605994029806', '       /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('278E3784-3F65-461D-8BAE-3AA790023C50', '587E007D-A2ED-43C2-A021-56330CA666D6', '4605994029813', '   //      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7B785AB-97A9-41AF-BFF0-0EFFBE582280', '9FA863C9-32AD-4AFF-83A3-245862A1C714', '4605994029844', '        100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D113182B-0025-4CAF-9A1D-06FF67F76DA4', 'C39B7741-F364-41B4-AC35-06EA14E698B2', '4605994030482', 'Dry  forte /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99FC0218-5D0C-4813-A021-4714BCE38F22', '90E4AF6A-DF4B-4CA3-819A-A74239456EDF', '4605994030499', ' .  /    / 30% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF2CF303-90BA-4C3D-869A-95D69FCCC3C7', '7CFADC7D-9094-4007-B3A7-CDC3934C71F9', '4605994031250', '  / 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('534A5A6E-A658-496C-BB24-0D58030A1C68', '5863348F-59B0-4F60-BB26-01A3BEE348C8', '4605994032011', '  /     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('432285FD-65C6-4A73-A3EA-589A2DDB444A', '16E4F9F2-37C9-46ED-BA3B-CDEF1F9BECE6', '4605994032035', ' /        60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('753E2BA7-2898-43B3-908A-28DA6FB444AD', '7EF7EBF0-4F74-4FE8-BA34-E8092800977F', '4605994032059', '  /        60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5F00FEB-344F-4360-95A1-71CA2CB16674', '3C4CB001-9BCE-40E4-A614-439CF4A81F61', '4605994032073', ' /     - 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('660361CF-2988-4BE4-B675-19CA1D3B0338', '67A81090-87FC-441B-BDC0-9A0288AF2AB9', '4606144002113', '   /59964/ - . . /2+1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6226DAC-9078-4512-9B5E-61151E9C861A', 'DF58FC51-DA7D-4663-AEA1-97DE7E408200', '4606144002618', '   2+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDFD8EDC-5DBD-4F75-B111-0EF523605A5A', '96389C7A-CDA2-4BE1-BC05-9CCB78DF5A0E', '4606144004902', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2302921-22F1-4B60-AB56-D0B29F661114', 'D7843C00-F7F8-429A-99FA-9AF9A402B058', '4606144004926', ' /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B81D101-142D-49AD-8F42-D38DEFE23C27', 'E4B3E2AF-D856-4E27-A60E-713C5182FB59', '4606144005565', '    / //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2D54015-18B9-4661-B092-16F0ABE9B53F', '1613B2FB-628A-42FE-824B-49AA856ED9B0', '4606144005695', '      1+1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EC2B9F8-0991-4C8A-9378-73962E6B9FF2', '8623FB3A-1E2C-4CA9-87D0-FCAADE5D0E83', '4606144006159', '    12   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC0152DC-7221-4DF2-97A1-0B8931AFD56E', '4567815D-ED71-46B8-8E7F-F04596D8300C', '4606144006487', '  smiles  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9CDC7CF-64F4-4070-AFA8-F34CEA004156', '85C1C9E3-DA9B-4513-9983-CFEE96D7B482', '4606144006548', '    360   /fcn10035/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7025089F-ADDA-47AE-A5BD-01C43F92B8A1', '1FE08D67-CE59-4156-BD4F-8FACF2DA16EF', '4606144006920', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9127F9B2-F15F-48EC-B6B7-EA829E9B6EFC', '6B28D663-9BB3-4161-A232-EE9765FBF359', '4606144007347', '   360    /1+1 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E543DE9-F87C-47C0-B28F-D45D8C4B1C18', '931BEDAA-5686-4243-9497-711214E1CA04', '4606144007743', '   2-5/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('780E71D7-C8C1-40BE-A6AA-A270559F619F', '4B9E55F5-00E9-424D-8414-91C15591D858', '4606144007811', '   . spider man ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('364C27A8-9AF1-4C55-BF82-32F50E330EDE', '85C1C9E3-DA9B-4513-9983-CFEE96D7B482', '4606144008207', '    360   /fcn10035/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CFF694A-B5BE-419A-BE65-E8E44C58528C', '01854D28-028C-4208-851D-5F444644F539', '4606159000036', ' 0,3  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA2157DD-5C42-4C25-874E-47226F499B7E', 'ED9244ED-521C-4EFA-B613-B6D9D55E6F2D', '4606207000056', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E555E5D9-1985-4514-A33B-8CC8CB8559E2', 'D5ED0A50-FDCB-40D1-A118-48D5E4B2FA2A', '4606207000179', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('971EA804-3DC1-4AA6-8AF5-CBC189898FFE', 'F9F73BCB-4231-46CC-A007-DE71379B9C87', '4606207000520', ' 10000/ 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E69648F-3A57-4C0C-9BB2-A3710BEC7C16', '5000D5D3-C2A0-4D66-A242-1233B730EAB5', '4606207000537', '  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC73FCD9-29FC-409C-97D4-287065ED35D7', '1F4B1C26-2629-4A00-8BF9-567B227EBAE2', '4606249000755', '    160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77A8CA24-F927-445D-ACBF-115A5FE0BA93', '1A7C2AA5-9271-4122-B6B5-719F05EA2B29', '4606257000044', '   25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB62E83C-359A-4794-9266-9BE6CC320742', 'DCCE2260-1350-4E7B-A8BC-2219492782AA', '4606257000198', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C67EF24-5F90-4A99-BBBF-CFE99531CE97', '4E32768F-C69E-434D-9ABE-F8D6C9864C0B', '4606257000211', '  3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81135363-163B-4824-83F7-187FF858547D', '68236BE6-0E43-4282-96F4-9B91A0DF71F2', '4606257000228', '  12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA3DBE5E-2B0F-49CF-BD92-9584D6A2CA54', '3F46DA15-98BB-4E35-8581-CAEC1D931588', '4606257000235', '   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA5BBF7C-CC76-4BAE-913D-A64DE28C63E4', 'AA4DF64A-67C9-4EB5-A864-35179979CF37', '4606272031023', '     /  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0960DD2-31B0-4236-98AA-756FBE290613', 'D4E285A7-C911-4060-93A5-959688123ADD', '4606272031047', '     /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('357936A4-320D-4ACF-B5EB-E8EBE5609B10', '93245D1D-A7CB-43DF-B01A-B9B155D1C76F', '4606272031061', '       / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('874DF3CB-25DA-42C8-BA20-5EA3C47527CB', '178D2095-F524-43FD-BBA1-5A027EA116FA', '4606272031085', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C66E81DB-2818-42A8-ABF9-515A5F95BB8C', '7ED0AFF1-F046-4E95-BC69-42E0EB795BFD', '4606272031108', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FFBD015-73E1-44CD-AFF2-4747461FC426', '077F2FEA-FE36-42EE-B941-CEF5C4B3487C', '4606272031122', '     / 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6E3F373-3D3B-48BB-90DB-42845336672A', '17F6F9FB-FA50-4220-BEFD-D0A326EF2538', '4606272031146', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4057FC3D-B8B0-4E4D-86C0-D3AC3E8EA9B6', '266ACBB7-433C-4C79-A889-A6F33B040DC4', '4606272031160', '     250 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E80330E-61F4-4413-A44E-C324F43F546C', 'A1DCBAF3-BA79-4244-86C8-3A51A0403CF5', '4606272031184', '   - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FB48AA4-6205-42C1-B2BF-06E1579020BC', 'F1D56A2A-89D9-467F-B7A8-B42099FC5EB3', '4606272031207', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89311832-95D5-4FB3-9D87-6D86CC0459EE', 'CDFFAFE7-0749-43C8-A8A1-359D958D7717', '4606272031245', '   5  / 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E47A7824-ED1E-4E8B-A30E-DC387021733A', '39CB0D61-BAF2-41A5-82BD-37D8962DBEEA', '4606272031269', '    / 1/9/250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6B1C7EA-7C18-4785-9F1E-0F1CC1C4930B', '062AEAEA-D00D-42CA-91BB-96DA0BAD72F7', '4606272031368', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1A9FBA1-DF7C-4A7C-9E11-E383537D8E24', 'D125AAA0-0B7E-4AE7-8AFE-03A3900B90B9', '4606272031429', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15CDDF8C-1D95-4A4C-8F42-355E575D9D57', '3333F59B-3383-4CDC-9EC9-DCA128D39E53', '4606272031467', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58EFA22C-6F63-436A-B5D6-624E83DA07F7', '5D01EFEB-9184-4889-9DB1-5F08A18A3A2E', '4606272031528', '   . 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93B60EE9-5251-4847-B7CA-7718B003B70B', 'F339F9D8-192B-4285-AD96-D934E4E70AFC', '4606272040049', '   / /     1/9/160 (12307071)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE876939-D39C-4D45-B53A-EF76744F1F78', '07F23F11-C81A-447E-8467-59F09E8FA5CC', '4606272040124', '   / /     1/11/160 (12308280)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBD81346-1B14-4FD2-8663-49E35E1D698C', '91A24109-7BA6-47D1-843E-A3FEDAA570E1', '4606272040186', '        1/11/200 (12308282)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('501644A7-22C8-4156-AC7C-171A9E016B77', '427677FC-BF39-4F69-84B2-724505FFFE92', '4606296000012', '- 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('039264AE-20CF-4652-909E-3A752545CD5F', 'A21AA3A7-009D-4713-AFEB-2473423A8F2C', '4606296000180', '-   0,7  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE2780DF-2B27-4C47-A41D-FDD4B477CFA4', 'FA136A79-7429-42A0-9D2E-AC5173D39F42', '4606351003873', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C6330A7-7B21-4812-9D1A-D9A8781ED0EE', 'DFEE6CC6-2267-46C8-BAAF-327A4D1ACDAF', '4606367001429', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('619B10A3-9718-4492-99DE-80C6C58C61B4', 'D60F26D7-ABAB-4328-9B61-B0EA4E822F6C', '4606371000135', '     35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6DAAB7B-78A2-42EF-9616-EEAB964AF430', 'B36308D0-FDFB-4422-B9BD-D31CBA912628', '4606371000371', '  ,   .  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25FD5855-907B-439B-B059-02544F57102B', '2D9F92EE-A51E-4BC8-8134-169730CF9FA1', '4606371000500', '   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACC96AED-16F4-432D-B443-9AFFAB8447FD', 'D33A09FD-4F5C-48D5-94DF-4F76B04EAA52', '4606371000524', '     35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0443AC6-6A71-4F45-BA9E-6B4AE6753AC8', 'D60F26D7-ABAB-4328-9B61-B0EA4E822F6C', '4606371000548', '     35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31C34656-8F63-4200-81DF-6F86A3B7AD1A', '66C661C4-536E-4150-885F-143DC3546AFB', '4606371000579', '     35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42ADD98E-2B56-49D4-B30E-45F917E719E1', 'D5581ED3-2B92-4B14-9903-D326AD543CC7', '4606371000678', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('859E43AE-02DD-45D9-8E38-62A8778DAC28', '7A5EA87B-9112-41D3-A1B5-1A12442530E8', '4606371002306', '      25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2834B3E0-5DCB-4542-9E7C-A1AAB1264854', '279F1355-6842-4D61-9F17-A8951E374323', '4606371002320', '- / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('001B774A-A4BB-4225-9788-9F4DA2AD49EC', '43743517-3469-408A-9924-EF2F979C1E31', '4606371002344', '-   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('572948EC-276A-48CF-9DE8-0387EE4980D2', 'A94BD502-FAAF-4F2A-A035-62A27C792130', '4606371002368', '         25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('302E73EA-D896-418B-B4AC-D99CF2B0AFDC', 'E2F996CF-4875-40AD-AA09-05DC312CB9E3', '4606371002382', '- / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('862063AF-B70A-4DCB-A89C-BD92CAB02C04', 'C0D03117-4762-4697-A3E0-49621DAED4E1', '4606371002405', '-      30 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E921864-99D2-49CB-A365-E2C07FC69ADA', 'E43DDB98-F112-45DA-B9BA-37795AF64A57', '4606371002412', '-      30 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39103EF0-D5E4-4873-AFFC-410A84938B60', '4D359591-C9E5-490A-B594-FD5CF1C75AC0', '4606371002436', '-     30 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56639C28-B9BD-49A5-98C5-BE32A2690A85', '93C6100B-9E75-4858-8F3C-DB94F616CB1C', '4606371002443', '-     30 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C6B7955-F692-4CE4-99EC-8815B0220A90', 'B284A54B-FCD2-49BA-BCA1-4AC91130F726', '4606371002450', '-     30 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7D64507-BF04-4E47-9292-EB25B5725685', '48D1D258-EB72-4BF0-A45D-D8C7F26F8D13', '4606371002979', '   / 25 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50BFA33C-3904-41FB-B3E8-2D014ABA9DE2', '6FA3C283-0E81-4F84-B5E3-30C331C0D960', '4606371003853', '- /    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1453135B-6591-478E-9FA1-514C3CB9E29F', 'C0687AA9-B533-49F8-AC48-E67093604DFD', '4606371003877', '- / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D0A8C0C-AFCF-415D-8F81-6E723423825B', '2A731C2F-F6C0-497F-BB27-0C99D2B90CAC', '4606371004454', '     35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E924C8E5-BFB6-4051-B50A-EAEE5F0F26D1', '98FAF2B2-EDEE-4EA3-A360-791AAF755E16', '4606371004461', '     35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D7B80CC-D69C-45E0-9782-15CCFD289624', 'DFD08096-2C87-49A6-BB52-CC6494F4690C', '4606471153007', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('589E80F6-5E5C-48F7-B8E8-EA0F104CA245', 'A88FC81D-6097-40F7-9848-590D331F4E05', '4606471153076', '    /  /   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3858686-9B21-4F36-9D4B-33CCFB8F4AE0', '93BBDF68-3E1C-48D9-8C9A-80EEC376DC41', '4606471153083', '    /  /   80 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D372E6D-BC3A-43D1-9A74-C9D861A0C3B1', '4B12C0B3-4BE1-4E6C-94BD-7FF87D79FD36', '4606471888886', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8762DC90-CF23-433E-8243-3EA491B54BDC', 'BE6978F7-EDE7-45BB-8C09-D7A1F09254C8', '4606486000402', '  50  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46E75FB1-1120-40F1-AF0D-45753CAF78B8', 'BF7CB033-D458-4D0D-BDFE-D9D03F0E2499', '4606486001218', ' 0,1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('599490E3-F556-4B77-83F5-FD6FD7068A47', 'DF43927A-207E-432B-B151-DA062ED10169', '4606486001225', ' 50 ///  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16BF3671-0058-4236-8F8A-A01F6CCD2D82', 'D7B14C05-A71F-452E-901D-46452B4FF067', '4606486002062', ' 5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04618E09-AB08-40C3-B32D-15B8A7A56AD2', 'B9DBD6DD-A0D6-40C4-B60B-F953B1DFE358', '4606486002086', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D83AE3A5-B3B0-440D-88DF-8A16052A3714', 'E536C140-6DDB-48D5-BA51-623985AE4DDF', '4606486002260', ' 100  /    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9BEBDCD-8E95-4224-8CAA-5069FEE50147', 'FBE9A8D5-3120-462C-A12A-D942003431CE', '4606486002390', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1315B583-6519-4741-988B-FBA6EE2F5E94', '8F70342A-4DDA-4D44-A423-CCE29B27DF6B', '4606486002475', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('142B9C61-3EBA-408F-8EEA-5856DC8AE145', '70A03348-83A5-459D-9C54-DF06CD293E16', '4606486002826', '  200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2540D6B3-FE41-4C70-97A2-96C033082FBC', '7F52911A-617E-42BA-B412-AB8C24C58D44', '4606486002864', ' //  200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EFA9503-20BD-4044-96DB-C65916024DD0', '082E5264-D077-45FB-B461-885845EDECA8', '4606486002895', '  200  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6620D9CA-88E7-450D-953F-E15BF82D7DB0', 'E3509CA9-FFAA-4666-92E4-23E66A19C967', '4606486002949', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F713E4DB-186F-41ED-B24A-9338A7C4403B', 'E3509CA9-FFAA-4666-92E4-23E66A19C967', '4606486002970', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DCD1BC3-D08D-4B0C-AA6E-CE480DC361C5', 'E5A9E034-AE70-4D4C-8081-BA4AD17306A4', '4606486003465', '  1,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B99174F2-E0EB-48ED-A145-C2222FAAE7F2', '9A79B4C7-D1A9-44F7-98FF-1EF8AA39CE01', '4606486003496', '  35  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47506247-526F-4A80-A1CA-63A297733A0D', 'EBBDE4AF-ACFA-4083-AEAD-177B5F87F707', '4606486003526', '     35  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('536ADDDA-E121-43E1-B35A-22E1CA728CF7', '99645C97-AFCE-4A9C-A90F-297100C123A4', '4606486003588', ' 20  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE7C420F-0AA4-450D-B53D-EF2A87008B14', 'C5F80A1C-256E-4BDF-9454-E9EB7CF9D775', '4606486003793', ' 300  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28FFCDB8-B5B6-4A97-8C99-9A342DB66B05', 'CD2B2D01-0763-4AC7-A5BA-6DAB20C74B56', '4606486003984', ' 2,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BC3D58F-7D72-4640-B1B8-827AC74187AD', '9E78DB05-844E-4E7C-A70B-FF4DD4A5D524', '4606486004929', ' 100  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F0DBBE3-0669-488B-B968-7B5DF663CF79', '8893F36F-5B49-4BF1-8B66-50925C74C519', '4606486005223', ' 0,6 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73293A66-A591-4737-9705-319269C97BCE', 'F0A32607-F27A-45F2-913C-1B8A3DD1A841', '4606486005490', ' 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D616EF7-2DF6-49B4-B9FE-F838F411B898', 'CD55CC74-830D-44C2-BE30-E49E9465A136', '4606486005513', ' 100  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00FD2010-3367-4BA3-B5A6-0ADDE57B265B', '501670FB-258C-46BA-A220-44C73A836C12', '4606486005926', ' 75  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB780B1A-F635-4F76-9800-0C9B1AAA50DB', 'F992E8CF-D990-41F5-A6E8-4049B2D5D0CF', '4606486005957', ' 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEC8569F-CE6C-4C77-9E83-EBC1200EE2C9', 'CA315A23-F41A-4359-AF05-BF1AFCC02DC2', '4606486006428', ' 2,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEE285F4-05E4-4D01-B347-A2B0251E2385', '25542232-345D-4A45-90C4-4DEBD810E3AE', '4606486006992', ' 250 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0893675B-C177-4EB5-9E0F-53F6D3992136', 'C1554E93-F407-46EA-8C78-D77FC7000A24', '4606486008156', ' 24  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEE13FC6-A242-49DC-AB3D-2A53CF4A41B0', 'ADF0F1F8-F10D-4FE4-8C5F-939FC127E323', '4606486008200', ' 5  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7991DA7D-41C0-4CBD-86D4-F152908FF604', '7DA4505C-6F73-4DF2-9DF1-A15A357EF235', '4606486008262', ' 10 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0219EE3F-FDE6-4373-A881-5DBDE5823567', '383DA411-DBAD-4F79-B246-F669116D44E5', '4606486008712', ' 5+400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AC35C40-6836-4CBB-AF85-65C610FE5BE8', '9C3A3985-2526-4173-89ED-87CFA79C6273', '4606486008767', ' 6 125+10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39BB265B-DAFA-4C4A-8D41-E05C262FAA37', 'B15C47FE-5A24-450E-A031-6AD616172CF9', '4606486010647', '   // 70 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9B76F00-08CB-44D4-BB83-32980B12A5E4', '2D440C3E-18D2-425C-A9BC-667903AB4F63', '4606486011217', ' 10+800  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0FA10B4-AC82-4511-8167-C00E71DE061A', 'A134A0B5-546B-40F5-8B4A-A1079532F53C', '4606486012481', '  0,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB87B8CF-7392-49B8-AC1F-DFC5D971DBF5', '8A208352-474F-4741-ABD4-D77049AC9B3D', '4606486012689', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E4BC4F7-47D5-4080-B3A4-7AB0B02995BD', 'DF9AEC06-6338-4ADD-BB87-C461758FDCDD', '4606486012788', ' 500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26D0B543-168E-45CF-A711-CC381323243E', 'E4FAC042-B418-4C4E-842E-F4A70C12266D', '4606486013082', '  500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98009D71-8515-41F3-AA3A-1E139CA96899', 'AF958DF3-B74B-4633-AE06-F69E06A2EEE8', '4606486013112', '  1,0  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('751B21D9-0451-4649-BB3B-E88B0384F356', 'EAD4A5EA-E9C6-42D4-9309-D6D56C652774', '4606486013143', '  0,01 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CCCE6E2-9EE8-4708-8FD8-A183BB611DAC', '2CF21EF5-18BB-4CD2-A7C3-64D8DCE9AC26', '4606486013167', '  0,01 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80EA183C-C837-4BE3-8DFE-7FA45ED570D2', 'E8411F94-EB73-4992-B22C-E087CE8493BF', '4606486013228', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58F5714D-35E4-4A32-AEC1-6331E8C49C2D', 'ED05C63D-786D-4B47-A536-3D49DFFC174F', '4606486013242', ' 0,01 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFD1DF57-1304-4B74-B2B1-D45D2B63952C', '81D8D0E6-52A8-4138-B72A-9A55ABD94BAE', '4606486013327', '  2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94A763C8-1909-4513-8A78-339851038007', 'FC5AF4B5-8BDF-44AB-AF13-B7E8A6DB48B3', '4606486014379', ' 5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28C85FBE-FFE8-44C0-A9DC-D439B7EF80C6', 'CD62540C-A968-4A30-899A-EB418689695B', '4606486014386', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('443C4FB3-8AD9-4B62-A3B4-FE94BA9FE910', '1DCA6128-F22C-4FEF-B2D6-E117EEDD4176', '4606486014607', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24488326-968F-48A8-8C2E-76254AA9D4F7', 'A2D4754A-C1EF-4444-9899-406A793CDC21', '4606486014706', ' 15   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C29E5FA4-BAE8-4704-AFA6-865F74A65D9D', 'AD92A700-2E66-4A30-98D4-AFB8084C8349', '4606486014744', ' 0,01  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEB382C6-2B8F-4689-84F9-41D67FA0941E', '51E58EA5-1D4A-4D14-9925-DA6687BB5D89', '4606486014836', ' 0,02  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45B80C04-2CE0-417C-90E6-680B612BE5BD', 'C8335160-84DD-4AF2-A19B-ACFAB0041CA5', '4606486015420', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94460D1D-6C2A-4AFD-9A92-34A22F17E72D', 'EE48B6DA-1B30-40D4-A077-F4DF53DF40FF', '4606486015444', ' 850  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('458011E0-9D50-41E4-8AB0-E7676D0E7308', '8656E43A-8AE2-421E-B399-503448F1A175', '4606486015468', '- 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F4EB771-6DB5-4BDC-91CC-E0D1E1AFBCBA', 'B454FC44-252C-4EC8-899B-2E589D6C7064', '4606486015499', ' 1000  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DF72C57-1D7B-494F-8160-38B5A2465EAD', 'FF2A6465-C1B1-4DE1-AC5D-B96BC6DDD816', '4606486015512', ' 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2463619-8326-426C-A68D-512A37540B95', '16592F22-C668-474B-ADF5-8CD3F1737FB0', '4606486016489', '  / 50 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72A2E0B7-7110-4FB1-BAF2-6D499E41DE61', 'C9394E4A-CC9C-43A2-A68B-3C775BCD5197', '4606486016557', ' 0,15  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA812FC2-699D-46E4-8EF0-FD5A1CFE5C41', 'FDE9AE69-A5F6-4AD9-9B4A-25D5F95F8D62', '4606486016908', ' 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B1A0A1D-02B4-4A1C-9435-6AD6B3D54C43', '844F2B95-1AF9-46C4-B8A4-8EB03381EA7C', '4606486017363', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9867F88C-8ADD-4B31-B9A6-25EB7DE42A90', '58367168-236B-44FB-A777-0BD107B3F2A8', '4606486017479', '  80  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('342BFBFD-CAD8-45C9-8F3E-B57A65574560', 'E8C94ED0-CD58-4D57-97DC-788B8327532E', '4606486018407', ' 400+2,5  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AABF50AA-49A6-40C7-B645-4ED5F0E03922', 'E7593465-06B8-4E84-868F-64692A0FB9C7', '4606486018544', ' 6,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B40EAD4E-FB7F-4B61-A7C4-68056C0895D5', 'E7593465-06B8-4E84-868F-64692A0FB9C7', '4606486018698', ' 6,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E497FAAF-97C1-448F-8558-E49E621BE33B', '5B889B19-C791-42CC-B156-D93B98F2C39A', '4606486019206', '- 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6353E351-87A6-4135-B984-5F070B28F894', '1D007A56-3628-4574-8423-72FE0307C7C3', '4606486019398', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50FFFA33-B685-4080-99D0-C6D0DEF3C302', 'B78D29D4-FD87-4B41-BB3D-ED4CBB0335AC', '4606486019817', ' 30  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('495B39E1-3CE3-47B4-BD81-6F154C22E9E6', '78921808-3484-4735-97F6-14068945C5D4', '4606486019848', '  0,06    28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7608A708-C915-45A8-B819-6FCC1348A507', '8BD84BD4-2695-4D92-85C6-6DE42E953B82', '4606486020899', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B42E2298-DE3C-467C-92E7-BB440DCAC6A4', '191CE193-5684-494C-B59D-14C7E10CE596', '4606486020912', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CEE8DFC-2434-4E05-BA3D-02B7C01F932C', 'F83903D3-A945-4677-BA69-7EE870D19254', '4606486020929', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5550BF27-DC3F-4F95-A404-95F9E2B2EFBA', 'C71100D5-2435-4108-9447-1F1DF1970F81', '4606486020943', ' 5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30F37560-B9FC-4A23-BE42-C48E557E967F', 'E1F6F4BF-CB11-4AAF-ABA5-D7916E6D1600', '4606486021230', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B10DC86-55F9-44F7-BBE6-E1EFAFD485ED', '393D78DF-1D34-44B1-8A97-CAF1335CB5AE', '4606486021247', '  50  / 60', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B680EA08-9EA9-43EB-BCCA-A139201D0543', 'B3B40E3C-1C57-436E-8F56-A6A319E629AB', '4606486021476', ' 200  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCB25E85-9DDA-48DA-9B17-1FC631457753', '1CC0165E-A6E4-4C19-87B1-425AF24385A8', '4606486022169', ' 25  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F3BB4BC-9648-459F-9634-7E482D8702C0', 'C55187C6-8C8A-440F-9565-9D3B15020804', '4606486022305', ' 0,4  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97E3FB6C-EB76-4648-B2A2-B5951A4B6320', '735B797F-832E-4557-9F17-69F61B65F89F', '4606486022398', ' 0,0002  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BFAFC6C-33A2-4CC1-A497-A3CE4EF5AB72', '519B7E47-0384-4929-AA60-CEFEFC219A9D', '4606486022428', ' 0,0004  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBC344F3-CD07-489A-A61D-C1BD3C06FB61', '4EDA5F09-5533-48D6-866D-CD21E503533E', '4606486022596', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86B811AA-CF76-4CCD-8141-CD122C0E6777', '93CCE25D-8016-4868-A9B4-D50AF5AA8D8F', '4606486022695', '  20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3302B953-F9D2-4115-B78A-A77AB0962482', 'B38A5433-DDA2-4F36-AE33-EB1EA938E558', '4606486022916', '  50+12,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E7FAF78-1229-412F-BD99-18920D6037CE', 'F2B331DE-AE9D-425C-8A79-46385B045603', '4606486023173', '  0,1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28990704-615B-4335-B139-95E102E8106F', '9345534B-69CD-4C42-993C-6A7323252BB8', '4606486023203', '  0,145 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92D2196C-953F-4469-99BF-8B1CBF72DFA4', 'C512459F-CBA5-43C9-AC87-C6F09E4DEABB', '4606486023296', ' 500  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0C77E20-644A-4366-9526-06E0FC31EA8E', '94D73054-62AF-4C4B-8BA1-C1088EEA931C', '4606486023364', '  20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DA017CB-6872-459E-8AFD-C19281462153', 'DD2CDD55-79EA-400E-8A94-1AB2C5A04777', '4606486023388', '   40  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25F897EA-4378-484F-92F1-EABB440EE41D', 'CBE5C905-08F6-4BD2-A28E-960DDB1D2A4D', '4606486023593', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C608A14F-04ED-441F-B977-3E6057A71671', '6E7842D4-A473-448A-B538-4D0942160BB4', '4606486023616', ' 40  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25C65F94-9EB2-41DF-9079-681C66810B13', '815BB264-58E9-4956-8D3B-57833B9DE940', '4606486023708', ' 100  45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFD5179C-334D-4A0D-96CB-369F09EB2683', '73F7674F-7790-411D-8F3A-CF4A17104758', '4606486023838', ' 2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C541FACC-F56E-4296-8800-CCD3D1537793', 'C1554E93-F407-46EA-8C78-D77FC7000A24', '4606486023920', ' 24  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF956B8C-FFE4-4F08-97F8-4C98AED0692E', 'D8CC2938-3DFC-4AEB-8584-B522FB67B9D9', '4606486024194', '  10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90D35891-740B-4780-BEE0-4CC052E2E463', '25A6F24F-796E-4814-97C2-2B52C2670537', '4606486024255', ' 3  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61B0E754-A864-4A9D-941F-E011D851D80E', 'EA6950A9-3CC9-42C6-A448-456AFEA326CD', '4606486024293', '  /  100  2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B58B832B-82B9-4964-952E-80820F17DDB1', '6C1A6EAD-4395-4087-AB9B-54EA93F87339', '4606486024552', '  0,0025+0,5 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F81C0B6C-4CC5-43B2-9D0C-C8991D596702', 'C8DDEE11-36B2-48D4-86C9-D0EFF64471FA', '4606486024576', '  500+5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF5B588E-1419-4F9D-B090-60E4544541A0', 'E8AECA8C-1849-4BBD-B82F-67B61CD68537', '4606486024644', ' 250  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDF073C8-E0B9-4354-99B3-D052D14E577C', '93E95E8A-3328-4148-AB0A-B79025389D69', '4606486024705', ' 200  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82857495-469F-44FF-8E66-EE9AA2345826', 'D936DE22-75D1-4759-8173-DAF9186E538F', '4606486024736', ' 24  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C111059-FEF6-4095-A772-BFD490A96CFE', '96A1A6E4-CE74-4C54-B3FE-8147FA3A4F31', '4606486024941', ' 10  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6E08158-4025-40CC-8A96-73D0C29A03A6', '45E8113F-630F-47B1-981F-6EC7DF65B798', '4606486025221', '  0,03     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CC30354-5CE8-4CD7-BA19-C3BD1D121218', 'DF11C35A-44A7-435C-8502-002A03E7976F', '4606486025245', ' 30  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA174235-490D-4B20-837B-18D00353B8BE', '3DBCC56B-D8A1-4DBD-89A0-6EEAC2A825A3', '4606486025269', ' 60  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D81B9DC-71F9-45F8-A983-320E0755E55C', '2B8C60C1-2DDC-4F00-BA63-06348DA31252', '4606486025276', '  / - 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76CF79D3-242D-4A49-BF78-31106C710F18', '7B39C43B-1749-4E11-8A37-B7CC678013C7', '4606486025283', '  200 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8163661D-59C4-4B23-9E52-2C7C2430AE47', '3362A3D9-61E2-4A42-94DE-47E48DCC39A5', '4606486025306', ' 600 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C3BCC46-C543-4EED-93B0-5795F1178F11', '0612A470-2143-478F-860D-57366C67349F', '4606486025344', ' 0,4   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A146CEAE-AB82-42FA-A910-CA45D35D398A', 'F21F000E-3E11-4E78-BA0C-538B40B1852D', '4606486025764', '  0,15  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('631C4A61-7278-4D89-B840-FCB63600F8C2', 'C75645A4-CEBF-4B43-BB67-D93652D05D88', '4606486025771', ' 50  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8EBEBBB-93D8-40F5-9CCE-745A3B4FE2B5', 'CA315A23-F41A-4359-AF05-BF1AFCC02DC2', '4606486026778', ' 2,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F6CEFE1-1EB8-4B26-978C-BEF482E34508', '42201755-57C1-4AB6-A46D-74E06D72101F', '4606486026990', '   1000   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC45AC73-DFB3-4278-8592-54A84AC84CF4', '9E78DB05-844E-4E7C-A70B-FF4DD4A5D524', '4606486027850', ' 100  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FAA4E5C-097C-4972-96BD-40479F02245E', '393D78DF-1D34-44B1-8A97-CAF1335CB5AE', '4606486027942', '  50  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B765F95-1CF8-48D7-B6AF-D664008960F0', '523FA1C1-E69D-4C24-9D60-786266DAE573', '4606492011942', ' 400  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEF9C69B-1DD6-403B-993F-7762CF9DE4B2', 'EB9BA557-AFC0-4372-9634-05E4D0B26FCF', '4606556000271', ' 0,0004  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8072605-50E2-4AC9-A02A-8DFDC97116CF', '8523B5DE-AFCE-4C73-8C7F-7B8D0F73FB11', '4606556000387', '  400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80150B4D-1B58-4971-BE4D-85E4CB528F0C', 'B9E0C6E5-947A-455C-ACFF-193C972B42E7', '4606556000394', '  125   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D3CE2C6-95D2-41B2-9DB5-896AC3F6BD1D', '405D05F2-6532-4443-87FC-A02570506C60', '4606556000424', '  1000   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0041903A-27ED-4375-B3EA-F42C9D67EEFC', 'AA662C92-8725-47DB-BFB4-99653E4ABBE9', '4606556001872', '- 120  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F918C9A-E530-43B4-938C-D3AE9C53A049', '8758B249-3061-4F99-BFF3-83DD3A059795', '4606556002190', '- 120  //   56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF830F6A-A58A-4278-BFD6-C3CEBF43FA73', '5B870813-6496-4E67-A317-A8D09A50EC91', '4606556002350', ' 8  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F750751-03B2-4B47-BE12-E2BEF3E50D40', 'A3266C93-3DEE-49F0-A740-D9DF2BF56B51', '4606556002367', ' 16  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F6B2332-8248-4384-93A9-CDFF1EAEEB80', 'D8C39397-855E-4A1D-BBC0-2040A34B736B', '4606556002855', ' 0,4  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51E470B4-E936-49CC-8EDC-1131AD0698AB', 'D314CBC4-646D-418D-850A-88AFF0FB7DCC', '4606556002961', '  1000   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6544B805-13D9-4904-A286-70CD3B10EEC1', '9D23FA81-180D-466D-AB79-8B57539553B4', '4606556003234', '  400  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DDCA17F-01FC-43CA-A86D-3DBEA24329AA', 'F5C8A4D5-5694-4868-BC8D-10D23E213B8F', '4606556003241', '  0,4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7AC0B53-6430-4F38-A6F1-F875B93BC5F5', 'C68CD6BD-E929-4440-97F5-A8E0A3408DAB', '4606556003494', '- 120 //.  32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28801401-2284-4E17-B1A2-AC0BD7F64956', 'B9E0C6E5-947A-455C-ACFF-193C972B42E7', '4606556003524', '  125   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DDB4CFF-0A2E-417D-9B2B-32E92D5922A8', 'C5512474-6818-4037-83E2-D023B468153C', '4606603000018', ' 0,025% 25/ 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5A52CEF-7AE6-4C04-BB24-2A49E344B798', '367C00D1-C3A6-4B89-9C85-F990BFED2850', '4606603000032', '-3  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03B5DB7A-91DC-4966-9320-B356FDB6D7DA', '142ED7E7-DC07-47A2-A482-4FA5CCF258DF', '4606603000056', ' 30   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C618407E-999F-4319-BB19-9623250727AA', 'B99D0BDA-EED5-43AC-8B4B-A6E1E5281BE1', '4606603000063', ' 5 ..  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E510DEC-A9B7-4772-92F7-AB352041CD55', '45A28C43-E1C7-47FD-915F-90F1FB088ABC', '4606603000094', ' 100/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3337332-BBCD-41E4-BDB1-C8528E9376FF', '3E12AD34-9583-47E5-BB16-EEFFC83508B5', '4606603000117', '  0,05% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CD96420-673A-4CA1-8977-341C396E8662', '75CADDEF-9B4B-423B-82BD-63FA1E498079', '4606603000124', ' 30   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5FFA90D-26A8-4E72-AC8E-30D5BD49505E', '25AC684E-E758-47F1-B724-BE149D7D6DAE', '4606603000131', ' 5 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36E60611-0C43-42AF-AC9A-AB1D7BD09D8F', 'E7CC4851-25CF-4B97-ABD4-4C7F09A0290A', '4606603000155', '-3 //    6  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47F7065B-1239-4A0D-B52B-C3F827563724', '1EE98CF7-5772-41DC-BAAF-79068CA73964', '4606603000186', ' / - /  /50 /   n  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F333884D-E4AF-4775-B854-6FEDA305B170', '1EE98CF7-5772-41DC-BAAF-79068CA73964', '4606603000292', ' / - /  /50 /   n  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA4F03BE-9AAA-4507-A3FD-5DF812BB79F8', '6A0D97D2-4F5D-4DAC-8639-A3379FB7726F', '4606603000308', '-3 // / -    20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DFD5397-9828-4925-8F59-6381746BF3C7', '09A9E039-582B-444D-83F1-718470BB1C59', '4606603000315', '-3 // / -   20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFB1A311-B31F-495E-BEBB-F0CC6D2765E6', '85CEF60D-56F2-431C-A4F1-966B152009B7', '4606603000322', ' 50   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DAEC71E-C1AF-4B14-9B22-D44A707FC73E', '4DA59491-F976-4E2C-9887-E892A73754F0', '4606603000339', ' 50   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F13372DB-976C-480B-B73A-6E652EAF1544', '93042596-43FC-4996-8ACD-17CB1D818E82', '4606603000346', '-3  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('399AF2A1-90C8-437F-B21B-DECAF78948B3', 'A8F842B9-37A9-4E25-87D7-D22C32F5D014', '4606603000353', '-3  48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AFF1F7D-4F2F-41ED-B144-7AED38558B2F', 'BCDD38BE-4A40-4C68-9D5F-B15344F8F34C', '4606666021500', 'Patricem       2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('224F4B3B-E9E3-4485-A1B1-6D128465E8A4', '70B7C3B6-5235-4AF0-8D30-CA1FF80EB099', '4606666021517', 'Patricem       2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67C285C7-BB50-4DB1-8DA0-7DDE10B16C6D', 'AC982743-E3B5-4D04-B208-62FF962C7445', '4606666021524', 'Patricem       2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB8D134D-E30B-4280-9AA2-92754D37BE28', '50F08310-ACBC-4186-8046-334B516B290D', '4606666021548', ' patricem//       2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C074033-65A6-48E2-BA08-2BF0C85D2FBE', '62CA2080-B9CC-4DC6-BC59-BB74C8284674', '4606666078344', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A2FDAC3-4E55-4296-9BE6-02F76DB762E5', 'F5413DF0-49D4-4F52-BAEC-C9464DDB2E52', '4606677009474', '  / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA057C12-1FC9-4342-B1A1-90F4DF48E3D3', 'DE050968-10ED-4F01-8B01-A80037FAB496', '4606677009481', '  -   175', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E564E59-6E1F-47F3-B952-7C81FE79193C', '0C8BAF07-6447-4992-A462-F7872D04D5EB', '4606677009511', 'Mc  /    175', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0314A4DF-3B57-4A7D-B8B0-51183A1AD29A', '72CB60C8-0EA7-48AE-98E2-418582375B14', '4606677009597', '   /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8D2535A-2D3B-4F95-BE33-5A7618E95BA4', '2A7C00FB-91CE-470F-AA71-9E1380B82009', '4606677021353', 'Mc   /   175', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25DFB0EF-A7FF-4E15-82BE-2B266614D3CA', '720672FE-9018-4D4B-A3B0-9CB27BFF5C17', '4606677021407', '   / / . 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3281FBE2-2037-42A5-A0BC-E6E3A10A7571', 'F722DD33-15F8-4277-AC55-CACB54E5AEA5', '4606677022145', '  -  /   - 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1906000D-57A0-442E-B884-3B3FCEA5AA54', '08C45EF5-9D7F-4021-8EB4-2387DD87C82C', '4606677022176', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B1EBB18-F0F3-4F17-A5AC-56220F9B9C4E', '45B51448-3F84-486C-A050-72AB167DC91D', '4606677082675', '    /  / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5EE30BD-2E0C-4FE2-ABDD-436BF3426973', 'B2A110EE-2AE3-4E83-A8D4-C5FDD5C3733B', '4606677089186', '        30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6908761-80A8-4E60-9956-B210629E38CD', '3A525A73-8023-476B-B8E4-79DF08D42B84', '4606677089216', '    /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('019ACEFB-EB13-4977-B118-80129A70E27F', 'B70BACA5-5B4D-4B21-B250-3683FE723BCA', '4606677125457', '   6060 5/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B24DD359-6364-4EF1-9717-66F10EF04154', '3C7E6724-C12A-43E0-8332-0CDF3DB6BD8C', '4606677125488', '   6060  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CA7EBE8-F95E-48A1-8312-88AB4E21D1A0', '2CE64610-A121-4554-ABFC-DC5AF587B875', '4606677128786', '    /   31 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD4E4755-9046-4771-A7B0-1E748DC3CCEF', '917287FB-7854-4C11-8654-3DE415831F72', '4606677129400', '     21 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AB95B24-D4E2-4B30-8D87-706E9E5DA241', 'D752FC4F-5F9F-423F-9915-CE6D245F8B7B', '4606677129707', '    / . 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5DC9391-81D4-4855-AA34-2F0120E5D292', 'B1BB55CE-4041-42CD-AAC4-A32B369EF513', '4606677134725', '   - / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37D3B2E0-0E1A-4C0F-A773-48F98DB256B7', 'C1432C53-8DC9-49C0-8CAB-5010CD6FE1F4', '4606683000502', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BA9C2E9-2D7F-4BDE-9C1B-F971C725258C', '7B11E69A-3484-47CB-8303-418EF7625875', '4606683000939', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('200C1D4E-091B-49C1-8EF6-8527AF641E83', 'A87F08EE-80C0-46F1-BD7B-23004F5A988A', '4606711000016', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3233980-6655-4001-8223-B18B73D35FC4', '010B463A-191D-4680-9790-5FE75D3356BE', '4606711014419', '   140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A619D83-B6B0-4408-894B-027AA0D9FB80', '6047A92C-0327-42D1-9E32-CE531B37ED02', '4606711014518', '   140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63D537E2-1343-4C65-B4B7-F8293D988F3F', 'F782C4ED-6D60-4DFD-88D2-D502F0A32916', '4606711100129', '    2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30ECAB3F-8D05-4F8A-92C9-A73F8998EFF1', '52C685AA-EC8F-4AE3-9FFF-1B26A72BD116', '4606711100228', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('931FFA36-EB37-48D5-B785-28024A1941D8', '8BB34FAD-E4CB-49AA-8C47-20733A5F9FD5', '4606711100327', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A09B8F7D-8CD7-49A8-975A-737C2A525E31', 'B1E0B23C-410D-4829-AD1C-B5993292186E', '4606711110128', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB61D6C1-48E3-4822-82D1-936AC98DF912', 'EFE8E86A-1E5D-4A26-B78F-FBFBF82F36D6', '4606711140316', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAC69861-7EA4-47D7-B448-0C337516FCDC', '9AA4E6F7-4FB8-4561-BCF2-EDB140583DA3', '4606711140415', '  46', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B10D80B8-FC3D-42DA-AE6D-7AF2A914C2DD', '42974BFA-BD95-4FD9-B7B7-C7EB26340755', '4606711140422', '  46', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D82F30F-79A3-493D-B2ED-C2A1315042D8', '90F5BD12-C6CE-46AE-9D58-CD32D3111346', '4606711350210', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F97E60B7-3C61-47A4-9AD8-754C137B7DF2', '6A23E752-81DE-400F-98B5-9E1983F23233', '4606711490527', '    2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D20E196-6079-42AF-8F3F-882EFBEA71F5', '636847EF-D434-41AC-85A2-EFAF9F432B71', '4606711700459', ' /     275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D0CE3E7-3BD4-467B-B18B-48CD97122188', '854D8ACA-1C77-4E81-86E2-D2D7C1E159AA', '4606711700466', ' /   275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86E970E4-5C55-4C0D-8360-DC3826A3195A', '01B26E2D-7A40-4844-9EBC-87FB1E87E63D', '4606711700473', ' /    275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E26F0584-D1C6-4CC4-9CCC-700DF3961766', '7AC9EB90-92AF-4C0A-816D-8AD4170BEE4C', '4606711700480', ' /  /  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B56C826-B7DD-4836-9C7B-357E4312178A', '5EDDD10D-7209-4AD6-BD3D-99E89C689FDD', '4606711700497', '   /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1532A9A-B57C-4702-8FA5-D5BE8D1BA29A', '94124953-F87E-4FA0-A5AF-B6A8A7CD52F4', '4606711700503', '   /  46', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE284402-214F-422B-90DD-EDA0CFD1A68C', '94A3DFA1-9D69-4E3F-95CC-2817174B62DD', '4606711700602', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('983A870C-A032-4EB7-BFE9-061799BD5BC7', 'E8A77055-5B73-4698-8F93-D25AAC99CAED', '4606711700626', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8B0ECAB-6E95-48E4-9601-C80B23D44C9A', 'F4D78B58-4762-40BF-9B6D-D3C33D208067', '4606711700718', '     65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56DA713A-9FDD-4B2D-873E-4B80CEA2336B', '0838A684-4278-46D1-9A14-5EFA2BE3523C', '4606711700862', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07E91A0C-BC8E-4160-A6F5-51275E108322', '2295E2F1-2983-41B8-8EE5-A18169AE1C24', '4606711700879', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE084B9E-68EF-42AE-AD83-95E91E6FE905', '255B6A97-0DF5-4973-939D-79CD71B2A19B', '4606711700947', '  /  300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD086DA3-4E12-4DD3-8B16-9E029537B85B', '6015BE68-890B-4692-BAE4-5F2FAD72E8A7', '4606711701104', '   275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('528B4A40-793A-4C53-8C28-59E14D04D71E', 'B1A9A04D-8109-41A2-8120-B391BBDCA065', '4606711701111', ' /   275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F5D568D-4C5F-4D6F-B49A-71502E24DD06', 'BC6B3586-4166-43E6-8F2E-CDF2889F91E6', '4606711701128', '  /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEFB4C02-1BD9-430E-820A-56C578BD91B8', '1A1872B7-63D0-4820-80F6-7F1DA1633EA9', '4606711701159', '  /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92689A6E-1BCF-4353-8D7E-5F967ACC7282', 'EADEEC86-0B89-4405-BD68-1FD665B2BD6E', '4606711701265', '     65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('671790BB-5D3D-4597-8CF4-0D2872452F93', 'DA68C4C4-ED75-4708-ADCA-925D4AC02BE4', '4606711701272', '     65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3AB69BF-5BBC-47C4-8669-B7C058AFF6DE', 'E48DB098-1572-4C19-ABA9-54CC4674983B', '4606711701296', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6CDA186-B65D-415A-892D-81DAEA433954', '70E0123C-3968-4D44-A763-FB344ED0BAD0', '4606711701302', '   /   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48B0F686-98FF-4346-A466-060983E2212E', 'D9D41895-D0CF-4699-B2A4-C873FCAE0775', '4606711701319', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BEACFDC-EC2B-42AE-B8D5-390F451EA7FC', '4E5C3297-9211-470A-B41B-B7FB6A59E862', '4606711701326', '       50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C10FA95-DB06-4E02-A5E9-871C7BD123C3', '6417903B-9D6D-4558-8094-AC12012E3042', '4606711701357', '   /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F326C503-8231-4694-BC45-374E76A9DBE1', '5035DD58-E199-46A3-BEBF-D3B1FEBBEB40', '4606711701364', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF3CC328-25AD-47D0-8724-F8011B0CDB2C', 'FDB0D7DD-9148-4CF5-8F0D-228340B469F0', '4606711701371', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66CD79F3-B777-415B-800B-2295425711BE', '89777828-6D2D-433D-A733-5B70DD29E31A', '4606711701401', '-    46    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('039FD896-8344-4DDF-A3FB-1F183FA6DCB9', '5F24B630-E7AA-4E0F-B0B0-D06A481F254A', '4606711701609', ' /   spf 20 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('203BF0C1-7E12-4DE9-98A6-CF094CACB722', '13D013AF-C732-4E72-B25C-DFB01DBF4E8C', '4606711701760', '   /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FD8FAC0-CC5B-4CA5-94F3-20F170FACE0C', '08CFF6C5-8930-4404-A857-C454F7C9691E', '4606711701791', '   /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E5C7F17-A285-47EF-95A7-274415907BD7', '9B3466F9-8373-4ADF-850C-6B7741660822', '4606711701807', '   /  46-50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33A7B4B8-3818-4A5D-B199-302F371C2DF8', '213BE44F-19B3-4245-B485-ED6AEC702132', '4606711701814', '      46-50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3A8F779-FDA7-46B8-B1B7-6E77743D8EB1', 'C57F5954-4CB6-479C-9F7D-FD157CAE4BDE', '4606711701869', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('338AB217-0640-4DDB-9C2C-EA9CE54FF5A6', '30DC7D7D-D534-4DD8-9142-F9726EE3FA43', '4606711701876', ' - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C39BD5F-AA15-4423-B779-33728DFF13D8', '296003F2-22EA-40E6-8EA3-4FFB0891F931', '4606711701883', '  /        75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F55A854-FE1F-4CA5-BED8-FEB74F77E293', '24293C59-A687-4FA3-8A78-7D76A122906C', '4606711701951', '     / spf 30  55 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('699E8DE6-7634-4276-98CC-636471329482', '3DB287B0-807A-4676-9AC7-58C1AB8FB256', '4606711701968', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0F3B8E8-60CA-418E-A9B8-78496E794E71', 'BFC53D32-A5B4-4D28-AC3D-E4BDD09F9495', '4606711702200', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A174AD9-C53E-4986-86B0-12E33795DA13', 'A844C6C3-1952-4DF3-BD72-A22EB0A823AC', '4606711702217', '  - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B81AD1CF-548F-4810-9C54-5AFBAE5AD2C6', 'BCC73B8D-5930-4CC2-A52C-B6B57D667FEE', '4606711702255', '  /   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CAE0DB7-179E-411F-BFA3-F2753CC189EF', '37331A6D-6448-40C9-A20D-2A822B202387', '4606711702262', '  //   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C5FBA4E-8ED2-421F-97EA-3CD874F0C970', '20AC5D56-3205-45F0-A7C4-6A08825260BE', '4606711702422', '    46', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C9506EC-187F-459D-A2B2-E3325F17301A', '134F9AFE-270B-48DC-9C60-E709EAAFAAFE', '4606711702446', '    /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1450156-6C03-48FC-AFCE-C92743C811E6', 'EDE1BE16-04DF-4CF4-9788-4E26F8F9977E', '4606711702774', '   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF4C3C95-7B57-40B2-80DB-4AB7675D58BA', '3C966485-8758-4AB7-AA2F-A0482D001AAA', '4606711702781', '- /  evo 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4C0089B-6E7C-4B71-9435-2CA33B783BF3', '9C9B7D98-ED23-431E-B21F-5B770618EC78', '4606711702828', '   /  - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E62FA4E-9E9F-4ED7-856C-1E865B993C62', '975A94B3-9B48-464F-8861-5E45BDC82815', '4606711702835', '   /   2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5439D002-02FC-4EBB-85EE-A7DB16603CDD', 'A1BE858F-E954-4CC6-86E9-006EC93A49ED', '4606711703009', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BF60088-2E9D-4A8F-8FCA-E88DEEB2B5C0', '73921F0F-6196-4C74-B7B3-06EE431EC536', '4606711703078', '   /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D872D0E-ADB4-44E3-A210-764C292B8085', '7A999C98-DDCE-4913-924E-631D88278FDF', '4606711703085', '    - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A39BE950-E1AB-45AC-B952-8F5628A20F6D', '5FD32D8E-38DD-44B4-B6AC-D20B3DF50418', '4606711703139', '   /   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33D8E74D-ACA8-4436-9637-CF8D55D5C1FB', 'D8EB9FCF-A189-4BF7-B1D0-238337957912', '4606711703146', '    /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89AEF548-6C91-4FA7-85C0-0FC9F9BD3CB5', '806771EC-B077-4D1B-9935-02C5D4AD3FAF', '4606711703153', '      spf 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE90F6D5-73C8-4026-BAE9-8DAEE8313300', '7538F483-AF6D-47C2-B06E-A52ADCDA4756', '4606711703160', '   / 275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E898F13-9D33-448F-B215-CA8DB07AC21A', '0C00B465-1F3C-41A9-BD3D-B7C8CAB85EB7', '4606711703177', '   / 275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2028E84E-3F5F-4410-8351-41CE55E5200D', '01522EC7-68AB-433F-8251-38BA70E58A14', '4606711703184', '   / 275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC65F64C-8814-4D8E-BA9C-BADBC4A5D24C', 'C2ACB2EB-3346-43A2-AB7F-C9559C2E42A6', '4606711703207', '   / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA0D4EBB-B87B-4A5A-8C25-150AF6F48389', '9FA9697D-EC0B-4162-8379-05946F109EE4', '4606711703214', '  - /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26DACBB5-968D-4A5C-8906-E13A2ECCA32B', '5B3B0CDA-F244-4BBD-BA62-81AF1A729B76', '4606711703276', ' evo   2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('921CD6D7-F1FF-4436-B80A-5BF63779002D', 'E783221F-1F4A-4220-A620-3D2DC4AB4581', '4606711703740', '       1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED14C83F-75EF-47F4-A452-45DBAA691121', '66C62E61-EB14-433A-929F-2B55816B3134', '4606711703757', '   /   2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('989E99BC-1FB1-42B0-9AB9-3870C6D1E5C4', '4C778440-D4D0-4E21-8F08-473038C202AC', '4606711704099', ' /   275 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A73A2D0A-1377-4EEF-8C3C-D619E12A6857', 'BAB62DD1-6916-480D-B973-0521B925BC10', '4606711704105', ' /   275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D13C34B-BE24-44BA-8AAD-A063E423AD7C', '30A159AD-D949-4356-9541-406930A411F0', '4606711704112', '  /   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A46A7132-D560-4D85-B6FB-0C095011A738', '0D9117D2-4E99-47F1-9241-DE616D8AFC89', '4606711704372', '    2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1BD2524-B19A-4DA7-AAFD-7A4A0C8731E6', '784F87AC-E337-478E-8C1F-C6BD4B70ACF9', '4606711704389', '     2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84C462DE-13CF-4370-ADA0-BA82110DA3D7', '8DD3051D-3EB9-4470-8E99-86DBFBB3BDF9', '4606711704426', '  - /    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('089D5AD6-F547-4784-B76F-BD6F20CA10F9', '4F8DDB29-FB34-4BA9-8FB3-DC031B05514F', '4606711704556', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FDF7F1A-87F2-4D82-A24A-D45FB5C23043', '3F47226B-5134-4371-BA3A-A00C62A8B9A4', '4606711704570', '   46', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAB198F1-06EC-49EA-8AD4-997FE668C09E', 'AC3FED6D-0FCF-47CC-B224-3DB12CFC2AC4', '4606711704587', '   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EDF8D73-369E-40F7-8BDA-665D2F095A6E', 'A2AF4198-518A-441E-8EDA-594678C8345E', '4606711704594', '  . 4,9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('507510FE-23F9-4E52-8B3D-6A1834F1184A', 'F0165D61-D9A0-4469-92DA-00EC9815B180', '4606711704600', 'Atopic  /     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84D17DB8-2F78-4807-8EA3-CAE46B03375A', '5297386D-9510-4165-A37C-1E3B6BA2DE5D', '4606711704860', '       2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1493BDE9-E08C-44E3-A8AC-4FF1B3C6A2F4', 'B8CC2D2B-FB4D-41B4-B544-439DFF6CC184', '4606711704884', '     2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBF33E0F-AAB0-4A13-9938-1FFBE7704FAD', '6D6F6C4B-3633-4B0D-8E09-C77E06DBD807', '4606711704891', '    2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20105FE9-59DA-428F-BC1C-4FC5251958E4', 'A3C2B2E5-6FD9-440D-8BA5-34D1D1B7A17D', '4606711704907', '     2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB4C03C0-806A-4098-B8F4-A1DF4E11FEEA', '2C415E86-C52B-443F-852A-F93EE621B6BA', '4606711704914', '     2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D13DE626-6C51-4284-95CA-D5617F67A27A', 'B25507C1-F18E-44E7-849A-C9A88DC07A05', '4606711704921', '     2,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3D9E5D8-F817-415D-BFC0-343F93017E5B', '90CF7BBC-44E0-40F4-99F5-70726A128CD7', '4606855900029', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B7BE697-BB3A-4226-AAA0-1F134E9118DB', 'D6CF8A85-CFCE-4B2F-8CA0-F8F50950B816', '4606855900173', '   . 330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('729359D1-D026-48E9-85D8-CAED0608B37B', '5F776195-B9B2-4AA7-9F38-2F915E77AB26', '4606982000548', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B551AB6-AFEE-491B-B76B-8A0B640D68ED', 'D03C913C-85F2-4AAD-99C0-0B7F2B5097BC', '4606982001460', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94B5175D-A196-427F-954E-A44A38E9620B', 'C1167263-1EA7-4028-80BD-269C2D9DC0DC', '4606982003211', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6442544-A063-4786-8405-8176E64C2093', '545DA22F-48ED-4AF7-8F53-166F621032C4', '4606982005314', '       30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53A35CCF-5561-4D7C-8C51-D856EF1A4CB3', 'BAA27C08-5241-439E-835D-924612AD407E', '4606982005321', ' -   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D264017-F154-4A68-988D-55A018F1FF6B', 'E7B53E2B-A59E-4AFC-BA53-9A8AC015B253', '4606982005338', '   +- 30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27619B9A-0EC4-4F67-844D-2B9DFF145D60', 'EA13AA55-DAF5-401B-B5C8-FE6B65A64753', '4606982005345', '   30  : +', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BAA74C7-DD3A-45A7-A4C5-617D973BC807', '51E49F0D-B9CE-4F18-87DD-0FF18FBB7835', '4606982005352', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AEEF22B-08D0-488B-8F73-B95821F05D30', '1DB28AB4-1D46-4764-9CEB-BA10B20B4513', '4606982005376', '     75  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD72EA2C-5C9A-44FC-B9E5-2D6326A20E55', '02DEE8AE-91D4-4BED-8680-A26F0793CBE8', '4606982005383', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35240898-6365-4F9C-BA9D-63C89C30CC2F', '7B2090A2-4811-4E6B-A714-5A6E37EF5842', '4606982005390', '    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D14B9F3-6627-4CDE-8EE2-0DE5F5E8783A', '1AE39287-DADF-44E1-B8D2-010556D60E4F', '4606982005406', '       - 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0EC997F-951A-4104-9711-271F64A112E1', '5AC7E0E9-ADF8-42A0-9132-5BF1269A21FF', '4606982005413', '    -  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3217CE20-3018-458D-8546-746B8C77A3DF', '193A361A-B28A-4B12-A3CA-E0EB8A28A2D7', '4606982005420', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDF7A688-7D28-4D95-9FF4-27242C9EF9A2', '05FF823F-6178-46E8-AAB8-9610A652CBDF', '4606982005437', '         2  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD61571F-FFA1-4CC0-8B8E-931CB8C12E4B', 'F9A3DB24-7425-4172-BBFD-4CD8E81382B0', '4606982005444', '     100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC73F209-37AB-4308-BF75-EE46103FC784', '782C52B8-53ED-4FC3-BE05-5B87ACDDC6AB', '4606982005468', '   +- 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7FBCE5D-63FC-4D57-9DC9-409FF278D972', 'DC04AACD-05C8-4D47-AC9A-4DA6FFAFAB8D', '4606982005901', '       75  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8EE5590-F5E1-4871-B541-1A4662B349F7', '4737DAA4-45CF-47AD-9DF1-8C877C1AEA9B', '4606992004550', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('535B2330-5D84-4FF2-9786-EE8BC1F2E64F', 'A5CAFA03-576F-45BE-B3D3-4AF94353E3C2', '4606992004697', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EAF0FC8-99C3-4F3F-B7AF-D614EBD6A220', 'B09DF756-57BD-4CA7-9DDA-D02F1C3633CF', '4607001340027', ' 500  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2008313C-E037-49CD-B12F-A94E9B59C42A', '975A7BD1-73BC-4A24-A395-DC91F81C8F8B', '4607001340041', '-   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FADE4468-1B22-4193-A1B4-9C5C813403D5', 'A9B3B28D-27A8-4C38-A1A8-B2914EC86A85', '4607001340058', '- /50 /  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03C3CEE4-6310-4915-ABF2-7DA6827DA8C2', 'AF5405CC-0B33-4448-89D7-FA8ACB9E18A8', '4607001340065', '-  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F6E92DE-20C5-4433-834F-AA1783DF1982', 'C0D5B1F5-C3E0-4F27-870A-7BA07EB3448B', '4607001340072', ' 0,25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D89CCE05-D0F7-4571-8687-5AA3A3DA6959', '1F8E62F0-0956-4CC3-A162-91116FA3C53B', '4607001340089', ' 0,25  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96DA53F2-F9FD-40AF-B1D5-F83C4148D3FB', '5AB86E55-78E8-4782-9427-37110EA04D8F', '4607001340096', ' 250  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AD9D5BD-B26C-4D16-8826-519ECFA2ACA2', 'DF3D45A0-A991-4335-B18F-E135F1008C66', '4607001340133', ' 0,3  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F0C0C4B-E35A-41CA-9498-27D9D72FC48A', '6D9E3340-85FA-4FCD-ABB3-ADA8FE65793F', '4607001340140', '- 250  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('007ABA8E-2145-45F7-B4B8-4E60287E7982', '75A0C5BD-921C-4E69-A8B8-2800C8ED354E', '4607001340157', '- 250  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('429E2B52-9CE4-4F73-B7C1-5562C3DE3B05', '172DA468-82C7-4529-97A9-B28FCD4B93CD', '4607001340164', '- 250  180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FFD639F-AFE8-4AF3-85D8-3636361AC7BA', 'D53DD71A-E20B-4BD6-AB67-C59EECF1D905', '4607001340195', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47333D72-5F03-4F56-AEEF-1428E9976E90', 'C62A709A-A9FA-4FE4-9D30-8D3A172495F6', '4607001340201', '- 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31974639-218C-4496-8312-BC3277874B1F', '01AA3D7D-8810-4A62-AF9A-65F4E3C39435', '4607001340218', '- /100 /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34A931EE-9333-4D85-A388-BD32EF660171', 'A46A2B0B-1296-42A3-9F9D-6673F1CBFFDC', '4607001340249', ' - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('375A1D3A-37B2-4B58-BCE0-9E6DF8F01FC3', '55C0651F-175E-4590-9FB1-3423FB815216', '4607001340263', ' 0,3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2362EF20-096D-4190-9093-B0398F896D8B', '7664F531-360B-484B-9908-397BEB2F0CB9', '4607001340362', '-   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA774D03-803F-401B-BAF5-92B28EBE16CC', '90F6B6AD-E816-4DE3-BFA6-3BD2546CF080', '4607001340416', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('870AFB60-F8AF-49C9-A068-DEA43112F03C', '19F67E74-F885-485F-AF93-C01B6C789BD0', '4607001340430', '   2 440  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E40299C1-07BC-4D8C-AE79-4CAD834E6FEA', '132CFAFF-8748-47CC-A2DA-1723195443CA', '4607001340492', ' 400  45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE7402EC-EB1E-40A5-8EC3-56C60A0536D7', '5CB3EC38-920C-4D0B-A899-0FEAFC9D607E', '4607001340508', '    q10 500  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDB431EF-A4AE-4D49-93F3-09B2A5EFA684', '2D8E772A-8242-4FA6-BFBD-7CC0E2E94CD3', '4607001340539', '-   0,5  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98BD2474-4256-4AC3-9D0A-0C0F18700C4E', 'F63232FA-B2D1-4619-ABB4-F80D690EC78A', '4607001340553', '-    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AC8D12B-C70E-45D5-B684-91E46DA6C511', 'EC1CBB25-C315-423F-BB91-FF65DF7BAA29', '4607001340775', '  1  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A8311D7-F352-47A0-9B69-B5FC8B88A1C8', 'E60522F6-729B-41AA-9319-F14AB326A93A', '4607001340799', '- 0,44  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03DB14F5-F441-4C3A-ABA4-E0CD9AFDA95D', 'DF3D45A0-A991-4335-B18F-E135F1008C66', '4607001340805', ' 0,3  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A70B4505-49C6-4B45-B639-34B8D8EF2B70', 'E60522F6-729B-41AA-9319-F14AB326A93A', '4607001340850', '- 0,44  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A37A947D-EBDC-4B58-B4F8-F241A59BC01B', '417BAA61-142C-4008-8A2F-9797DF121103', '4607001500056', ' 10% - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D252471-C507-42F0-BED5-0A6487AFE40A', 'BC851F9F-CE69-4F70-9DD3-C673F7A3857C', '4607001500117', '   3  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0438CF3B-7A4B-467E-8E06-C8702C166634', 'C8F4567C-D818-42DC-9136-89CAD6847187', '4607001500148', '*  0,05% 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EE02EAD-4403-46FE-9F91-76BFE56B9960', '42ECDB89-DC98-48E3-93C5-8E5CD6FFE5CF', '4607001500315', '  20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73A28C23-3955-4D40-8F56-4E7DD5C717B6', 'DF61DCFE-FC56-4F03-B39A-57EC297C352D', '4607001500346', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D5B294F-ABB5-44DD-9554-8C612C7DFDBE', '782878B4-6AC4-4153-8B09-20CB0EFFA61F', '4607001500421', ' 20  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85503FC7-2D9A-4A6E-AD92-538520D8E805', 'DF3A114A-5FB5-4555-AD81-58992C1FAAEC', '4607001500568', '  -  - // 3% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('368808F5-444C-4FF7-9272-0F46C4FD644F', 'F4E14138-CC71-432E-BEAC-0DA737184271', '4607001500612', '   5  - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('618C5317-2A38-45EF-A5A2-019C5BA081D6', '8B0ED951-BFA1-4DF2-A728-69747B741940', '4607001500728', ' 10% 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4AE91AF-123B-44E3-B6EE-C488A9FEA3AD', '629B9BE7-6BDF-4ADA-992D-57DB93B616AC', '4607001760252', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F2D0F45-83FD-4C0C-A67F-888F383ED0EA', 'C75E6814-1F23-40B0-A011-D6277A421D47', '4607001761051', ' -  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED9AB247-1E11-477A-A5A8-BA6C4795D1AE', '040BBCAD-1187-4599-9065-0412FB636E1F', '4607001761075', ' -  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5FB33D9-3CAC-4B11-A386-2FF2E77E6F60', 'EAB94531-1D6E-4E85-BB66-3F8E6A5D73FA', '4607001761143', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38F0AA64-6B7A-44A8-8B72-89C932BDE413', '9A483FF7-0E74-405F-ACB4-02C6490A51E1', '4607001761709', ' -  200 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEF0282D-456A-4C4B-AD73-EB022A5A46FD', 'B6B37B76-5EBE-4CFC-B6BF-495E1D371BC7', '4607002030033', '  0,9% 250 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F8DCC9B-AC76-4357-AB61-9A21013159BB', '71B4222D-C51E-4DDA-8719-09D8BB83F41C', '4607002030040', '   /   / 0,9% 500 - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB5C4C00-21E4-498C-A4D0-BD65130D3CF2', 'CDDED6DE-3218-4255-89EE-E2A290D54597', '4607002030064', ' 5% - / 250 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5935E693-9DC2-48B2-BC0A-F7B98072F562', 'BBF6042A-3B09-429B-9813-021D85C94D81', '4607002030378', ' - 1  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D86EA293-7922-4703-A627-8B1D3E6869B5', 'F6E6A854-4F94-4543-A663-E3A7CEDF6771', '4607002030385', '  500 - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6215BE68-56AF-4688-8B02-F9E4DC7E655F', 'E7791523-51E4-4D0E-80B1-324E0D138C66', '4607003110017', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D578B71-3B8C-43FC-8757-C61062F58BBB', '8864E779-F434-4115-B8F8-5A26C00D13E2', '4607003110062', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AC4BB2B-A043-4E83-8780-C04290DFEAAA', '3F7DEE0C-BB47-4170-8F04-EE851D60D8A9', '4607003111281', '-  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8753DF03-863F-407B-90DE-04D2CBA38540', '59A9D3C6-BD5D-4287-8116-35F30333056A', '4607003240394', ' 0,05  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C109ECF3-D1B2-46D3-BC05-9008AD334ACE', 'DD97335C-18F5-4416-A31D-A2F821E7942D', '4607003241100', ' 100  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('572F4F9F-2E81-4B78-8EEB-677DDAB88544', '3B296FF0-D835-4142-A618-F93BF823D4E1', '4607003241452', ' -6 /   15 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB41BFDB-4C36-47A7-97AC-EB4C7B3E90D4', '35C81855-EEA6-4636-952E-AD37590C9799', '4607003241575', '   150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D16A6839-83F6-4918-9AD5-0C902BF12925', '5AD48058-CA66-4181-BE9F-E24D55D352EF', '4607003241711', ' - 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B2FFF1E-A80E-4D38-BBDA-508761AC1218', 'C759710C-E905-49E5-B858-E1F281C1C3D8', '4607003241797', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4FCEAEF-1EC6-41FF-AED8-26E25A555389', '73EA872A-A0D1-4C02-8EBA-AC5ABBEC848E', '4607003241810', ' //  / 10 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('317B25FD-EDE8-4942-A78F-F74671412E61', 'B3BCF684-5039-42B2-BBED-25A7B9804D26', '4607003241834', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18C0E483-CC59-493A-B341-67FC691648ED', 'BE363822-1149-435A-93D9-5BE102211195', '4607003241841', '  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B81C3DD-14CE-49E8-921E-F78C4E10A263', 'DFC387DD-EC50-4FE5-8AD4-9BD5E2DF33BD', '4607003241858', '   1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23C157F2-67FE-468D-80C6-5BF6DC662D48', 'C20827CD-B26F-4655-95AD-13949276C558', '4607003241872', ' 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D281451-8F13-43DA-BB42-EE4784A24293', '9ADC19AA-B166-4876-8BBD-047097E90A30', '4607003241995', ' 15  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA3B66F1-565B-40BD-A3C6-E9EA4A1C50A5', '0E8BB796-A612-4B94-85B1-69474B660CFB', '4607003242060', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31E51C20-2231-4501-A6B5-E57599378740', '824F55F4-B4C2-48FE-9212-F1EE6332D7FA', '4607003242121', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB70BD69-1386-442A-9021-464153337535', '61D87D6D-0327-4F0E-AA61-44FC0FAA069A', '4607003242312', ' - /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA174225-556C-4EB6-9C51-E609D3349319', '98DF62CB-A28A-4B2F-B685-CE85EB81D682', '4607003242442', '  15 6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55496E0A-6539-4BB7-B8DF-297E977CB2C7', '4832E253-418B-4896-A81A-989078F3FA7D', '4607003242497', ' 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4545438C-11F6-4869-A758-F9CE3596A9A9', 'EC17DA47-3F3E-4A69-99A2-4A90D9884228', '4607003242503', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7AA6123-0B8E-4D69-9965-2C2AE57D4C7F', 'F022B9BA-35B4-4C0B-8338-3A6A6CEE71D6', '4607003242558', '   0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF059B50-5986-4057-9410-F56A2FD173CE', '4AAF216F-7034-4F34-B2B5-2F814C60CBD1', '4607003242565', '  5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16BFCD54-CD80-4539-97D3-8CEE8124993A', '29596950-B819-4D18-9E21-07DBDA372A3E', '4607003242602', '   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00B617A8-78F7-4875-8D91-191B8CC1054D', '1C50F3CF-1230-4B90-88F3-5629FEA4759F', '4607003242619', '   9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97B00BA5-F115-4304-B1F9-0325EEB4E5B8', 'BBF54937-8DDB-4B6F-AA50-7D76F605EDE8', '4607003242657', ' 100  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86FEE43E-6262-4EB4-AD1F-FF12DCDD508E', 'AE5CC2A0-9E92-493F-9385-8B79D2C69D59', '4607003242664', ' 100  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7C2D94E-4297-410C-9E3F-2B39577EBB09', '640C5E1C-80BD-43D6-BA5D-7F0A7249ACE5', '4607003243050', '  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D9D2294-613E-43CF-82C7-ADAD2F11A08F', 'D61746ED-D29D-403F-91DC-54C056E3B4A8', '4607003243074', ' /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('079BA360-AADA-4892-9151-36A972CC6136', '594895B6-D20E-49E6-8F9E-F6C91F38BFF6', '4607003243081', '  /  250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC1FA794-8883-4E2B-B353-7F470163A531', 'D3F45339-5BCF-43AF-B6D6-B9C7E07D139E', '4607003243104', ' 2%   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67BD0E26-9B3D-4BE5-938A-4A10327C824D', '54E31845-324D-4FCB-A5EF-5CF7F77F2235', '4607003243289', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDE3A82F-62EE-4EBF-BC2E-617913298E93', '0C9DBE05-E647-4D26-BE13-71C62BE6C6EE', '4607003243296', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AA5A3DE-3EE5-4628-BF26-FAC6853DA898', '7661E61E-D8B4-4C94-B0C9-FB46D98376A9', '4607003243456', '- 200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00E90220-1E33-4E58-8F80-E43DF0A6847B', '11AAC8B9-8518-4DFE-8F47-72D500956D75', '4607003243517', '-   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DB909F3-6BC2-4B87-8E30-213F2D88F15A', 'A217D554-8584-4E20-95A2-E8D16512E208', '4607003243562', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CE12467-5BD1-4CBB-BB9C-F80B8D4EC691', '268814CD-BDFD-4B75-98E1-391B39EC3E14', '4607003243579', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44A794BD-9C41-495F-AA43-E84C328F2B26', '2886828B-DA6C-4711-B64C-F9532680C41F', '4607003243586', ' 5   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FEFF732-C05F-49AA-BD57-BFD1EA1642AA', 'FE0999A5-2DA3-4AF0-8B4C-7EFBCAEC1968', '4607003243616', ' 12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('552B9566-E84F-4876-9067-97DDBE815C71', '507D6EA6-94B0-41CC-A5ED-0EFC2C6370AC', '4607003243623', ' 250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD6D3F6B-F773-4ED8-8AA3-0A1825F8DF7C', 'D1F6B56A-FB2F-4D6F-A488-C630780F6805', '4607003243661', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B5C546F-6F9C-4100-826A-623A504E8FBE', '4CCD8410-2289-44F6-9E42-321E9F4DBB5C', '4607003243746', ' - / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFD6C484-8269-4482-98B3-86382AA9BF30', '13069181-7261-44C8-B734-1ACE4FDFEE2F', '4607003243845', '  35  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F829CAD-5150-4B1C-AC04-A94493AE86FB', '978E8DF0-EC4A-40D1-80A4-0B705F1636E1', '4607003243944', '  //    35  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76320C59-C0BE-429E-8E80-F50FE7AB3B4B', 'C9556D42-3A45-45C6-8C8A-4F81ED6D1E31', '4607003243968', '  35  / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('088A0A61-BA0D-4E84-8660-1DD3D71F0179', 'E6ADB4FE-F7CE-4BCC-91EF-EDA0E6A6FABA', '4607003244002', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EF6924E-C209-4F51-9878-42EBF00557EC', 'B4F9A642-B072-44A3-B29E-C36D7C15FAE6', '4607003244149', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E2B6D2A-68D5-44F7-935B-E40537FA7A40', '98FCC116-52CE-4AC5-A32D-AA7906D06690', '4607003244170', '  7,5% 15 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B4CA6BC-B6E2-4424-967B-2A20CB82800F', '2BD4E9B8-C902-49EC-A577-46AC33A4FD8B', '4607003244200', '   2% 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FAFB80F-2B4E-4A6C-83EA-F486F42093ED', '0CBD01BE-045A-452F-99C0-8DEA945C29AA', '4607003244224', ' 5%  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49B1F942-DE93-44D4-A27D-E15C84889B39', '2A8B3236-9A4D-422F-A2F6-D55781ABF0E1', '4607003244521', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36D6A165-2885-4377-8F7B-B54858DE034C', '8B0724D8-113B-451A-9F18-AFB7320C9C32', '4607003244545', ' 20  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27652DB5-BBF5-4E3C-8EEA-618DBBD84143', '1861D334-8E6F-4CDE-AC74-D73202E32788', '4607003244583', ' 0,0025  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC922508-13E6-41B0-AFF1-1B100EA9DFB2', '25805E22-DEA7-4D2D-B352-1E84F6F1673E', '4607003244606', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D27F4D9-F77F-48D8-9B9F-F9D1C217E436', '79AE560E-7ED0-414F-AB10-69139471635D', '4607003244620', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFD0BE30-5507-43AF-BF18-D0C6EF51C3BC', 'F1E42041-25FA-4432-A81D-178FE2A3E12C', '4607003244644', ' 2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A589114-C1FC-4AA6-AAC1-876B287A01DA', '1A8F7058-3AD3-43C1-87AC-7792DEC9ED20', '4607003244699', ' 0,01 //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7BC2079-F9C3-45E3-A0F6-F7FF36873437', '082788CB-01DF-4698-9EF3-602918269EF9', '4607003244705', '   10 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4096EFFB-8AC9-4B57-8B04-ECB23A94737E', 'D79ECE8E-952D-4B9D-B6BC-33D8E82DE9EB', '4607003244712', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCF98ECC-A360-47F9-8A61-DAAC8396B6BF', 'A060CD24-11A5-48E8-885C-6DB436A4654D', '4607003244736', ' 24  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E54385C-6C24-4588-A86A-4F4EB62AF910', 'C1554E93-F407-46EA-8C78-D77FC7000A24', '4607003244767', ' 24  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F54A41D4-A4BB-4CBD-8A03-DEEA2268F59F', 'DE16DCE8-9907-45FF-BDA0-7F798D2F68D3', '4607003244811', ' 0,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2968475C-B1E9-4AA1-AC72-BE6DB064BE91', '53AEF577-00C9-4A73-BBB5-C9B0B43F1267', '4607003245245', ' 0,005 60  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CE1F9F4-6AC8-4CEE-AC57-41C79F4BFB2F', '01DE5C3C-9685-427A-B88D-673338B42FF6', '4607003245313', ' 10  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BC39A9B-4DCA-401F-8246-75B7F1A56EE8', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '4607003245337', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02B12128-05A1-4AC7-8147-4DA81AB9B87C', 'CF6F9D3C-232F-4E31-8764-9FA70B39197A', '4607003245504', ' 250  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31AA4041-B530-4DB6-8D44-5AA9BBE17803', 'E4C5B43B-BA90-41D9-A590-8BB6969070CE', '4607003245580', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79D7B2BC-5BE2-4013-983F-8FBF36B9EF2A', 'A30A853B-5CB4-4607-BD51-3F642A317A99', '4607003245634', ' 5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52A13B31-B208-4DA8-8242-97DBB89B95B2', 'EDE107EB-0D43-4973-A181-3C001627B3CF', '4607003245658', '  2,5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11C593F3-C342-49F5-BB5E-6D90EB1CC000', 'EDE107EB-0D43-4973-A181-3C001627B3CF', '4607003245665', '  2,5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF3DF2A4-0D4C-4DC1-BDDD-5FB7106A1B14', 'F5F39EB6-C693-4284-8456-8DD8D8150B21', '4607003245696', '      6 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('666A05B7-0851-48BA-B0FA-C15D7947FEA6', 'E821C626-AB3C-4829-B9CE-F4F568841A7E', '4607003245726', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96DFE5D4-E9BE-4DD1-A70C-9D6136E8C007', '20C8E756-F4F3-48FB-99D7-78E7C39EA021', '4607003245733', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EC2B973-CAF8-4A89-A2DF-AFE9383E4552', '973B4D2D-3FA3-46B9-B5FE-7A10EA833356', '4607003246044', ' 250  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4313597-C918-4295-B56A-F9C679F98527', 'F7A93BC7-1206-46F5-B772-83D9B0C7F335', '4607003246082', '- 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DBFDFDC-546E-4FB5-BF02-E8874421AB89', 'B9DBD6DD-A0D6-40C4-B60B-F953B1DFE358', '4607003246099', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('689E66EC-06DE-439E-8BCA-4CFFD8A52CF0', 'D7BA583E-DF3D-4B7B-9B51-CE623923A007', '4607003246105', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('208240FF-7E2A-454C-B7C0-8B65F6FF9CA2', '8CEA05F4-C96C-4007-B9D0-86CEB65E4148', '4607003246136', ' 10  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A19ECD6A-C17F-4C5F-A37E-E3F796F4A5C0', 'A8F600CF-FDAC-4BB3-BA2A-9DB0DD687182', '4607003246150', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD3C48D5-B5C2-45EE-A3A0-E328DD42F5BF', 'E3509CA9-FFAA-4666-92E4-23E66A19C967', '4607003246167', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BDB2A88-16EB-4E75-A9C5-284BFB693697', '88A5DBF7-58DE-4993-A60C-62275B98B864', '4607003246174', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B667B9CD-3910-4292-9B89-A7929465828D', 'AD48568B-7C59-4D5F-861D-B3E6536E3FC0', '4607003246211', '  /   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAA633AA-FCDA-4B77-B47C-82CE41A2FA53', '4ACF79F5-683A-4DAA-B749-4B704FBF5AF3', '4607003246235', '  //  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('825040E4-1624-4331-9829-8BCBC5BC27AD', '509BB4E9-D3BA-4ABE-8CDA-5FFDEE6121E9', '4607003246242', '  //  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41445D02-E2FE-46E7-A415-89D9CC9ECD9A', '4F9D1F01-0E0F-4981-8E69-FCD919C30C32', '4607003246259', '  / / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8DCC1F2-A07E-4C7E-AAF8-AD7FCF8913CF', 'CA9104A5-70E7-4F8C-B1CA-8FCB1BFFB02E', '4607003246273', ' - /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2B04DCE-082D-48C6-A849-3CD52DD82102', 'ED336A56-EAB5-485A-AE26-9186B45B0AFF', '4607003246365', ' 70  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E38454F-B010-4938-B1B6-A4736257C2BC', 'DC7B5ACE-F581-4E6B-8D47-59D89B22C239', '4607003246402', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E83E746-C2F7-42D3-AA90-457FC629BD22', '90335F52-EAF5-4583-B416-C552CE716897', '4607003246570', '  /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B5C83A7-1750-4F27-BD1F-7296962CF6AD', 'E3F1D6F5-8729-4069-9879-74E68B20B4EE', '4607003246990', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20A5BCEC-620E-4EFA-8FD9-B4AEA92FAD5D', '29F629A4-2D68-4890-8BCE-F6B8D2D98A82', '4607003247003', ' 500  / 42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E88FE9F-DE82-48E4-8FCD-C5DCEB1F12AC', 'BE7C4A89-F463-4AAE-872C-408A89D186B9', '4607003247010', '- - 0+150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85BFD86A-E62F-4D29-9CC5-5B080637C3EC', '41A86B6B-8257-4050-A374-6DE78DC216A3', '4607003247027', '-  /  .  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97CAA83D-E125-4FA7-9F79-9A7A2E0A90ED', '482B2542-7BB5-4474-8ABC-A66799CEA3A3', '4607003247034', '- - 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE17B1B6-E6F0-4550-BC86-AEE7E19ADC9A', '823A52F8-9EDF-4F58-9017-EEA5192F330F', '4607003247072', '     0-3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB96BAFC-FCBF-41EB-B53A-45F8FD0E3B79', '568653CD-FD15-4C1D-8E74-A3A06E2C2AA6', '4607003247089', '     4-8  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB07C923-6C99-4A56-ABAD-07651319740A', 'A6E07012-71FF-4A6B-92C9-8533EB48CF27', '4607003247096', '  40  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A29DAE3-72D6-4AFC-9E17-DD96A4F1EC98', 'CDF7F9EF-D7FE-4FA4-B429-84C4470E15F9', '4607003247119', '  80  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B11F2B1-1049-4507-B941-6E9359DFC606', '747F6A58-0F58-4D22-A588-66C755B14B49', '4607003247225', ' 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DF0828B-FEA6-4EF0-B9EB-5D2AC2FF93E4', '06406BDB-A743-475A-B7B1-6469329BCC26', '4607003247232', ' 5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D36855BE-B489-4614-B97B-55AC56E7656B', '3DA2217B-0562-4940-B132-B985F595DCBE', '4607003247263', ' 0,2  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFF6E9BD-6A1C-41A2-AECE-AEB30859DBCD', 'F9FFBE39-291F-4688-A536-6DCC68AB08C7', '4607003247294', ' 0,4  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B36E1D9-C57E-47D9-AB11-B3F7DB02C900', '0431B4DD-FA86-4A7C-A7E7-519A5F7B272E', '4607003247362', '     0+ 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD874592-0F4B-446D-9086-31B3A6D337B7', '8C5DB4F5-A262-4EE4-A993-E18D41A36BB9', '4607003247379', '  / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B5E41DA-57A5-4D78-B4EA-59A4C4DC5370', 'AEA565AD-C774-4F47-8431-28A39DA15610', '4607003247409', '-  /      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B8D30CF-1C31-4E7E-B5C9-CE0B6142ABAA', 'BF58B097-9F61-42CE-B87B-FB54DD354FD0', '4607003247423', ' 100  42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20EDBE47-72B0-4C09-9C85-A321BEC85F98', 'CC94363F-4A8E-40F9-83DE-15A17356396E', '4607003247478', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB973C38-E2C2-4069-AFB4-A9F85B0367E2', '2548F93A-4536-40B9-8296-355A75AF16F7', '4607003247539', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EBD2836-33D4-4B2D-9416-437D39BBF99B', '449484DB-67EA-4CE4-815F-D0FFF05346FF', '4607003247546', ' - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C44FFB9-7496-44B2-9497-F808C5B36473', '9C9BB25A-3B79-4312-9C84-5426E69AAE24', '4607003247607', ' 500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6B29FC6-D589-44C0-B467-28EFEDA3BA52', '749F7F70-90DF-447B-BD40-68B5D3022F26', '4607003247621', '   - 500  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D816DD60-3678-4AC6-8398-85288D3A5191', '8B7AC8B1-7A5B-40D1-869B-634E5BA1068C', '4607003247638', '  500   / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80F36231-1941-436F-8E9E-A80CB812F4D9', 'EB3D9BA0-7FAC-4D4D-9883-7F2D457117C5', '4607003247652', ' 12,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C24EE17F-43AD-40FC-B647-FCBD88A375FC', 'E1F6F4BF-CB11-4AAF-ABA5-D7916E6D1600', '4607003247669', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39C60111-FE4F-4F1E-A0EA-B7E66A8F714D', 'F3968626-BF9C-4AD3-8F13-AE32D2F08C6C', '4607003247676', ' 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32CD5261-21A6-4300-9768-590CA8995526', 'B59F9546-4571-4914-BE36-12A77A271AEC', '4607003247683', ' 0,005 //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D48A45FA-D115-4912-A8AE-BBEFE61AD59B', 'FBE9A8D5-3120-462C-A12A-D942003431CE', '4607003247690', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4513BB5-62B1-4B47-A081-9B683EA124A5', 'CE321FD1-87FC-491B-97E4-481CFA2BE7E8', '4607003247713', ' 40   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C56A0867-6EC8-411A-8470-239682C65538', 'B991D4F2-3BE1-4BF3-977D-00F181978A19', '4607003247744', ' 125  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C03DCD6C-A2F3-4D99-881A-C93A94848200', 'E438F4D6-8EEF-4793-844F-EC68B4264B1B', '4607003247751', ' 500  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('516C6915-D6C3-45EA-AB18-C1C09A5A7C9D', 'A410F55D-3BB7-4553-9C09-CCA0691F8B22', '4607003247768', ' 80    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C398F8FA-5B8D-4895-98D3-47D70156D83D', 'A2864CE8-2E2D-4506-878B-CCF15BA66D7B', '4607003247775', '  25   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF62EACC-9F21-4606-92AE-D293ED406A39', '9075A33A-BB8C-4CC1-9AE8-53420879CCA6', '4607003247799', ' 80   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDEE733F-AA51-4D4E-B827-1FE8355B69DA', 'ED5EB627-6D00-472D-9147-EE703BF079ED', '4607003247881', '  0,1 //  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B9C128B-71A0-41C3-BE5E-9E5C83656D3A', '535D2189-C3AF-4974-9151-2739D91B4738', '4607003247904', ' -    200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('581B2A9F-8F17-434C-AC35-7AA364BE3F5C', '696AFDDA-5A55-4C10-92D5-FC916F32E737', '4607003247911', '-    200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE3AF5A5-9CD0-4B2F-899D-942303A8C5B9', '609D92F8-5D2F-4289-A2F2-2767D60CD692', '4607003247928', ' 0,2  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEF69BA3-AF12-4F4C-AEFE-50C82E6DA8AB', 'BC1A90CF-907A-4888-B36F-D8334107D802', '4607003247942', ' 200 //   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('160C1A38-5CDE-490D-A68F-BD40588C6038', 'F5E4D100-1773-4AAB-A36F-0E4BB4C4B6E4', '4607003247959', ' 600 12 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF4E5B5B-9707-4DDE-B1DE-8D1EB5B8EBFF', '46A61C5F-BE8D-46FF-8DAA-89641C5CCD9B', '4607003247980', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE13FAF0-849B-47CD-9638-F039B3A88EC7', 'AD48568B-7C59-4D5F-861D-B3E6536E3FC0', '4607003248000', '  /   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B88CFB4-DCE6-4AFD-991D-9905B661353C', '00476D77-AE86-497A-AAFC-68ECC0529042', '4607003248017', ' 2  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E0B9B3B-F622-4635-ACA4-4E784B690520', 'A176800B-9D87-483B-900C-6440E3539911', '4607003248031', '  /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1ABFCD0-F4C3-4A28-836F-541624D25561', '78F91E79-99E7-4203-B2CA-8F1B205E5C37', '4607003248048', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('567E21A8-C67B-4AE3-AE0D-4995724BC926', 'AB12FE04-AFA7-4A43-8D6F-C92D3E599846', '4607003248055', '  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2B52551-E820-4866-B4E7-22617BA21419', 'B92DFCBC-36D8-4CD7-BB6A-3400688C65B3', '4607003248062', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE7B9956-D3F5-439B-996D-B930496A2EE5', '8B353AF1-929A-48DA-BABF-51B401992315', '4607003248116', ' 100  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6BAD25A-C056-4725-8963-B6F69617E356', '72C930CD-2168-4204-A34A-5B966670B400', '4607003248215', ' 10 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33AFFA2F-1457-499E-A7ED-766A576CBA8B', '455CB0FE-2F64-4258-8B99-F6A24358580D', '4607003248222', '  //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DE7852E-75D5-4F5C-A049-26A6609D9E60', 'D1809A06-2439-4960-9513-5A3733FC58C8', '4607003248246', '-    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19AB0108-A3C0-4AEE-800E-4861C74E2E74', '9090D63E-41AF-44E0-BBB7-503C5845EC01', '4607003248277', ' 0,4   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35442CB6-0ED9-48AB-9AA4-76D1F45A4F85', '82AB0C71-E628-4C59-B2A1-C25EA872000C', '4607003248307', ' 5   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99457171-10AE-4385-AE25-AF7F2FE1BAD1', 'CD62540C-A968-4A30-899A-EB418689695B', '4607003248314', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EB27808-DF60-4495-A6D1-774E429814B8', 'FC5AF4B5-8BDF-44AB-AF13-B7E8A6DB48B3', '4607003248345', ' 5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CDA8C66-C2E9-4367-9B09-1155A544B9A0', '9549EEB5-D47F-49CD-AD81-1EC147EB62C1', '4607003248352', '   teens   8  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CBD1CC0-2FA4-4439-9972-CC5BD3B7290E', '2EEC8434-BFC6-45DF-95F8-34B52254C74E', '4607003248369', ' //100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFEB8E4B-C382-4C23-9FD1-89A858E5FD44', 'EBCC8D02-397A-4E7D-BF41-85979CD891AA', '4607003248406', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEDAB71D-58C9-45F5-95E9-1EF7BA59EA6E', 'CB7207E5-9413-451B-8BF8-4BB14DB027B7', '4607003248413', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DC2F85A-8B6B-47AC-A7FE-0B4DE5510BE5', '7AA455DB-8D5D-4926-AFED-3FE0EFA47405', '4607003248437', ' 400  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2792FB72-52D5-4793-AE1C-C3083896DD69', '33B52667-B318-4189-88AB-684A940D45F6', '4607003248468', '-   -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BAEB3BF-9975-4359-A96B-3A46232C5B76', '3ABD61F3-0E48-4390-A351-D039D8472BFF', '4607003248499', '-    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A3957D4-F800-4E5C-B2D1-DFC85D92546F', '70B693F9-B7A1-4730-8425-72BFB8BD7CE1', '4607003248505', ' 50/ 18  120   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('046474BB-0D2F-4483-9719-9A7595B74EB9', 'A0D94D62-B0B8-4012-BD06-B087A010FE31', '4607003248512', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E68F864C-829C-4F5E-AA70-CB74A73F6742', 'D080F738-6158-45B8-9403-E68E61A0D84F', '4607003248536', '  50  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B40DDA63-E7AE-487E-9792-24C40873C6E4', 'E83EAC18-1C8E-44D1-A751-68B1F5B28F57', '4607003248543', '-    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('745D68A4-7965-45A7-ADB7-969488C505CC', 'DDA8D735-590E-4926-89AB-9D87E58728E8', '4607003248550', ' 0,01 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5029DAA-64C2-4E52-9F74-C2BAB67920EF', 'ED05C63D-786D-4B47-A536-3D49DFFC174F', '4607003248567', ' 0,01 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D63790A-ECBC-45F5-953A-A2200E1513B7', '015B04E4-50BE-4A2E-B028-C0036CEA6A2A', '4607003248581', '-   -   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C7BA733-9982-4591-9B30-CD58410A8320', 'CB294D01-03D2-4AE3-B487-C63A18CB7BDF', '4607003248598', '  /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B181E9B1-1E24-4DAE-B6D8-0EA8DE321CE1', '986AE6EC-B909-499C-B9F6-E9E468199E92', '4607003248604', ' 10   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F469E0D-828C-4B44-AAC5-3B3BE502FB39', '6BAFB635-EDFE-496C-9C53-26AFC216F516', '4607003248628', ' 50  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77956C02-9835-4165-957B-905B884EB395', '7271A329-A0B9-4307-93AC-30598590AE32', '4607003248635', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A207137B-128E-432D-9018-56EB9A785389', 'D6E42F8B-299A-4204-A389-FB061B6EAC19', '4607003248642', ' 5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D4F39EA-6234-4BAF-B341-1E51F3990EE5', '7D45696E-4550-404B-A011-01ACBA485E54', '4607003248659', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('685BDA56-F210-41F6-8804-4C2E5C8C8B32', 'A79D4BB9-3FD6-49ED-BBEC-9508B03A5931', '4607003248673', '   0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E070567F-6974-4BC3-ACCA-A0F9967C729B', '5EDE0925-26E5-42F1-88B9-B6AADF2EB00C', '4607003248727', ' - /  spf15 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91C042EA-CAB9-4935-8A88-6C7FBE1329D4', '4CCD8410-2289-44F6-9E42-321E9F4DBB5C', '4607003248734', ' - / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B21FF4E-8F16-4ED0-975B-37FE5C373BFD', '95D6962F-8BB5-47FA-87D6-86BA0A1EA5C3', '4607003248741', ' 0,02 ///  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D1082AE-AE18-4875-B279-A9A967DD166E', '934EEA89-E9EC-4763-B44F-31C666EFC0A1', '4607003248772', '-    spf50 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F2559D1-ABDF-4A7F-8455-77AB8368C841', '2534A872-F88F-4177-AAD4-30D308C2AE25', '4607003248789', '-  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7CD542B-1A12-4547-BE3E-EF487FF2CFA2', 'F357524F-7023-4ACB-A6EF-3A31F9607DF3', '4607003248864', ' 0,01 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68A0792A-D06D-4139-ABB4-7112ACAB70B6', '81788E6F-C71D-4721-A054-658F19C1986D', '4607003248871', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A612B0B-3DA9-45A2-BBC8-EBA8C3049F09', '76551D51-15FD-4C8A-8FAF-513F0683AE69', '4607003248895', '  5% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F769C8C-0B70-411B-A517-7BD8E1065C45', '077DE7BE-9D16-46D4-9D36-66831051CD72', '4607003248901', '-   sfr30 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09500D37-19D5-409F-B812-781870D2DBEE', '22BA9638-E13C-47DB-9529-2268E17F4054', '4607003248932', '  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F263FD08-B40A-4F3D-93CD-7065B5B2E579', 'F5272511-5194-49FC-9A39-3AC85C7BD37C', '4607003248956', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16CD7B30-FE8B-40F0-9AA3-EC39AF25C0C1', 'BA18864B-4375-479D-8E7C-4DE00FC8350A', '4607003248963', ' 10  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8366F32F-6180-4E00-9461-81590BAC68C6', 'FC6DD5DD-0229-439D-9A61-F869CD9014EC', '4607003248994', ' 0,6 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9BC1385-2C8B-4869-BC93-58BE5021D787', '3B0C218C-24C6-483E-AA5E-F95F000B711E', '4607003249021', ' 150  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9C3167A-E273-4D0C-AE5B-DFE9EC2AF06D', 'B2D2C149-A49C-4D86-8461-ADCCEE1613DD', '4607003249045', ' 0,2  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37599F79-72A9-409A-9A38-DE35E82F8207', '9599686A-8971-43E5-A6DA-3B4620E5D4ED', '4607003249052', ' 75  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5693B1F6-811C-40DB-8143-77BBAEF255FA', '5F71EDDD-C322-4BFC-A7C3-FB6D511BB779', '4607003249069', ' 25  / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6B56BC8-B8F6-472D-9F9B-110561443E49', '6257902B-6B05-4C86-A4AE-AE10FA4E6BD0', '4607003249151', '   5% 60  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51818F06-FCD2-4E4B-BE92-E3BCE46D8E68', 'ED397675-D882-46D0-9596-DC9DFBACA37F', '4607003661052', ' 150  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A740B25-FA16-46D0-A3B9-3A6B616391B3', '95D7B093-3774-449C-9A61-1364C55398C2', '4607003661700', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2E8608B-B8DC-4329-8E78-EC0779A0B40C', '95D7B093-3774-449C-9A61-1364C55398C2', '4607003661731', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57284015-9C25-474B-8CA6-AA7F90713AC4', 'B01F0077-0EA3-4644-ABAA-DDF3EC47A987', '4607003661755', '  0,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C845489B-519B-4E37-BEBB-728CCE197964', '76F2B168-26B8-4FCD-9B97-3889F4BDDB76', '4607003661762', '  500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5F09760-BB55-4D6B-9A24-814E5E4DC0C5', 'CD75ACB9-55E7-4D7D-83DE-7E7735AF39C0', '4607003663131', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58063E90-717D-42D7-ABE6-6044B5FC127B', '0CA03E33-5B8F-45A1-AEA1-C3CDE6D4B17B', '4607003663155', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B654E65-0B74-4557-B5C6-6470E80F0DD0', '5EA112A5-3920-4594-BD09-12C5C419A15F', '4607003664121', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58A11015-7789-484F-AEA9-6B887D3DFC4A', 'B1223618-E317-4F66-9F84-ABD6AFEFABF1', '4607003664152', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C74F071-48AE-4DE1-8180-7250F12676A3', 'E5352466-DD56-4B04-8BD1-E5CA68E27C79', '4607003664251', ' 250  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0BA4F0D-D5FB-4434-8934-B49565FFA3F2', 'FE37EC4D-2F1A-4399-9159-8435F56A8D4D', '4607003664619', ' 10000  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F399049-94F9-4028-A6E1-2700F64F5D30', '448087F7-578A-4E86-8175-B9B966DBCE57', '4607003664756', ' 25000  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9031C6E8-8DC1-4556-AFE1-D986BA6079DC', '448087F7-578A-4E86-8175-B9B966DBCE57', '4607003664787', ' 25000  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('566937C9-49C3-4693-BE19-B8A3DEEBB623', 'EEF7BD5B-4627-49EE-92D6-5E21218A1A01', '4607003665043', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B112E30C-A610-4B10-BEA0-81BAF8753FC7', '993C55A4-BBFC-4937-B21A-5995C2A5FBAD', '4607003665326', ' 80  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('429FA111-A18F-4F4D-8F40-4F0A02C2C023', 'A9FA2EDE-C748-4B01-ABA4-4A1488E4E95F', '4607003665340', ' 80  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E982392-08E5-4F81-900E-AEF168F48B48', 'B3B15A5D-135C-4675-882F-2580C7942139', '4607003665869', ' 500  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F19AE828-7840-4AC5-8FB0-B45105664BFE', 'B2FFD3E8-0806-4916-A1C6-6927A2462087', '4607003666033', ' 20  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53EAD377-EB8F-4AA8-882C-72F5A3CE297E', 'FD4DA183-1004-4F0E-B5BD-089F524009D9', '4607003666149', ' 0,25 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D151DC6F-92E1-4A2E-B375-3B032E7CC6C6', '6ED63115-234B-431C-92BE-13C56A31503C', '4607003666170', ' 0,1  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A1532C9-0746-4AAE-8B28-97062E260991', '6F80F4A1-C19D-498D-A0C7-C6E60D801610', '4607003666309', ' 0,25 //  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD7E7148-67EA-4FF0-9330-56CAA77949D3', '8FCD8C6A-0503-4CB7-9D24-92C9CDDBF033', '4607003666361', ' 0,5 //  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AFA75B9-B9A9-4C4B-B101-227C7FCE4576', '457637AA-814A-4B9A-AEEA-1F0CFC613890', '4607003667269', ' / 125+31,25 5  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF654A76-A30E-4576-A1C9-8EA9301BB890', '43A7109A-437B-42DB-AD15-B5C8B0B96890', '4607003667337', ' 0,5  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('021F4BB1-2577-40A2-80A3-64229731EA1C', '511BE3D3-696F-4DF6-813C-2316BA59E4FB', '4607003668136', ' 500  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFB1B347-DA41-4CB3-A838-04F6C6582980', '19425F8A-B25B-49FC-B326-AF4C2DE6420C', '4607003668181', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72DDB9B1-C026-4C7E-9474-BD58F01F203C', 'B24479B7-AA98-4325-A65C-9C050E60FCE6', '4607003668310', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27BC2BF5-CAD6-457C-AB72-051C70BF8E90', 'EA8BF6FD-0D3E-43F9-B19A-1BEC178A68D3', '4607003668471', '  // 500+125 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DF90D0D-815A-46C9-A4D2-16041906DCD3', 'BB94C8F5-3898-42A9-92CC-0869819F6A9C', '4607003668556', '  / 875+125 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80696EC1-1485-4A62-B956-8D62BE406A29', '521BFCFC-3057-4F72-B547-F14D5C12BF3C', '4607003668587', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D00659A1-D128-465C-9928-9A567141392F', 'D9233E2E-0BFD-4073-9440-F4A7B18B8F6B', '4607003668662', ' 500 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E4406A3-D823-49A7-8099-193CC81D0EDE', 'F73DEAD0-71A9-4B65-BFE8-9EDA7CB2441B', '4607003668778', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C7B5ED2-9F21-45C8-BB32-772299059BBD', '62B34EFA-A0D5-4A19-A913-018788E5221B', '4607003668808', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDEE4E42-F6DE-4284-83D6-EB40D862F29B', 'C278562E-DBC7-457D-96BC-852DDF8A33EC', '4607003668839', '  250  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F947293-256F-47E3-B39F-EB4D7CD61851', '648AB9AD-0669-46C5-87BE-77138B757C4A', '4607003668976', ' 250  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0DC03D9-2C78-46D9-9982-8E5B5480A6D2', 'F4406DE7-01C6-4EC4-95B9-EC717EDA0610', '4607003669003', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB043594-4880-482D-A297-2948B04C0864', 'CDE52199-EBB5-464D-9C25-BA8CC4F78D18', '4607003669027', ' 0,5 60//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5D51356-E4D2-42EA-8FF6-4CB975D334DA', '73F7674F-7790-411D-8F3A-CF4A17104758', '4607003669164', ' 2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CF1AA3B-69BB-4310-89FF-8EC9ADFAA9ED', '8DDC723D-FD54-4232-96DE-8A9E100FD5AE', '4607003669263', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA590242-4E59-4752-88DE-6B40614523A9', '020E7356-6C23-45B4-875C-6182F0C21CD5', '4607003669270', '  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('697CA03C-3975-4225-BB17-2C266797B59A', '994F511E-04CC-42FE-BC27-0C7A354ED3CA', '4607003669287', '    500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CDF0748-5B2E-47CD-96FD-4A7864C27DCF', 'D1F6B56A-FB2F-4D6F-A488-C630780F6805', '4607003669591', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B2E0A9D-D0D0-4D53-A513-19F7B483E5FF', 'C94D964C-E949-4253-9C6B-A4958E314018', '4607003669652', ' // 200  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B83B6105-7FF5-4752-A703-7639ADCD64E7', 'C0673726-D197-4039-90B5-02AF8F0C2501', '4607003669874', ' 2  / -  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED146F66-D354-47DF-9A76-05CEF98C30AD', '07F42C16-4CA8-4150-9FA5-03209D4BFA1B', '4607003669881', ' /- , 3 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCA2323C-6BB7-4CB3-9004-36657084858D', '5998D880-41B1-4048-9DA8-0912F5CBFEF7', '4607004310133', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('491D49B1-6029-4A47-BA25-0FC38CDB256B', '92D275DA-2A71-4D49-B6D2-8EC020FAEBA1', '4607004310249', '-   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7624B6A2-4677-46A3-8E4D-4023CDD54647', '1A4F989B-8E19-44A6-B415-99EE8A9EFFFE', '4607004430015', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74741A23-90CE-441D-A592-5B3E11C93C42', '9EC1E7A0-23A0-467C-AA0E-B10410DB58EB', '4607004430039', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F97DCDA4-2814-4678-B1DD-B0BC0289C098', 'C76A23CC-B2FA-43B0-8F75-358DA33B3391', '4607004430077', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B91FE76D-E816-4F41-BB27-0AEADE257FF2', '92192037-49B6-4033-BFD8-177670B9554A', '4607004431357', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3A35927-FFF7-4091-ABE7-DF8A9F6A49E7', '40644418-D48C-49F3-B89E-D98080414F5F', '4607004431418', ' 0,5  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9879EAB-F22D-4CCE-A94F-FFD39558C887', '2BD7DAEA-55AB-4032-93D4-47FD6A372336', '4607004431449', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE2C629B-6A72-4DFE-B8A3-8E362DA71805', '2CAECB7E-3B33-485E-930D-F88C358F7E0E', '4607004850011', '-    30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0532A628-97BE-49A8-8CF9-1B3466E48F53', '7B3AA473-25EF-4E56-A795-776343779DB9', '4607004852084', '     /.     /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4EB410A-513C-45E5-9012-59586925651B', '402A68E1-4C3F-41B7-8190-09CB4FD44C5A', '4607004852091', '  // /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FBA98B3-F274-47F0-B4AD-D61F7EFB7366', '186D550D-EB9F-467E-9354-36D2FF8D7DF8', '4607004852152', '     /.      1728', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB132029-0121-473A-A72B-9CE9430963D4', '62D8CBAB-D024-467A-9961-046F9BE9A2B1', '4607004852169', '     /.       // /.1728/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D190B89-486B-4B0C-ADBC-DFF3EAD7D036', '8FB033E6-41CC-4718-954F-826BCAE70106', '4607004852213', '    / //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAB25230-B8C1-4951-A4C2-D708413ADFF6', 'D8E85C27-B48C-4405-B27A-59288D471DA0', '4607004852312', '   /    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('905E4FA7-7567-44E4-81CC-1D77C7B98282', 'C4BFA45E-55E9-4D3E-9735-0D19121ED1A9', '4607004852510', '-       /.   // /.41*60/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C8149B2-202F-4DFF-9E42-A926C4E1C043', '29C6CE4C-3F12-43D5-BCFB-B359CB53D9DD', '4607004854040', '-   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52A1A9C3-6AC5-4DF6-8B32-D4EEC450558D', '6D29929B-C587-42FA-BFFA-757368B730DF', '4607004855047', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E684E98C-483E-4B8C-B047-F8FD9B5FA819', '68A8BB02-7175-42AF-88AC-9974EF03470B', '4607004855061', '- / / / 125 ', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FFE1BDB-5E66-4C78-85DD-F2D787BB8E72', '8FDF9BBE-5544-4A87-9792-1EE370B95367', '4607005280336', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4737B842-6ADC-46A3-8AA3-F195992E07BA', 'D5B73DE7-3326-4FC9-8991-0E4434F23F81', '4607005280435', '    40 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8E90921-000D-4D51-99C1-6E0DFA0A9C20', '9FB6584C-8224-443D-96B8-D8B9D60D53B4', '4607005280695', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6933C0AD-38E5-4422-A3CF-A3BF9E709A5F', '8BBE24DB-9085-4B61-88D8-CFA5CAFFE12D', '4607005320827', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('846EE555-6715-4FAF-B741-5F66735A0610', '9FF0FC39-009A-4FA4-B93E-9F26EBD75F74', '4607005320919', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F49D96F-EF2C-4F35-9E23-6EF14321CFDD', '630C4611-084E-44B5-A001-8D693AAFA15E', '4607005321145', ' -    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD6FE06D-719C-4FEC-A2D2-326475458255', '5A537779-1FC7-42F4-9267-A3BC078B9090', '4607005321299', '     100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3849AF31-E344-4D86-9973-E75C27FEC6AA', 'FC1E966B-AB2A-4174-97D8-35C7C32CBEA6', '4607005322012', '   /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A73F3B13-5D24-478C-B03F-5068D3CE20AF', 'BA378D1D-1B75-4E33-B502-70D027CFB921', '4607005895455', ' 2,5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C07DA6E5-BDAF-4306-9DFF-2F719DB96CBF', 'D936DE22-75D1-4759-8173-DAF9186E538F', '4607005899026', ' 24  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58C42277-30A7-46C9-A160-9963C3C75758', 'D3D68CC4-0EC7-4E8F-A872-B974C66D4233', '4607005930231', ' 0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('892C8310-DBD8-417F-B405-49454237E177', 'E19B1D87-045F-45CC-820C-AC86C01C8A27', '4607005930316', ' 0,1% 15   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49D9863D-77A8-4432-8C02-2A99AD84EB73', '90085A69-F4DB-4875-9542-001108E9D541', '4607005930361', '  0,05% 15  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6EA7C0B-A626-4A01-9CFA-51ABAAF61889', '883A14C8-638D-4777-B8AE-4EC783D7F713', '4607005931597', ' 0,5% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFE8F0FE-8DBA-44AF-95C4-0F37F3DD0F1A', 'D867208F-6656-4288-9275-501B44E20235', '4607005933539', ' 5000/ 5 - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7711E0E3-3DF8-4E2E-BB12-4388A99F27E8', '7180B3C6-FFB8-4E84-8EB8-4A1DF88D7CCE', '4607005933560', ' 25/ - / 3  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D322E77-DDBC-4772-B2E7-C5F97CF20F90', '687270CE-81F8-401A-8B56-5521411926AC', '4607005933836', ' 0,5% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EF1BF15-A399-4534-A8AC-80FA7E7172A3', 'FA15C994-21A1-4F25-8940-BEF9A39F2B9D', '4607005933874', ' 2% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E10C8897-B4E2-4A4C-8C60-9439D3985F29', 'FC963FB0-4CBF-4F38-88BF-B85EF7E4033B', '4607005933904', '  10% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48F819A8-A958-4756-9729-4A188290EDB3', '88E1AA58-919B-4192-AB4E-D74E97E455C1', '4607005933959', '  40  / 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7BB1322-16BD-42A5-8E7A-C96FC4855F28', 'D40DE8F4-6E3A-44CE-9CF8-71989F033A69', '4607005934048', ' 40% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03B4F05C-4AD4-42B5-AFFF-EE0D0ED1424F', '25015BCD-AE96-40CD-BE99-CDACCD6E2B80', '4607005934062', ' 0,1% 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3F8D8AB-B3B9-4B7A-8579-B44469AC5ACB', '3E1DB9E2-3410-48C2-8F50-1AC400BEA234', '4607005934116', '  0,25 // / 10 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BA4A70E-4AD1-450F-BDB1-F954499D0C4A', 'C46D34B3-5447-4604-A879-72790ED2AF95', '4607005934147', ' 2% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A762D48-0DA5-41B0-8726-D670AB6E2B00', 'A93EDB6B-87E0-4D49-9DF5-7DC0DE9935D6', '4607005934352', ' 0,01 // 1,5 -  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23C1DDD3-CFEE-47B6-9411-F2A393D9EF70', '04534B27-24FE-417D-BD62-F24A9E2CDCA6', '4607005934369', ' 0,01 // 1,5 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E922298-649A-4DB4-912C-E0C132E5309E', 'D72D9EEC-C7A2-493D-AA48-CCDEC38CBC91', '4607005934437', ' 30/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77A32526-D451-4E57-9B9A-B00F4812A014', '1C94BA1A-1832-438A-B857-A331A3B9410E', '4607006490079', '    9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FC20BBF-1628-4346-AB24-5E603D066464', '8768602D-19A8-46F3-8F7E-9EC887B4D190', '4607006670020', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('368CC9EA-B501-4D5F-9E04-B03FC81F6544', 'DFF10265-D282-49D3-88FB-488FD244999C', '4607006670082', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F10F9BA-FE27-4261-8649-AD0000B2E483', 'AA20F492-5730-4E9D-80A6-1729EFCFC5CE', '4607006670471', '     16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('442EDD07-E636-4622-9D1F-D434412A24F0', 'F55245B7-5B41-494E-B4CD-2F6099EDD366', '4607006670549', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8B8614A-971A-4D53-A6D6-BA971095FDB8', '27007DB3-D4BD-454C-B779-D4407523B1D1', '4607006670563', ' 1,97,2   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('531EB7A8-8E6B-483C-A8F4-4BF68181A8C2', '76EC5E4A-91FD-4651-83A2-4F03943B46A7', '4607006670969', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AA5FCBD-8934-48E2-979A-967554AF5AB8', '13C7DB80-9D4E-40EF-9D1C-F3D79FC99FD7', '4607006671430', '  /. / 1 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC39EEB8-ACB1-4B41-8896-C6D7FC6434ED', '3DB80A7D-52B0-4229-BB6E-35FF63D245E2', '4607006671508', '  120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E9C167F-72E0-4D2C-93A1-2BD2B34F8F52', 'AA20F492-5730-4E9D-80A6-1729EFCFC5CE', '4607006673182', '     16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8022E9F2-60D1-40B7-99FB-B834095D4881', 'DB620AB0-06C8-4CAB-A848-4ECD5F611AA8', '4607006676954', '   5,6   /-  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83F20E45-DE5F-4E03-B937-BE6300D1DD48', '83B0106E-9C26-4B7A-838F-D86348B031E7', '4607006677050', '   / -   5,6 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30EEA0A9-D7A9-4D68-8CDA-C1E13656DC09', 'B4671A2F-CDED-4483-AB92-B72CAF71B37F', '4607006677197', '  5,6   /- 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('720C2F2F-20BD-4686-B1E6-356C1605C8B4', '9BE03E2B-B055-45EE-BCE8-2B83F94AC49C', '4607006677296', '   / -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADFA99AE-D385-4FFE-96E6-3D7E0088BCEF', 'FC27EF9B-A38D-4134-B40F-DABC7CF0E27B', '4607006820128', ' 5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CE7D252-2790-41A2-9A22-36FB4764E643', '2A1A8E39-52A8-4474-AD16-AC5E33630C9E', '4607006820142', ' 5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7B5410C-481B-4546-AAD2-ED75922E9F9A', '9BF66C3E-1036-4087-B1CF-7B9714398289', '4607006820289', '  1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAD1B260-4730-4921-88F4-8013F95FEAEF', '868C50DC-41AE-4F6F-B078-2CF4988C9079', '4607006820302', ' 5    10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8676E760-07DC-4C06-83E6-A4789830F187', 'FCE7F94B-B8C1-4372-A68E-C8464D9458DD', '4607006950030', ' - 0,05% 70 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40D30FB5-BD63-47B2-B27E-EA69253C45D0', 'EF19AF55-4760-4385-8A39-C387538ABBED', '4607006950047', ' 0,05% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B138C5D-37B8-4C95-83B7-4AB5835413C8', '824ABEFE-13CA-46D5-8DBF-B3DF02DECBDE', '4607006950788', '  10%  38', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92C9384F-4629-414B-8B70-D0E575F799C1', '689BCF01-A568-4187-B1F3-EA1302D3F1FF', '4607007170239', ' 5  .///  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('912A08BD-A3F8-4CC5-8554-14E2EC18D926', '26EDF895-54AB-471A-8F23-0AD399613360', '4607007170246', ' 5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C437FD85-99BA-4850-8BD9-C8127F49BE14', 'C7C06D72-3DD3-41C8-B9C7-6046A1E05327', '4607007170253', ' 5   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC4382B0-9324-4363-A619-ECB30278824C', '8F54F6F2-277F-4AA9-A6C9-CAB09F9AC81B', '4607007170260', ' 5    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7B50A81-A6B6-40C1-9CBA-420C2C1711BB', 'E94BECD3-630D-49DA-A43E-A80C9F77AED6', '4607008010251', '  200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16E9C147-1777-4B6E-8EA3-3C6922D2B65D', '40631181-7DC2-4864-B0F7-FFD0A34AF41A', '4607008010275', ' 400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A489ED4-74D0-4AF6-B932-599314C90A93', '58937A59-9C0B-4EC0-9BA5-66CEB5AE1A5B', '4607008010282', ' 400  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65E55BAF-A5E3-4BD4-8EBF-B807684428D2', 'DA951261-2AC3-4562-93A9-A61508392DF2', '4607008010701', '   3   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EEFD5AA-C67B-4167-91A2-DDFF9562FB9B', '2F4D4E41-549D-4A9E-B326-DEFC03318770', '4607008130140', ' 875/125  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABFC4374-A37C-432F-A224-6DF995D89E6F', '66F50A6B-56BA-446A-9414-7B75EE5F7EE4', '4607008130713', ' 3%  4,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D3898DE-C691-470F-B63C-7FE97A7491B9', 'A1678961-E829-4E77-BC77-B4F8BC87B11F', '4607008130850', ' 500 125  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A1D8DD8-3D0F-41A1-95BA-C2EE26AD98F3', '4BFCD08C-BFE7-4394-82D4-010B1CDEA71C', '4607008130911', ' 9500 6 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC46AE27-5912-4874-B790-A9F5FB104655', 'D24CD007-EB72-4B85-8CAD-2EE067092151', '4607008131062', ' 5  20   / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66B2627D-2CC0-487F-91EC-BDC4FABD3ACF', 'BAE71CC1-5F47-4C9B-BD5A-9772B8963B44', '4607008131321', ' 27,5  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0309863-0DD1-4542-B2EB-3E769805C784', '7B5A0853-96DE-4F67-919E-6BCA113AC0A0', '4607008131765', ' 0,5/0,4     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('749DED35-0470-4805-969C-F7C62D205F1E', 'D87A58B5-81E7-4379-AC8A-72385E250D2C', '4607008131772', ' 0,5+0,4  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F26FAA6-117C-4A40-AA7A-0B22EA1FFFDD', 'A5AD8C1F-8474-4862-A7F2-04700CDC6B88', '4607008132144', ' 50/ 120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D23729A0-979F-4F80-A5EC-AF431739089C', 'B21AEFA1-EEC1-42CD-8294-D3AC99F579CD', '4607008132151', ' 125/ 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D4275AC-DDD5-4BBE-B2C7-21D5F632C9CB', '0430033E-9089-4D36-B758-744F14016ECE', '4607008132168', ' 250/ 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54CFA330-C26D-4598-93F3-7B31DFA86C4D', '739305F8-765B-4A48-B3C9-5B7674E94482', '4607008132175', ' 25+50/ 120 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE915D5B-FDCC-44F4-B67F-6E81772672F6', '66CBCAAC-BA18-4D66-A71B-686EC59C4B45', '4607008132182', ' 25+125/ 120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8A05FEA-E053-41D3-9157-3933C680DBD8', '2B22E94D-66CE-492C-BB06-C3DB89136F25', '4607008132199', ' 25/250 120  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22FA0FB8-FF64-4FC6-A38A-97C52A87BA53', '14C61F11-9E09-4589-AC34-CA27E76BB157', '4607008132298', '  50/ 120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CD26D60-A7D1-47FA-8207-83751494B4B1', 'C94A109D-551C-428B-AAE4-6B258A85966B', '4607008132366', '  22 +184 /   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9D4595F-7BE1-4730-8919-0B03F915C645', '62A9FD3D-4AE6-4699-9A2F-BC407D01815A', '4607008132755', '  50+250/ 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B1BD937-AB22-4D4A-868A-BE7EC7BBEB37', 'B6069E79-D62D-4633-9A46-B582F6838164', '4607008132762', '  50+500/ 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1452D68-F38A-4B99-AC51-95FCBC23F017', '433BC953-EB8B-4F29-B929-8F04C0FD5A1C', '4607008133059', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9841EE1-2EFD-4510-8B7E-CD4BAAA42C11', '4534AD04-006E-408D-AD08-8F933867CFFC', '4607008160017', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1737794-8F46-458B-A7B9-CC3F6AF25A6E', '80D1A108-4D4B-4FBA-8381-550365C4999E', '4607008160024', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('657162D1-874F-4920-8274-CDD52698F9A0', '5C8508FB-43E3-4D46-B24D-3F831AE8322F', '4607008160062', '   - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4889DCA-CED2-4EDE-99F3-3F6CB3AE764C', 'EBBB412A-270E-4576-AA69-81EA648F6D55', '4607008160086', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8F6E679-3B52-4AD6-B4D2-2A82D5D78256', '2995D9D7-6C7C-407C-B3BA-EF0B75662AEF', '4607008160109', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9C80D9E-84F3-403F-8D2B-E6DD1E582502', '756C0BB4-9658-4681-99FF-42AA24625588', '4607008160147', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34295026-6EBE-477B-9183-71C0B4EE7ED7', '1C427F68-5F5D-4382-97BF-5971E6315EBA', '4607008160161', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C26A96B-4790-4E74-89A3-161DC0CF47DD', 'F3778D98-3389-44DE-8DE1-21624F36251D', '4607008160178', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90E3C79D-3EB9-4C06-AA62-E47E753A1EB5', '10B2E1E6-B2FF-4AAD-8E3D-DFB43750CE8E', '4607008160185', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('347B817C-62B8-415D-95DF-1595685A9C31', '49D55F83-916C-4D99-B6D9-6DC651FE3733', '4607008160192', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F22D741-0546-4F5A-8CA8-C022FBDE86E6', '6C3A0728-1E36-4BF9-9D7E-946EC7E5E512', '4607008160208', '  dolce   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FD03065-A21A-47E1-89ED-1E6378FCF8C5', '2A786C55-55A7-4603-9C85-15002DBACBFA', '4607008160222', '  dolce    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55E8FE8F-AE00-4681-9CD1-E57076805E34', '40169EFF-E169-4BA1-9E68-4F94220A5421', '4607008160246', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('220432D4-A1BA-489E-8190-FCF4AA708270', 'C02B9D6B-F11E-4D26-9528-8445B5BFA719', '4607008160260', '  -   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61671E97-77C7-478D-9950-42033EBE26D5', '0A05B3F9-81F2-49D7-8372-447D60EF94C8', '4607008160284', '  dolce      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27F25043-864C-4AFC-A95F-562EFFC03707', '8FF7D259-F1B0-43F9-B9D0-F967E7DBC57D', '4607008160314', '    10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43247281-732F-4AA2-B9D5-5F4868FC3DFC', 'D685C6CB-DB0F-4852-AAFF-247847933496', '4607008160321', '    10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7DE1E1F-1EC9-4FFD-A004-DEEA430CA4F5', '99F1FB95-034D-4B1E-8FF9-715B0FB27A40', '4607008160345', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EBD92DF-B4B0-44BD-BB40-BF426B83D551', '5807E5A0-476D-4E8A-B0C3-30E21745F5A3', '4607008160369', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A0409E9-EDCA-4A80-AD84-411E6D00A91E', '40C3B7C2-C9E0-48C6-914C-4C49E9ED9878', '4607008360028', ' 5 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('649A13ED-912F-4976-88EF-CEDBC8DC9A53', '4D5B870A-11FC-4E40-841F-B14920FE712F', '4607008360110', ' 5   / 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1B954D4-4804-4AE5-AE3B-426FBEB3E520', '4E19D0A0-5D90-4630-9861-9301796E0C3E', '4607008360295', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A69DE741-56E4-46E6-8CFD-BA2C9ACA71F9', 'E7BEF268-A886-4E51-95FD-AEB04CBC9471', '4607008360301', ' 10  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B946598E-B7D9-4980-9EDE-915C485F7522', 'C27176D7-335E-4E76-8608-603A0FBD610E', '4607008360370', ' 250  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F20B369-9B10-48B8-82CD-EA318D184164', 'A3E3F21D-9FE0-4E54-9353-203D74C68294', '4607008360646', ' // 0,1   10 - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB4EEF2F-ED70-4EC0-A620-DE4EAC38558B', '8A2A925D-57CC-415F-9495-6124377428B4', '4607008360714', ' 0,1 +  30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE5A9AF1-8C8C-4DAC-8AB0-80FF12ABF02A', '48AC61DF-27C9-4D73-ABAD-1110660591ED', '4607008360950', ' 100 300  - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E957CF2E-A4D7-41EF-B11C-8FEDECBFE1E2', 'B1CFCD1D-0734-4D0E-B89A-0749F9C5460D', '4607008960068', ' (   )  / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E839A53B-A5E9-41C7-866B-6C8ED234BA22', '43156FD1-10BC-4A4F-A87E-6EC6AB58442B', '4607008960075', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83A22BAE-D15A-4A3E-B4DC-F710371F0C99', '60C72F70-5914-4290-A595-C7280BFE5272', '4607008960082', ' /   / /  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30464FC5-3C3E-4D30-AA0C-642D6E55DD1D', '2484331D-6E1A-430F-8D02-49CBEF6B0C7D', '4607008960099', '   / / / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7F8D33F-A2B2-44A5-A5CC-BDF97313BDFC', '16E308B6-7358-45A1-A034-CD017FB52989', '4607008960167', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3317CDC-CE79-46DA-901F-3E3DF06B9D4E', '128BD816-DB92-49FE-890B-CFF2CB0F179D', '4607008960198', '  .  / / / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7F94A6F-5879-4C04-8108-3728B1C66549', 'F4A4CC40-98D9-4664-BEC7-9221A5EC8124', '4607008960273', '   ,  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58770349-87B5-404A-BA3F-E2006311F60D', 'F98056CD-BB91-4EF4-A55F-E39DEEB3A3EC', '4607008960280', '         75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('372A2548-713E-465E-8C21-FD320C39DF79', 'AB3D8416-3EA3-4CEF-8D8A-ECC702744BD1', '4607008960426', '   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E91F3FB6-5B77-4906-AE2C-03B294786A99', '65FFC468-D0FB-4320-8DCD-6E5CB24DC151', '4607008960679', ' ( )  / /  ,', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B668107-D5F2-40EA-97C2-4F0838EA1D0B', '9509014A-887A-4BED-8819-4B9AAC6234E5', '4607008960778', '   /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35FD108D-67A3-4A62-9DDB-DBBB9B17FF34', '91556904-6D33-41B6-8CB6-7AF9167F619D', '4607009250069', ' 20%  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A98C6387-514D-46F6-83BD-38236D0D4869', '4BB44C33-C96F-465D-90C8-3DF2DD4C6FE0', '4607009510088', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E5E7B7E-2205-47A9-B390-700E0AB69006', '2F25EFBF-FB6A-4B4A-8FD6-DA4D3A1271EA', '4607009580180', ' / /   20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED29EDB8-B45D-43AA-AF36-D9161F3D8B37', 'B307F550-5302-45B3-B0A5-5F0FCBF378D3', '4607009580203', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4371537A-E7A5-4F81-B26A-36F6D606E30A', 'C49ACBB4-1887-4876-86E1-0069E0C08571', '4607009580388', '   /  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE783A67-CA48-4B7D-9D9A-B7DE7518B887', '572CED4B-EF9C-41CC-8D94-8B87C6EB563C', '4607009580906', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0675F2E-3D3D-49D8-B45E-6019244E28F5', '519F89AC-2D20-42D2-98ED-4F5262BC5101', '4607009580937', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D421524-48C1-4614-90D9-976183410B20', 'E7C716B0-B6A5-482A-942C-FB38E265E8F0', '4607009580982', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A06E7EF-FB3B-4710-B935-16365526D771', 'F9833D6C-F2C2-4FAB-9E82-85B1E6454024', '4607009581026', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77DF6BF3-D5CA-4EFA-91CE-5206FB3D1011', 'D30A5F23-C750-4483-AE74-32F296BAB0E6', '4607009581125', '-100 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8427D7C-7C76-45D4-8B25-AC09BE3F4337', '7D0CD50F-CCBE-4A39-8EC3-41CF677E0189', '4607009581309', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6748444E-8908-49FF-BFBB-87D57F7D29A5', '29DA9C8A-CCB2-4E93-90FB-5F29D2F08920', '4607009581378', ' / /   10 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA6CBDB5-3D00-4632-B210-4FF052F18FB3', 'FA4A2FEB-BB82-4040-BF7B-12EED9FB1492', '4607009581538', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09963A42-F789-40F7-859A-6F23E006451E', '66D03634-0207-4D06-BDB8-4BCCBFD78C05', '4607009581668', '-   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19067B87-8599-4550-B393-3002303E89D0', 'A8D4D1D0-F5DF-4576-946B-7594100306B6', '4607009581798', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7241D3EB-8F87-49CE-B70C-D92B37A2BEBB', '64D5409B-7BF6-4423-BA9D-7E7835A7F153', '4607009581811', ' /  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D51EF8D7-8F04-4026-8BF6-D3A74A07B652', 'DF6A5AA4-AEB4-46A2-BAD4-51F96166835F', '4607009581859', ' /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D0A6E30-394F-4B1B-9E94-0E904B1C2BDD', 'B2F451AA-FB90-4319-9723-B8970F3B2068', '4607009581880', ' /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A32D12CC-4B54-412C-A397-8D2B4257B078', 'EED37017-4EA0-46F5-A0E8-738018E5DEA9', '4607009581941', ' /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11553237-5CD9-4957-B0DA-8495E5B9B152', '06994EA8-DECD-4BBD-9776-91D1E2D1E350', '4607009582108', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C5B28A0-1B64-4F63-B1CA-9FDC36DE610F', '3AD3C55F-EAE6-45C7-8593-43F9159F1E71', '4607009582177', '-100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86C25CAB-5CD5-4022-8E35-A2148F95C3A5', '3E364A08-A34D-4EB0-9DC7-73D127724166', '4607009582184', '-100  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22B0D178-33C3-4FAA-8F6B-C6C10BDC2B23', '8FA8FB58-90F7-4A74-97EA-251431263795', '4607009582221', ' /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7BDC028-A57C-4BA4-94ED-E8A18A115603', '73730485-6ECA-4101-A1E1-0555C03B8A5E', '4607009582238', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27C61AF2-4771-4A10-8370-9B614B037DB6', '7D0CD50F-CCBE-4A39-8EC3-41CF677E0189', '4607009582290', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7E547FC-1028-4B4F-9472-FEF75A1679DA', 'D625FEA1-F8A3-43E0-B58F-8E644F87E74D', '4607009582399', '-100 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('300B3B05-C327-4F28-BBEB-E75D4887049B', '1FF7E0D0-7FEB-45C8-9D14-3F2E68770CD0', '4607009583877', ' / /  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76B40791-CB51-4A4C-86AF-07C40F1CA078', 'F98E4259-76C0-40F4-8A59-820F4270EBDB', '4607009584003', '   25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('306040FC-800A-4F8E-82AA-B43001564B96', '59ACB3A8-1D06-41F2-85F9-1BDCF625F992', '4607010089498', 'Filorosso      40/70 den/ 1/ 3//velour', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35A94381-E88E-400C-B6CC-F06A41F1EEB9', '2C24EC54-804D-4A9B-BAE4-8ACD2255F279', '4607010089825', ' //  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87F03F42-82F9-479F-8BFF-9C7D4F932226', 'AAFA8C7D-6445-4CEB-A8A5-E1B79F646256', '4607010242541', '911   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF2FF982-7A7A-4081-BBF3-3941C5049EB7', '2956B8B7-BD38-40C3-B14F-DC596D8E14DF', '4607010242565', '911   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B45C2AEF-4D46-40C0-A3FD-9FA0A5A31AE4', '05CD3F9B-C392-4CD9-ABC3-0E7F9F49B2F5', '4607010242589', '911   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BB13DEE-694B-4F19-A092-09F2D763D41C', '12F7C1E1-E148-4A0B-99CD-A1F10E8A87D4', '4607010242886', '    280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED8A144E-4A5E-45DF-B99C-C13DB14E7586', '463287D8-C98C-4BE6-B89A-37B7BBA39C9C', '4607010243012', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56E17168-D6D2-45C5-917A-8BC27D8A7135', 'A281A602-14A8-4176-8E63-07556E15A11C', '4607010243029', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDC05A65-72EF-4A47-ADAB-B5A6BE7870FB', '8D2F1B20-A3DD-47D6-A3FB-FF9DA30C3F82', '4607010243081', '911   /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29E9F99E-3349-4215-929F-3C7CB2FA3CA1', '8909DDB0-BCA3-475E-9467-4AB190D4C089', '4607010243098', '911   /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D60519AC-8796-42A3-B85D-2C5302FE1176', '57137608-35CE-4DB3-9A75-9AAA5DCF779D', '4607010243104', '911   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('418F036D-1BF8-4438-8456-5EB0551EB9CA', '96EA1885-E958-40ED-B305-ABFDEE7C5FC1', '4607010244521', '911        50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47F82E59-CD61-4FF6-A83D-C242E9857ADC', '39691CE3-8213-47F8-B093-41B0ECECF04C', '4607010244538', '  -   /75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C061B72-A7AC-4E6A-9798-F0B85F6B69A7', '83AEE61A-E364-4C99-A7D4-3FDDA119058C', '4607010244545', '        - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2E5B643-8748-4685-B632-9E1330455A96', '2A771A8B-A3D9-4FEC-9158-DC6C9A0B6AB7', '4607010244552', '       - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32337DC8-9AD8-498D-9AB0-EA1E4EB72B30', '45F2FB85-3F8B-4E89-AC1D-B3A41905C633', '4607010244569', '     - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E3FDBFA-ED34-49F5-89D0-7783FDF1599C', '4A6E0C58-8F90-40E0-BCB5-0685E8F7ECD8', '4607010244606', '          1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80727B7F-C05D-4491-A1D5-6D84F5D654CC', '6F525768-6E5B-440C-9447-663FB021D91E', '4607010244613', '      // 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8877B81D-533A-4DFA-BA79-6E99C2A29FC6', 'B3D91B0D-DFC3-40D3-A7DA-027319FA5FB3', '4607010244637', '        /n1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F097798D-14CF-44F8-9830-1000873511F0', '7B784A6D-D0F3-4D62-8135-F1C2D3111608', '4607010244644', '     // 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7BE4264-5B34-4A19-99DE-EE45DBEEFB88', '366F6E35-9C48-4026-B3BE-8F718CD288C5', '4607010244651', '     / /n1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE157C2A-C710-4B3D-B733-5E596D2E2D9E', 'F00FCAEE-592A-451F-91B5-23CCB1A01D53', '4607010244682', '          /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B828AE56-BA0C-4DE0-951D-732768AF8B71', 'B4E2F75E-8BAA-44AF-B743-4904C49E2E4A', '4607010244736', '911    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E10A98D-2A0E-4298-9880-3CC755C26015', 'AADE8E66-1BA1-42AC-8B46-768C44B629F2', '4607010244880', '911 - /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('386FF7B7-A77A-4715-9BED-C1E7AE808D72', 'C6EB43FF-49CC-4C50-B28A-0F4AA13A488A', '4607010244903', '911   / /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D60D8AC-9CE1-4CC7-AD9C-7BD21295EE63', '62EB7520-AA53-42DB-B920-9700C5155375', '4607010244934', '911      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF132FDE-5F6E-40D3-864F-14439B69636E', '10FBB6FA-482A-4C9C-A8A2-A5BDCB4A8102', '4607010244965', '911   /     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F680297E-2ECB-40B4-82F5-AEB9E7772C56', '8DF0B427-34F7-4CA6-8FAD-412297379CCA', '4607010244972', '      /    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('286CFF16-CFBC-4365-BEEE-551ECEFAEBDC', '7134BD53-A439-4C90-8FE0-4D38DC7390A9', '4607010244989', '     .  /      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FEBEAD0-B286-4FEB-ACE5-13EF86932BF3', 'A1257F8A-DCF9-4773-A64F-41398365CDF8', '4607010244996', '     / /n1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E49AE5B8-1EDC-4124-BF43-125D190735DB', 'BC5A3BE8-CA86-466A-8EEF-6A0AD014A9FF', '4607010245009', '      //n1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B446388F-102A-41A4-8353-3CF3EAD9D003', 'E1F63853-8A97-4F1C-B8C9-33BBB43A6D2D', '4607010245016', '     / //n1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CD7B72B-D8D2-4930-9B38-0ACAFBF1A972', '96E383BC-474E-4C1C-94E4-044B7E94C253', '4607010245023', '    /     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A541A9C4-C801-4D15-BF4C-511D56E0E6EB', '1C11520F-30C6-43C8-A974-1436011EED6D', '4607010245030', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('202CC4D2-EA33-45B2-B471-5216E1E6F059', '2FB26096-4FC4-4D5F-8A1A-1EE5AB1BF570', '4607010245047', '        50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('254804F6-3C19-4D0D-BDC5-2EA2463BC69F', '7703B5E6-84C4-4CEB-B1AD-812B798D8007', '4607010245054', '     /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC4F57CC-7314-4E37-8349-4D7977CBE963', '99207CBD-4F07-4137-B7A7-46D3B62ACEE6', '4607010245061', '     / .  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A0DFBE7-73BA-47DB-87CC-6DD2902814D6', '7E48A7C4-6137-4705-A234-30AD5DE82732', '4607010245078', '   - - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FEE5513-D81D-47AF-9291-23E7F3E6F835', '85F66684-CA68-4D5B-A864-9FBD441EF52E', '4607010245085', '    - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62C6C60E-5DCB-4051-83CE-6C338D385B92', 'B1A0D3EE-F65D-419E-9640-6A9D7878F4A2', '4607010245153', '            20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F86633C-C589-46FC-A66C-9A1A3C12C598', '42E72A64-AD23-490C-93FF-7C72C24E875E', '4607010245191', ' /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A87A78E-7E29-4224-A94D-DE2881FEB9DB', '290F34FF-791F-4B6C-A3F1-6A7A49DCBB0A', '4607010245207', '   /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08FC404E-0DC3-45AD-9C21-2F3B04A35171', '347A7BBF-36A1-45F8-8DC0-B9C11E8AE3DB', '4607010245214', '   /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('975D3ADC-363E-4188-B1A2-0C73D48499A9', '73F79400-B290-4492-973E-A61590791C41', '4607010245238', '    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB1732B1-3E82-458D-833D-4EDE9433ACB0', 'D8E255C2-23B7-44CD-9CCD-781BA1A5E6A1', '4607010245436', '      / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('399BB562-71E4-4E55-BAA4-C233B7BC88BE', 'A3A93336-3340-4342-8EEC-84E3E1387D0C', '4607010245450', '     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD0C7A20-C017-4347-B286-5B5B1F41E805', '71315933-62DB-4669-A411-B304BA43A1F3', '4607010245474', '     / -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0DC7A9C-CB67-4CC9-AFA0-F349A8EB6FA0', 'A813ACA2-A373-48E6-A185-444E240EC85C', '4607010245498', '911 -  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D96B543B-82BB-46D9-8297-DA695C2B3582', '80F69BA8-2ADF-4BAB-B424-EF71AD50D93A', '4607010245504', '   .  85', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('095D918E-62CC-4075-BCAC-609A4875108F', '6D4739BD-C874-4C96-9BF5-FAF51A855758', '4607010245511', '  - /     85', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1B39298-9F72-4C98-887F-882FD11477CD', '66C5ECD0-2115-4C60-8442-2591F8398E48', '4607010245528', '    - / 85', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E13C979B-2725-4AE1-AD77-7C726E8BC567', 'FA04F07C-6F31-4B90-96E6-F7DCCD29630B', '4607010245535', '  .   -./..85', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C4EEAD0-8AF0-46CC-B7E5-B8A7263FEBC5', 'BA2CB427-3343-4FC5-BAD0-E527F750304E', '4607010245542', 'Natura medica - / 85', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66755BB1-02B6-4D4B-9A40-6980C1995DD2', '5C8BBBF5-7EDA-49E9-AB40-D9F58CE22380', '4607010245597', '1000    - / 85 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2BB9166-4828-4636-A167-A32E00555B0B', 'B7195D6D-5B63-4138-A4EC-7A914554ACB5', '4607010245603', '1000    - /  85 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C1B8B4D-4100-46F3-A2CD-1DE2033E5E9F', 'E7316B92-FEE9-43E0-9188-B92CDCC4C316', '4607010245610', '1000    -   85 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3A6D528-D078-4AE4-A007-4FAAAF396624', 'ECB5BFFD-3DBE-49F4-A23F-ED5EA3A554FE', '4607010245634', ' / // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('196B3E07-155C-4E5B-8A32-13953ADFFBF8', '64580040-9F5A-4ED4-84DC-6D936F2CC5D1', '4607010245641', '1000     /  150 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE71E600-E9D5-41E7-8F40-AC3B98CED4A4', '4EA355A0-DA01-469D-A44D-3143C726F20E', '4607010245849', '       / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45DB03F2-5ABC-48DB-AB8A-F5D480CBF4C0', '101A7F18-97F7-435F-86B7-CF033368ABCD', '4607010245856', '      /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B56D0E1-36FF-4590-8127-3933F0E7D623', 'C905F237-DC45-4419-8A0F-45C53BFBBD98', '4607010245863', '  -  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B427E5D0-F043-4681-A99E-01A123D7326B', 'B2183958-3E8E-467E-B2D3-41DA1A629CD6', '4607010245894', '     / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57C6B828-7D0E-4773-8D58-495618E2F79D', 'FB90BB16-CC41-4F9B-AFCE-401D2D6A4138', '4607010245931', '911   5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BF52016-11DC-4EC2-909E-A47E5AF99374', 'F732AF42-952C-4069-920A-AFC5D070A88A', '4607010245948', '911        150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('041DACC6-3A8E-4B00-938F-1649CEC7895A', 'ECBDB313-58D0-40B9-A629-AB37BB5D69AC', '4607010245955', '911     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('138D5069-CD01-4DED-9D04-10C597F9107B', '9938110F-7143-4A8C-8742-E5EB9F871CCA', '4607010245962', '911   / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('408EAE85-C45F-41C3-92E6-6AF4ECE4FA69', '494D50FD-C575-4A76-9464-6FBE06E227EF', '4607010246044', '911   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB03A175-993B-4726-94C5-3890954C945B', '4AC61412-6839-48C6-B0C7-CC258BB573B2', '4607010246068', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99DD8447-1105-47CB-9C62-446ECB9CF301', '4B7FE951-F5CD-4B39-A330-131853F02BC6', '4607010246075', '     130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05E5DD91-C8D5-4A7C-8533-FF67A17036D4', 'F878E7E0-052B-4CD9-8256-9FFE757E9E4E', '4607010246136', '     q10/ //50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CAFD67E-511F-436A-B576-13B78B13434D', '3A5F32D0-1382-45A1-97E9-9852B4368690', '4607010246143', '      //50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0809B69C-D07A-4E07-9D04-98022799152D', '095BCD7C-A481-4A5B-935A-C9EB6E9FF70F', '4607010246198', '        50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A986826-F8DD-4167-8274-D4537E9E2B03', 'C0182E7D-0672-42CF-B322-8C27CDCA5CF5', '4607010246303', '        75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C577C9B2-411E-47BD-86EE-218C4BEFCEB0', '77D34B8B-05A9-4684-9D76-722892A551A3', '4607010246310', '     /  /20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72A13E60-E8EA-49AD-9320-33F77E68A9E6', '7D0A284C-33C3-4123-B0F8-486FB1E63CA5', '4607010246358', '911   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8837668-BB97-481D-8ACC-7B752FCC0CBD', '30FC2B99-3C21-443B-BA7A-A90DE8E31BFE', '4607010246365', '911   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76469575-7971-4D33-82CB-DD3499F70ED2', 'EF40211C-A2E5-4472-AC3B-245288286903', '4607010246372', '911   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5988212A-A889-4A52-8ECE-19EA8076B4B6', 'E62187F8-8EFA-4921-A594-7B6707E9E5B5', '4607010246389', '911   //  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EFCF287-E6DC-40EE-BAF0-82730FBA634E', '0BD959D8-42DB-4642-B5A6-01808D1E703A', '4607010246396', '911   /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44169218-47A7-4F80-A79C-C1B9CD8ABCB5', '614AD6A9-D8E8-4F2C-BD77-BA2A0903F6BB', '4607010246402', '911   /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F6F096E-A5E6-4A78-90FE-D6D24729E064', 'A29A9480-38F8-4B5B-91D0-D9ECEC9095DD', '4607010246457', '911     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB10ACB9-9FFC-482A-A755-0190E8AD5B6F', '56E124F5-5360-4BF1-9951-7838379B9471', '4607010246464', '   /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7219773A-8F68-4BDA-8214-C49832915D28', '8FEC4654-52FD-4C53-AACF-38CC1F2AE970', '4607010246501', '911   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B2491BD-057F-455D-B3EC-9870AE41183A', '1A1B15AA-DFC4-492E-A8BA-46BE60F9D3FE', '4607010246518', '   / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C262482E-3E2E-4203-A231-2584A6CF046E', '08C60314-357D-4827-8DA3-69979A78B628', '4607010246525', '    / /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F199F85C-72FF-4680-A7D6-598EE70F5D6F', 'D87D98AE-27F9-4430-A86D-A048B0A9872B', '4607010246556', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31426B4F-4AFD-4509-B2EF-44F072638C66', '3257C5F2-3DDC-4D07-BEA2-88910BDF66B0', '4607010246679', '911   /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('973358F1-2A33-4D5D-BFED-EE64D2DD6E8F', 'ABEAAF4E-A8DD-497A-8B46-BEED2F7D5568', '4607010246686', '911      150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AC2E432-36B0-4B05-A247-1C73A73E279D', '6F79EF9C-901C-4344-8B65-F879F03D1BE5', '4607010246716', '911 -  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23E238F7-E353-4A19-B0A2-270E8C4AB86E', '802EE953-9E16-4D74-AA8E-45BF2E934ED4', '4607010246860', '   - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05A9CA12-7D0F-4022-A98A-B84C5CA5F885', '7E0E2323-67A1-4FD8-B74E-04A389AB2BB6', '4607010246877', '   -  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7339D939-FB90-4AC1-89FB-2AC99B8B7895', '3AE76D02-DD6D-4699-8B1C-2BCB2FE232CC', '4607010246884', '   /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A35C7998-9635-4F20-8BFD-BF8CAB8B7C8F', '7DF6769B-DED3-4D9E-97E9-A5B8D5B684DD', '4607010246891', '    - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95042107-5FC4-4B3A-864B-96E886F57620', '78809F55-6A7A-4B19-8022-BD407D9EFE0A', '4607010246921', '  - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74E69900-144E-4B22-A989-4A5A2A162F11', 'F8702BD5-7656-4DC1-89CE-3F8415477371', '4607010246938', ' -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54F7CB5C-F837-40CC-9145-8BAC75C97167', '108E20F7-B57D-4E69-8309-34BD419DF4A0', '4607010246983', '   / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C74444C9-0738-4223-9D79-6C55DA8A49EB', '8D247482-E9E0-44FB-9CDB-35D2108C5412', '4607010246990', '911        150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('312E331D-F484-4471-A84F-3BAB7615D648', '6A099949-4286-4FC1-902A-D0573E3AF4B8', '4607010247003', '911            150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7337E874-30EC-48AB-AF09-F2524F995BA7', '93CBF187-4372-463C-9793-44D6DA7C543B', '4607010247010', '911           150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F23D20B-9A26-4317-9959-EA1B1A2800DC', '4809D207-D111-406A-8FE1-CABCD9E3876F', '4607010247218', '     /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED9BF04C-16ED-4AE4-90D1-D2F48BF30A36', '4674B2BF-6DBB-4B4F-BC5C-10BF549A74C5', '4607010247225', '     / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAAA28A9-F0E3-4F64-A0D3-0DB73F169A55', '36EA9828-1D58-456E-B12A-57BE8CC823B2', '4607010247768', '  -      50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A11503F6-11F4-4021-8183-F7234BD4DE01', 'FFC58929-6B54-4114-80FF-EFC13B355BA5', '4607010247799', '  - /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5290298D-AA96-4AC2-8857-D8DE5ED0D9F2', '2FC68495-202A-4EBF-B80C-01642C1EE887', '4607010247805', '     - /  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5343F1D7-1A2D-4017-9CA5-4377F4950658', 'A2016B63-49DA-4B6E-B9BD-4497A7AA77DA', '4607010247829', '   / /    - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C146E5F9-BB57-4405-8C84-D45DAC0971F8', '70426A52-48B1-47FE-B645-6DF14C1F0DB9', '4607010247836', '    /   . 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52B84193-B8A7-4616-B663-AFE652C171B0', '1BBE0EB6-CE79-44C2-8225-F2C608057250', '4607010247843', '911    / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CE56C34-9A3C-42DB-BA18-EEB4A2EEFCEA', '903A7D16-72AA-4F76-A0FD-E4EBD041DB3D', '4607010247904', '   /      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5584E7CF-0B50-4396-B5A1-FE952AE938D0', '6DCF53DF-F732-4C3C-A737-3CD2D1C99959', '4607010247911', '     //   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4292C23-5F90-4093-AF9A-82D9E5391A45', 'F09787E8-009D-4CA3-8A4B-87D4B397D926', '4607010247928', '   /  /    30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('940A540B-1EAD-4C30-8A44-FEF146F4975B', 'EBC630E2-5E9C-4963-8765-F88541FA1952', '4607010248116', '   /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4723D91D-9062-44E8-B289-9243730D79DA', 'EA09B758-21C3-49DC-9900-02D66302A580', '4607010248123', '   /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5D4F4C5-7823-4095-A5FE-736927A82472', '6228EFA6-563E-4F2A-A19D-5CC3F61C5A58', '4607010248147', '    /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40A57B5C-B2E9-4E77-BC31-3D08449A4708', '845D8D43-B238-4802-8FE0-466214176A8B', '4607010248499', '       /// 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDF4E3CB-C1BB-42E5-8F59-7F320E70021A', '971ACA30-C714-4DE2-B51A-39941DB20C12', '4607010248512', '             50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D240B2D8-4EA5-41F2-A0F3-BB74D8A3B42E', '84D4A06D-1FD8-4F79-9437-74E264F2C93A', '4607010248529', '      1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3947C3C-D4E1-44B6-B8BD-D354BB8FAFB0', '079C9CD0-3346-4FB1-95F6-2D61B92B5F06', '4607010248567', '      1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E03ADC56-3C00-4F90-AD62-44AF360F2CBB', '694FF2CF-A3A9-4A59-8DBB-D5CD6EAD1FE1', '4607010248581', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CCB8651-6A6A-4D2C-8D29-D650AFAEF2AD', '06B8CFDB-F138-429F-973A-6D21F4DC9BF1', '4607010248598', '911   -95 10 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A0A3A1A-94A3-4066-8A98-84C65E681D81', 'AFBB193D-F227-4F8C-B146-5D6C5B06A359', '4607010248611', ' caviale  e 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0F5D8E8-BEF7-464C-8B3B-9B1A86770E57', '15C9BF11-280B-479D-892A-58F4A0FF808F', '4607010248628', ' caviale  a / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA5AC10B-0D13-4D09-BC60-25B5A81B7B80', '637F1CAF-C389-475E-B923-57408F1D4559', '4607010248680', '911  f /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('108657EB-9556-4702-B479-13C276D2729F', '892788CF-19F5-4433-8AB6-BF24B5EC5CE1', '4607010248697', '911  f /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4099B8A6-62E2-457E-BCCE-24B4AA411A61', '4DAF3576-FFB4-4F61-95F3-A3574738B241', '4607010248727', '            ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50D3A56C-2930-4D24-949B-AC8EF4BF9C93', '97F3FD85-5359-4271-A30A-8A033EA34909', '4607010248765', '       / 75 ,  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9246523-A727-4E5C-8080-7D17EFE952A5', 'FA2F247C-E1A9-425A-AC5D-3358EB3E7569', '4607010248772', '   /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EA15A7F-A6D1-4D75-957F-6999D4B73B64', 'B1DCF099-3F35-40F2-B452-0EB6F020D449', '4607010249120', '        / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77F1D6F5-069F-4804-86D4-E994F207326C', '1155C98A-20F6-4921-BFBD-5DA0C455E377', '4607010249137', '        / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBDBECD2-2569-48B1-9D22-21988EFDCD86', 'D9739CA2-6024-40DF-80C0-1FE97E3B55C2', '4607010249144', '         / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('475A6868-F77A-425A-AD7E-EF4A6485BDAD', 'A62FE24E-6CC5-4120-B3A6-12B3D8650AEE', '4607010249168', '         / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('083B6439-6884-4433-8560-AC35841F8E41', '5DA2AB08-DCBB-4B42-AAC0-B318D6066813', '4607010249182', '911 -    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F5D29EF-5D53-47B6-8C92-9BEDB9A0AE93', '3CF63336-13E3-4DA3-87DA-B628143D9FFF', '4607010330057', ' 5% 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3CA3EFB-2BC0-491F-961B-203DC091BC4A', '38E0C423-9975-41CB-89F9-C0039BAA5E5E', '4607010330620', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F74740F-DA36-4D7A-872B-9FC7E0643307', '9E2B9E47-FE47-4B08-A394-593B1FB183C1', '4607010961107', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5794FCAE-9D52-4DC6-B3EE-3A0F6826B66A', 'EB122C77-B0FF-479C-9DA4-D26157F7390B', '4607010964795', '9   . 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEA4DAEF-64A8-4869-B0AD-8DDEE8FCD310', '1D13319F-8421-4E8D-9BE2-76913DB8BD10', '4607010964801', '9   /  160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD757BD9-CB13-425A-94AE-8A6BD543FE02', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4607011630538', ' 5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12312454-8013-4ADC-BE8F-3B2311C09899', '3EE6AD69-102E-4B25-8FFE-434949018FCB', '4607011630729', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1B7521F-2824-4ABA-B507-790EDA118E9E', '3C3BC3D7-B960-4DF4-9C36-F498BF495949', '4607011630897', ' 200  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49718D2D-61AE-4DBB-93EA-56B76A13A0D5', '31AC594C-B9F2-4553-B339-7B893FBB21B5', '4607011630941', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('501D8F15-2433-431D-A2FB-796877E6F5A7', '336AC824-33DF-4F29-BB73-5D04DE5A5DE3', '4607011631146', ' 0,0025 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18383CCB-CD33-452B-8F0C-B8D65FDDC655', 'DAFF09AA-D4A4-42E0-A713-954556DEB8F4', '4607011631344', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD7E61D7-A19B-4628-9B91-3774246012B8', 'B4F9A642-B072-44A3-B29E-C36D7C15FAE6', '4607011631351', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89326A23-9D76-4B89-83A8-DDA474E8285C', 'B013CB50-0835-4EF5-895A-2CB691E0FE2B', '4607011631467', ' 10  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4BA5170-AFF0-4CAC-895E-9CA9920DF8F3', 'EF1A9ADD-E06D-4DFF-9A64-5F6D19C4BBC4', '4607011631528', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC588DCA-960E-4C75-B45F-E54933BC6932', 'E5A9E034-AE70-4D4C-8081-BA4AD17306A4', '4607011631757', '  1,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC34307B-D2EB-4945-9C87-DE52E1A3D5BD', '8D8165A8-DE15-43D7-86B1-74BA387F404C', '4607011631924', ' 0,03 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFC4BFED-4B2A-4DC2-8FD9-748CD1CB5FF0', 'CFCB71BD-1125-45CE-98D2-EEFA5A3A4E7B', '4607011631979', ' 0,01 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40C3106C-4FD8-45B4-8631-7BAF87EB9842', 'D1F6B56A-FB2F-4D6F-A488-C630780F6805', '4607011632020', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD7D5AFB-2E00-4FA7-B631-C75A8B8A8D09', 'E3509CA9-FFAA-4666-92E4-23E66A19C967', '4607011632112', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('458DAF2C-58F3-42A3-9EC2-5DBE395FFD12', 'BB075934-B648-42EF-BD90-6E370B8CAC9D', '4607011632167', ' 15  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74EB67DD-28C0-4648-90D5-D12BBD7664FB', 'D7A54DD6-B84E-4367-8AB9-DE528588418A', '4607011633027', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFFD5852-7575-43D4-B811-08D51EDE36EE', '8F70342A-4DDA-4D44-A423-CCE29B27DF6B', '4607011633157', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C12E6C48-FA4A-4A3F-9248-D33DB739899F', '59E1DCB3-F8E3-407A-BDC5-15F3FBDA839F', '4607011633300', ' 37,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F4DC59C-31B2-4985-83D4-08EF5A1081D6', '43F1A00F-34A3-4B28-AB8D-B86972F587CA', '4607011633317', ' 75  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C6F4EFD-B65E-47BC-9112-991732B22677', '99645C97-AFCE-4A9C-A90F-297100C123A4', '4607011633348', ' 20  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72D238C3-4AC6-4BB4-AFC0-9E4FE65DFE83', '874AE1FE-388D-47FD-9AD7-ABE195F8A174', '4607011633591', '  5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3E42EFF-9572-4F20-BC11-4BAA1F934E59', 'F5272511-5194-49FC-9A39-3AC85C7BD37C', '4607011633614', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA7EA356-2913-4D69-8C75-11AD2F88C726', 'ACEC81ED-8880-42A9-AC21-E4BA67C65048', '4607011633638', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9447979-70A1-4B69-8155-0AA2E495CF57', '0BA3581D-26F8-460C-B60A-73CB564291B3', '4607011633669', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('948A0DA7-7F9B-44C9-8C30-5C67007EDAD4', 'BF311D05-DD4E-4A22-81B1-7617D6391234', '4607011634055', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66DD2873-567E-404D-8018-EB47B73E4F2C', 'E82B61C4-FF64-4405-9CC1-E001841E5E4E', '4607011660153', '   / 85', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('521FF0F0-5E4F-41DB-8C47-BF116EEABF1A', '2C974310-FB6C-4CB6-9336-51C119CC93BF', '4607011660290', '  /   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56A5F951-B6C9-47C7-B462-13903A2F3378', 'FBFEBFE6-C73D-476A-9186-D37B0424FB19', '4607011662539', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E2DB6D7-EEAB-4110-828D-1B7311992DE3', '250E2218-0A75-4D34-8D10-5B20F614050D', '4607011664052', '    /.52-56/   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD808775-D00F-44A6-A258-8E1C1511CA43', '846057B7-F9AF-4F65-B261-D0E074DD7E82', '4607011664212', ' / / -  . - 75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('090606B4-221D-48E2-ACD7-309AB2FDB1A1', 'E3893736-6FEE-4D70-B613-9536435AD85A', '4607011664274', ' - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7B465F2-DFFA-476C-B99F-5953B7BF74C1', '91F8C9F5-8011-490B-9DD7-339781BCEF6B', '4607011664298', '    /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D04B9E4A-90DA-472A-8164-CB0B8C7D08B4', '2D33E359-8EEA-492C-97FD-45C838AD1F17', '4607011664304', ' - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF3C769D-1EC4-4047-9490-CED35D7FC61C', 'CCA093BD-FB0C-4EFA-B097-531D84589478', '4607011664328', '  -     1 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CA68AB1-D45F-4036-A0F2-640039C1E5B9', 'F866E177-709C-422B-93DC-A39D4E129572', '4607011664335', '   /  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F74E7886-2304-4F9A-93A2-3C6DCB55512D', 'AC8E30EA-C5D7-4C04-9F38-5609A1D22945', '4607011664342', '  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDDAA3A0-0887-4F4E-8A39-6C7E012BC141', 'C5D11F5C-43C6-4C6C-A7E6-783D7902FE7C', '4607011664359', '  // 75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15913F3B-D5B2-4755-8DB2-3B084A647197', 'CE9D105B-891F-4520-AD2E-9435D933FCAC', '4607011664366', '  /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A49B1E2E-184A-4FF8-9CD7-8AEDB827E901', '69DAE890-3F83-4382-8F37-163A389F5F60', '4607011664397', ' //    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('759AED18-1CB7-46BC-8111-862153222360', '008BCF24-F92A-4690-B581-C32D131D39AD', '4607011664410', '   / / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D291B22B-2606-4579-BE77-592F3DB6AF8D', 'A7A54AA1-1A78-4023-9B5D-4360ADF8C499', '4607011664427', '   / / / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36C1E293-046A-446E-810D-9A2D94010575', 'BCBDD7B4-EF60-4A6F-A0A3-1520E110BFD0', '4607011664434', '   / / / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FAFF3A9-0EDC-4A5A-BE5A-F2CAAA5ABF0E', 'BCBDD7B4-EF60-4A6F-A0A3-1520E110BFD0', '4607011664441', '   / / / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('981A884E-7421-42C0-B667-53C79186B074', '0601A195-40B9-4A39-8B3A-11D2695871F6', '4607011664458', '   / // 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C4B0A97-73F1-4DDE-8B39-42234247368E', '38866AAA-9D80-41C0-8FCC-60183530BF70', '4607011664465', '   / // 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('912A963B-0AC7-4F6A-9BFE-BEDD75A7B24D', 'D33D9F2A-722E-4B6A-B0D7-A250C11CCD5B', '4607011664489', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C16E81F1-E7C3-409D-B6E1-584C39C15247', '4DAA6A5D-57B5-4D49-8882-265B03915A79', '4607011664519', '  /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('958857CC-8E12-419C-92F9-EF28FFBD9F53', '1BE9B7EA-86BB-4625-AE6F-2D2C64725157', '4607011664533', ' ( ) / 75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B6DA203-4E33-422C-8017-EA03920FD2E3', '6AA2A4AB-4042-4D1D-8514-1ECCA9A28CE0', '4607011664557', ' /-3/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7D2E499-9903-42C4-8A74-767B4ED1B75F', 'CF4F342D-55E2-4B8D-83C9-5CD1E4D906D1', '4607011664595', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EFE372B-D214-4F40-B5DD-882DB429D72A', '1737F36A-0A6B-4EE8-8B49-44504B567C32', '4607011664601', '    2 30/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0706AAD-08DC-476B-92F8-0E1EDD6847DD', 'F952FE47-5565-4ACE-99A8-6612DECCB406', '4607011664618', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C92D10C0-D6AC-4D5B-B87B-EE8D7530CAC3', '69E56BAE-AB09-4743-8477-41F61643F2EE', '4607011664625', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14720D25-5390-4815-A8E0-BC2479978937', 'D08D9000-F94A-44E0-9DC3-E7D25ADD323D', '4607011664632', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1360A932-ACFF-4097-BB15-D750E98812FE', '5BD04554-35C6-4CBE-B430-39332DEB4B4D', '4607011664649', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A08B54D-43CD-4484-8D81-C4444804A7AD', '452868BF-013D-4C0E-AABD-66DE1683B01B', '4607011664656', '    / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80351469-F8AE-4E7A-87CE-3B198CEC990A', '64A336D2-F18A-4408-ACE3-970BCD893753', '4607011664663', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD684779-39B2-4A25-AD17-35FE0B97CC04', 'FBFEBFE6-C73D-476A-9186-D37B0424FB19', '4607011664670', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C487349D-6237-4395-BFAE-1B0665F547C0', '75536121-BC69-4749-9F6A-5F1E093077B0', '4607011664687', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('642EB330-D736-4769-9FE0-D1FA1B8C009C', '933D549E-CDF0-4EE0-99DF-1C0298065635', '4607011665202', '.  / / 50  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF6457E5-9B51-4AA1-B2BD-B1A29FD5150B', 'CCD842B7-F4FD-40AC-918A-46B4EF8E085B', '4607011665219', ' - / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2FCF422-5D24-4367-83E0-42903489B83A', 'F3ED152A-1F4A-44D1-93F4-A6CA1BC6BBBF', '4607011665325', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64249A29-9910-41F0-AC8D-B349F70E1D95', '673020D4-4132-443A-B410-A7CF0BC7A32D', '4607011665332', '   /, / / new 130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78A4D1FE-47FD-47C0-B26F-F1A777D10D15', '3EFCDCE6-3942-40A4-B9F1-FE2BD67D8B04', '4607011665370', '  / ( )   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42AB0B98-2C82-4096-ABA8-252551B85D6E', 'AE5B8719-5B60-4A79-B903-850500176A7F', '4607011665738', '    .15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D7E5166-3B85-4ED7-BB0D-AB328605763B', '5F508C39-F611-4E48-8A55-822DDD835334', '4607011665776', '   -   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C11D574D-DFB0-4A1A-8593-213C74F7E9AD', '92E43E36-E3F3-4CC0-8C8D-67F313BFBA61', '4607011665783', '   /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9B1469D-1B68-47EE-BDBB-319580FA325C', 'DAE47D33-1655-45CE-9F0B-5E3031F5090C', '4607011665837', ' .   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15E71368-EF89-42BE-83C7-0B5A7C53DA1B', 'CF8AD59C-BD3A-4B9A-AD74-CCA862182FF4', '4607011665950', '  /  +/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2925008-A442-4927-9346-8316A971FCE3', 'E0112588-7291-4182-B4D4-A232EA0D91EC', '4607011665974', ' (/) / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F21BD5BC-0092-48B9-BF7C-856F167739ED', 'F0BD9884-6721-4DBD-8AF7-05426930FA08', '4607011665981', ' () / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CC68C13-CF02-489B-A8A9-6BB4D50E1093', '2EE9D551-EA07-4EDF-9548-36A6A1153CF6', '4607011665998', '    /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA25780D-8B91-4ED0-A1BA-C448FFA726BE', 'FF88C064-2EED-4089-ADED-AB65E74F735D', '4607011666018', '  / 17     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EA3EFD3-10BC-4C15-9AC8-AEF8F0913819', 'F0420BE0-24CD-4B27-AD47-B77B95FA5B63', '4607011666025', '      / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28443200-4F41-4556-918A-59E045D67457', '0F346A5A-E4BF-4891-8DB2-4F2D8636F5FA', '4607011666032', ' .   () 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76083E57-3F12-4C9D-AEBE-B860B36BED29', '028C7B48-D486-4890-8C23-78353429685F', '4607011666049', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D6F9E76-C4A2-46E3-A1AC-B7DFAEE8D8B8', '5FAA942F-CE21-4D76-8E3C-8E6836C31C94', '4607011666056', ' .   -100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0C0D10B-0524-4985-9A5F-EFA070B910E0', 'EC5C4B47-A2AB-4CB3-9140-DBBC7D77C382', '4607011666094', '- .  .(,.)  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D1C3F56-0525-4D98-9FF8-453F0E16155C', 'B3EE8CDB-BA46-40E9-85D6-44DE26681C08', '4607011666100', '        / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE6C7219-B0BE-442C-A49D-B1B0A5A99F87', 'C36F05BA-3440-4EC7-B367-3DFEEA9C562B', '4607011666124', '  . / // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C795937-196F-4239-9DF6-764052475DA6', '48B222B9-C7A5-4BC0-9377-3792FF6C908E', '4607011666131', ' / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68D3D9C8-2C53-42AF-BE71-B12D0C106C19', 'ED551A74-A7A4-44D4-B6F5-BC2279BF5C5C', '4607011666148', '  - / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A385766-7BDD-4937-B1BD-6C901C27737F', 'E08DDE34-B626-420E-A3FF-5BC6DCA3CCE5', '4607011666186', ' .  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F879E21-053D-4772-861D-A3D921AA7814', '9901E5CC-486E-4706-9D4F-DEDAAD2668C2', '4607011666193', '  //   / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D6DA57B-0B80-4661-AC54-D8B8B0D14E6D', '408C60C0-4C3A-4415-9453-8D32203CE100', '4607011666209', ' .   /   31 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50652414-513A-445B-A60B-4F85CA5CF269', '8D06D13C-CA08-436A-824C-675133D657C5', '4607011666216', '    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2EC9314-3578-46ED-864E-AA4231787E98', '33C48D4D-EEE1-46EF-80B8-28073D36BD68', '4607011666223', '   /    . / ,/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3227C921-CB5F-46CA-AF55-60959C0FE66E', '6E52282D-D950-466D-B60E-A9F4ABCC112B', '4607011666230', '    / 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEB50B58-6ACC-455A-930F-54F2BEB29265', 'C14ED972-F3CB-4CEB-A3CA-0765803BB28D', '4607011666254', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D60023C5-9AB7-4375-8584-7DA2A9C3DE81', 'FE166F36-1C63-4BDC-A4B2-454829238F9D', '4607011666261', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6E95849-36CC-49D7-9FFE-D4B2FCF108E0', '372E1697-45F9-4A92-A97E-B31A1ADAA00D', '4607011666278', '   / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA7E7B5E-D6E8-45AE-A777-429F686F1487', '8D46F142-5154-4DEC-9274-2CA8DF65814F', '4607011666292', '    / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EBD2249-95FB-4F87-A853-E04678E962B8', '89F99267-33E0-4177-94CD-C1B522BE17F5', '4607011666308', '   ./  /.   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F10D219B-EE3D-4775-B3ED-B367955220E2', '8D02351E-4B73-4DC4-B3E9-C9B2422F782A', '4607011666315', '    - 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4AA75D6-EC8A-4CC9-842E-D2AE66A913E5', '7C1CA08D-E3C6-4EF0-95BA-E7E198F22B93', '4607011666322', '   - 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4818D01B-0375-4C7A-84BA-969C3CA0854F', 'BDB7721C-816A-4B99-BD53-2BD20D30A0F0', '4607011666339', '   - 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0BA0BBE-1161-4182-9DFA-1CC50FD129A5', 'E5BFB5C7-E561-4CAB-AF1F-5075762E7E8B', '4607011666353', '   /  .  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E67346A-5045-42FA-9AEF-45D67B0DBCF8', '9FE35B1A-4BD0-443B-9A73-1C98FDD5D26A', '4607011666360', ' / // / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C639DFBC-A7B6-4F25-A209-74A002E93EB6', '4DA2501D-79BD-4DBE-A54A-836EDDA90B24', '4607011666377', ' .  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5A525B9-A156-41AB-90E7-01A69A3C1096', '98514BB9-4826-4C61-A4B3-AD568D00C681', '4607011666391', '   ( /) / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAE15DB8-7E85-4865-A9E6-BB548A426308', 'A38EFDF0-9D61-4250-BE43-32A7963DB44F', '4607011666407', '   /     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5D05EAF-ED97-4F52-A134-7CCC2F384954', 'ED551A74-A7A4-44D4-B6F5-BC2279BF5C5C', '4607011666421', '  - / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1C90D8D-76C6-402C-8FF3-9BAD973A377C', 'C34364CB-074B-4FB0-9C97-F5B073C89A7C', '4607011666438', ' // / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0C7E648-3F35-4A72-869D-12624B895FC2', '70F05C7B-BD99-4290-AA60-12A0B4D5BC61', '4607011666445', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB778105-7D8B-40B6-92B4-5BA8947D987C', 'EB15BF1C-3F9B-487E-B5A1-069E58643F16', '4607011666469', '  -      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4C49E9D-B126-4BA0-A7BA-38DAF68E07B3', 'ABDD8584-B631-47E0-8065-765DD1334CBC', '4607011666476', ' -   /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1032A3F8-57CB-4650-89D9-908AFFE7E3F0', 'F530E49E-58BE-48E7-AA8B-0C8E7B0C76EB', '4607011666483', '  /    /.,/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('032BE0A0-A423-4F96-B452-1BF59ED78271', 'B127D056-85BE-4ACA-965C-2592CDE84F72', '4607011666490', '  /// / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A9CAA86-CF4F-453F-A818-2F01B03EAFE0', 'BA5017F4-9B6C-4C1F-B5BA-D70BE6E0DD34', '4607011666506', '  -/ 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('287183F5-5AD1-4A81-A65B-4CC7132D5DE2', '8C7DD45E-013A-4C22-95A1-2335D6F749A6', '4607011666513', '  / / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCE86495-B226-4F12-9F5C-C9341B49C228', '4603360A-9A90-4A89-988A-474462595A01', '4607011666520', ' /   / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3332904D-B3F2-4231-BDA7-477122DD2976', '161CBC79-3EC2-447D-AD4D-A507D7841872', '4607011666537', ' ( / ) / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68717E26-8137-4E30-A7A4-61E4A672BFA8', '3534336C-6176-46E3-AD4D-F2AE64CD5074', '4607011666544', ' .  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6751B4B1-2EA5-4EA7-8F2B-622ACE3EF9AF', '47155D79-6C6F-4CBC-A795-72EA53E12FC0', '4607011666551', ' / / -  . - 125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D71495E-F742-406F-8935-96C5B3AC087A', '6A25B90E-BDD1-4A03-B20C-C880A545FB7A', '4607011666568', '   /    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51E4E573-1372-450A-90BC-5FDE6CAE7910', 'E85B8B1E-3A57-4593-8ECD-6EF3E57BF276', '4607011666575', '  //   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2752B195-FDF0-47E3-BCBE-387C9689A1E0', 'DFEE9831-39E9-43B2-8321-CCE54B76820F', '4607011666582', '  - /  .  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDFF624C-107A-4450-AEE0-48D0320B86BB', 'C885441D-A2CD-45CC-A4D7-5ADA08D4235F', '4607011666599', '  - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36D978A3-6766-4BF0-9B5C-0E38D0736333', '02F642AE-2533-423F-AE24-987C31D2E523', '4607011666605', '  - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4AE178D-C25E-40A2-9178-D2C421B11780', 'F7090113-15AA-4B6B-A5F0-A325DF522A6C', '4607011666612', '   /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7C0FFA0-DF9E-4C44-9C4D-B10F5DE1DA76', '3CC68232-DF0B-4FC6-8BF1-93364C4F962A', '4607011666629', '- / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF270498-6B08-402F-B418-67B99B70090F', 'B3DD4276-2631-4F7A-88DB-ED43E411E3C6', '4607011666636', '  -     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99E8F136-67D1-4ECA-8608-B9E10A706A26', '4352E1D9-9BF0-4EB9-8AF0-F75554DE4CDA', '4607011666643', ' .    /  ../ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2ECF62B-9B1E-46E1-AA20-A775E1C03330', '457FA609-3736-486D-97EA-2CF1491FD743', '4607011666650', '     / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B1535FD-C0F4-4EED-B547-E700A53366DF', '9AA15D16-D1BF-4675-A622-1C35E8FFBB1B', '4607011666667', '    / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8703079C-9B3F-4D77-A582-17F70F8165B1', '880E723A-BAD3-4AF5-9DF9-96E536806248', '4607011666674', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE4AAB58-F72C-4F4B-9D89-6CD1A4E3A912', 'B5AAD3DD-0899-422F-BAC6-336EACC45768', '4607011666681', ' .   () 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81115BAD-CFB4-438D-830A-78930B4BC808', 'A27CED23-13FA-433E-9BE3-3363C843E7FB', '4607011666704', ' .  -50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('402B9F70-422C-4BB5-A981-8343E50780F9', 'A917E721-A309-464B-91FC-4620509A6CF6', '4607011666711', ' .  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05A9572D-092B-4B39-851F-991FE080CAC3', '19175AB9-04AC-4973-91E4-189EF12B60EF', '4607011666728', '  /   .- 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA49D7BF-7258-4B45-9CDE-D74A1D5B5F1F', '49DD2711-3982-4472-83B6-6045FF3F3569', '4607011666735', '       / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB507AB5-49B3-4332-93D4-85FDEFDD2324', '5A8835B0-DBE6-4531-BB3C-E19E4C522E91', '4607011666742', '     / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF2C0FF4-18D9-4D44-BEC6-4046152282BE', '3DE4E65A-B5CD-4CC7-A933-3C60C1912BBA', '4607011666759', '  (/) - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F80918B-A28A-49EC-B2EF-3407CDF0C61F', 'E3882E16-B254-47AA-A199-DEBB5221874E', '4607011666766', '  (/) - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34B49334-0EEB-49AE-AA23-67EBE3D843FA', '1505F4B4-3535-4E9F-91FF-8E4350E449C0', '4607011666773', ' / / -  . - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB8239AA-5241-410D-BE33-D3A062E93B8C', '345BD77E-2DED-4013-8F2B-0B7633398BFA', '4607011666780', '     / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFB27865-C868-439D-8391-840D7BC5EA84', 'EDD83284-8148-4C83-91A0-461C5A66E4E3', '4607011666797', '   /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71076951-8A7F-4AE8-B7F4-D9A06EBC6035', '34FC1099-B66E-4CF7-8A17-789304E9456A', '4607011666803', '  /// / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35811860-A4DC-46FD-8CBB-3B425BCA46C0', 'E25C44CD-3803-434C-86DA-7A178B15D194', '4607011666810', ' 60   30  /. / / / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D9AC4D0-83CD-4C50-82C8-3143FB2748E4', 'BB280AF6-5DF5-469E-B544-CBD81A82FB4A', '4607011666827', ' 60   30  /. / / / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('887F0BF4-A714-416B-A4C2-F5935235498E', '3651AD54-FB10-422C-A506-9BAA3F129DB4', '4607011666834', '  60   30  /  / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECE510BE-D547-4E1E-B6B6-ADDB42613E6E', 'AF4C1FB3-F310-4F20-A0E7-11FCE2D7029A', '4607011666841', '  - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBDFDD80-985F-4B33-8868-0B7B290167B4', '3CD44EB2-A331-41C9-8AF8-2121B9E43B7C', '4607011666858', ' / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC21443A-8C49-45C7-BA56-0D734CC17625', 'B928E8D0-A54D-4FCE-8772-1C5D69F55EA6', '4607011666865', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('919071CB-C18A-4F67-99A8-A5E99FC92886', '14092EBC-0436-4BDA-92FD-F77BA0336F1A', '4607011666872', '  /. // 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B10E852C-DDF2-4E2E-BF61-56AFC5F0824F', '8C9B265D-53FC-4FAE-872D-8C85052ED0CA', '4607011666889', '  - /  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E0F65E8-0324-4365-BCB5-1268D335EFA8', '4084487C-1D32-4DC8-9741-F657FF593492', '4607011666896', '   ./. 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7457225-E4BC-447D-8877-F8521C683033', '7B13F034-63E6-4A06-9A2F-B40F921F0FD1', '4607011666902', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3D008CB-A730-4E77-9AE4-73458CE81594', '2F5575C5-6A15-4F7D-A1A1-DFAFE35E5499', '4607011666971', ' -/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDFA6F56-A599-4EC9-9B0E-A59B49360DD4', '323E88F8-A47B-4597-ADBA-EA56C0059F01', '4607011666988', '  / . 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52693486-7B9E-4568-823B-4CFFD9CB8BA2', '0A5452E6-27ED-482C-AE20-A9B0D7943602', '4607011667015', '   /././ 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1270FD91-47B3-411B-8423-BC92CD15911C', '3DCDF8D3-4FFB-49F0-A8FD-5005101983A6', '4607011667022', '  /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A267E520-EB09-4C8A-A215-862395980606', '7BB20BAE-28B7-4805-9AE2-8599980FCA59', '4607011667039', ' 60    / / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54ACEC04-753B-4FE3-A51A-F776F60472A2', '881FC1FF-FF38-4B19-8678-F4AAAFCC1202', '4607011667046', '60    / / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('490EBCFB-BD68-47D1-9BD8-E439B3974DF4', '641FAE0E-2678-45C3-B662-96AEF4243892', '4607011667053', '  /// / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3750810D-97C3-4384-9F32-92E424E4C625', 'BB280AF6-5DF5-469E-B544-CBD81A82FB4A', '4607011667084', ' 60   30  /. / / / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EED24B1-2B04-4E9F-870B-344F3A1D8550', '3BB3EB07-F8D1-4E99-AE9E-5BA93333D151', '4607011667091', ' / / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B71136B2-83B6-4CCD-98C9-9E5811BA2DE2', '790945DE-C52D-4EB6-A4BF-E22F4EE91040', '4607011667107', '  /       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C8F447E-D8B3-44D1-8B88-3DFA33FE25BA', 'A51B4D20-82F2-40BA-87B4-88BF9268B99B', '4607011667114', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29C43054-495F-4B23-A276-C1B475DB81F6', 'B50D85DB-403A-4D0A-B231-5A4B898BB678', '4607011667121', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A65E93E7-2D1A-4275-9129-9377A09D333E', '7E7B2C4D-013A-4492-9D89-9B3AB4A4B466', '4607011667152', '  / / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B8EB564-2C1F-447E-B9AD-244D26F5CC02', 'DB2C71F9-3882-4C3C-B9F8-C1ED22BEA408', '4607011667169', '  / / / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7951CAE-A994-490D-9D50-175541198261', 'BDFBF94F-1102-4690-90F9-822E7DC592BB', '4607011667176', '  - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1559A714-8089-4A89-AB18-75B17D19F551', 'CA2F7B05-5C00-4D40-927B-8BF8BAC7CE6F', '4607011667183', '  . .  .  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('944BD8B6-8B28-438C-BB99-DC2E60F745FF', '2FE61529-F27C-469C-A46F-48F7572ED368', '4607011667206', '   - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFBED064-560E-4B38-859F-F47E357A731B', 'F2AD2C41-538B-4BDF-BD74-D7B906152491', '4607011667220', '  - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0FCA0DD-FD84-411C-B1A0-06A5B5392860', 'AECE7565-8DC1-4AA3-8190-40D44F7E446D', '4607011667237', '  - ,  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47749548-92AA-49AD-8353-45FF893EED08', 'EB91EDE4-C916-42AF-A208-0984EA8F3A3B', '4607011667251', '   / /  .  75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7A1E9CE-3DE3-4C66-8F1C-085843C0783C', 'FA05D8FA-DC34-4170-A05D-A37CC307EADF', '4607011667268', '  /, , / / /  .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA5EFC42-45BD-436F-857E-73790DF8F36F', '4DDC2430-C02E-41B9-AFAB-404C3F389F02', '4607011667282', '  - / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CBFC4A4-314A-4B77-9DBC-E6174C78443C', '61B40774-99A3-438F-A525-891BF892F223', '4607011667299', '  - / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D51B0672-13C6-4F91-86EE-265906AEA242', 'EB15BF1C-3F9B-487E-B5A1-069E58643F16', '4607011667305', '  -      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F5BC7D0-D7E4-4622-B1D4-0AEF1B9DE1CE', '86DF2A77-85BE-4C7A-ABC3-AD58AC31C00C', '4607011667329', '  -/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BE1B3DB-1DD0-4353-B0E4-9D005836DACB', '5F92635E-809B-4258-85F3-9E72FE76AE84', '4607011667336', '  -/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15864490-9979-4B52-B2C1-ECB479D07827', 'C885441D-A2CD-45CC-A4D7-5ADA08D4235F', '4607011667343', '  - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24437705-80D6-41CF-BEF1-EE98B9202489', '8054A199-CD5E-428F-B0D2-083C60BF647C', '4607011667435', '   -/  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E10B19D-6199-4B85-85BD-C2696252AA77', '7F6B38FD-E97A-4DBF-81F0-92A01AF79500', '4607012269317', '    163', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('219F744C-8618-40B8-BA4C-C767177A85F2', '40BB4F68-89A4-4AB9-A231-2DE035A90471', '4607012510112', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9C4ACCB-0292-45E6-B40D-99B7FAB7275C', '578E1E16-327D-4245-A82C-8037935AE6C6', '4607012580269', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF33A384-BAC4-4CAC-8970-0FFC29BB59BB', '8741F812-52B8-462D-A011-F3E0CFB2B5D9', '4607012580290', '  25   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('974EF9D6-A012-4784-A0D6-FCF1EF63AB24', '8C9E5444-FC2C-4E52-ABC2-5DA883D103AE', '4607012580320', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9FFD711-98D4-4032-9912-DF3206C85B07', 'FA179778-5BA9-4A39-8FA6-EEF50330FC40', '4607012580344', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CBBD79D-B50B-48D3-B6A5-BD07B3DF3F5C', 'D6BE81E5-F97B-442F-9041-53BE57610A0F', '4607012580368', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F86FB6D-D3CD-4029-BF31-ED7DE25B2C2F', '8AEE9D01-4204-4D50-B3DE-67E7B0F335FF', '4607012580375', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B274EBE-8D58-4282-AE9B-E199041860FC', '40A404F7-7B6B-4C84-8730-7F0965FCEBAD', '4607012580382', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5A8DD5D-873A-48E7-A58F-67E43242C3DB', '7C49A6FD-A943-4903-BB4B-17AECFF2A602', '4607012580399', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFCB6F29-55FD-42EF-B230-16435CEDB526', '81448EBD-6A6C-4A73-AAA7-CC6876E1711B', '4607012580405', '  0,05  200   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69ACCACA-8042-4DA4-AA42-575E72EDA198', '7965652F-9443-47BD-835E-40D57B7F0DD0', '4607012580610', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0774C960-73DE-47DC-B588-721EB89FB09A', '9DE36E8F-E50F-4A5F-868D-29218B07978C', '4607012580634', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E16A7244-B663-4910-840D-6CBF4A582A61', 'EB324EB5-FB99-402D-8F5E-B4954C88A3F7', '4607012580658', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('617BF82E-37D9-406E-9ABA-CB577C454204', 'AE44A718-B9A0-4924-9B58-0B8DEFFF7086', '4607012580672', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E953A10-FD1E-4805-8848-61CBCB9F8736', 'AE44A718-B9A0-4924-9B58-0B8DEFFF7086', '4607012580702', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3216CB5E-1254-416B-82C2-28AB3DA22E49', '97239FD1-843C-4947-B1C9-50DE08B753BB', '4607012581464', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9ED6A13F-C6EB-44F4-A239-D0BE9844C724', 'F0169D63-E3D2-4DAD-9FD7-2BEE08EDF788', '4607012581709', '     //   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BE6B15E-3D01-4012-B613-43B78BB37056', '7EF74D3E-64B5-41D0-A20D-73A07A4F1745', '4607013280502', '  42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16697962-C4B3-4A8F-8A9B-41D411CEEE8D', 'CE36E775-BF1D-4EA7-88FF-44B78344C1F5', '4607013280526', '   / 1,5 / 50 42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96216986-C78E-4718-8A87-3C1E28B800A4', 'ACA0EE61-B830-4683-B77B-7AD4244ABA30', '4607013280830', '- -  .,  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBC2F519-312D-4F3B-92B9-6BA86C86D804', 'B2A6D9A8-F51F-4D37-A569-0980D778B066', '4607013589247', ' 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCE2B000-A3BC-4146-BC87-B870E7CDA83D', '5AD7EE70-88FA-45EC-BA7A-96F0E9C619C4', '4607013589254', ' 350  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B0B51F7-B9D6-420E-A7FA-3A5DB7DAA227', 'F73946CA-DA9B-495F-BBE5-8E5BF5F51254', '4607013589261', ' 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B3791A3-448A-46CE-BD3E-BE6B67B00CFE', '49CC631C-A830-4589-9AC6-1D401BDC36BD', '4607013589278', ' - 400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A86934B-64D8-48BD-A388-621C218C33D3', 'AFD61E55-C6CB-4187-9B5A-A8A390678096', '4607013589285', '  500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('277C3E4D-9FE4-476E-B0FF-A3340F2993E7', '2E922182-CF6F-43EA-92E3-48578AD67E40', '4607013589292', '  0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87065AAF-90A1-4A34-9466-9E0A54959F25', '1F0EBED4-DAB4-417F-B0A1-AFC63BB70F23', '4607013589315', '   250  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D4344FF-9E83-4C5E-9EF8-867123798E64', 'CC81F820-8EC1-41CC-BF89-9C484821C352', '4607013589322', '  0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31111B30-614D-42EF-B315-221BEBD26E5A', '93CBC634-8D35-4D4F-BC15-8C4FEF1EAA2D', '4607013589353', '  400  38', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DE86CF7-DE90-4F9F-8481-1B96B34D4464', 'A3BBFE03-D21A-4F64-A775-38C483BDA81D', '4607013589377', ' 300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82D09CD7-76C1-4716-A45A-F4E4A86C3B89', '8C2337BD-7FBB-4B4A-8352-2114F96BFE17', '4607013589391', '  400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA00F716-8876-444A-957B-5DA5C5E49BAB', 'A0CB881E-21EB-43EF-85DE-92A424EE3EBA', '4607013589407', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('333097F9-E156-49D8-B2E4-DB537F21488A', '34111F94-B4FC-4A7C-8C4D-14F9BD21EE35', '4607013589414', '  1,4  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CA26E20-6BFC-4222-A60D-CFC92452082B', '35256C60-27A4-4E38-BC56-2F8948450136', '4607013589438', '   1500  10 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('285B9966-B00C-4043-AE8A-DCF3AD856D95', '6C5E69D4-7FAB-4C9D-B1B3-B21CFB1608BE', '4607013589575', ' /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('088C74F6-0CA9-457C-B945-F7AF9AA7832B', '1DF98664-3CF8-4904-B419-AE53089B28A5', '4607013589643', '  2,5 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0E85336-EE78-4866-BDA4-F243F5C24A1F', 'DBF087D0-5DF0-467D-A488-82E1A7529A5F', '4607013589650', '      2,5 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFADDCE2-646F-4975-B52E-0C10E8193112', 'B7B19725-AB4E-440E-9065-64FB17DC5EAF', '4607013790025', ' 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F46F3F3A-B85B-40BE-8126-DC7AB925DC48', 'D660E65F-C422-4C22-821B-988881AD6521', '4607013790230', '    650', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28FB9AB9-37A9-48BC-A2CC-DF3AC7943227', '5FACC521-2356-4BEE-8EE6-F8E7778CB720', '4607013791053', '  .     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('969CF666-1D36-4D87-87C1-9AB154CEF9F3', '1268D124-20D8-43A1-B4EC-D40CABEA080F', '4607013792043', '. /./   0,05  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D98F95DC-0AA2-4A67-9FEB-3738C4383A3E', 'ED06F829-FB50-480F-AEA2-25C2184A785A', '4607013792319', '. /./   0,05  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0D2A4CF-A0F1-4182-8235-7431138352F7', 'DCFC1647-200C-4626-B8D5-3218A7020B34', '4607013860155', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCD5600D-18C6-43ED-98A8-248540489611', '17D0E2BF-9948-4994-9951-525F9CB35B5E', '4607013860186', ' 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23ED79F8-2F70-4193-9E44-076BBD6EBFDD', '5B418C73-4705-4B52-BADA-23D59852E48A', '4607013860209', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('397558AC-50FC-4073-B8F9-45A6FE932A75', 'DF2EA595-1419-4D7D-9061-6666132F7BF0', '4607013860216', ' 10 20', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D7CB44D-7FD7-4356-B243-9E93FC48B456', 'BE524DCB-5255-4D38-AA86-C0F495A16480', '4607013860452', '  / -  5 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E522FC13-F7B9-45FA-B382-CD70DA949B3C', 'FD5F1A5F-0CA8-47ED-B167-8A3859A78E63', '4607013860780', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C8F8A16-5DB4-4856-A201-F64DA1155773', 'C07DC5A0-2214-48A3-ABBE-BED6D942F630', '4607013860834', ' 200  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AA0333E-A220-44D0-8DF3-37D443E3476A', '8E27F8AC-09D8-4824-A60C-9397194B208B', '4607013861176', ' 410  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0460513D-83B5-42D9-9CC8-C44368BC65FC', 'F70E3E3D-4640-410B-BE77-4247EC47CAC6', '4607013861183', ' 267  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC0E0A33-9E4D-45F8-984D-133CC2C26F84', 'D34FAC4B-FCE1-4D5E-8B10-66B4B84EF62B', '4607015239430', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30D48651-44A9-4E75-993A-A407FCBD060B', '4FCBD3B0-C0C7-45BE-A7D2-2AD4FE249B40', '4607015590227', '   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAC5F366-F9DA-4EC3-8040-1E6ADE29F675', '811F8966-EFB6-4A54-9661-E262C59781C8', '4607015591149', '    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63A1EEB7-7D0B-42A7-9AE4-4BBA98520804', 'C93D027C-A71E-4574-97B2-0C6B3245E218', '4607015591200', ' -  //  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A71716D-2269-4C71-B00E-700DEE7F6352', '42E34A30-4B2A-42B8-A5A6-9EEBA108E6CA', '4607015594140', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB973A87-4942-4D2F-B6B2-276E407B7998', '424A1756-6B72-459B-A937-BCC4A68DB055', '4607015597004', '   /6090/ 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A5E09D6-FC06-4760-A2F8-85E2127B410E', 'FD4DB856-354C-4D92-873B-CD11DBA744A0', '4607015597011', '  /6060/ 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2CFEB60-B350-4E7F-B59A-8DBA25E5A0D6', '00EDA777-B9C0-4957-89AD-70747E8FC4CD', '4607015597028', '  nappy  60*40  p24 // 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA7A1F24-D581-4B5A-89B3-1F86CC4A1D7F', 'FEEECC31-8F22-4A08-AFCB-5EE1903E1D19', '4607015597035', '   /6090/ 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8A75300-0191-4D65-A118-8341D08FF4C9', '7D4F3FEB-F93D-4E35-AE1F-9227598D517C', '4607015597042', '   /6060/ 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05C5A975-4295-4C83-B05B-4763AB5AD691', 'A38D00AE-00BE-41EB-A641-D711D8333470', '4607015890013', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72C65D88-3375-4564-BE12-46B51BDF6F63', 'B1EBA0B6-BD46-4897-B88A-C2137F8D5DFC', '4607015890105', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F360886-AB8B-40A2-8479-EA23FCC5C5C7', '49E63669-9515-45D3-A79C-45743459BC0E', '4607015890679', '    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('866F97C9-FFDD-4270-9F6C-37E62E23007C', '76C6E6C4-7912-4C84-9C37-580250481E5B', '4607016282527', '  amra  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D4D9EAB-C848-4016-AB30-731508488C29', 'B2A6D58C-25A1-409F-B0C1-2CBDC4FA76AA', '4607016284569', '  amra 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BCF21E9-502C-4650-AEA3-C475C117950E', '2DE9354C-EFC8-4AEC-AE7B-1F1404870B05', '4607017264874', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F844C5ED-91A6-4286-85F5-54739F80F7AA', 'E81A0E47-D65C-4C1D-8385-F807D0A0C022', '4607017264881', '  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('453E71D5-23F3-4F77-9505-632DD6BF8D13', '99C068FD-EFBD-4B8C-AD6F-312C6CBDD603', '4607017264898', ' ./  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2090A2B-C71C-45F5-BC11-C9CF0F8E5BA8', '1D788FD5-06CC-4B39-81D3-4637CB5BDA4E', '4607017264904', '  /      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB018AF6-F2A6-4D42-A7B1-5E6211125CD6', '5ADADC6F-EC5E-4523-94E3-CF2DC182324F', '4607017267950', '   15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8DC2E22-711D-41D7-A717-C8B462D3D1A5', 'C8B8BA7A-159E-44C6-AB10-10352D27778B', '4607017267967', '   1,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62F3AAC3-9598-424D-809E-DC1EAE54D49F', '6BA7AB24-A2B4-4038-9498-5DAFAFBD3ACE', '4607017268209', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF82F9C7-0B18-4F1A-8514-AB1D0BE08237', '16D2F57C-15AA-4EF1-8D33-A90EC5481248', '4607017268216', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74305079-989A-405A-90CB-91CD62963154', '7FE3AB5F-4204-4FA1-8608-B43073533605', '4607017268810', 'l art -   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21BE5739-3505-4FDF-9025-7B5DB8A39A63', 'F8888C05-124F-4523-849C-6EDAB21BE967', '4607017269145', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5589A3C1-BD30-44B2-9B89-F550A77D96E5', 'C999003F-1FD0-4710-9446-6546CDACEAFF', '4607017269176', '   / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52527F5F-1F9C-485A-8D76-769C212DE303', 'E6C544F6-53B9-4CB2-90F2-1F1E1F8D644B', '4607017269183', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('203D79B9-8A0B-403F-9E16-EF7B0DE4AD27', '64D813F5-51F5-4663-8B78-9776DA3069E5', '4607017269282', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B7925A8-56AB-4046-87EE-EB15E2B433D3', 'CEC55208-D507-418B-920C-F129DA272A0C', '4607017269725', '  /    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0C6343F-1E67-401F-BEC3-2CBCF3B72FA1', 'CEC55208-D507-418B-920C-F129DA272A0C', '4607017269886', '  /    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CC08C0C-3F48-4915-9AD7-C7617D5C0A23', '8754EADA-67C5-4754-BBBC-874D0C4907D5', '4607017269930', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EFB6C51-9122-4D1E-82D0-ED7E77F562D6', 'D89004A1-33CF-4D05-BE71-35B88812CB20', '4607017269978', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ED0E012-6708-49C3-9D1F-B11A938CC743', '5A9CA51C-A20A-4D5D-91D4-D7BB6CE176C8', '4607017269985', '   15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16077170-6F39-490B-BF95-81DA0706513C', 'C8B8BA7A-159E-44C6-AB10-10352D27778B', '4607017269992', '   1,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F389980F-C645-4443-92EA-7BB57CCEB431', '90583272-88B4-43A4-AE19-0BF81F077A69', '4607017471708', '   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B35DCB78-7B2A-4FA0-B916-A9F7D4746563', '8D62C420-E04B-4533-8834-04B38B5F0A76', '4607017471746', ' 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05C6806B-C9B6-4FAE-923A-07563976A2AF', '171C5F3C-94AF-46F4-8BAF-F2F9FEB8025F', '4607017471791', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D945C2B3-9B83-4429-A193-04F2B134E601', '7D07C724-69DB-441F-B156-6F84971ADEB7', '4607017471807', '  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D48AE080-A263-40FE-9FDD-E3AF045335CB', '90583272-88B4-43A4-AE19-0BF81F077A69', '4607017471814', '   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A06FDFA-6DD2-4E61-9B35-927D962A8471', '263F45F0-82DE-4E28-81D2-B71DD8A6D9F8', '4607017471821', '  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEEB5627-C18F-4B8F-B537-9F34AA84EB81', 'E0472DCA-8E2E-46EC-B5EF-F02779067D15', '4607017471883', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA15042D-96DD-4B3E-BC0C-38222E6B18B9', 'B763DD43-5F2A-444B-8781-155186DCFCFE', '4607017472231', '    500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B227FD14-2706-4A07-8F11-00A8D5E86B93', 'A470B731-F772-4FB8-8CA3-DB4B3AD214CA', '4607017840627', '   / 3 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE7897F0-5F95-44F4-9FEB-CE642C4394F8', 'B98C8667-21F1-4990-8AFB-21219B58685C', '4607017940044', '   32 // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEB31328-E805-4D98-827A-156F748E8151', '7D93C61F-8C54-4547-98C8-03B7B8288A81', '4607017940181', '   35 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A380935-00D6-4990-80B4-B7FC11327312', 'A5A5C27D-DEEE-400B-8B54-5BE33DC907A0', '4607017940938', '     44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('445BB074-4B3D-485A-829C-500918D1470F', '9C2EAAA5-222C-435F-BA0C-8BF6DC029590', '4607017941805', '- - 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0806DB9C-152F-4964-9A68-5886D32C4B0D', 'D09ED89A-E987-4EA1-839C-1182A9ED22C2', '4607017941942', '   28 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A83BECE-DE0E-4125-9A15-36A5DEB3A6F9', '511203F5-5DE1-467A-A0BA-CAC28A6E06C8', '4607017942871', '   33', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47AFFB94-D2D0-44A7-B57F-27267F6F4E76', 'D0955469-90F4-42D0-A549-E6A28CC15585', '4607017942901', '    28 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E22B039-C947-432A-9DC0-CAD6DAF39A36', '83F02A94-B6C4-4631-892E-F0A1376CA336', '4607018197225', '  /     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97CC0684-4CAC-424F-A7FF-389BC25D6252', '08D49C15-54CA-44AA-8143-5E779BA87258', '4607018264569', '  550  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B40B510-68E1-4FA3-8E84-3D8D6835B8D4', '7F752928-739A-4B96-9BBE-F3020A1FC79E', '4607018264583', '  550  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('420ED7F9-D00E-424A-AE1B-25D3AEDB2BEA', '43D656A1-96A0-4B51-8CB2-506169D41F18', '4607018265092', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48D3A098-42A4-4986-A013-70B0E56AD34D', 'D94A7A71-D7A7-4EFD-AC3F-C6BCF11055A7', '4607018761587', '  46', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9B3323F-E911-4DD3-8E12-C0222DC320CF', '6166EDD2-7461-4127-A2FB-6F83F8E2EDA6', '4607019010134', ' 25 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6741499-C164-41FE-AB58-CDE2AAE7C8AA', '6166EDD2-7461-4127-A2FB-6F83F8E2EDA6', '4607019010141', ' 25 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3494DB3-0F17-40B4-8141-0D1F71131542', '98CEED98-6DBB-487B-8A2D-F266A652B052', '4607019010738', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BF33743-2FE3-412B-A3A5-DD6B94848E1D', '28B7F1A1-0AAF-48F9-B25A-F4948FD44BF2', '4607019010752', ' 250  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5D0FD3B-D8B8-46D6-BAE3-67EE0BB5A801', '7C1AAC5A-53EA-49E6-B255-39B48BD1C43E', '4607019011056', ' 16   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3B33A3F-2A09-4D09-A026-1A6807BB4F3D', '990597C6-C223-4239-9D83-396268C094BD', '4607019011094', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('119ADEAE-209D-482F-9318-4AFDF0049A53', 'CB98FBC2-E800-4BE9-8926-3867B4C51782', '4607019011100', ' 3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AEFABFD-E733-4E61-A9E4-2550E3821CEE', 'B1430623-4713-4F59-8E45-4BBC614A5435', '4607019011124', ' 100   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF0799F8-3B89-459F-B9C3-43C61F873DA5', '6193B6B2-92DC-4F08-925C-D3781BEDC796', '4607019011131', ' /-/ 0,12  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD0C477B-518E-4BCF-9FAA-4A75607EAF9A', '28EB3D99-BF82-41A5-8D8B-00C7E5C6A93D', '4607019011148', ' /-/ 0,12  / 112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7B375B3-7D71-4CD8-AC30-48719501BF0C', 'F7B33774-9759-4851-B09E-43B78732F1AE', '4607019011346', ' 150  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('717BDFAF-A5B1-447F-93B2-B81FB8B1F2A7', 'ECFDCCEB-C5B7-4A5E-A3F7-0596FF56B558', '4607019011407', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01FDBFD2-15C3-46F4-BDCE-A59167AB0E32', '1D32D8AD-DC7A-4C37-BA87-2ACD150C3CFD', '4607019011438', ' 0,005  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F7580BE-9686-412E-986B-CF97C8F4B77B', '2F2033A3-AC15-4EA5-B863-7CDC6B50FA08', '4607019390366', ' 202  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEFDCEAA-8B95-4150-913C-B2C1C8315673', 'E516CE7A-0184-40FB-A822-4E1797F9A2F6', '4607019390403', ' 155  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('132A5575-D2EA-453E-93F6-3AA6EAD8F9CE', '3F85CCAA-FAF9-409E-ABA0-28829CD99477', '4607019390410', ' 155  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAF9D185-1DCA-4281-9604-66899D2C8036', '2E8C11B7-3AA9-43F4-B164-4AF202ADAB3B', '4607019390441', '  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CA4C0B6-FE59-49F7-A774-7F1C40B3312E', '084A6311-6214-4596-AE4E-82E05DA61E0B', '4607019390489', ' .  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC0A0594-CB17-4E66-9030-0B4CBA5EF78C', 'E0EEB6B1-FF7C-4DD1-A589-3BC78D086F86', '4607019530021', '  0,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5116058-493D-4E6E-A684-3B04D494BB86', '812E1B78-25A5-4DA7-B98E-EA4D0FFF304F', '4607019530045', '  0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97A9AE70-9636-4A5A-B12B-8C71DE0468AE', 'B2EABEC0-22B5-4212-BAAC-2B7618EF4317', '4607019840434', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FFFFE07-A619-468F-A924-330CA3543E85', 'D02A1938-D7D9-4A04-876A-70FC4B80E9A9', '4607019840465', ' 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('120B413C-1B84-4E2F-8FF3-A429DE59E4F4', '99E2F94C-E719-4774-830A-C42875EF0094', '4607020210042', '   667', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A45F69DE-6A0D-4A93-99C0-D435F28AC29F', '7130A8D8-4070-4962-B7C7-569484AF55AA', '4607020210066', '    1200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('762B8A3A-803F-48E8-8D3C-11F85EE6F968', '7EB8F127-25EB-49F4-91C3-0E8E883FEF45', '4607020211278', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('089F03D4-A20F-4C17-805B-00B0EFB1B8E2', 'D3C3AC48-5F4F-4B1B-B34F-7F3094BD27DE', '4607020330146', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C08F21C-BFA1-4128-AF8F-455B33AABE54', 'E3509CA9-FFAA-4666-92E4-23E66A19C967', '4607020330603', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55445CDE-4DDD-437F-B461-C0609D791058', 'F1E42041-25FA-4432-A81D-178FE2A3E12C', '4607020331785', ' 2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90B7FCB4-CE4A-4155-A385-4F1BD68AB713', 'F1108C12-A2AF-4961-B56D-318DE7451DFE', '4607020332126', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('841BBC43-B615-481A-8E04-B4802F1D28C5', 'F7EA6D1F-8751-4C10-8C8A-EB82A3731D22', '4607020332201', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E38F99D-3BC8-4133-B1C6-D679665F29DF', 'BBD5C76A-5E6B-4A62-8B24-FA3A4AEFDB0A', '4607020332270', ' 0,024 //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25E7BF55-14E0-48FE-AC93-9C9E2ED8AD05', '2AD6A1B2-0BD4-461F-8CF4-40C34C22D246', '4607020332287', ' 0,024 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D965E9D-402A-4B59-9B17-7540B1299E21', 'E7593465-06B8-4E84-868F-64692A0FB9C7', '4607020332348', ' 6,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10760E89-C3A4-4CF8-BCB7-2947E014512A', '80AC0F86-21DC-470F-BA71-4EE9D967BC7A', '4607020332393', ' 0,0125  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DDDCB90-3D3C-4FB9-9544-7D6FCFB1D291', 'BA437685-6405-4A6E-97BF-0ED85CDBC7C4', '4607020332447', ' 25 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40CD86C0-4F4C-4A65-90F4-A2BECCB30744', '90BE6146-C5F6-4B4B-96BF-0D3FBFD79E59', '4607020332577', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63BAF513-73EF-45FA-B88A-00055F0B9871', '3DDD54E7-6783-453B-98C3-4631918EB3A1', '4607020332621', '  8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AC528BD-75AF-4923-AF4C-9BE75AC0405F', '1923FE95-09D3-44A4-A70B-4C4C4E0996E9', '4607020332676', ' 0,0125 // /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F589EA62-113B-4D38-B105-7A8FB856A287', 'A2864CE8-2E2D-4506-878B-CCF15BA66D7B', '4607020332720', '  25   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5219C09A-DA63-48B7-B4A4-59D20BA0AAD9', 'E1F6F4BF-CB11-4AAF-ABA5-D7916E6D1600', '4607020332775', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F526BA59-E170-4243-B9E3-47D5EA8FFD14', 'F3968626-BF9C-4AD3-8F13-AE32D2F08C6C', '4607020332843', ' 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E300E792-E38F-4514-814F-E16AA6E50E49', '6CE0431E-A526-4DAC-BF3D-9148C2113FF0', '4607020332874', ' 5 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BB876C1-BDD4-48AC-B529-12E9B87CC6F3', 'FB6FF834-3CD1-4B24-8A60-5AB176DC3B94', '4607020332911', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CE8C8B2-315F-4D93-8E5C-27B922E9B618', 'DEEF506B-DE83-4CBB-8DAB-FDA810401698', '4607020332928', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA6920D8-47BA-4698-A938-1EC793783D55', 'DAFF09AA-D4A4-42E0-A713-954556DEB8F4', '4607020332966', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23842EA2-FFAC-4061-84F6-AFC59C8C098B', 'B4F9A642-B072-44A3-B29E-C36D7C15FAE6', '4607020332973', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('592607F6-BB07-4FB9-857E-0B9AF99AD7E4', 'ADF0F1F8-F10D-4FE4-8C5F-939FC127E323', '4607020333055', ' 5  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDB1D8A4-EC50-4E6E-B631-FD1263480EE0', '906B5ABA-5C25-44B1-82C4-C8F31C7B4E40', '4607020333123', ' 10  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2AE81D8-94F2-41C0-8132-A35512036DA9', 'F8724186-3A0E-476C-9CDA-9822A8652909', '4607020333246', ' 0,024 //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5401116-FB8D-455F-989B-4A2AB4147529', 'EEC4E04E-1570-499D-9DB6-02F1C08A0B1E', '4607020641259', '  2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A426214F-160C-4EEE-8FE5-1EDF7A9FCB07', 'BF6DE3FA-F127-4E7F-85A0-5B53610223F1', '4607020641273', '   2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F91CE4C-7772-41BB-8613-47815461E7AC', 'BB648890-F34B-4398-8376-41A8B81DE16B', '4607020641297', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF31415D-6E24-4B81-9E87-B4A144D48330', '5A89E855-CFE7-49ED-A3C5-222BA3300589', '4607020641310', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B94186A7-CF87-4660-B229-3F481D54B8B7', '8250A8A3-308D-4871-8A99-C022C9B34CC8', '4607020641334', '   2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8D5C7AB-7804-4CBF-89E8-55AE0010170E', '7E7EC015-E17C-4A07-947B-1C7DEC7B8433', '4607020641396', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92733D0F-F07A-450D-9C79-D0DDA9F5EBEC', '3DD4D777-99C3-4B11-9994-8F3A49BF015F', '4607020641419', '   2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DB466B6-74AD-40AE-ACDA-B84AB79F770A', '4EDE423F-16B5-43FB-B66C-D86248054DA9', '4607020641433', '    2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85279B2B-0B12-415F-9F73-F6A4570E75FE', '63908EE6-43DA-4D96-B81B-E45F91718E5A', '4607020641457', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35BD4480-DCDA-4728-8FA0-CCD7E437DC08', '4C3A232F-10B3-428C-B336-90C60DBB4D17', '4607020641471', '  , / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E404B0F-1A8B-4CF7-B53A-303AED34CF9A', '639384DC-F160-4022-8A11-B63CC552B84F', '4607020641983', '    / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7B28E55-CF82-4745-980D-8C9B63DEC029', '8C42A555-F6C0-4E29-8E4B-C39E041CC00D', '4607020642072', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCF3DD9C-AE93-40EA-9AFA-5113EB0DBF10', '3FBDD378-79F1-474B-99A2-1F75FB313EF7', '4607020642102', '    / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F15041E7-C034-4B2B-9AA5-8CF6452D6BDC', '797EBF9E-B4A4-406C-A555-573A5BEFCE09', '4607020642188', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8800E3BE-B699-4747-AF36-D90E9864323C', 'CDE8F633-BAF0-4A44-99AF-866599F1E455', '4607020901513', ' 1 /      20 / 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7DFB52B-4808-47A3-8D2A-97CC4A31DC52', 'D15EC5A2-CA14-481D-85F6-43567B46FAC9', '4607020901520', '     / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('117DB0EC-7730-4D81-8A58-091CB993FC14', '6E85B4DD-2F1D-46F9-A282-13B7C7CE1709', '4607020901551', '   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A84994C4-CD00-4143-BA11-43417B8BB637', '81457422-101D-4249-8383-8FDEA7571674', '4607020901582', ' 8     20 / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('139D539F-0281-4C23-990B-F7FDA0932482', 'BF6018A6-EB86-476D-8320-2FE1A78F60A8', '4607020901605', '  10   2 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8B4F9A5-E9BB-4560-BBC0-CC86BB4E3507', '7E117CE6-9773-4E0D-AA4D-6899AA253ECA', '4607020901612', '       / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C3B91D9-35F5-4F32-B64B-DD68D76B7FB4', '4B28FAF8-051B-4955-B621-84FB882475CC', '4607020902350', '  2 /   2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12B0D1B9-CCF0-412B-87C8-EE044347F527', '229A5CF3-85F9-4E7B-8F82-3A2ABBB2F29E', '4607020902442', ' 11       / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26516ADE-A4A0-436C-B8A7-A7E81834A225', '92388EDA-E1B3-48B9-8239-5F565C9E1BFD', '4607020903333', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59E62A03-80DF-4C89-8995-8156C9C72EBD', '0366DB89-CA73-4E73-8112-60395C5C7015', '4607020903357', '   / 1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB927371-B60E-4A5F-A91A-5ED8D1331A14', '8875E9B2-AA5F-4693-8F84-F9959C409CD1', '4607020903371', '  / 1,5 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C077C38C-DCAF-4963-A4F0-32041FD6229C', '6DBE63A2-ABA8-4064-ACCC-1621B642497A', '4607020903418', '     1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('592A8A3F-7833-4395-9C71-A896F03BD254', '7726AF0B-3B98-46F6-8606-301156A5B81B', '4607020903456', '  19    2 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D04BF047-E1F0-4D7D-A59D-01FA7888AFCE', 'DD0C90BB-6B36-47CF-A56A-2D3BA031859B', '4607020903494', '  22    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7447B537-88F4-4182-BB04-E7E56490778B', '777EE769-257C-4D76-8CD9-03942A9FFBE9', '4607020903586', '  16    2 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60B74696-74A9-4D19-B475-EC4998AB1B1B', 'EC408564-6250-4296-9BF4-3F753AAC2DFB', '4607020903630', '  17  2 / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EB8560B-D4DB-4B7A-AE24-200A115F6696', '907C031F-44FB-4B0C-AA18-9B4425BD9DB3', '4607020903654', '  23    2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45A23BA8-EC98-430C-90AD-11AEC9996467', '732D2BBD-E5FE-4EEA-82E2-89A81C36B676', '4607020903975', '  21  2 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B0A4275-2C96-435A-AF35-1E8B90BDDFE8', '151815F8-012D-4CF5-AC08-ECFFBC4A694D', '4607020904019', '    1 20 - 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AFD0A6A-7A87-4657-877F-EC51588931E0', 'C6A69560-DE08-4704-9368-FA8B5BC88328', '4607020904026', '  2 -   1,5 20/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('417B9F0F-4844-4CC2-BEEC-53F01169A359', '8BE21F28-23F6-47CA-BF7A-60A3B1D2D33B', '4607020904033', '    3 20 - 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B88F0347-AD4E-4B16-955D-0C662CD98A08', 'F45CF71F-1BCD-4381-86A4-22F3F01B85F3', '4607020904040', '   4 20 - 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1612BB6-8226-4C17-9DCE-A9C014486C79', '1D2F8674-FC57-434C-A853-E4779E16655E', '4607020904309', '  28    /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AABCCF3-3AB2-421A-8C36-E7385B46EFEC', '67AD3BBB-4535-468F-A884-2C476161CD1F', '4607020904361', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D06D2E6A-6D4A-465B-8815-89B630436C7E', 'DD93186C-1F8E-49F4-B908-C7C7866E3D05', '4607020904620', '     1,5 26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('303462B2-2749-4680-BD63-F78BF20D184A', '256B253F-A516-4712-BA0F-059B932B38A0', '4607021271097', '     1010 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9640DF4-18D4-4CE0-8D51-E6376109FD57', '2421D49A-2E62-4E35-B0DA-5693E1F3FCF0', '4607021271103', '     1010 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9833FB90-FE9D-4CD3-8437-5F81C096E707', '2BC11E50-4540-434C-8C6F-F425E26F7E0E', '4607021271271', '     5% 57,5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60A4D680-1158-488D-88A2-E8B32E50A1EA', '5914B99F-75ED-4333-ACC3-0B5BD5B370FA', '4607021271318', '     57,5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0824289-CA34-486D-AC7F-E7E925CF91B1', '5914B99F-75ED-4333-ACC3-0B5BD5B370FA', '4607021271325', '     57,5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A50DA00-9D44-4A71-B1F9-41ADA5F64775', '9EE7BD9C-0DC5-4812-AE3B-3C59CAF2AD47', '4607021271769', '       5*7 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58C78CE6-CD3E-4901-A290-E650FB4F46A2', 'C6F7D199-FCC1-4ABE-8E8A-48A1E0FE69B9', '4607021271813', '       610 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F0EE70B-38D9-412F-A2CE-D676826A2291', '31FEADA4-FA66-4592-8342-BA5B7CA35BCF', '4607021272179', '     1010 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01D925EF-282C-4FE8-8D25-EADDE8E28BA5', '588D831E-C817-4EC7-86D0-4F4E5EB7DE15', '4607021272186', '    1010 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AEAB3A7-A289-4FB6-A1EC-E3E2FA287837', 'ACFB8DFC-8269-4A8A-9C87-AB8F9FAEAC39', '4607021273473', '   1,97,2 10/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15BB38B5-89FD-4DBF-9AF6-130A3B92AA9C', '0E2B0797-4620-4DAC-967A-F7A2F59531FF', '4607021709910', ' 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06AB27DF-9E14-463F-98ED-0E6B9055A760', '580A8C09-7999-433E-B0FB-9B7719CA2D86', '4607021709927', ' /   170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A8D5D68-6481-45EF-9DEC-3166338DD3B5', '2BBCB747-798E-44EE-B4F0-76F1EEBAFAF6', '4607021709934', ' /   170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C0464EB-B5B6-4C13-83B0-AC49E8A75DF5', '5198F22C-047D-4B97-82D1-3B27857BCE7B', '4607021709941', ' /   170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42DC39C2-66F3-4D28-8AA4-6F45DC2C1AA2', '8FAF38BE-CD30-4EC6-AAE9-6F3904B7E879', '4607021930116', '    300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('341FA430-951A-496B-B5FF-40F67C3EBF93', '15AB0DC7-126F-41F4-9A5A-A5F4246DA917', '4607021932905', '   3,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8AD3A38-FD57-428C-897F-8726C8D49068', '82A9051D-66BF-46C9-9D01-398D7D432A31', '4607021939355', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('936D507B-A70F-4C94-920B-93E6C4AA5E2C', 'EAF0B2D2-CCA1-4848-9A98-8A8CF04CDCEB', '4607022750140', ' 20  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('162D77E0-8B73-4B1B-A56A-27089BBA0C68', 'F75919DA-F6E2-4363-BACC-B45ED2DB1767', '4607022750331', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94CEE32B-0B75-4C63-BDEA-C35491415C7F', '9EA689E4-DB20-455F-9394-A34D963A6A71', '4607022750379', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66CC1F9C-4586-474C-9088-34610EFBE6B2', 'FA5322A1-2E99-405B-BA72-D58D87249E93', '4607022750409', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B561E634-31BB-46D4-98E0-C42D6298E9DF', 'E3E4FE67-8FAF-4031-B48F-41C974A71C18', '4607022750515', ' 0,25  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('628044CE-9950-4474-BBE1-B508851CCE70', 'C75645A4-CEBF-4B43-BB67-D93652D05D88', '4607022750539', ' 50  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DEF526F-E4D9-447F-B72F-E7DA0243C85B', '50B823C2-920D-48FB-A5F5-48BF644FBFEF', '4607022891645', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89DD1616-CDA5-4E63-A0E7-F509CCBCCF00', '17D50EE0-FC9A-4DA0-8ECF-14387CB01F59', '4607022891799', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B819B31-AEA2-4FCE-97CB-6DA49D4B8EDB', 'D141900D-FF41-4E3B-9979-E922F45AADB6', '4607022892505', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('073E0DA0-416B-4EC2-89F1-1C16977F9E90', 'E907224D-1FAA-489F-8A67-09D4B8145B32', '4607022892550', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3AA5E5D-C39A-4239-8D4F-12897AA0E888', '95312087-063D-4123-AAA4-B72352247070', '4607022892598', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AF17F09-0783-480D-8741-8E82E2A844DD', 'CCDEE90A-15E2-451E-89DD-1D7F3F0932EB', '4607022892611', '  /-/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61320773-1DBF-4B5C-9283-EA888D519214', 'F2F3C922-1687-49B8-8BFC-60B51081ABAB', '4607022892741', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4E48F65-9613-4C8B-8300-5F7A7916BC9B', '44D4AAD5-9C17-4F83-BB68-F4FCF839CF80', '4607022892758', '  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD016830-26E1-409C-ABAC-1313FE9ACEE2', '9BA5D914-4B06-482E-A079-EB89CEF505EE', '4607022892871', '     / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4703B99F-8BBB-478C-B66D-9AE8C0B92C0E', 'E1800B54-2BB6-4C46-A835-A44B71957ECB', '4607022892956', '  - / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E20D5338-62CE-4936-9F1E-A3C199670324', 'B99D4243-25B8-4917-A352-4A7D12051535', '4607022893045', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9829953C-865E-43A1-8B00-6E06535CB9AA', 'BEFBA7B4-CE4E-4A34-BC69-DE2F4E959E71', '4607022893090', '   1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFCFD96C-4A4A-49FC-AD40-03FD7E6879CF', 'EC9DBDE0-FBAA-4EE2-B05F-3C5965DD703F', '4607022895797', '   - 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7003A888-152A-448E-A366-19209935273D', '8E732587-FE22-420A-9ED8-B9FA336FF1F9', '4607022895834', ' // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D87D6DF-BA5A-4650-868B-3048880000CE', '852D6A8A-48E6-4B26-A3E3-74CADF4B6D22', '4607022895865', '   1,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D89F67E-7C7F-4A76-BB0D-1AEF4962D1E1', 'FD414159-BF79-4B74-B45D-B011B5D907D4', '4607022898385', '  //-/ 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AB347DE-3DCC-4239-BA1B-99E394665EC9', 'C2FD8C0A-943A-449E-9869-FE1D671DF9A6', '4607022930061', ' 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('032C6E49-972A-4282-B531-33772C68895D', '3FAB23F9-99BD-4D8C-9081-751C8EC7F1F3', '4607023601069', '   450  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E37F7957-271D-443A-9AD5-C8CC9F80B4B3', '8579D005-80D9-4DFC-BE33-7569139E491E', '4607023601076', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C863AE7D-54DF-4C28-8689-B2726C454D9B', 'C6DA9D8F-B198-4ED1-B2C8-C3D53717883B', '4607023601090', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93037D09-FE45-40BC-8031-711525725800', '68952C21-761B-4072-9151-044195741ADF', '4607023601106', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('471B35EE-EB5D-41F6-8F61-E771747D57C6', '8F3D848D-846F-4158-8D3C-C1BA7358C026', '4607023601113', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47B1697C-4BDA-4188-949A-212E04BDD6F2', 'A5361436-5597-4370-B61E-1502AF94B59E', '4607023601137', '  ++  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0611ABF7-6BC1-4A38-A16E-2F65A193249C', '949463C7-2156-4C99-BA69-E3548FF0322A', '4607024580011', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E24964F0-E63D-481E-A11D-80AD24916EB8', 'DFEA33DB-4106-4D6C-84F9-9D0F9B8C1966', '4607024580127', ' -6--  6  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1934BCE7-2664-4130-BBB3-B8634823C0C8', 'E37EC06E-9833-4BAE-80F5-280F53F3DCA8', '4607024580158', '   -- 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A249908-D35E-4DB3-AB67-45334F45F0D7', 'C91FCF54-94CF-4B9D-8232-A18C54764C5D', '4607024580196', '     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('672DB3E6-310D-4AA4-AB67-E665D12C3304', '774469DA-1702-4018-A495-435DAD2D9961', '4607024580257', '   bee sure-s', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BAE734D-5072-4E70-95E7-221084859B2F', '774469DA-1702-4018-A495-435DAD2D9961', '4607024580264', '   bee sure-s', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFFC3761-1152-4D84-B170-F1E48233D662', '7E9F9BA6-DF4C-4154-8D98-35AE1226B48A', '4607024580332', ' -3-- //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F873F4DF-29FE-4578-A0C9-5C78319049F2', 'EFBDD246-E647-4DB8-AFD5-1601A0429698', '4607024580356', '   -5--', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE658329-54D7-485E-866B-AB21B036E29D', '774469DA-1702-4018-A495-435DAD2D9961', '4607024580493', '   bee sure-s', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C45925D5-A55E-42FC-99BD-C55CDA5E87B6', 'E7A552B2-CA5A-4519-B694-E3AAC648297F', '4607024942345', ' 250 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1E45A99-2E27-48CE-96D6-C05EDFCF8105', '0E338B1A-3BC4-4F2C-8EC1-F9A4D6BE5052', '4607024942482', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2E467D6-1B5D-439C-92EA-6D11082B1DAF', '1BD03792-6D07-4BD5-841A-40BF94903B34', '4607024944011', ' 125 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('295A50F5-7E81-4544-8DC4-52C54CE023F9', '40C5BFC4-E9F9-4C71-AFE6-DA8972C22713', '4607024944318', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D113D17-A8DD-4261-BF4F-6051CBC9594A', 'ED2A9B22-36C6-4406-A700-F7D60430533C', '4607024944363', ' 10  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7E27B32-940A-4A09-886E-A45F418B7BB3', '7F41EAE8-46DA-4F93-A3AB-B7380921E1E1', '4607024944677', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3141F6A3-D435-41BE-A4DC-EDADCB068A22', 'A5521000-4A58-437A-8DE7-AFA7AA9A209B', '4607024944691', ' 125  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADF9CAEE-FADF-410E-8625-B9FA6DAC3C4C', 'EFA4D3D1-8AFD-46EA-B66B-FAAC88CA7901', '4607024944738', ' 125  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EECE33EB-9B06-42AF-B4D3-17E18ADDC38A', '83837F08-3FC5-450C-A89D-F40F9796BF53', '4607024944769', ' 0,001n30 // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('948A1876-27B7-4B4E-8D70-0625BB8B7FF1', 'ED7C1B08-5562-4C31-91AF-BE6B2EE56AF6', '4607024944783', ' 0,0005  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54AD3A0F-9829-470A-9AEA-7CDF9EBCB789', '41653097-6B98-41B0-9513-9981FF979D9E', '4607024944790', ' 0,5  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0BF50FE-678E-434D-824D-E49A60088800', 'AF59A325-0553-422F-A07F-1007BC0A242A', '4607024944806', ' 0,2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDF40128-24C3-4EC3-A0B2-B2C360E179B9', 'FABA311A-4874-4379-9ACD-CD0A8DC982A6', '4607024944837', ' 0,2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71121183-BC83-4B7D-A8A5-F0569BBB8E51', 'C8C3AB62-0E4E-40E9-BAE6-EA6B1DA1C76A', '4607024944868', '  0,25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A75E8273-CDEE-447E-A563-FCE8CF4B1507', 'D7EDD075-52A6-471F-A5C7-D6AA7117A7ED', '4607024970515', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B4A3D25-3628-4BF9-AA66-8D273CD4F1BF', '2CAF73E2-585B-41E1-B512-0F8A8672F760', '4607024970768', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7FD9F78-EF93-465F-A936-B1B771E8B705', 'CB6C2EE5-CE4D-406A-8C4D-4EA5350FEAAA', '4607025200116', ' 350  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1C64AF3-94E4-44CE-9100-E9D89DD660D1', '91CE9C6B-3686-439C-B0E6-26B6FC66300D', '4607025200192', ' 0,35  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADC550CB-0859-428C-989B-F2F0F947EDBF', '0C33C14A-9F11-4704-B6E5-A77DE41FF137', '4607025200475', ' 0,35  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B733CEA2-04E5-4E82-96C3-2210AFC1F774', 'D7D45DE9-78D0-4D4C-B257-626AC6309EEB', '4607025201311', '  300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF8C6E74-A989-4CEE-A7C0-C8981E1F4B9C', 'FF989D66-B24C-498F-91D0-0B78425A5B98', '4607025840596', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B50DFEBE-D5E4-48DD-81C3-7EDC57B0214E', '0C705BDA-BDBF-4EAC-904C-96E0C5565218', '4607025840633', ' .   / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E98DFCF-0B06-49BF-AF41-220063100064', '867B84E9-D363-4E5C-A500-1D2ACB76DC9B', '4607025840640', ' . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('667E57C8-4EB3-4963-ABE6-E28C2D54FBEF', '6C3D86E5-EBFA-4453-AA78-4C9A402C9488', '4607025841142', ' /    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CA6D77D-E0F5-489D-B341-E9D905251461', 'BB1CC96B-C435-4A9B-823F-3D343C5CB808', '4607025842668', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEA141FF-AF7B-4468-A554-68A2B56D3E0E', '68A7187F-EA0A-4F4B-9952-484E7C8C7A05', '4607025843764', '    // 2/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBB2C922-6B0E-417A-A924-E50AF9DB4025', 'B9DC1944-8677-4FEA-86A8-FB46F3CD9DF8', '4607026640034', ' 0,65  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14F28571-0087-46AB-A490-348D4D40E93E', 'FF2EBAED-FC0A-43C3-8628-D7CB7885A5E3', '4607026640218', ' 0,65  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8E5B00B-95C7-4D81-94D7-969D8DE08F52', '61A7B4DD-80B0-41B7-9A6B-6B1A455D1C89', '4607026736119', ' // /  /611/  1 /60-80/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C43E3DA3-1965-4152-87C1-EE6FCF6B604E', 'A0EF8590-C9B6-43BE-A5D1-F45469CA49D0', '4607027210014', '   . 0-6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F277CC3-024A-4A43-A8E1-56BEB04A29C4', '456E48C9-9501-4DEB-BA33-510EFF76077F', '4607027210045', '11111      . 6-12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11D62625-ECDF-4F92-9E6D-9AE840CEEA42', 'EBD77376-D530-4CB4-AF63-0C33780BF796', '4607027210052', '11112      . 6-12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BB73D80-0B57-420B-B7C1-C61EF4E7ABCD', '01C42F1D-DC39-45C6-A635-14F20BB65139', '4607027210076', '     . 0-611201', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD5360B4-CE3E-40F5-9163-E8A442614FD3', '4445B7BF-1D8B-40CF-A9A4-C4F4CC66A46B', '4607027210106', '11211      . 6-12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D825BB1B-E463-45C2-8785-75D2A91A7CE7', '961D8B3C-256F-48E6-B2B8-D3E51A871404', '4607027210113', '   . 6-12 11212', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4294D8C4-9376-4AF6-92DA-3E350C878D08', '943A33A9-78FD-477E-89A4-789A0FC36187', '4607027210137', '     0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE5744B3-5E16-443A-8975-30D9AAA8CE5C', '8165A50C-B34B-474B-804C-4B9EFFBC7547', '4607027210182', '     .. 0-6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46742680-3107-4ABF-8E40-73A11B714BAE', '3A36A84B-6113-4229-B2B7-E283F9635669', '4607027210212', '   .. 6-12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AC09AB9-4439-4729-BC71-12E62421AB44', '9C6EC4F0-5DB8-4D65-97A0-7AB271B628D2', '4607027210229', '  - / / 0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B739C1D-3A2B-4338-8B46-F3A9276D2439', 'B0163F20-B2D3-45D8-BB9B-F7AF8576FBE2', '4607027210236', '-  12-18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE788DFC-B727-4B99-88E6-E90AF23A2A4E', '750CA7E6-8533-41A1-903B-69865EB3EB4B', '4607027210243', '11610   -  /,/ 6-12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC3C0B3E-AB89-486A-B660-7E82804EDCBA', 'D63AB1A6-6F95-4F44-979E-32C9F2C6C089', '4607027210267', '-   /,./ 0-6  11620', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14ADAEAE-9826-46BD-B012-7D0B17A6B678', '02ED683C-3DEB-4138-ADE0-779C3366D79C', '4607027210274', ' /,./ 6-12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F441C6D9-70AA-4993-868F-2E14A94BEF57', '104AD88F-14A6-4665-B9AA-20E1CAC2EA14', '4607027210304', '-  /,./ 0-6  11820', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26489936-E3A0-4FB5-93E0-3053114C06C1', 'ACBE0148-EED2-4C63-9E11-6325474A15F1', '4607027210311', '-  /,./ 6-12  11821', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE55A422-9FF7-4915-9591-531A6C81F005', '41A7785E-9EC1-4630-A552-48FC6AB19F79', '4607027210328', '-   /,/ 0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2FF9943-D37A-405F-900D-D29C9020781A', 'B8212BDD-07F5-4140-A7C3-99922AE2B903', '4607027210335', '-    6-12  (11831)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A967C016-2D91-4B9B-AAB0-6B40017D2868', '8B2C90C2-CA5B-40F9-A4E5-BF9CEA53140F', '4607027210342', '-    0-6 (11850)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B205FC8A-9773-4CE2-A273-9ACE02F2ECF1', '7823F2BA-D7A0-40C5-A5E2-3F1E812092EA', '4607027210359', '      6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C5F9FBF-1C5C-4598-8E3A-6671AFB24ED0', '7DFD1ABC-288E-4CDF-8E55-FF9653AB5645', '4607027210366', '11320   -  /,./ 0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F32C71A6-E7F0-4CB5-B945-2CC83680D97F', 'D0C832D7-B442-49D3-BB29-3EE88E799494', '4607027210397', '11351   -  /,./ 6-12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BBCC6BD-B8F1-47E8-8618-F410A7C1A60E', '02156D72-5465-462A-BEB1-13278DD23101', '4607027210403', '  -  /,./ 0-6 /11220/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EC3FEF8-83A7-4C3A-A653-2EE2A3AD7DEC', '550CBE1F-AA92-4101-A58E-80CA467BA5CC', '4607027210465', '      12+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D644387-B687-403D-A4A4-8D6DD456AB3F', '8AF4ABCB-11AD-46F4-A610-1D029789BCC2', '4607027210496', '      6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('296A1962-FA71-4BE9-BF5B-6A7429AACB69', 'CFC2FB42-0331-409F-BFC7-12B9EFC2D4B7', '4607027210502', '-    0-6  (11050)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4159C2AF-1711-406D-B319-78C34BADC1F5', '1787D316-6FD9-4DE3-B3B0-616752986C7A', '4607027210526', '-   /,./ 0-6  10920', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72BE4D08-AA3C-4513-A852-CBD10B258687', '0336DAC3-7116-4CB7-B275-140BBB13BFC7', '4607027210533', '-    /,./ 6-12  10921', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99C58840-B259-4C20-9C59-171D0BEB2067', '83FAEF59-702D-4A6E-9B68-43E9D54BD523', '4607027210540', '  -  12-18 /10922/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91C92D1D-A2C4-430A-B5B1-A93E2ACF6668', '9E016B97-2C60-4ECA-B12E-CC4E2F541D59', '4607027210571', '      0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('816C25F5-D80E-4DF0-862D-5108AB22E9E1', 'F3F697EC-E17C-4CE2-A161-53979E436298', '4607027210588', '      6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('324949EC-DD9A-420D-85D1-9DF3944563BA', '2D5A674B-5D0F-4060-9396-38E60EBE1C82', '4607027210595', '  -  /,./ 0-6 /10850/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F0FA6E8-CA70-4BC7-9BFB-0739F0B84A3D', '347FB952-A3B7-40CD-AB55-179B0969B0E7', '4607027210618', '10720   -  /,./ 0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16A55865-0239-4CC1-AEF5-A2F303441473', 'CA4B2869-01DC-4B33-8CD2-1DC870BAD740', '4607027210625', '-   /,./ 6-12  10721', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B1AE2E0-6B19-4322-AA73-54079EEBF03E', 'AE2BD99F-2738-4A28-A6E3-DB93EEECC816', '4607027210649', '  -  /,./ 6-12 /10751/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78216FC0-04C3-44D7-B50E-BDE105DA186D', 'E5744E8E-994A-4929-869A-283F5B0D3403', '4607027210656', '12010   -    /,/ 0-6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2419EAAE-7192-4737-890F-9FD211633D9A', '56C30DF2-8608-4A79-AFA7-B2D173FBCA37', '4607027210885', '  .. / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12607A91-0957-443A-A8A9-860D7A253298', 'DBA481D6-99A7-4E8E-BC11-24EDC22A89DC', '4607027210892', '    .. / 240 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25258B45-D6F6-4E7D-A9FA-79A54A9DEFFA', '1B0CBED9-9ACF-4536-BFE9-F809A6E3AB06', '4607027210915', '   / 275 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A3C939B-AFDE-41F8-954C-2DAFF6768DBA', '1455F6D6-0FE1-48DA-AF53-7ADB782BFF53', '4607027211233', '-  /,/ 21621', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DF07E11-6D8F-42EA-AF11-92B7110003DC', '826FA1A8-9770-4FF5-A426-4448710369AA', '4607027211295', '  -   6-12/21831/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A07E68A-82A3-4128-BD44-C4299DFEE041', 'FC11F2CA-7949-4B3F-8368-E8D074DCEA0C', '4607027211462', '      0+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBFF9321-3B6B-47CF-BC8A-90D881BFAF25', 'EDB9E931-D6C3-4FD2-8114-3A3B9451801F', '4607027211479', '      6+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A22668B-D4FB-4F18-AD74-DF34C6623141', '351A422B-A618-4720-892E-69D558B6418D', '4607027211530', '  -  /,./ 0-6 ./20820/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBD14E99-8E85-4819-8BDF-2A09803EC13C', '8C2C1075-E7D6-4602-9975-30C6D165BBC3', '4607027211561', '  -  /../ 6-12/20851/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD5B71D8-D56C-470F-83FB-D2F613418AD2', '4F2DE8F7-851B-40F9-8EED-72F38BD46674', '4607027212544', '        0-12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E6CCECB-DD10-4EB4-A93A-0488075C855E', '105C5DFB-96E2-4D29-AD72-255150C37D5A', '4607027213480', '       0-12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FE0F313-54A2-496F-8F89-2AC8B7C725BA', '6F71EC86-244A-4782-8FFC-EFA06335F328', '4607027213497', '      / 0-12 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('909F428D-5D7C-4047-9032-C16D06DF0B26', '049DA6D8-ACF1-4E74-A3CA-EE6AD443B315', '4607027213565', '11612   -  /,/ 18+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E95FEBC-E880-416D-8565-A7E71EA9ED79', '01F41D14-0425-4133-8D42-E5EF3EE6CF3F', '4607027213589', '     . 18+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC1398CE-348E-4BEE-BFC3-FB63B070C561', '52A00FB5-6867-4022-B6FE-F44FCB3DA240', '4607027215118', '      /./1321/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26F87163-71BE-4345-8A87-BE197E0325E7', 'F20BD2F0-EFE1-4086-B88F-0DBD00B381BC', '4607027215194', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3453973D-0F47-44B4-B7E0-661A25ADDC50', 'F7FE4C7E-5089-4C73-903B-A486C0824455', '4607027215491', '- / 1624/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11D00D57-D00F-48D6-8B2C-DD29B689B449', '349CB9D3-7779-4DF1-B728-1BC68DCCE7D2', '4607027215606', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C7EFE2E-8E5D-4C19-B5F5-A4CC75E0A7EE', '22423FB4-F161-4253-88D1-A53F43945E67', '4607027215620', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42C4009F-3ED6-4771-8384-1C1766B08C7D', 'A0850D44-E008-4B74-9912-8B7C769D4458', '4607027215798', '  3  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41E8ADC7-25D3-4432-846F-C2BE771E475A', 'CFA96888-8ED4-41FC-A71B-496DBD84D6E0', '4607027216511', '  /    //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A22BA951-540D-47B3-9D24-CF9828A06C89', '44ADC0BB-C3E0-411E-BC69-0083417B1ED6', '4607027216610', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A67F1A52-5C4D-4D0E-BB24-2E5684C57614', '2123A757-AA99-403D-AC65-27A360AD20B6', '4607027216757', '      ./2262/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8AA16DB-4338-4F16-B025-D2FD7D8BF8E6', '22FC54C6-2B0E-40C9-98C5-07BDAB54B66C', '4607027216856', '  / / 4 .  // 225/1974', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A128A363-8302-4198-A421-32CEC62E70B3', 'D9F50E6F-E68A-4746-95F8-817829F72931', '4607027217488', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BF498CF-0F37-49CD-B897-221581F93200', '552972EF-7CEE-4731-A1F0-B22EE08BD9E1', '4607027217495', '  /1329/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA89B6F3-FA19-4751-A94A-B6BA0A9559AE', '68290419-0FBA-42B9-B2F2-E37825BCEDF5', '4607027217549', '     . //1310', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A39DA4F5-BA75-45BF-AB0E-B6DE3C3F8187', '33524168-1820-4F49-91E0-65BA2903B722', '4607027217556', '    . s //1309', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3313AED-DE20-41A4-A92F-4BC901704A66', '81302DCA-0F5E-4105-9E87-04781708D27C', '4607027217587', '  /+.+.-./ 2816', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE9B8214-2073-421D-A662-EE1E2FBBAE24', 'EFB5BFF5-07C1-4241-B958-BF0832ABD7EB', '4607027217853', '  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02DEF1D0-671D-447F-8487-83A33F539C89', '3B06F9BD-BA1B-4E29-8B82-E98174233A1B', '4607027217952', '    , , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C714CA6A-68D2-478B-91A2-500E297566F9', '71ED71E3-D3CC-4757-ADBE-BB7A6F5F21A9', '4607027218096', '    4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB4DAB77-1BE9-4537-B202-EDBFE530FE97', 'A9AFACD2-E34B-4678-A4CB-0C0288CE7DD3', '4607027218270', '    0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E46E448A-4807-4DBB-96DB-8BEB647B0319', '0DD3A423-5C9E-4483-B28E-9A96E98A1452', '4607027218522', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4B4B553-FD3F-4054-BA0B-84330B8BF139', 'C5E52495-AEE5-48C7-A132-E64310DC4C38', '4607027218775', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71DA24BB-6921-4F0F-96DD-D11F4D1231E2', 'BE9A5CA6-8326-440A-9481-92F917D31312', '4607027218799', '   ..   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('909E0332-4845-4E02-B728-991E1BB97062', '07E131B9-3555-4ED4-994A-C823CB7F102A', '4607027219000', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A98C0B2B-9FDF-4387-96ED-C6105F90E694', 'FB26CAEA-A2D1-4AAB-9763-4F6C12BC98C9', '4607027219208', '       //1303', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('416D951F-12B0-4DBC-B11A-00FEDB6274DE', 'A3C7C1DE-CC4D-45F1-AEF0-7AC4161782C9', '4607027219246', '    .c .. /./1319/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E1091B2-0889-44DB-A5E9-C9D661A6AE2E', '2382353C-A16A-4A9E-A15B-C6EB48858C25', '4607027219291', '   . l 0-6 . // 1209', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B36C278-ABC4-4968-AF54-D433BFA3087A', '14188D5A-24F9-4CCC-AEA8-5D5CDD8098F7', '4607027219314', '    . s 0-3. //1207/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E25330C-6EC1-42DB-9BC7-6521136A355C', '751C170E-7D5E-46A2-BE1F-DCED506A1FF8', '4607027219345', '    .s /./1204', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D4E3137-1B72-4CCE-B0A7-CB34B1B9602E', '9C4F3A56-26FA-4986-B4D8-868BE71C6550', '4607027219475', '2161     230*220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C471E60-B03F-42CD-BBAD-CC428B506901', '10F84554-BAB8-4D31-A89E-A94567DCD117', '4607027219499', '    119*160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('198898DD-B7ED-43F8-80AF-8AB66CE493F8', '3E77B218-DAE1-456A-9416-43DACE577DE2', '4607027219550', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('753E1C66-D8D1-4354-B567-CB0F4154F629', '16385E7E-B514-4162-A634-0A7295211DC7', '4607027219574', '  /.+++.+/ 2818', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8B8708F-0E93-4231-AD9C-C41856020696', '568C55B4-735B-48C0-8EC5-3FE0AFDE551F', '4607027219604', '   ..     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1B1EAAE-7696-4A1B-9C5C-738FF65C234F', 'F0D02BED-2CD7-4E8D-855D-E21EC88242F9', '4607027219611', '   ..     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D6C122A-DE71-420C-98CE-C9393A57DA9F', '159C4554-37C5-4FDB-9D91-C14DB080F957', '4607027219741', '     ..  6-12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E140DC26-4023-4C31-89D3-7C68374D4B85', 'A5E25E6B-4AE4-482D-ABCE-42E32E646D16', '4607027219765', '     ..  3-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B12CBDC0-9FCB-4312-BCB9-5858077E33CF', '2B850BA0-F13D-4D31-8F85-505C9201C51B', '4607027219970', '  130/1102/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A18576E8-4A7F-4C1F-8F37-CD74F5C61949', '0E2CBF16-C103-40BD-BEAC-CD358F4B1084', '4607027410056', '    / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78A3F095-42F7-4EF8-B373-1BFA93B6CE56', '5EADFDBE-2CB4-4A0E-B644-7F8D69FCC99A', '4607027410094', '   1010  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92E1ABB5-A475-4468-9AD7-B63DA2707894', '303E9CDF-877E-45F3-ACA9-ED12919A0026', '4607027760113', ' 0,1 /2+1/  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C92155F5-025B-42CF-ABD5-31CE9394DC47', 'BC5CF39F-6951-4B8F-8FB3-852CC62F4DBF', '4607027760120', ' 200  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4CF260D-CDAD-4875-9C88-6A74DE8CFCAA', 'B956617A-26F7-4F22-BE6E-3C621F3AF710', '4607027760427', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('643D460B-8A79-4F28-9453-54A0C4C292C0', 'A1E08493-23A3-478E-993B-F71BB8383FE0', '4607027760434', '   20 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3AB4F4A-3D6C-4292-8B24-A59D262461EC', '147F00D5-F40D-4314-BEB3-A8DA4396BA26', '4607027760458', '  2,5  /-   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('164662FF-BEA9-42E2-97CE-54CC7EDD117E', 'B79EBF40-D721-43C6-8EC9-C9F0B119AA7C', '4607027760465', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8A0ECD2-3A4E-4A06-81B4-F01024558405', 'E5320E7F-36AF-4F22-BB19-ECF0F7513032', '4607027760595', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6FE3AE3-D54A-4342-B1F6-F2C4E2F2F2C7', 'C75645A4-CEBF-4B43-BB67-D93652D05D88', '4607027760694', ' 50  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6E7F157-A156-4486-A06D-73E176567673', 'D7BA583E-DF3D-4B7B-9B51-CE623923A007', '4607027761332', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03907BBB-0853-4B2D-837A-63E8FE3335C3', 'E8DF49C0-C7B9-4BE7-AB54-384E84FC8CF9', '4607027761363', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87D3B458-BD4D-4857-9A46-F98A07EAF10C', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '4607027761387', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4DA88A3-D47B-46C8-B030-BED8A9D79249', 'C96BAD46-7897-4ACF-A08A-A68C74AE38A4', '4607027761424', '  5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB57092F-F3A8-4852-947F-54201706A9ED', 'E3E4FE67-8FAF-4031-B48F-41C974A71C18', '4607027761455', ' 0,25  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B0E34BB-9CA4-4C26-A1ED-C60A35C4E044', 'A8DACF8E-4A0F-4CA9-98CA-12D9E76F57E8', '4607027761882', ' 0,01+0,1585  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FD99FDC-23AC-4D5A-A126-A09C0D267BE8', 'A6C92833-CA6D-46AE-B08D-876E2C622B8C', '4607027761899', ' 15  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06C6D3D1-37A5-48C2-BF5C-35CC900993FC', 'EEF7BD5B-4627-49EE-92D6-5E21218A1A01', '4607027761905', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE99D482-344A-472F-A714-EE3DA0EB211D', '8B14B0DC-A0AA-4FBD-BA71-97859E51AA3E', '4607027762148', '  100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('727A1DB9-53E9-4C06-B4BD-65151820026B', '9A2F1AD0-3B0D-47F9-9EFF-CF5775906CC0', '4607027762179', ' 1,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('128AA0AA-E687-4D51-8739-C8CA6FB859D3', 'AAD0356F-F10B-4F36-B29A-E91F52510CDB', '4607027762193', ' 0,005  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0268DBDE-AACD-45B0-9A4C-D96E1895368C', 'B3B40E3C-1C57-436E-8F56-A6A319E629AB', '4607027762254', ' 200  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1B5B2C4-4F3D-4789-A096-5952BABF7629', '476C2448-64DE-4B1B-8583-277759495449', '4607027762292', ' 0,025  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24BAEFD9-DA13-482F-9A23-3407F122D781', '50646B34-CD1C-49D8-9B64-DDBD1B01C6B3', '4607027762315', ' 250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AC6BFC4-C176-43F0-BA93-D625B9E0D5E6', 'BA378D1D-1B75-4E33-B502-70D027CFB921', '4607027762322', ' 2,5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('688D86A7-04AA-4D12-961A-F9DA26C5B2BF', 'C169BD25-E074-4E93-B73F-4EA1303DB8C5', '4607027762414', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90A6C1F6-C3BC-44D6-9752-C6D3858E87B5', 'AFD04618-C3D5-4A36-A87F-957981467D02', '4607027762421', ' 15  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4C3E3C3-91EA-49A4-8F9B-6C037599E07E', 'FE0999A5-2DA3-4AF0-8B4C-7EFBCAEC1968', '4607027762438', ' 12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62B300A2-040B-4853-9C7E-281FA78AFC7F', 'F0F0334A-5DC4-4F5F-8D40-611CA809948B', '4607027762452', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBF843CA-B67F-4983-AAA4-E5BD5D1F519C', 'E3509CA9-FFAA-4666-92E4-23E66A19C967', '4607027762506', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3395CFD0-79B9-4C6A-A857-9EC93BAFB818', 'E5A9E034-AE70-4D4C-8081-BA4AD17306A4', '4607027762520', '  1,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C3BFF5A-653A-43CA-898B-660448FB61FC', 'E6ADB4FE-F7CE-4BCC-91EF-EDA0E6A6FABA', '4607027762568', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B424BA3F-22FF-428A-801E-CF979475F6C8', 'F0F8D09F-5EF6-42C8-A5E7-5052AC0C8B15', '4607027762582', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66C8888A-FED6-47BE-A4B1-53534841F344', 'CD2B2D01-0763-4AC7-A5BA-6DAB20C74B56', '4607027762612', ' 2,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A45F802-1A7B-41B2-94D8-382474049BCC', 'CA315A23-F41A-4359-AF05-BF1AFCC02DC2', '4607027762629', ' 2,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCCA3155-1039-46C2-9797-3886F428531A', 'B5A8E244-1518-4E60-8295-618522418B79', '4607027762728', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('961DA571-CFB4-4F68-9321-A0292D63B970', 'F8B7485F-EEF4-4B1C-B47A-8EADB97857C3', '4607027762735', ' 500  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95D7ADED-53DD-4DB7-90C0-9E6FBBAC4AEC', '75D394F5-E00A-44DD-A673-434C6D84D535', '4607027762865', ' 10  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA03DF9E-B2FD-4C43-898E-0AAD2C46FA88', '85DAC478-AA2B-4B6E-AF82-96506EDF1C46', '4607027762872', ' 15  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15C63B77-DCB0-4DA9-A2C7-310AE8A47813', 'F7EA6D1F-8751-4C10-8C8A-EB82A3731D22', '4607027762896', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81216376-DA21-49A4-9735-01C8665D4AE0', 'B8B2B5FF-AB77-4AF8-9AC3-E4A4B380C13C', '4607027762971', ' 0,0025 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08A6B267-A460-4FEB-8ED4-77B2EB6E888E', 'BE8D3326-FC69-45C3-922E-27A1E5A955B1', '4607027763077', ' 0,0025+0,00625 30+30  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DCB6F55-B06F-4DF0-AE80-4C9F6D302591', '30FFFF85-8ADA-40FD-952C-494824983AE2', '4607027763121', ' 2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22D9F268-99E9-4915-9E4C-269CF9F2F1FE', 'DAFF09AA-D4A4-42E0-A713-954556DEB8F4', '4607027763145', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68ED0035-B472-4D74-864C-B4AC020F0905', 'CE8E476D-5768-4EF2-ADE4-A2EA56764152', '4607027763183', ' / 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('774AE8DA-A5C6-4491-A738-3436EF187DD1', 'DAB4FC83-73B0-41AA-8677-C193D44194F1', '4607027763190', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E2BD73F-1E9C-44FF-9C04-EF499CE331EA', 'EF1A9ADD-E06D-4DFF-9A64-5F6D19C4BBC4', '4607027763213', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D860618-21CD-42A9-A55C-C7817EACA493', '9EF4DD36-015F-48B1-AB8E-95EE7983DD75', '4607027763220', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F55D1BF-9EBF-4194-BB37-986E9315B799', 'EAABE21B-C9EB-4C05-AC33-1C4555D07091', '4607027763299', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33B08D69-B782-4931-BC5C-ED7F1630656C', '4F7A93D4-3DFD-42AF-B2BA-CF9FFC7AFC96', '4607027763329', ' 0,016 30+30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58D5371F-727B-4B8A-8241-92B5E74D6931', '1C26E46C-EE9C-4224-8551-69C8A7A469D9', '4607027763343', '  0,04  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83C28D6B-FE11-4CE8-A01D-65AB3F13A56C', '895958B4-7E44-4294-B0D3-E7C94BAAF4D3', '4607027763640', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD6FBCFA-DB2E-4CD6-8090-9CBE8F9285EB', 'C2FE7594-46F6-4C24-A5E1-057F9DE7EE8A', '4607027763701', ' 250  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C50C0F2-BE21-452F-A75A-989647BBC11C', '572B26A8-32FB-4679-9C08-D6A13F2887C6', '4607027763824', '  30  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2D8192B-0149-4B3C-B56A-4A76E20DCDED', 'D8258614-BEC2-43E9-B3E6-45F8C2430578', '4607027763831', '  14  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C28D7F2-3A07-49FB-AEF4-0316B67B985F', 'DC071810-90D4-4B42-AC9A-F97D9D7725AE', '4607027764098', ' 150  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04C58791-30BF-46AA-B79C-8F0B2AD3E366', 'EB3D9BA0-7FAC-4D4D-9883-7F2D457117C5', '4607027764104', ' 12,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E5F0BDC-7F53-4A9D-8F42-D91136C4772A', 'E1F6F4BF-CB11-4AAF-ABA5-D7916E6D1600', '4607027764111', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D6EC6EF-F25A-4154-9D1C-34A31A7C270F', 'DBA9B18A-9654-488C-94EE-0F212971264A', '4607027764128', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B88534C2-525F-4044-863F-CA369FAD948D', 'A955C8FB-700A-482A-8C5F-B1995A6B8015', '4607027764173', ' 0,002 /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FF534EC-6DF4-4EE6-BA70-70F5CC394C32', 'A85FE826-7FD8-4397-BF95-D4E36C1D80D7', '4607027764197', ' 0,004  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59461A23-AE4B-4EA1-B071-0926312D917A', '7642F6E6-0C38-46BB-BFD3-5BF36379E3D0', '4607027764203', '  10+25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE7411CD-7D00-4462-A3E5-3CA1838D943F', '0E3194A5-B8E5-4592-8154-66EA3CC8BD3F', '4607027764210', '  10+12,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56062C2C-CD7C-4AD2-91E8-1424A964CAE3', '1F5B63B2-46AA-4E96-8B51-4E21FD71F8BF', '4607027764227', '  20 12,5+2020 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C680BDE-F4B4-4567-87B9-40113828719C', '6CA90E08-4D70-4F7B-9BCD-3DCF23C8ED9F', '4607027764241', ' 20  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61BD003C-2DB8-4248-8AF7-2219628DB4C8', 'EAC294D6-0851-4D08-B150-8D9CB6347420', '4607027764272', ' 40 /.  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77FD86BE-BF3D-453A-963E-0482C5E3DC70', 'E5352466-DD56-4B04-8BD1-E5CA68E27C79', '4607027764296', ' 250  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC2274E7-0794-40C5-9311-70BF283747B9', 'AA640547-CD01-4FD2-A9D3-983E8D62F89F', '4607027764319', '  35 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E13D33D9-B336-47CE-B426-48C1FF37755F', '94F601F1-BEB7-460B-9962-357854DEB33B', '4607027764326', ' 25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F71D3460-DF26-44DA-941A-D709C1B2393C', 'CDF0A62F-800D-4D61-83B8-9B4C4D5AEEE8', '4607027764333', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('079D1EE2-4F62-49D3-AB08-9A45D9CB3F34', 'A95BD90D-CE91-40B7-8487-AC6DCE486BB1', '4607027764340', ' 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('422F257C-7BBE-406B-8003-F76335F9F25C', '79240A16-E045-4AA5-BF94-E6C29D72593A', '4607027764364', ' 80  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBA4D186-A6D4-4D08-A89E-A5D5CE8F9B82', 'DFA51B68-FA5C-42B5-8906-68ABC3A0C9A4', '4607027764371', ' 160  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A347A85A-9F63-439F-A381-187B39EE01EB', 'A060CD24-11A5-48E8-885C-6DB436A4654D', '4607027764388', ' 24  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E29F7BD-0591-4FFE-B54A-55EFB51516CD', 'D936DE22-75D1-4759-8173-DAF9186E538F', '4607027764395', ' 24  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFECE2C0-67FC-4BB1-967C-92118DC8B7EB', 'C1554E93-F407-46EA-8C78-D77FC7000A24', '4607027764401', ' 24  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E213541-6CC0-49C9-9746-4D3D772F1ED9', 'C8335160-84DD-4AF2-A19B-ACFAB0041CA5', '4607027764449', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E02D2BA-47C5-4CBA-9FDB-B8B58CD2F51E', 'FBCD1B38-6F47-4F68-AD5E-EE276BD7FFAA', '4607027764456', ' 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99EA8282-0E69-41DE-9DF8-602E401747F2', 'D7D9E719-DA5B-479B-8D44-FCA5A6DA1627', '4607027764562', ' 4  30 (1+1)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3366961B-50C1-4DD0-A758-CD339EDC2E9B', 'C712F775-BA9A-4A9F-9E92-EA7291F5E206', '4607027764586', ' 0,025 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD12DE87-4A1E-43EF-A0C8-2ABE0347FF8A', 'D7B14C05-A71F-452E-901D-46452B4FF067', '4607027764609', ' 5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D469C1A9-9A0A-4859-8C11-63AE028D965F', 'B9DBD6DD-A0D6-40C4-B60B-F953B1DFE358', '4607027764616', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37A804EB-895B-4119-93E5-FD9B999E27D3', '56B85517-9484-4526-91CF-DF86C418BD3A', '4607027764630', ' 0,0025+0,00625  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('556D52BF-57C8-4AA0-96D3-725F3FA15708', 'F1480B17-835B-400F-B472-2176BA4E456F', '4607027764678', ' 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCDE1D5A-2E98-457C-BC3E-64997E0B7A11', '303E9CDF-877E-45F3-ACA9-ED12919A0026', '4607027764708', ' 0,1 /2+1/  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D960C6A9-A639-4B84-A265-5CF0F1E4BE6F', 'F8AD7638-002F-4713-A087-68B8A29F2232', '4607027764715', ' 250 /2+1/  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0A49D8E-6FAB-47B2-AC43-E76337FAD484', 'ADF0F1F8-F10D-4FE4-8C5F-939FC127E323', '4607027764722', ' 5  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18A3D9D3-5C9F-4C85-9B94-42534B5E8814', '906B5ABA-5C25-44B1-82C4-C8F31C7B4E40', '4607027764739', ' 10  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8755BCF1-2828-4CA2-9A7D-487199F1A22C', '844F2B95-1AF9-46C4-B8A4-8EB03381EA7C', '4607027764760', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CD7CDC7-D388-458F-AE1F-CF5203479F84', 'FD012C79-DC6B-4E92-8420-9C30362F3452', '4607027764814', ' 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCBE6559-2440-486D-863D-263C185BA8B9', 'BE74047A-48F2-452D-84DA-E5F4DCBC278A', '4607027764968', ' 0,02 //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C1CD647-6F85-4FAA-BD25-E39DA2F439F7', 'F6E5A801-6F2F-4553-A51F-D5BB78AB0154', '4607027765019', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('059DF7A9-1E1E-4463-A9BC-DF379A421C09', '14D4A2BD-BECD-4856-89BA-F55A642C1BB0', '4607027765026', '  500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11291C23-71FD-4252-8D8E-9EBE54AFB687', 'E6DA0F03-FB0D-4784-846B-5027FE3366C2', '4607027765057', ' 5%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('847DA08D-9BCC-4326-93A7-80895588F2DD', 'DB3DDAEA-50BD-40B2-8D81-B547DEFF707D', '4607027765095', ' 8  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('147C78D0-110A-41E8-9650-D14BAC128846', 'FFFD72F1-8BAA-47FC-8EAC-725A0A8419CD', '4607027765125', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C92016B-3369-45A9-B76F-380C269C6574', 'D44EF9AF-C4FD-4833-BD44-9873596AE54D', '4607027765132', ' 0,15  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F546B864-71C5-47E5-8E97-7E098F2C65B4', 'EF1380D4-E9F6-4359-BFAE-DC62230321DF', '4607027765149', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E77D1F2F-09C1-40B3-9DBB-4362DB34F1A4', '92227FB8-AC31-4C5C-B497-364B8BD91B4B', '4607027765156', ' 100   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF4A00FF-0F77-4299-A4DA-6FE28BBE17CD', 'A8F600CF-FDAC-4BB3-BA2A-9DB0DD687182', '4607027765163', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A5E1881-B717-457B-A7E3-4C4A460167C6', 'CFB81857-8300-4AFD-B0E2-B911A4FD609B', '4607027765187', ' 10  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C9A1EC8-1CE0-49F4-87C4-DC7A73A88B7B', 'B827EDC0-49C5-47A3-B812-03C4EA82F828', '4607027765248', ' 0,005 /1+1  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF240F31-4E0C-4E50-8D14-099A66BE2197', 'D8CC2938-3DFC-4AEB-8584-B522FB67B9D9', '4607027765255', '  10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE433369-991B-4074-AC10-45EB97C68552', 'FF2A6465-C1B1-4DE1-AC5D-B96BC6DDD816', '4607027765279', ' 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A69E023F-6083-451B-B1A1-F3C40F7AFB1C', '61286D8F-F32C-407E-8DE0-CBC864BE2E1C', '4607027765316', ' 400  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9895231-0039-4874-99F6-8DDBB476B0BC', '1B5073E7-3C22-45FD-A62F-31EFBC251690', '4607027765378', '  30  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6703E397-BAD7-4BA6-8328-CEF134F909A1', '04D3BECC-D0C9-45D9-921B-A54D47A40CC4', '4607027765385', '  60  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57FC4925-5859-4B81-BFE1-AE9AC529BA50', 'FDEB511C-43F6-4EBE-A2D8-D6B4E791DF14', '4607027765408', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9230A3FA-072B-4F75-91E9-9B1BFDD8FE59', 'A12DA65A-170A-45C3-8536-0AAE601C5FF8', '4607027765422', '-  /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBEB6A4B-2C45-4A76-8B25-AD634F3661EF', 'C45541CA-0071-4226-BC49-19E8E10147C4', '4607027765521', ' 0,125 /1+1/  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC784CF1-FC97-48CC-BB5B-D4A20D020DAA', '3DA20BAF-700A-4C87-B0D4-D81BF9BADDBD', '4607027765590', ' 250  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93498B31-C2AF-4C61-A221-8BC766539583', '4832E253-418B-4896-A81A-989078F3FA7D', '4607027765606', ' 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2569A64-2CDD-43A6-ACA9-77B2869BDC39', 'E1496441-8D1A-46E2-9D95-72801AE10935', '4607027765620', ' 0,1 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('528D7B64-D17A-4054-A90A-091E2E60199C', 'DFA51B68-FA5C-42B5-8906-68ABC3A0C9A4', '4607027765637', ' 160  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32B0FB58-8D45-4E7D-95E8-3360CEB7F231', 'A82DB4F1-C5F5-4BDD-B26B-D7465AB93BB3', '4607027765675', ' 0,005  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25DA0FD8-3DC3-42F3-968C-B9CFDB423110', '7B221B36-191C-4044-B030-EB5F79275C6A', '4607027765699', ' 0,4  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D7BEBFC-CC9D-43B6-B746-C7244EE5B91E', 'A82DB4F1-C5F5-4BDD-B26B-D7465AB93BB3', '4607027765774', ' 0,005  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('447158CE-76B6-41D9-BCB3-6BB63BA960F6', 'CB8EFD34-CEBA-4936-9C3E-74EF51C79BFC', '4607027765842', ' 0,08+0,0125  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F507207-F2C4-40DC-B8A9-2D491BA2FED0', 'E71C984D-8A43-4533-A751-2235A0147644', '4607027765859', ' 160+12,5 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B328C64D-6D7A-4E21-8EFE-BC066A6F8103', '846E6F4C-23BD-4F13-9AD5-E7398463FC7C', '4607027765866', ' 0,16+0,025  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FECCC4F-A11F-4AA5-8694-76C09DCDA668', 'E723C4CC-A191-4F6A-ABC7-FF0BDFE18DCF', '4607027765880', '- 1,25+4 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A1D7055-C25D-4501-8C59-95B8433B8F21', '477221E5-4F88-4887-9A30-95108CB3D14F', '4607027765903', ' 2,5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A34B4C1A-F311-4E96-8B94-A469A96F024F', '507D6EA6-94B0-41CC-A5ED-0EFC2C6370AC', '4607027766023', ' 250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE5F8413-F059-40CA-88E2-9A31762C58BE', 'EC17DA47-3F3E-4A69-99A2-4A90D9884228', '4607027766030', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0CEBA40-BA5E-4039-A2C9-EECCE3015C2D', 'D7871D5D-0746-4A24-9693-341F246CE1DB', '4607027766047', '  500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD1619AA-49DA-4C28-B02E-C95EEC0239C9', 'D3125849-8A88-4008-AD89-467CE389CB35', '4607027766061', ' 800  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD97167B-1023-4B5E-AFCC-DE3ECDB07C7E', 'B827EDC0-49C5-47A3-B812-03C4EA82F828', '4607027766085', ' 0,005 /1+1  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CA983EA-AB39-4CC8-9DFA-023E9F5586DC', '234E7AFC-30AB-42DB-BDF5-E8A7371B9232', '4607027766115', '   10+158,5 30  850 60/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FDCA2CC-2C25-4299-8F98-C16BD119E72B', '37E918AA-BE35-493E-A47D-050A2633306B', '4607027766139', '- 0,000625+0,002 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FEC1602-9F10-465B-9FF0-0889F522105F', 'E723C4CC-A191-4F6A-ABC7-FF0BDFE18DCF', '4607027766146', '- 1,25+4 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('017F1ACE-7F49-4609-8F5F-5A45739C90D1', '1CF314DA-6C9E-45D8-AD35-E182B554DBBB', '4607027766160', ' 1%  15 /1+1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66BE9C7C-3C25-4D2C-9852-6CB7C11FC8EC', '23561A65-0799-4C89-B98E-5192534489A5', '4607027766177', '  1%   15 /1+1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9634E96-9BE2-4227-AF59-BBD21646F37D', 'E6FC26D6-BB66-42DC-A573-57F04C16BFBE', '4607027766221', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FC6366C-6F50-4F72-A7F8-E00D743D983E', 'F3968626-BF9C-4AD3-8F13-AE32D2F08C6C', '4607027766245', ' 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DB5DFE2-1042-4D63-90A9-E719D1148785', 'AE5BD1C6-FBB1-4BE0-B83A-607DD4440BBC', '4607027766252', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7A61276-6FF6-41AE-B0B8-02BAAC33DBB7', '988EA7AA-149E-49E2-A4BC-A8677B1AB21D', '4607027766276', ' 0,1 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6345421-C85A-40E4-929A-355138C3F7A0', 'E7AD194D-D645-4D53-9D6E-558FD7136A4C', '4607027766283', ' 50  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59D128D1-BEBD-4358-AA6E-9F05F6CE1542', 'CAABB659-5BEA-467F-A760-45DC3C24B693', '4607027766320', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7044A9A-69E2-4FE4-ACDA-5727B5E0DF50', '3CE44628-9CEF-4AFD-A058-64FEE48C05D1', '4607027766344', '  35   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F24EEF1-CF02-42BC-A684-66EC946DB9F4', 'E9AE1090-1666-454C-9EAA-3314920583A2', '4607027766351', '   35   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B84CB99A-CC70-4A29-A74F-3EF52B2C5B75', 'B0CF804F-E3CE-4C9F-9F4A-0A9685469357', '4607027766368', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8263F2F9-F799-4688-B0A4-3209A9C95402', 'C6851FAA-F536-4F4F-A210-E35682955B54', '4607027766375', ' 0,01 ///  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6E662D9-C05D-4E47-AED8-56FA1188D200', 'D1F6B56A-FB2F-4D6F-A488-C630780F6805', '4607027766382', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A089623-60BD-483D-A8F9-1867C515855F', 'BD67C0DE-AFF1-4CC9-9CC5-4FF3003439A2', '4607027766412', ' 100  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30E1F9B1-6473-4366-BCED-E710DB31F957', 'FBE9A8D5-3120-462C-A12A-D942003431CE', '4607027766429', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FEE6FF9-40D0-49B0-AF54-E1E74308F6D0', 'FC0A8A49-FC42-4870-A09D-41C58597F1EE', '4607027766436', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0302E2E6-F6BB-4120-8E1E-36CF9A6F3592', '8F70342A-4DDA-4D44-A423-CCE29B27DF6B', '4607027766450', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33DF3AC4-C4B5-46FC-8449-0370F211FCF1', 'D7009BCC-FBC6-4A42-ACE1-7ACC3DD36DB6', '4607027766481', '- 5%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC8F01E4-D914-42A4-9E72-44B86E5F1861', 'D96AAB80-6264-471F-A5A2-00CAFDFCB66E', '4607027766498', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CE232BD-4489-4669-B596-86AF0ACC03F6', '28267499-4B09-4AD0-B77D-4E49C8F26489', '4607027766504', ' 0,08+0,0125  //1+1 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA8C73F7-B7AC-4211-938A-4A7A77CAEF26', '06602D2B-C276-4554-BAFF-461BC5E08714', '4607027766535', ' // 10  30  /1+1/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('701D5D7E-19D3-4209-8E2E-99DEC5DA998B', '3C625013-C4F0-451E-88CE-8720A0F00259', '4607027766559', ' 0,02 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C50DDF3-2BBE-4FCA-90C4-CD2F373BCCC9', '3CC4DA97-9771-4E26-939E-7A5882FCB598', '4607027766573', ' 0,04 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C69B4F33-FEBD-4FD1-9A95-146BD04C9D73', '7211D508-FD88-4C02-BC9C-A42D7513EAEB', '4607027766603', ' 0,4  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46C20138-C44D-4832-8BA7-D5B7387CCBED', 'AAD311C0-41F7-4353-9921-33B41E53C703', '4607027766610', ' 0,4  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01A56073-FE21-4873-A95F-6F76D4FD28E8', '67C4685A-2F22-4130-9DC1-17D3DB3A3F2E', '4607027766627', ' 0,04 302 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C8C493F-9340-402D-BA22-B23DF39C47C8', '979D9203-4EF3-4B89-BB4E-4B7F040B735A', '4607027766641', ' 0,08 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB6C5E1A-5C05-482B-9BA2-5E762FBD4FF3', '45176FE8-D2DA-421C-99FB-D20227366118', '4607027766658', ' 0,08 302 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A3846D8-9D30-42E9-8AE8-C607E5AA8DCA', 'D3EA75C0-C156-45C9-A5FE-ECC3ED052429', '4607027766665', ' 0,16 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B65895B-1FAC-48C3-9ECC-FF55EDA39226', 'D3EA75C0-C156-45C9-A5FE-ECC3ED052429', '4607027766672', ' 0,16 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12CD87B5-5C61-4295-8D94-A97C678FC51E', '7778E06A-2351-4059-98F7-D1AEB2A69EB2', '4607027766696', '  5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('682FEA25-A625-4F19-9F55-A3BA8F0D954D', '79132B3B-541E-4F12-AF08-893DF31F66D9', '4607027766726', ' 25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16ED6AE6-557E-4371-B7B1-BBB3EBC5C518', 'DBC7E2DE-C8B1-4BC9-BB9E-23A2499447C1', '4607027766733', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C29F6186-634E-40A8-8DE9-EB2F55D5BB6B', 'D2B40C1C-AD0F-42D8-9DA3-3973FF172D19', '4607027766757', ' 5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFF09671-2CF2-41D6-B095-43AA93321D19', 'AC46F878-E333-4629-9CC0-263195CC9AC1', '4607027767150', ' 0,15  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10C6BD1C-D801-4822-BF25-EAEBA9467DEA', '9238DD3E-9305-4628-B82C-19E636B03734', '4607027767167', ' 2,5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('062935F6-AA20-47C5-A76F-3DDB5BFC7F1C', 'EDE107EB-0D43-4973-A181-3C001627B3CF', '4607027767174', '  2,5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D3DCE7A-1A91-4B09-8F55-B06B9752223F', '2C9F7EE4-1DFC-4E8A-B80C-17E08581CF99', '4607027767211', ' 0,08  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C17C74E7-E68E-454B-9B74-4054C0E7B96D', 'C55187C6-8C8A-440F-9565-9D3B15020804', '4607027767228', ' 0,4  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4F9D3AC-D787-4C55-82CF-CB45BB88099B', '5BF36141-CAF5-40EE-98A7-B303342DE27E', '4607027767235', ' 25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('609B782C-FAE0-4062-8AF2-542535F45E55', '7F62734C-DFE9-4930-B6AD-59EB74B928D3', '4607027767242', '  0,3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('482A9AB6-B158-42A9-9A31-A6A45A814BB8', '9381B0BF-178D-48E8-B3BE-F54F8FF379D5', '4607027767259', '  300  30 /1+1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0EA76F9-13C1-480C-AB13-80CC4CA4EE98', '0A21F8A3-4676-4188-9915-682E5BD1525F', '4607027767273', ' 50  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FF22342-9913-4735-9558-3E5651271E19', 'AB91DD46-31D6-40DE-8B23-D806CE43BF5D', '4607027767327', '  5+4  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E1FDD78-2022-4645-ABF4-BF5AA5F6E0A3', '0379466F-B7E1-4276-AC74-55064F4D85AB', '4607027767358', '  0,01+0,004  30 1+1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7625138-152D-4DC0-B345-1E081003EC51', 'B0DEFB87-0A8A-4F04-8776-897D19805794', '4607027767389', '   0,005+0,008  30 1+1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5564CB14-C201-4154-B049-D6DDA70CED4D', '654B695F-BD0D-4148-81FA-F09CD14A0F26', '4607027767419', '  0,01+0,008  30+30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86230E93-3155-4E01-AE17-6FEACE2FB334', '6A225E9A-7D6E-454A-929B-94867A6C64B9', '4607027767433', ' 0,16+0,0125  //1+1 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFC6C8A5-B291-478F-ACE3-D8FC6BA04FDD', '88BEF51A-AE50-4F81-A3FB-678E04FB4B97', '4607027767440', ' 0,16+0,0125 ///1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC6ED561-05CA-47F4-8696-5FE5BBD4A5A8', '846E6F4C-23BD-4F13-9AD5-E7398463FC7C', '4607027767457', ' 0,16+0,025  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CABA1A3E-B989-4968-9DDD-BDFF32397800', 'C8335160-84DD-4AF2-A19B-ACFAB0041CA5', '4607027767471', ' 500  / 60', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92572A11-94FF-49CB-9BC6-5B97F58E9439', '80D12F87-3386-4436-B502-54D05BC9AB26', '4607027767488', ' 8  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A77E09E-1041-4C5E-BEF0-A4F82DE722D4', '7B7028C7-6C87-4900-8CDA-776DD9F08012', '4607027767495', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94DA155C-9EBD-4880-A832-DC19342E27F2', '215AD29C-4218-4AA6-8BE4-6592D3C3B00B', '4607027767501', ' 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AB07395-8F50-42CB-8971-E08FF4866BC2', '7C2B1D3A-E379-41CF-9D48-4BC66C78AC6C', '4607027767518', '  250   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DAA44C1-F4C1-4AA3-ADB3-B0502DDDDC03', '77102916-6714-4A9D-AF87-BCDDAA9BF434', '4607027767556', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55DADDFA-B8B0-436B-BCE7-6CE1882E5AC8', '04BB93D9-218A-4D76-9716-6734CDF8C361', '4607027767563', ' 1% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('515A55B4-D643-4EAD-895B-897BAABFA8CB', '51EF3E8A-E11B-4EB4-B5DF-A5D2279DF543', '4607027767655', '  25/ 3 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4D3A976-C897-42DE-8B7B-39138F89EDBD', '78B24F1E-A7F4-488E-8975-A1B44AD1CDFB', '4607027767730', ' 3% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63FE0434-5A50-4D47-89FE-1C57E6C8730C', 'CD4F275A-68F3-4EBF-AD8E-EB72C511FD3C', '4607027767754', ' / 10% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2F5EBC0-4AAF-45AA-9D6F-D3CF505531AB', 'FA15C994-21A1-4F25-8940-BEF9A39F2B9D', '4607027767921', ' 2% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E7665E7-9E37-459E-B57B-2AA438AD97D8', '822FF5D2-9090-48C9-B40D-4AB2A5C1777F', '4607027768010', '  5% 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A6EA31A-65DB-4243-88CE-A9676F51F9DD', 'C463CFCE-CA7C-413D-A8DE-A1FF28BD1591', '4607027768034', '  1% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93275BB4-BCDE-4519-B2B2-5E95FA3B6A3F', '024DC391-29CD-4562-A318-6AB34BC6D2E1', '4607027768065', '  100  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E76141DE-465A-404B-B9AA-B025468DF071', '7929AE43-24D2-4A3E-AEA5-ED41C73E5F0B', '4607027768072', '  200  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C388AE8-0BD9-4F02-B088-4FE30EEAB810', 'B4F9A642-B072-44A3-B29E-C36D7C15FAE6', '4607027768102', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92669CEB-C410-4B0A-964B-07AA5335C5E1', 'DDBA14DD-4B68-4726-9E19-9656CBD01F17', '4607027768119', ' 5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB432899-7451-48E9-BEDB-7E31AFD9FDB1', '613F27D6-9B15-4B6B-BAA4-99790A1A1E1B', '4607027768126', ' 10  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6213CF0B-91CA-4966-AAB2-DB2243E502C7', 'C8E4E98C-7285-4571-9EF4-AF5C19F9D3F2', '4607027768157', ' 0,0002 ///  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E50CD19-E990-41A5-B97A-F5CA4841ED24', 'E438F4D6-8EEF-4793-844F-EC68B4264B1B', '4607027768263', ' 500  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92B7DDA2-F435-4D4C-BABA-F6E4F42AE38E', 'BF2C0017-AC70-47CA-B87C-42B1081F1D40', '4607027768270', ' 15/5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C0A8BE5-AC93-47CA-AEA2-A396079F9980', 'E76BF72B-FD23-4967-B348-B0ED5170E3E0', '4607027768287', ' 30/5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74B5A1CF-11FE-40FA-AA7D-598CB27C90FB', '94A68C49-97D4-4223-BE23-41FD2F367FDB', '4607027768294', '  0,125   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A2ED8B8-4D6C-4E07-B6A9-25E1F741B36E', '1C5A4491-0763-4C25-9898-F7BBB76CC2B0', '4607027768300', '   0,5   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FAA6828-8476-4E65-95A9-2692A0506CF6', 'A7BB877A-FC98-4B5D-A599-1A99AA3D5E13', '4607027768331', ' 150 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A22DFD1-B5B6-44C2-BBFD-B2E9BD52C8C8', '4909499C-A341-4349-AE0B-D72624243F63', '4607027768348', ' 0,0075 -       40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('470DE26F-0BB9-4B86-AAA5-42F9F793CD8A', 'B54EFDD4-4FC1-420E-BE7F-E98CEBAF45F7', '4607027768355', ' 0,0075 - /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA15603A-2255-43CF-9529-6685B709987F', '6F1F6878-A9DA-4854-9E42-32C1BABEB1DF', '4607027768416', ' / 2%  2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79393048-3752-44F4-AF1F-B852E1DE0D2D', '1BB6707A-6EBC-4CBD-8447-25BD8509C88B', '4607027768430', '  60  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28DC67A8-9D6E-4A11-A500-221FC36DA077', '65306F05-3E16-4B40-BE0E-1B55ED8846B3', '4607027768447', ' 2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8D69E66-700A-4828-B032-D52B6E058C3A', 'FA9C0FD2-3981-4AB0-988E-FB710F7F5F08', '4607027768454', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A55E3E5D-A012-4D01-ABDA-201277683D68', '178306AE-51C8-4DF9-A7BC-32F4DD03055B', '4607027768492', ' 0,005+0,01 30 /1+1/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50AC48EA-9CC1-4466-80CC-55D391901933', '178306AE-51C8-4DF9-A7BC-32F4DD03055B', '4607027768508', ' 0,005+0,01 30 /1+1/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9B3229D-CCED-4550-9234-3775FDAC1685', 'AE0179D0-71F7-4531-B8EE-659186E7FF1E', '4607027768515', ' 0,01+0,02 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A822900D-98E1-42DC-AA79-AF70FD8E81B7', 'AE0179D0-71F7-4531-B8EE-659186E7FF1E', '4607027768522', ' 0,01+0,02 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB6F0F21-26F4-491A-857F-6ACD44C0CB95', 'D50031D5-AE7A-422B-8A6B-8C9DF4C9E326', '4607027768553', ' //  5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ACA84F2-5AF7-44F6-9EDD-7D0ED06F8ECF', '37FBAF0F-1365-4DA5-9A0D-22B7A0437352', '4607027768560', ' 0,5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4A39AEE-050D-49C6-9E07-8668E622545A', 'A757D5AD-5E89-4AFC-AD94-7CAED62F90FB', '4607027768577', ' 0,25/5 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('509C522D-13DD-404E-BACC-38C5150FEBEA', 'A30A853B-5CB4-4607-BD51-3F642A317A99', '4607027768591', ' 5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01626FD2-EA87-4DDE-8CCB-C884B0D87C58', 'A7BB877A-FC98-4B5D-A599-1A99AA3D5E13', '4607027768775', ' 150 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1756054D-D00D-47C3-83B8-A5FE953BD68B', '48451C35-C0C8-49E2-9E7B-76BC8EF7DD4E', '4607027768829', ' 0,025 ///  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABFCFDA4-7288-43C4-81E9-5CD699D56771', 'D07F9B1E-1BBE-45A2-9AAA-BB25CA02F2A1', '4607027768836', ' 0,075  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45D2C834-16F3-4127-92DA-E8564E709C7A', 'F5272511-5194-49FC-9A39-3AC85C7BD37C', '4607027768904', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F76C622-E937-4199-A7F0-4D5C80BE7B21', 'ACEC81ED-8880-42A9-AC21-E4BA67C65048', '4607027768928', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6C2410A-D674-47CE-97CF-D19E2AF70FB7', 'FBCD1B38-6F47-4F68-AD5E-EE276BD7FFAA', '4607027768935', ' 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26F93631-C200-4E3D-927B-ADCED14E44D3', 'E3772684-F429-4F13-ADFF-12A4DA8C588A', '4607027768959', ' 20%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C7964A6-9D4A-4F74-8706-9337AD19A98A', 'F7059C94-3638-492E-B7AB-B16CBD2B0375', '4607027768997', ' 4/5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8B1D697-A0D9-4185-AD44-C5B0E4DB5515', '990597C6-C223-4239-9D83-396268C094BD', '4607027769062', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AFABD73-BEEA-447A-8E0B-102AFA1ECE67', 'D7A54DD6-B84E-4367-8AB9-DE528588418A', '4607027769086', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54047995-4E1E-49E3-B530-CEB89C629B1F', '78134962-8E50-4BA8-99A4-5549AEDC2D72', '4607027769123', ' 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1747499-BCDA-48E0-AB77-BE44739B16E7', 'EFC3A374-C6FD-48A9-BF83-8EA1D37104D9', '4607027769130', ' 100  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CD08BCC-0CDB-4408-8D22-BFDE47A2FC4F', '18488BF7-AA58-4060-A90B-E48785ACD6FD', '4607027769147', ' 100  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5805F6DC-E952-4DEF-8834-1B7B6A04F2E7', '6EE69062-D2F3-4C48-9D11-FA4AAFC429C1', '4607027769154', '  100  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B73344B-A39B-4170-8DF8-15695E3CC6F9', 'F0A32607-F27A-45F2-913C-1B8A3DD1A841', '4607027769161', ' 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60271329-08C6-4F29-8A6F-3A38610B344B', 'CD55CC74-830D-44C2-BE30-E49E9465A136', '4607027769178', ' 100  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AC213DD-EF20-41F3-A25A-B5CF88078E3E', '0B8892B8-3F0E-4797-A518-1B11294E0474', '4607027769314', '  0,05% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B936E2F-45FF-48E9-ADB9-35F78C5CB26A', 'CAD099D4-BF09-446E-AAD3-3C0153A94F6A', '4607027769321', ' 0,1% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8268905-38F7-4DDE-A65E-26FCDD019ABA', '364D7F31-3EEC-4C14-BA92-35AC121EB70F', '4607027769529', ' 50  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24749805-0601-4D73-AAF1-6B70B1F53C26', 'CD6B1EC5-4062-4B0E-B87F-C96AFA6E8DCF', '4607027769680', ' 0,05   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A137904-296F-4147-8974-A25290BDF902', '99117497-F5AB-4A0C-9069-775ADE2BBF68', '4607027769697', ' // 150  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('563FC6D9-D50B-4C4E-893F-9C15E0FEA3C9', 'FDC428E9-B0F5-45D5-A13B-AAF3794149CB', '4607027769703', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06477E08-D9D8-4BC9-AF2F-7CC337F8B7A3', 'ECFDCCEB-C5B7-4A5E-A3F7-0596FF56B558', '4607027769727', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20A252DD-D4C6-491E-AB6F-1026DCCB055C', 'E94B81BA-268F-445B-9052-974486AE6E1B', '4607027769826', ' 0,1  //  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE359CEF-1A88-4CA7-A44F-4ED25E0562B2', 'FB84D67E-35B9-46A9-81BF-3CF97AAB1023', '4607027769840', ' 0,5   50 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3452DC46-0010-476D-8ED2-9A0E46B19422', 'CD56768D-390E-40C4-BC20-A5E8CD72E4ED', '4607027769895', '- 0,005 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D868FAE-3993-40D3-94D7-EE9BEBE74C6A', 'B2AB35D3-DA76-4DFB-B74A-15CF8C686BE4', '4607027769901', '- 0,01 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30EB65C1-5C2A-4E58-9161-BA4AC1C6F7B8', 'CB63BB8B-6F5F-41A4-8418-16391038246E', '4607027769918', '- 10 /1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3B02AC5-7484-44FC-9A8C-0C394C262C81', '0D56100E-2A78-4A5E-B252-02B1D1F7D5BC', '4607027769925', '- 20  30 /1+1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC686A1F-19C5-4246-9B5A-B12D8A68592B', '7EE3F564-57F4-42EE-997C-3E3692DF8644', '4607028010033', ' - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCD9233F-134A-4F15-BC1C-2DAF5A204616', 'DE02AD67-052A-403D-A173-45E3C4F58F13', '4607028390036', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29EA6E8E-9988-42F1-B7A8-DB31E9B0E4C8', '3BF67EEF-3E3D-469C-BB89-4C118608A851', '4607028392337', '  100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C28DFC20-73B2-49A5-A80B-E7DEC2ADE270', '7A913BE9-2C02-4CB3-A5BB-9C9774BC87EC', '4607028393891', '  10000 +0,8 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88C96F52-FADE-4880-99F7-B5CA8F6020ED', '8935BF53-CB6F-45E9-A051-74CA8B73F063', '4607028980251', '    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FC35D7B-9C77-42BB-B9C5-1BD6E794BC79', '8E1ACD42-877C-4D42-A36F-4DEC41B6EA6F', '4607029290243', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('491BBDED-7E87-4CFE-B524-654FA3C1FEB2', '2850B526-802A-4273-96B8-797918ECED61', '4607029291394', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('283B2798-F5BE-494A-A450-910FD5AAE0E2', 'C373949A-24F1-43E6-A7C5-25F5666ACE18', '4607029291400', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38FEBDE0-C250-4796-8B78-53B7B562E0D6', 'D67D7BC1-30CE-4070-9CD6-E8C27BEDE7F1', '4607029291486', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA2123FE-459B-4259-B411-DBA7D3C6CF8B', '05F44753-DF0C-48F6-927A-5AC8DDA3EED7', '4607029291554', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BCB02E1-FED9-4D34-9726-1B4835EF397E', 'D20EAAF1-91B5-4814-867F-5B897BA7FF3A', '4607029291592', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7523B11B-354C-4285-AA1D-D37C7F6ACDBF', '952976EE-6B3B-40CA-8F17-0C3DC538B7D0', '4607029291608', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA0CBEC4-7F05-4C03-8632-0D7E7AFFFEC5', 'CF2E2CC0-2E70-441D-9847-D37E425C3784', '4607029291677', '  // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB95580F-8D9C-4F13-A9AF-5849684ACBD8', 'DBAA9FDF-1AF2-44E0-8E96-F5C14076AC06', '4607029291738', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3245D91F-F2BE-4DFA-BE4A-E79CB5B8B0FA', '4E04DCC0-2565-4DB2-A461-F1FF093BFF4E', '4607029291752', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BE57247-B05D-4803-B8E7-A0B7C0F2AA2A', '4AF0AE83-FBE3-45DD-B3F7-CC136B1DF50B', '4607029291783', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D0840C2-81D3-4FFD-9596-D2EFFAF6D8AD', 'EB5E62DC-1DB0-4AB7-ACFC-EEBEE7835A91', '4607029293497', '   25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B7D0512-4F80-49C1-9137-7E01B790AF4F', '7256BD30-3F99-4F70-A6E8-0FB9A98A3ECA', '4607029294357', '-     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AECCC3EA-7AAD-4254-96A5-E8C58EE56B80', 'F09EC7E6-6E04-4B75-A649-6356E33DC397', '4607029294364', '  .    /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5A25A96-1480-417C-B6D0-5930CD7EEA6B', '040DF9DA-29D4-4D2D-9EA3-2AAD84B2B327', '4607029295248', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('405FF30D-B5AD-4E2C-9A82-D532D5494C99', 'CC8C209A-85B1-40BD-8909-B37532E2A67E', '4607029295262', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2971CB8-7F7E-483B-9277-86D2BA05D234', '8A1BB1DA-72E9-476F-BD50-FD6F4E05B8A7', '4607029295286', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D649B8A-86EA-45DF-9C54-7B94E1C38DD7', 'BA9289A6-389E-4E96-A868-D2F15DF0F019', '4607029296016', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3B15EC7-172E-457A-9DB1-F81CC6AB465D', 'CF2E2CC0-2E70-441D-9847-D37E425C3784', '4607029296108', '  // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B29B594C-2592-4805-A504-DCF599B06AA0', '2485304F-4466-43BD-AE72-A45D140D497B', '4607029296122', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3500A082-219E-4B63-A7D6-10CB96A0ACDB', '40992B2F-3BB0-4AA7-A8CC-166D25557650', '4607029580115', '  / 1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B13A278A-C37E-4445-B4A1-F901F2743112', 'D80F1C23-9A50-4E61-8846-B40616F52632', '4607029580139', '    100 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D705A2DD-EC47-4EA8-BE91-6AF358B0F61E', '6AE11E07-7ADA-4A4E-9F61-0846A2A0F22C', '4607029580146', '    0,1  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E15F44D-4B9C-4A40-B50F-5B49899816EE', '1730D9A1-B7F5-4A4B-B261-C66DF0BAFAA4', '4607029580160', '  2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FA75928-D738-477B-A5F2-BA7A44CAE613', '2D8AA192-59D2-4DD7-B228-E366D4B52C6D', '4607029580177', '    20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59EA5316-A2DE-4626-ACE4-AA8432327F98', '9CA9EBD4-B2D0-4A5F-9F8B-CE45D6C7D362', '4607029580238', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A1AC42D-3768-4DB6-8358-2ED7D41C5613', '5F9D6C26-972F-4E59-ACE5-86C4C02E6400', '4607032904243', '   9060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B77A952-13E4-404C-919B-EAF49CB8ED6B', 'C088AF5D-A403-48D1-BC29-6DCC2B9CF73E', '4607033350179', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEDF1771-F137-4BA1-93DE-27AB5A880CB5', '91A04ECC-1CA2-4FAE-8D52-5EF512D20151', '4607033350391', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BA2AF61-514D-413D-B1B7-9ABE2FF1585F', '1FADB98B-A1C6-40BA-9FA3-48BEF449BBD8', '4607033350568', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BB12FC2-243B-4E57-95B1-9212513B4AEB', 'B7366AC2-8AE7-4FB2-9BA7-51B0912CA2C1', '4607034470456', '   /  / 74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('175AA29C-230B-4404-AE0A-93D9EEE58E8B', '2E28FEA4-6CEE-4AF7-A9B7-A6B399A7E9EB', '4607034470463', '      74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F73DAE53-0E18-4B17-B595-7A7F9ED9210B', 'A76330AB-C8E4-4A00-92E9-31EB031D0E2C', '4607034470517', '   4-7     74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4ABE3085-7379-40F6-AB21-9D8BA7D7350C', 'C6EDDD7D-FBDD-4CE7-974C-B3A2EB1F3F57', '4607034470524', '   4-7  // 45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85417D0C-05AA-48F9-A760-E448DD706C44', 'EC40E25C-95FB-48A0-8E75-22C756F326E5', '4607034470531', '    0-3   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FAA4562-E6D4-4763-BA16-02275E531ADA', '606E0D4C-3A4C-4F5C-90F3-457CBD449DA6', '4607034470548', '       74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECB637F8-424F-4894-99A7-CD689F7277DC', '0FCE24BB-3AF9-47F8-A0FC-FEAC426F0221', '4607034470555', '     /  74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('041B0F0A-B92B-4467-A845-2F5943545A95', '0E8AC81E-0619-48B8-A73C-A02F5A6E6182', '4607034470609', 'Rocs  medical  45 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFF42613-32A0-4295-82E3-CE81360AE637', '9C59CC6B-2932-472A-A428-8AC9B2A8B05E', '4607034470623', '   /  / 74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5B72918-DC65-4B91-9D8C-11AE5FBF89BC', '64E00F02-29E8-4DDD-AB8E-BB516EE90F77', '4607034470715', '      45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF372BFE-2AF4-4F13-A570-004ED91965DA', '7A7397BF-AC0E-4DED-B155-B410525C6617', '4607034470876', '    4-7    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1E77DF7-2903-46F8-AE9B-8264DA0AEEE2', 'ECCD9DBF-F313-4AE4-82C0-430FC02CEBC3', '4607034471309', '    74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('474DEE29-343B-465C-9082-8660ED891B21', '26577A24-66F5-4BE8-9DD3-BC2EE5D12843', '4607034471590', '   /0-3/ . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A254E5D-13CD-451F-AFCF-686A7BA3CD6D', '3037CC45-DEEF-4D1F-B4D0-AF80F183B80F', '4607034471750', '     74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FAF1DDC-EA91-4E60-9C5F-9689F2718461', 'C2AB4067-56C3-429A-B927-332D788F7056', '4607034471903', '   /    74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0BE0CE7-A28A-47E0-B9B8-BD68646F436D', '8EB756A2-5FC2-49F9-B628-732E20901803', '4607034471910', '   teens /  74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB962C55-5AA6-4DF3-8AAB-940A01F84AE5', 'AC1A8A24-953C-4F94-B142-82ED64ADFE96', '4607034471996', '  /    35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A61AA7E-6A3B-46E3-9C7D-61E668E5B1AB', 'CB6BA951-0776-4E50-980D-EF0521BAC184', '4607034472023', '     74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D967FF47-76DC-4707-BF93-6D6F882EC1DA', '0EF3F5CA-E31B-4711-BE7F-62FE4E1F6913', '4607034472047', '   -     0  3  /+/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA529988-CF10-44D9-9EEF-54864063C760', '4386A621-1033-42BC-AEE4-A419C19C03CD', '4607034472092', '     45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05B24724-D6B2-4182-A28A-E646B105DC32', '200879BD-9B4B-4E43-B0AA-91A3283023B4', '4607034472184', '       135', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C337FFE3-8CE7-411F-9B0F-E4B1D917F148', 'BB6D468D-2966-46AA-A9AB-15ED31A52811', '4607034472191', '       135', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('831C6A98-970F-4AB8-8EB8-766C35C65B63', '13798320-29E1-4D64-92FD-188AF5CB78F3', '4607034472207', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1067E070-C52C-4A94-A9DE-75393C6FAED6', '33D8D0D8-3254-4B9D-9C27-8A2F3224F659', '4607034472221', ' - /   + /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4F3EFE5-DC9A-495C-8031-5EA3D50F2AB8', 'E6D7BFBC-A456-4416-855F-562FD050C3AE', '4607034472276', '         45+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71842BD4-E13A-4B80-B931-04CCF5BDBCE2', 'C6E15EA7-C06C-4B3D-9378-76DE0C636B31', '4607034472306', '    /  74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9740248-CAFC-4B35-B18F-6FDDB6447527', '6069D3A0-25A6-4600-AEF8-0218A4F963A7', '4607034472351', '     74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC945D89-C3B5-4EEF-997A-0E16D8AAE672', 'E3EEDDED-9D72-4C0E-BA0B-8DEE99786910', '4607034472368', '  rocs uno calcium//74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54829F80-331E-471B-B1B4-C922BE66E66E', '98EB8E09-1DF4-4A87-8E12-B151EAAA8158', '4607034472399', '   uno   74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAA9E4DA-583B-46C2-9066-A4F5D1E26E09', 'EA2FA4F7-F9FB-40DC-914A-D3C8AF89CE16', '4607034472429', '    /74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F8C1A68-48D0-4F63-8649-73AC6DAEC6BB', 'FA526DB8-3182-4C0F-8D0C-0B20F4C9AD62', '4607034472504', '   pro    0  3       45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('543D6DA4-4A05-401E-9613-523546478D15', '755C18CD-881E-4759-9761-18A2A53314C3', '4607034472559', '     74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C335FF45-90B5-4F96-A584-FE5FA09B7EC0', 'FC677AE0-7E7C-4484-85D1-176CD90F714D', '4607034472566', '      74+ 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('321BC9FA-D304-4297-8E22-1C8D98DEA013', 'DF95F73F-35A1-4C33-B780-8B3ADB653A8D', '4607034472696', 'Rocs  /   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1732457D-37E0-44D2-9BA0-69BF3B1A0DA6', '515FA70E-E2B8-40C5-A8E3-CC53C393C173', '4607034472702', '   -   +  /pr 105/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A22C9ABE-B7D5-4E34-8A8A-66354F7EBD04', '553A0EDB-DC39-47CC-9708-3B4DA9E0E91B', '4607034472733', '     94', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6F16DAE-9DB7-4CB3-B53D-DE9FD67BF9D7', '8A4AC66C-A10D-4801-A209-C720670C839B', '4607034472757', 'Rocs    7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A66F2C0F-64B4-453A-A9B7-581883D37126', '73C8F587-22FD-4F85-8A4D-5897625F7EEC', '4607034472764', '   16+    74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EE95280-B247-432D-ABA6-A4336084E802', 'D998C40F-99C0-49C1-BD4D-C5B576F7BCF1', '4607034472788', '  rocs   74,0+/ -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('908CCC66-601B-4730-A0F0-E0654C2A3990', '3A7A49D8-A359-4FB2-8E24-00B9FD7D01D2', '4607034472818', 'Rocs  medical  // 45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D72040D3-DDC1-4A33-96DF-1069D7B943B3', '6FF24248-8D5E-4A85-9356-C1EDA9E731CF', '4607034472856', '     74+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5857192A-8941-495C-945D-41D3BFC9F607', '2AB2A8B4-2659-48F2-B20D-4EBA4F752CF6', '4607034472962', '   /     94', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('560BFA04-2094-4BB7-A522-F2CCCF86882A', '0A879E6F-3980-4244-AEC6-7AA4724949D8', '4607034472979', '  /   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CAA7C37-AC4E-41F8-9E6F-7DB482750086', '2F1803A0-54C7-4C1B-9E1A-FF6CA5206B5A', '4607034473006', '      /.  45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D09FC07A-B02F-4BCE-913D-3B6771A4E538', 'DADCF774-0A78-40A4-8557-8A701A1F21B6', '4607034473037', '  rocs  sweet princess   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30102D77-DE1F-4CF1-90B0-FDD236E44738', '72B71AD1-6535-4C71-9012-09D733FA9382', '4607034473044', '   /    94', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F6C12E0-F538-435D-800D-9A004FBBC933', '30487AF0-D6E5-4EB2-B02E-335E0E60FA7A', '4607034473235', '    3-7    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6F76A1D-614D-48C2-8183-441EC8273EA2', '337A0910-104E-4AEB-A1C6-5648AF534EA4', '4607034473310', '   -    45,0+/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C512BEF-1A16-468B-8FB0-7C2161F689F8', '65DB4D2C-4C68-4DFD-AB9A-BC2283AE91A5', '4607034473327', 'Rocs  pro  / 64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAF6967A-1E53-49D5-B07D-BEB5A3376992', '8F959052-FD09-4422-BECB-5179FEC61C71', '4607034473334', '    / 94', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3C9C928-C227-444F-9A2E-4CD78DDE674B', '564431BA-227B-4C45-ADA0-2D11F52C42BE', '4607034473365', '     94', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E23E662-4CC9-441A-96F8-1A94FBC64674', 'EE3A5953-115A-4A58-A53D-857590B22F9A', '4607034473372', ' /  74,0+/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33D5E206-11D9-495E-82DB-6119F91F2350', 'A22D82DF-0298-4E54-B961-E8FF112C195C', '4607034473396', '   pro    3  7    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02B70551-0A02-4101-86F8-31D5FBD803CC', 'BB642729-D094-4682-A00E-9E71542A2DE5', '4607034473532', '  lapikka        45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33A81AD4-2D21-43D6-9140-55F434B3CFD0', '5E31E360-F157-400B-BEE5-88508DBFE818', '4607034473549', '  lapikka      45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36027C0D-8C83-4F6E-93F0-1B99B6ED0CA4', 'CEFDED5B-B86A-449C-A51C-647AEF88EAC9', '4607034473556', '           74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C784586-A6E7-427D-95E2-580DAA4E7408', 'B318C59D-156A-484E-ACC6-EA8088624D7D', '4607034473723', '  /,    .    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA964EC2-893D-4132-8C54-ED3280756EC9', 'ED9FE2B9-643D-4BFA-A75C-48132ADC640D', '4607034473730', '  /,    .    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DC900A4-4C0F-4B10-B171-1A494064D21E', 'D68D9061-97AD-4D7C-9CE9-7288B10BED64', '4607034473785', '  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8638117-8770-46C3-91C1-DD8F8F2419EB', '097B7DD0-43EB-4DE9-8C88-28C0E7D63C2B', '4607034473792', '     / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DB37EA8-B6C5-478C-8FAE-F1BFD3F24997', '451F913A-30FF-4629-B66D-8F018052506C', '4607034473877', ' - /  /+ /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3DBE5FF-4098-4C2B-BE08-89B26836E5C1', '6FC885C2-11D3-472F-B8D2-CAFB24FBB991', '4607034473884', '   -   +  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB09EC82-519D-4D09-AC4F-D31AF1A71E49', 'BB4FD6D4-86FA-4BC0-98D3-DF911DBF6F0A', '4607034473921', '    young & white enamel 135', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C95337F-A24E-45D0-BF08-27FFAB990803', '061A7ADB-6EBD-475C-B3E1-117A0A7C397C', '4607034473969', '  lapikka        74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B05DD3C6-F4C3-4142-89D1-42249FE4ECEA', '7A9C6E3D-D190-4C27-88DE-BD2ED2F7D321', '4607034473976', '       45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('320239C7-038B-4674-88CA-E6FF66B866D8', 'D20A463C-053B-489F-A5DD-EEA02C59697B', '4607034474058', '    94+/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE14BB40-CDC9-4AC7-A4B8-09C8CBCB3688', 'B495ED12-EF41-4E48-B94F-C632BF0E70D2', '4607034474126', '     94', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23D070A5-56D8-4CC2-BCFD-067186DE5CE4', 'E116BB53-E66C-4F94-B178-116A1D2D39E5', '4607034474133', '     94', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C29613DD-141E-47C7-9E21-3EE723A0CBC3', '20AF8C37-0D61-4D90-AFA6-5FB126A514F4', '4607034474140', '    /  94', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32C719F5-FDF4-4F0B-B95B-3A80F9AFEC5D', 'E9B8BACD-993F-460E-AA37-442922E151F5', '4607034940010', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67034FAC-4366-433F-97B6-FB0A38E1B40A', '0EAE9BAE-DE9D-4365-8C21-B2F9BE29101A', '4607034940041', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9E8E798-1630-46C9-B84C-B189EDBC1007', 'CAFC3987-B62F-48DB-8F86-613B89BEB811', '4607034940102', '     1 .528 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED2D878F-6FF1-41FF-A9FD-7C8A08F55996', '7B820B43-CF17-4573-819C-193998A2BFD0', '4607034940133', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('177934E1-A90E-4390-B80F-C319520E1049', '5CADAA93-5117-4369-9DBE-764DBC69F365', '4607034940171', ' . /./ .   ./.1 .22 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F8ABCAF-616F-4384-868D-A44E36DD4973', '8076960A-FEBE-4FAB-B666-9ED53001D970', '4607034940256', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BE8FE01-BE09-4757-8CC5-3904057F8A36', '8076960A-FEBE-4FAB-B666-9ED53001D970', '4607034940263', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('287FAF94-978E-4999-A101-48C611D2276F', '0C689AD1-47F0-4206-9585-3B730089E310', '4607034940348', '       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ECE370A-9CBC-459E-875C-9F339F3A2DD9', 'D3CC2DB6-9AC8-413E-87AD-E9B85F68807A', '4607034940430', '    -1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35512609-E0B6-433D-A47C-311A32FCA9E0', '88A9BAE7-09E3-4AE0-84F8-4EAFCC2E3564', '4607034940553', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5A927B1-E6EB-48AC-BF27-F98C20A941BA', 'EB6F836C-369F-4716-93A4-94B5C012733C', '4607034940638', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('154A66EB-EAE4-459B-B693-44F3D4E4D50F', 'B334D248-850A-4B06-AC07-0354B3F6ACA1', '4607034940805', '  .     ..  .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3078C096-C7B5-400E-A952-34E93DB5B5EA', '382015E3-AC2E-4B77-BB69-49D1C148C2B9', '4607034941680', ' /   18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('579AFD75-5BCB-4270-BF0A-98FCC58526B8', '7509EC70-C137-44A6-A942-D740B94F7B6D', '4607034941710', ' /   22 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1D7602A-0E53-4237-91A5-9DFD4BCDB055', '9EB39C69-D139-474B-A38C-C7888CBB479C', '4607035390074', ' 6  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4ED39134-31B5-4A1F-A775-823136187400', '52D9AD1E-3BCB-4536-862F-1386BAEAC865', '4607035390081', ' 12  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15F94442-10C9-471E-8279-17746D615E3A', 'CC9C7253-724A-460F-8326-C76F074FC8F5', '4607035390142', ' 3   / 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4BC271A-A625-4D16-BD90-1D8F399E0814', '530AEF12-89F4-49A5-834D-C6E2D97BB086', '4607035390180', ' 6   / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C384330B-E92D-4754-B22D-75B42E064E78', 'E58B7C8A-D5B3-4B32-A593-51C9F41B92D4', '4607035390289', ' 12  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C428FC26-44AA-40CA-A14B-6E6F6465B447', '99E807B5-7739-4BC2-8D78-568C4E1CD3D7', '4607035390364', ' 3000   / - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44D27BBD-9C52-4526-BAD8-B050ECDF6AB3', '0CD48DF3-3EA4-437C-BE76-3D5FC85EFB5C', '4607035391422', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C71576F8-C20B-498D-8837-4D4B4938958B', '86011BF2-6DE2-45E2-8396-21C2FAD27F04', '4607035391767', ' 3000  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEA65904-ACD2-419C-ABDB-99DDC009BAFB', 'E58B7C8A-D5B3-4B32-A593-51C9F41B92D4', '4607035392207', ' 12  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B0EF3A1-A028-4363-8FC4-E8400CE2C7DE', 'E58B7C8A-D5B3-4B32-A593-51C9F41B92D4', '4607035392214', ' 12  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C12A0117-A60D-4676-A9DC-C6164C70D4C8', '9EB39C69-D139-474B-A38C-C7888CBB479C', '4607035392320', ' 6  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C73A8DAD-FD20-4DE4-AF90-87D8770C14D6', '18A263DA-91AD-4EE4-8ECF-0A7F83B6FF33', '4607035392337', ' 12    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1348B057-1D9E-427C-A25E-F8DCE2D98DB2', '97AADB79-0576-4B6F-8D56-769589480907', '4607035440014', '  500 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27DC228A-08DD-4EDD-9E88-78B4990C68DF', '29696657-A3FD-4B64-B2E2-00E6241C70AE', '4607035440021', '  100 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E71F8EB3-7B06-4586-8966-D3588DA192E9', '8C2F8B55-9A4C-4E63-9B0A-7088E9A41AD9', '4607035440038', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEAF6736-DBDA-478C-86C4-FF40E10C5457', 'E1F53634-60BE-4F06-B7E3-781EB721A939', '4607035440052', ' 10   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15914C8C-7FA9-4090-9DFF-062D3C8134EA', 'F723737C-C104-48EA-BB4D-533F006E61D8', '4607035440076', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1181B686-D603-4569-8E5B-D2822B5A36B3', 'E800D3FF-4463-4207-A7E3-930DE38C7966', '4607035440083', ' 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('443B84E0-3A94-41B2-B213-E1EE25F67662', 'B1B1D03D-DF33-4CA6-8F2A-CEB34CC70329', '4607035440090', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB343053-A985-4EC2-B5FE-67F4242FCF67', '27269978-636E-40B1-9ADC-302EAA59AABE', '4607035440175', ' 400   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68BF42B0-AEE2-42BA-ABE0-B25FE23DA485', 'B2D4E1DD-5535-4BC3-9A2B-C2C424184FC2', '4607035440458', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33373DF9-6602-418D-BA5A-8D42CCDEEB92', 'B1B1D03D-DF33-4CA6-8F2A-CEB34CC70329', '4607035440465', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1928554A-308A-4D30-ADD5-72532B2ECD0F', 'D994AA9F-9D33-4B73-BD2E-A7C2C4ADBEDB', '4607035440472', ' 200   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57816B0E-4107-417F-82D5-04F0BFD66341', 'EC7BFA2F-87C7-4B6C-8847-34B192958FDE', '4607035440489', ' 200   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CFBC0C1-5524-4551-8EC6-B2E17DFF8864', '74115033-87C3-438D-85C9-C53C10AA5C21', '4607035440588', ' 60    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFC037F8-39B8-44A7-9865-274A9D2E1A65', 'FB586F30-AB90-4664-B98D-6ED211890930', '4607037050013', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAF120E3-684F-4C9D-B917-DA0741EEA825', 'C6684960-2EDD-4A37-9434-9237284E937D', '4607037190023', '  30 1 3 / / - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('567AB4A1-C52C-4A95-8342-7F22088BF282', '324413E3-9C08-46B1-9A14-4CA37246BC68', '4607037190054', ' //  1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('755B2918-E098-4B24-9F15-BE57E5A77494', 'D72D9EEC-C7A2-493D-AA48-CCDEC38CBC91', '4607037190672', ' 30/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF2CD6CA-41CE-407E-85E9-C3EBBC905DA5', 'BD58A560-348C-4FE6-990B-2B3BB3684B4D', '4607037190979', '  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98999A59-6888-482E-A034-3EE58C859FAF', '1EC931AF-FDEE-46D8-B1B2-F07F435C5CD5', '4607038321808', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B3F3B37-1856-4476-B4F6-FF3FAD6BEC15', '82D15D8D-DD99-4146-978A-4AB5DD658D1A', '4607038730013', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B53A06C-15EA-4CC9-B392-928FFEF49A87', '5280AEF9-9835-40C3-98FD-DDD173E005BE', '4607038730044', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88518D9D-C195-43E4-ACAA-3D5D1DA0593E', '68916825-A88E-42A7-A944-595F607C9375', '4607038730068', ' /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BD91C8C-2A3E-4E5A-A85A-9A932B875A33', '93EFC371-F336-45B3-83B4-1E830056CE13', '4607038730075', '    0,2  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF9161C2-7CEC-4054-8B89-4CF4A1D7B30B', '4617A1DF-09B0-4202-9F2D-29B3C7A9697E', '4607038730181', ' B6  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A6FBB82-8435-4A77-8F68-936138AE475E', 'F3A9C686-A00B-4D6A-B496-3C0E3E17B7F8', '4607038730211', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('893F7068-C5E7-43BC-A0B0-83A0ADBE56BF', '9D60CFBC-D846-469F-8F97-C4D2E074E2BE', '4607038730228', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A7BEB85-22AD-48D2-8B6B-61FD58EC942A', '59661479-9151-4F0D-BF21-CF63AF06AFBB', '4607039770018', '     1,41', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEA35D5B-93AB-4980-8E9F-5ECF93289DCE', '29F8B6C0-CF0B-4B85-84A3-F4646CCF50D5', '4607039770025', '   1,42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69AA7A52-AD8E-4357-AAAD-1134D156D4E1', '46EF8E43-EA94-4D3B-B9D3-11E8C8B5F1A0', '4607039770131', ' -3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('249A893E-C762-4F06-A6EC-0C42BC2B5AB9', '476BB8C4-02AD-4512-A540-26C8CA7B8E3A', '4607039770148', ' -6    210', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E8A64E8-90B9-4BCB-AD65-96D8603B0AC2', 'FD5C2CD0-447A-47CB-B6DE-AE6B81F7DA45', '4607039770162', '  48  68', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00EC20C7-44B5-4AF9-AC65-0F3ECB6171C2', '94B2128D-7427-4247-92DC-A7A4F0640ED3', '4607039770230', '    -1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC987864-3872-463E-830E-2E79892E2BBF', '0A35C761-8DC7-4786-86C2-4DC2A9511C77', '4607039770247', ' -3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CB5A2EB-683D-4F1A-8C56-2AF5B844AB16', '4AB593AD-820E-4D12-B38F-68A98991BE83', '4607039770254', '  6 210', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D28A2F2-D0C0-47C7-BFCD-28C6E3DB4D42', '9B26E01D-6BBC-4C76-87D0-28EE44387630', '4607039770278', ' 9 /270/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6199C74F-8E67-4FA1-8830-D122619ED651', '51985963-C7F7-403F-9A1C-ED2A86346A3F', '4607039770292', ' -9 /340/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCD1412C-5EBD-4590-84FE-7FF7EC585612', 'FB8C6291-AC14-4ED9-A976-97E5033803A2', '4607039770414', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F3AC59E-3DB5-41D1-8A1E-C9023ED9A208', '02AD38F2-17AD-47B1-B5F9-B4C131B2D141', '4607039770445', '      1  0,68', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A1DF748-4BDB-4F4D-9CFD-19AE5E4B3075', '9DB4DC61-89B7-48B3-AF6B-EE049C8DCFC3', '4607039770612', ' /  30 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F1E7995-8911-4EBC-A261-95B9A472A677', 'F901EE88-815D-4302-A99C-77F973EAF072', '4607039771251', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E17F0A00-B9D2-4B62-B46D-DD051955AA15', 'FF989D66-B24C-498F-91D0-0B78425A5B98', '4607039771350', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C22D9A1-AE72-4105-B0AC-36084450D61C', '6CB76723-2C43-4BC5-AE79-230649F6C818', '4607039771497', '    48  68', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7304CA4-316E-4DCE-970D-491FFC7273F8', '738683CB-41B0-492A-9BFF-5630106A7138', '4607039771510', '      0,681,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6067F74-728B-418D-90CF-4697C351A6D5', 'FF989D66-B24C-498F-91D0-0B78425A5B98', '4607039771701', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4DB1D80-2958-4193-ABAE-BD3E7BFED4E9', 'FD5C2CD0-447A-47CB-B6DE-AE6B81F7DA45', '4607039771725', '  48  68', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71A66613-7D75-4640-A41D-EFC14B4450B8', '7FE44252-9909-4DF0-8B52-E366261E5718', '4607039771961', '   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64F7FE8F-1280-4561-9CB2-996A7F7D262B', '72211307-56A4-4963-ADA5-8D011480FBBA', '4607039772104', ' /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39CCAD61-5671-4AA4-B72B-74AFB217CF94', '1CCCF69B-4B7D-4960-81A3-29BBBFA1EAEF', '4607039773583', '   /35/ .. / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9038651-89C5-4C31-B804-49BC1FBC8407', '9F3B19F4-0863-4A6F-B101-0DFC65A82E7A', '4607039774405', ' -14 /  490', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0898E09C-AB22-40FF-A571-22B1CE1ABF7B', '8F6E584A-8F26-49A2-A75A-90AE49CC2ED3', '4607039774412', '   14 380', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2E07132-C320-470E-92C6-342411534CAC', '9F3B19F4-0863-4A6F-B101-0DFC65A82E7A', '4607039774726', ' -14 /  490', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECEB9F0E-7228-409B-A547-A7FD666C4E9E', 'BA4D35D1-29B0-415A-B63C-2D6FDD4AA736', '4607039776249', '    1,4 1,0/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1077921F-6FCF-47E5-9AF7-20C299B96D2E', 'F901EE88-815D-4302-A99C-77F973EAF072', '4607039778687', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('197D4CE3-F897-4EC5-974E-12C5E41FF72F', 'FF989D66-B24C-498F-91D0-0B78425A5B98', '4607039778809', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D110ECFC-6B6F-44C4-A990-DB502ECDA850', 'FF989D66-B24C-498F-91D0-0B78425A5B98', '4607039778816', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26783C3D-0F9B-4F2B-ADA9-0124EA75A6B6', 'B62B18FF-B805-4ABD-AB43-20F40AEA0496', '4607039778915', ' //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBF895F4-F05F-488A-AD7B-951C9270544D', '7AAFE2EF-5273-4169-A808-22297A539F2B', '4607039971064', '  /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A6DCA02-88F8-49A4-AD09-7614DD6FDB17', 'E42E637D-FE66-4C20-80DB-2891474F144F', '4607039971569', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC9ADDBF-B15B-4B6C-A637-697A9143D0DA', '75372828-561A-4653-B898-31CA39C9BBFF', '4607039971903', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5CEEA19-3A03-46C8-8D39-66CB173B5CFC', 'FA7FCD82-C1DC-4D4E-85B4-38D1E42CA35B', '4607039972627', '  48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6946DDB-7E49-4E62-805C-8A485FB4F3E7', '0752EF2B-08C0-46E0-8EB1-50B615DFEC17', '4607039973273', ' - 0,4  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F909DF0-2CC9-46B3-AF19-0BA785618D31', '18697824-56F0-4061-89B6-B4FEAFAF122F', '4607039973525', '- - / 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AA52366-9720-4EAB-A881-C5A3AEBCF77E', '3EE62EE9-0F48-458A-952F-4620F6D8EC6C', '4607039973532', '   /    . . 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB8B179F-99D1-4B15-B358-1E0674717789', '9A81B766-6AF3-4FD1-BF36-3069AFE6E50F', '4607039973600', '      150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('906D5327-C801-4D6A-A42D-57BEF829DDE8', '9446E710-6888-4A80-845F-C56EBDCD64D8', '4607039973631', '  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3CEA463-EAC2-42F2-A410-6B17AD699D7B', 'BEF125C3-AE7D-4DB1-885B-245B75D9BB3D', '4607039973815', ' / b6/ 0,25    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0F8DB55-B812-448E-8C25-F00AC857C7F7', '81788721-BA50-44D0-A8F1-9A324010B8E0', '4607039973914', '  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68E93DA3-4FE7-4EA7-83E2-DE5D54E2829C', 'FD9404BD-67B8-4B9E-98BA-5DF9C6318C3F', '4607039973921', '   . 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A23873A4-952D-44A5-B807-DBF14DCEDDA1', '921DA7F1-4FC2-4612-8098-4D287FEF9AFE', '4607039974010', '       150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEFEE094-2125-4C34-82D3-431781C8A7CA', '01F3927A-CE88-45EB-95EE-00D7BFCFD6EA', '4607039974027', ' Dr. vistong    -- 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEF07DF2-313E-46CD-948D-9788AC8684EF', 'E3565C7F-BB78-4AEC-81E4-1149252DEECF', '4607039974171', ' 500  160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B995276C-4E6D-4A2F-A472-6B81462BEB90', '3973859E-55E0-4CFD-9174-71609A3634E0', '4607039974188', '  /    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('837925E2-8B08-46BF-A19B-B600305049A7', 'E07465B4-689C-4F6D-8D07-2EE0D913D0B8', '4607039974232', '   0,4  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED284C37-C7F9-46BE-9E98-3A6B37CBBFAB', '598DE62D-005C-42A7-B85F-B0C0A2BBBC5F', '4607039974256', '     1,7 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC16591D-5E8D-42E4-82E7-F186BAEAA616', '7C64A0E3-02D9-447E-B742-A95642B5B2AD', '4607039974447', '     2,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33B544BD-290B-4916-B344-B7291F76A11A', 'F0658B8B-91C9-4839-A197-509BC1E9B461', '4607039975154', '  0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EAB3CFB-21DC-4CC7-ADDC-AA5E604BBDB9', '85908E55-D66C-47A4-A42B-706CB7E7AAC5', '4607039975161', '  0,41  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD7ED034-BAEE-42C6-BDBB-A234F1767BDF', 'CB61875E-6B19-4254-937E-D84C19DEFBDC', '4607039975178', '- 0,3  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DADC8608-2B83-491E-9BF5-50440E98BBB3', 'FF1E8587-8957-42F1-A3E1-D99D9A50817D', '4607039975215', '  -  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7C84827-0CE6-4CCD-ACF1-D7FF83645396', 'D0E1529E-A59E-4DE8-9379-B33F9C245400', '4607039975246', ' 0,39  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08AB2776-AAF5-46E9-8F2E-D6C1F97FE74F', '1A09B867-EEFF-42FF-B62F-109D9D80A5D5', '4607039975253', '  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76B08A07-9EF4-47A4-ABE3-A66F98F0695C', '666A35B7-E530-45A4-A317-928D11B89820', '4607039975260', '  0,5  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF402672-F2C3-4E29-9B01-31972100E461', '1E076626-9809-4587-9C33-F178E789DECE', '4607039975284', '  -  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B720BFCE-2F71-495B-BFF6-7EC468BCBA84', '41AF460D-534A-4DF1-A04E-365C40B3757B', '4607039975338', '  -  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B8F0792-CF06-405A-A352-0F18BDB3885B', '72255A38-2DA8-4949-A315-F50D9BFA8441', '4607039975352', '  - 0,4  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EF9D365-0EB8-4A4E-A2D6-C217FED83C88', 'E8DDCC5F-C803-4B38-9673-E860FD78B4B1', '4607039975369', '  - 0,4  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66FCC173-549A-44EB-A681-9A0E1F9E230B', 'EDDD6773-7EE0-4CD7-8B80-D983F0DBC79E', '4607039975376', '  - 0,4  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9214A0F1-36DB-43C1-8F93-A502AEFDAC03', 'AA94A24D-68CB-4B66-8AA9-7CF58E319E47', '4607039975383', ' 0,5  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03FB4C86-6369-4208-9128-3D7CCA753AC1', '8589811C-B0B0-412B-B2BF-029DA0A60075', '4607039975390', ' 0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9951D615-67AC-4C8A-8963-1D11CC8C3655', 'A120810F-F881-4AEE-8266-C9023F13D491', '4607039975413', ' 0,27  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F72EC440-2294-479A-9BCB-B1E4E858098D', 'C6987945-CBC7-424F-9147-A5A20661FAFB', '4607039975468', ' 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47947FF0-B161-40BA-9E03-D7A1DE43B65E', '587752B3-E595-4606-B675-C5B489C45F1A', '4607039975505', ' 0,5  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF5152DB-AF15-4C7B-9A94-EE7EA470356A', '6FCDE6F2-9C74-402B-BC3A-74BED0EEED3E', '4607039975567', '  48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23FE06AA-E441-41B1-A849-BC4A02BC6E51', '2993761C-3334-4D18-B4C8-28E02EA77A06', '4607039975574', '  0,5 36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11515DE5-B887-41EA-8255-1A9ED545F0A7', 'D8FF96AE-A979-4852-B33E-52A17F33E902', '4607039975581', ' 1,6  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A44B025-FE24-48F1-8634-771D4DB6E180', '9BC23028-AA6D-4033-A795-EA8898AE9C0A', '4607039975604', '- 240  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98162C21-0DCC-489A-BD95-1A70D97DAAAF', 'F0A32F40-7DB4-4C05-8F0A-A732D2620E70', '4607039975628', ' 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDA387AA-1C13-4B2D-AFB5-71DC6B7A8DAF', '0598E4E5-8DD3-49B7-9920-50A048AB09CF', '4607039975635', ' 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1073D1AE-3D70-43A8-83D3-554336111E80', 'B3B4A5B6-6FA9-4076-8E34-E2384FBBCC60', '4607039975758', '      90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('616B5EC0-1D99-4CE3-9B31-3FF1F3C26D33', '67B0A56D-7FC6-4333-8DE2-437031A835A5', '4607039975772', '       90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('783D3E74-7A41-474F-A737-DFC8CAB1E33C', '27EDC8E7-6900-49F0-ABA6-905624924127', '4607039975789', '  3    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C526B419-587E-4402-9375-346BDE7BAF0E', 'BD5A07FB-F0A7-40C2-ADE5-68ED7587119E', '4607039975826', '      . 6, 12  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D588A2C-3DAA-4803-B3F7-ECE9E71215D4', 'B9A444B1-E7D6-485E-9A41-AC93D9AEACF3', '4607039975840', '  6 0,54  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E393AA64-E9BD-4878-A0AC-5F25CC567283', 'CD808B5F-1F5F-4EA3-A68B-555A44CF3FA3', '4607039975888', '    250 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D56FB409-C1F7-4AA4-9099-C96E9D59EA15', 'B59CDD74-EBA3-41D6-A78C-7714304EC3B2', '4607039975901', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86B7CA6E-6DB8-4CA1-ACF7-5EEF242A5E53', 'E057A5CA-2876-407F-9EB0-E4B2D8114B84', '4607039975932', '  12 // 0,2  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FCD1309-A0F1-43FF-AD7B-A900DA3C80E4', '5C865870-32B1-4393-9C10-A7597A1EE77C', '4607039975956', '   // 0,25  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F111EF9E-B841-425A-975D-1B8D2A4210B4', 'E19C0EEA-D316-410F-99AF-4FADDD9D2742', '4607039976045', '   48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60969DAE-3AE5-4852-99E2-17AF5B9F7E69', '36442825-9491-4798-BBA8-12D1C670DBE6', '4607039976052', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71E66834-7EF6-4497-937A-243F0EB4D29F', '0970C537-BA58-4966-898E-3D60E93309E8', '4607039976076', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8397A86-4549-4031-B72E-9FFB89563DD1', 'DBEF1FD5-6CA0-40FA-AD8F-F927F735E376', '4607039976144', '   36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CB9C704-6A7C-4211-A5F2-4A3E4AEB2089', '04022C42-43BD-47FC-B5C4-8C6FD5683960', '4607039976151', ' 0,46  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38D82BDD-4764-41E8-9886-E705F2052F55', '573F5A11-7938-4C26-A436-56AFCC769453', '4607039976182', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34AC7D33-E343-4787-96B4-BD901306AF82', '7DB55616-5555-4B28-841E-05718293B052', '4607039976199', '  1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B525BE1-D532-400B-AD23-037E5D7A0498', 'DF85FE24-7F6C-4001-A73A-F264D9AF6AD9', '4607039976236', '   0,4  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A684466B-71B7-4F6F-8F56-03E29CA8166B', 'B837B903-436E-4085-8599-C45D2AA9A940', '4607039976243', '   0,4  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90204F78-8225-49E9-BFE1-6703F17E5CCB', 'BB41C69D-F3F8-4E9F-85A0-31B1EBFA1A30', '4607039976250', '  400   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('562C9836-AF8A-4DB5-9277-39445048BE8E', 'AD9B9554-5001-4EAD-A040-79FED1761939', '4607039976267', '   0,4  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75C4D2AF-D413-4D06-BD02-5D9F8493EF30', '4CE7CF9E-6B8F-4263-8AFF-1BA80A292185', '4607039976274', ' p  0,4  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23F54549-A959-461B-874C-C58C63D0435A', 'CE7CCC3C-96E3-40A2-AD69-8F0702AB16FA', '4607040313587', '    300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77F4BCEB-0656-4EF2-B0D0-9784B17C2BC0', '5322E81E-6C1A-42FE-9DD8-436256EC9B2A', '4607040313907', '      300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('269D7A40-FF4E-4377-8404-C7306BD4F72A', '39946B1C-0C65-49F8-AB4D-D8D9D00DD680', '4607040317905', '    /    600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEE94C8C-EF1C-49D4-877C-6AAE0A786DC8', '27076C47-351B-4B30-84E8-96045B64ECC6', '4607040640638', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7528C0CE-88A1-4E2F-9213-8BF49B2861DF', '35A54B11-E018-4F8F-9510-9A6DA572F60E', '4607040640645', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('471B1F18-34A9-41E9-983D-938BE40B22CA', 'E64951B9-3ED2-4BB6-BD31-62D18D4DF1E6', '4607040640652', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC7B2857-CB4D-499B-88FB-DEB1308CE7F9', 'DC002BFB-5A51-472C-9E15-E17AB6646502', '4607040640669', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DF14203-3896-4E32-AD9A-1D2911AD64D6', 'C3440E97-F8E0-4CC5-98A6-BB69C52458E3', '4607040640676', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95014458-9E0E-4DBB-955B-AF60BFBF1EDE', '6D751125-59E3-41B4-B15A-339FD75A1534', '4607040640751', ' stoppr.  / . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08DA03CC-5A59-4BDB-B979-7F1E65B5A70C', '48502580-771B-46C7-8FF7-6BB26CAC1F30', '4607040640782', ' stoppr.  / . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E85D683-74B1-462D-98E8-D401AD56E822', '24F30635-FC66-46C1-95F0-4A3FC594BCC3', '4607040642250', 'Stoppr.    / /1-4,7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5532D2EE-092A-49B7-BE8F-C617ABA65904', '1F6A7FA3-01D4-4346-A1F6-D6070F400725', '4607040642267', 'Stoppr.    / /2- 4,7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C135293D-709E-4366-B4E8-5EC2D7D84F17', '202CB0F6-8350-4E32-A67D-06E23952394E', '4607040642274', '      3,7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C96D9BE9-0CC5-49F8-A0CE-AB165FE5E79C', 'BD9F5C05-EB5B-44C5-853D-A9DC7F005A96', '4607040642533', '    /  /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBD18F32-2468-4AD4-AFDA-196178BC85E9', 'C70BB3D8-C877-4CE6-AA15-34BBCE714C6B', '4607040642540', '-   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA0249C3-4D7F-4710-8FA5-2B00B5B33542', '7062C60A-3D0B-4D50-9C95-0952EF725962', '4607040643820', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4091C85-B891-4F97-B94D-96A67A889EB0', '73219F9F-B6BE-420F-9F18-3BAF035E14A5', '4607040643837', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B97DB1D-3D45-4C26-8DA1-7A77BEB8E5AE', '13AC886B-5751-425E-B3E8-64703A82A685', '4607040645411', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD3C03A8-2333-4A62-B131-A59BE2027C29', 'B067F37D-B90B-4DDC-ABC3-24BA7F42E1F9', '4607040647620', '    /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('554A2972-5F49-49B4-BC6A-F75CB7E1F1E3', 'AA610C46-914B-4BB4-BEDD-4D9917E9D799', '4607040647637', '    /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('627B5E20-4876-42CA-978C-C64D7201886E', 'B298C64B-8DE7-4D5E-852D-ADC7C8734097', '4607040649655', '.    3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF61EA8C-3A25-46B3-A14C-B373F4FFD622', '27076C47-351B-4B30-84E8-96045B64ECC6', '4607040649679', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60AC82E9-C69C-45F2-97E1-D54F52E0883E', 'C43FA8CB-938F-4751-9F4F-FFF16C602CE6', '4607040649686', '.    3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6009F82-A863-42D6-A406-2B90A698AF2D', 'FFB3BC73-2A44-4553-B7DB-9AF7C291215B', '4607041020156', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACDA0F4E-7E9D-4400-9184-06DC7B05B731', '91D68FCE-F636-45BF-80F6-1FDD50E94BA1', '4607041020163', '7-   /    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5D1D1C3-DB0D-4AB9-81BB-B878353C1983', 'D6C8FFC1-E2AE-4BF8-B043-AB3C4F697BC9', '4607041020446', '    - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6A74A32-E578-45A5-B754-51D9AA9D3268', 'EEF44DF5-E9CD-4F85-9AA2-9D8550F553F9', '4607041020491', '7           75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A84BC8B-03D4-4FFE-89FC-58E27B7123C1', '277D9E54-CBB9-4F47-A6CA-71EAF2B7A538', '4607041020903', '    /4,1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FD4615A-64DD-48C2-9D68-F8E81D3377CF', '863ED327-C116-4373-BADC-04F897ADBBB1', '4607041021016', '  / 4,1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A80F68B3-B35A-419F-BA1A-FD6C92892C07', '1A9BAA62-F4C8-4E2C-8D1B-F0EB40E772E7', '4607041021115', '  -     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F01D8E5-A2FB-4BE1-8369-83F4F6B57C0D', '50E8CFE2-DBC4-4A85-9BC0-61470BB27078', '4607041022280', '    4,1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03FF494E-8FDB-4C75-B1AE-732A46ECF81D', 'A8825CBB-F264-4938-B4A8-AFADED1A1E51', '4607041022297', '   - 4,1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEB9A506-FCD2-4301-AF98-5F4131B365D4', '6141324E-9025-434F-8690-2ED31984B1E5', '4607041022303', '    4,1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA4BC8BE-FE2F-4C9A-A40E-AA161B44097A', 'EE0844BC-20FB-499F-A963-5349A5278D94', '4607041023560', '-     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22090DD8-A2D6-46E2-833A-26903F2343E8', 'B11E439E-31B0-46C9-85BC-3735DEE0153E', '4607041024185', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4052E7AE-F747-4EC6-B5B9-D69593FF53DB', '9E92C3EE-DC84-4C33-9523-67E1545F93D4', '4607041024468', '       330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1488B1A-1439-4B91-A614-22ABA57AEBFA', '6F351DB7-1B66-4833-81E3-F02D206A9980', '4607041061012', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90A8DEF3-5F48-47E9-A601-365E4BE3A792', 'B661EC03-240A-4FF4-9536-9AE4A97B2C5C', '4607041061166', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED972074-592A-4A0C-BB84-CC685093241D', 'F8B21818-18C4-43D0-952D-9C96E86CAE34', '4607041061203', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5153F4F0-88E8-450F-B335-ABF3827B7BC1', 'D8947B50-8039-48BA-9EF2-2EA2D9661781', '4607041061289', '   20 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A29C83E4-AAD1-4291-B458-E84AB4C16C14', 'B0D4EFE6-3EED-4BE4-910C-9271DFE32888', '4607041061296', '    20 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F198451-30F1-4DDE-892A-1D8F5DEA2A5C', 'ACF99A7B-3337-4F58-ADFE-468F686ECC8C', '4607041061463', '  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1686094C-93A6-4825-9BF4-74FF167FEBC8', '373AE1D3-3BEA-409E-A701-1BF0B32067F5', '4607041061630', '   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFDE445B-41E5-41CD-9F57-CBF92DBC09CA', 'E9AF478D-E203-422D-BD08-100F818B2F0D', '4607041063610', '-     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6FED7EA-DDE2-4ED1-88CC-3EF9D03B8546', '7A62BCF4-AB17-4DCB-A2EC-5EBB3A018725', '4607041065652', '     2 / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC1C06D6-062D-490A-9FA1-246F514D2245', '436D01DB-50F4-4DF7-9EB5-C984D23C7873', '4607041065669', '    /   / 723', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5615E22A-C008-45C1-907F-C635FC182EF2', 'A15A63E9-C2DD-49F1-9D38-9BCC13A4C9F1', '4607041066413', ' / / /  3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5F3CAE1-7DE7-4F6B-8230-CB380B2ED50F', 'FC7853EB-57C8-4997-AFFE-904DC70F354D', '4607041066444', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B88ABB78-2940-4103-882A-4E27C3764744', '815CF491-7C9B-4AB3-B394-1E63BE23ABFF', '4607041066451', '   -  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39295FE6-721C-4F97-A066-A46CC127C2B8', '2C37DAD3-5E2F-4B08-BF93-9595E6195992', '4607041066475', '       16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C74167E0-0F54-4218-BF9C-54BEFBC8C0AB', '23FDCB2C-DB2A-4CD1-9356-A950ECC2322C', '4607041066932', ' 550  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94578F2F-B735-45E5-9D9E-463C0D565D7B', '889547B6-05DD-44EB-987F-8EBD9BC4D4B4', '4607041067083', '    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('379F1877-1E18-406A-B2B9-B149874FDC44', '3F35AC60-E4A3-4E5B-9AC1-1EC7FCEB26B7', '4607041067199', '      -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DC14EF2-11B4-4368-804C-F8ACCCD0BBB0', '52E254EB-0E4B-4DF9-8080-57DDF2FA2589', '4607041067601', '       7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95637EC7-F514-41B2-A293-A32A3075BF3E', '3DD6D45E-AB8A-49DB-A01D-677F6F5F6F7A', '4607041067663', '   -    . 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F39E659-5F3D-4E00-92A9-D14944D95927', '5D837435-E322-42BD-9743-1F177AEF048A', '4607041067670', '   -    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5929A685-1B56-4F54-B3A3-5F7FF60E0854', '4A38024F-ED84-46E8-BE8E-8299159FBA4E', '4607041067687', '-        30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6668AC4C-6428-4A00-879B-03FC00201F3E', 'B1A8CD53-8C8B-4692-BDD3-69995EE588D1', '4607041067700', ' 0,55  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D334D0D-0D61-4BD8-ACD5-3EC7F3C3065D', '4A40FFAC-C775-4D5D-ADF7-064BC96601BE', '4607041067922', '        7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07C6897B-C7FB-4C24-8411-11FB9939B3BD', 'D13FD578-E7C2-49AB-8F28-056C222C0D77', '4607041068004', '     2 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A7BC4A7-BA5A-4487-815C-21855424DF77', '829FF2A5-4A16-4683-AF67-42BA2CD825C2', '4607041068011', '      2 / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53D9E470-2C92-4952-9A88-3DFCDAF042C5', '47E526E7-5010-4DF4-A429-78CEDE8A5B38', '4607041068042', '       7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E8CF492-5245-4754-961F-62E3F9DD461E', 'D9610845-FBC8-4C8D-A6AC-C7C8FD0886C6', '4607041068073', '       150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E2C8336-48CE-4EB1-8842-949177B6E6EF', '5E4BE520-D90C-438B-8D87-0450DC5713AD', '4607041068158', '     /    14 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E5291EC-5D11-44D2-AEBB-902C01C76D4E', '6C2ACE67-DF7F-432B-B86C-427E26AFF8C3', '4607041068226', '  0,55  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BAC4798-3EC2-4FEA-892D-139E07F6BF96', '49AED581-8CBC-4794-BE3F-9A85B9520961', '4607041068233', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D287984-097D-41E2-9187-4F813532508C', '7C8C1946-FB75-40DF-9846-955CD3E2B4AA', '4607041068332', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CB95B42-AA57-41B6-B2C6-9E4EBB41CBAE', '9CFC0F70-8428-441D-8113-439C194BA0FF', '4607041068493', '      -   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8A49CAE-CC72-4F8D-92EF-4D5144B92BE3', 'C301C821-ACC9-487A-A611-472BABB53222', '4607041068905', '      1- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83644F7D-ED45-470D-A8C5-0774DC59E805', '407E03FC-4A7B-41CC-893E-0FE2A9BA68D3', '4607041069001', '    0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A17556E8-3397-4405-B9BD-DE57DEF41E96', 'C069EC2B-9612-4062-AAFE-738E337C2103', '4607041069018', '    0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32A0E6FB-A99C-4685-869C-7115320B87A0', 'CFCF1314-163B-4CCB-A4DF-11B4264B41FF', '4607041069025', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0112984-E53C-42A5-8BEB-50F5841BF6F7', '12439FA7-AAC2-45C1-A0D8-AD2EFC191491', '4607041069346', '  / /  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F13922E-86CE-463A-8236-41D71AD8E930', 'A84CAC88-972D-4E97-97B5-54CD4FF8A0EA', '4607041069353', '  /  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB634076-B934-45A5-A8AD-53082A4D0748', 'B0F32461-0F3D-4155-81CA-5B6368306FDF', '4607041069438', '    (  ) 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE5D3095-4417-4580-80E4-CEDFAFECFF3C', '59E94BD5-037D-433D-BE86-782CA077D6E1', '4607041069445', '    () 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89210708-8B69-4328-A821-FA847F13605A', 'F0E54A6D-DF6E-4368-97BD-AC1422E8C3A5', '4607041069636', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F7E725E-41C4-45E1-9461-81280DAC795B', '1B141C22-F35F-4292-8ED1-A922DB4A0F28', '4607041069643', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05AA80C5-DB22-4ED7-8750-5E417545BE82', 'CC663C63-C128-42C2-A6F7-752C4E01722D', '4607041069667', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('522EB790-9CB6-437A-A157-B81D89B6B5A7', '94B7DE7B-8DEB-4292-84CE-D2281DC3EDBF', '4607041291020', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B71E53D2-787A-4568-B54E-EF602CF74066', 'FA91313E-3C3D-4367-B008-9A3EEC6280BC', '4607041291082', '  /  1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B60C51EE-10A9-453F-B0B8-E7183DB8896C', 'E84FCD9E-05A3-46A4-9110-E57C8E7FBDD5', '4607041291297', ' 1   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('558CF677-8622-4609-93F0-65A1A2F9A281', '9C6FB32C-5435-4145-9AD1-CBC23EF6C389', '4607041291471', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE85E9CE-88F2-4428-9D93-D0B1F8AB9FF0', '281D204D-3D24-4E85-A912-382C66EFAD51', '4607041291808', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3696237E-52FE-4A56-BBAD-40B92E3215D3', '2402436B-BCA2-4BD0-897B-1FD29B549E6B', '4607041292119', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56DE4A33-C6D4-48D2-A048-0E0B2BF7201C', 'F1345CDD-AB31-47C4-AADE-C0BAF0E0CA5D', '4607043670106', '  CS-105  (  )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6C8E65F-91AC-479E-BA2E-6B4B2F7F170C', '9FE45B4C-122B-453E-BEA5-0CC961F8BE5B', '4607043670380', '    cs medica sonicpulsar cs-161 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45571B4A-1A35-47B6-B8A3-866E8E5ED24F', '6F7A27C4-A6A1-45A6-9BB8-A424389FD460', '4607043670410', '  .  CS-161 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F20F57DD-F248-40C9-8A27-A1218BAAE9C4', 'B5900945-EF76-4D19-AAC7-CD5E71687863', '4607043670465', '    cs medica sonicpulsar cs-161', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3BE501A-0593-4FD3-B795-F0AAD819EBCA', '5EE4FDDD-8917-4EF1-B076-CCB0861BBC88', '4607043671332', '   CS Medica CS-465-W', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAA13805-4CFE-445D-BE2C-343FB195DDF2', '46878EF7-47F9-4700-9C30-4C9FC5B8E10E', '4607045190015', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29736329-5756-4423-9417-A788690A6F53', '20D3243A-CC15-4690-919C-3A61437AF9D6', '4607045190053', ' 0,05% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA6F563F-F893-4B09-A87A-1E34F9D8FD00', '6A135D11-FFC4-4774-8D58-E5F5ACE1B8D3', '4607045190114', '  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('374D6AC5-E306-42C7-8EEC-270FF53FB680', '5ABB421B-F666-4A57-9E83-B761E1DD7294', '4607045190190', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F4A4848-9088-4981-9621-2D30858A6CA4', '0C3C105B-A118-4C1B-BABB-67923E87CDB6', '4607045190275', '  1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F0571EB-A4FA-4DCE-BAA4-461C72124572', '2E3404D7-8BA0-4F83-B50F-79A5FD4E2B82', '4607045190282', '  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF1D0F6C-1A60-409B-8F36-32BB3352F92B', 'B1AB603B-371A-4353-A2A9-D4B1E4F43FD0', '4607045190299', '  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAF045C4-C051-4CA8-BF8D-D486639A9211', '09774515-0F4A-4A4A-ABB9-9D3E2A0F3599', '4607045190305', '  1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5705B371-D0F3-400D-9B41-0455E2BC63DE', 'A862D53A-ECB1-4589-AC7B-6D5AA2C90D07', '4607045190756', '  1%  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C62599E0-727B-4136-924F-0C0242F81DB6', 'E133DE91-28DA-4349-983F-D32F07D7E830', '4607045190787', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F0B09A7-A4ED-4BF7-A816-E134292531FB', 'B98A1D42-40D9-426D-98E8-CCBA493C5FB4', '4607045191227', '    15  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06491BE4-7600-4E9B-8E3B-6C05CF8803C5', '59A3929C-0EDA-49BC-A954-1F90F613C895', '4607045191289', '  1% 4 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25EAFF33-CF6C-4061-BDF7-DB10669530D3', '538508B5-1F7A-4A22-819F-7899389460BA', '4607045191388', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2AC80AB-D137-4359-9515-32B3A6C936BB', 'FD398B91-949C-4A2A-98D8-7899F6A2486B', '4607045191425', '    /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D13DC07-04CF-496E-AC36-4DB53CF2E7C3', '7D0D16DD-9497-4088-9123-064BFD645675', '4607045191616', '  5  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B46BDBC-EF47-4AB4-AD9F-EB4301032717', '14F34DC6-7EE4-42A7-B9EC-7A36DF04EF5B', '4607045191647', '   /   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1ABB1AE-FA1C-4D44-A7C7-D189E403A05B', '91898F96-BF7A-4225-8205-FA4344A617CD', '4607045191708', ' 0,1%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91F3EAAF-5072-4153-A5D2-BA9F802FE4BC', '07E337DA-92B7-491B-8D2D-3F2429E32056', '4607045191746', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC967CD3-4DDA-4027-BD0D-F029947A9709', 'BA8360E9-C845-43D5-9C4C-2AA3ED5DF3BF', '4607045191777', '   / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60C53BAF-B594-44C9-892E-34FD85AD837E', '21FF4654-0A61-4FCF-B476-374B10E41DCB', '4607045191784', '   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5E20325-862D-4F62-BD2E-73B2037C83FD', '7AFC3443-81F7-406F-A81A-94CE584E77A2', '4607045191821', '   / 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('941D12C9-2FF7-4166-AB40-7175ABC5BCC9', '8D2B6E1A-3BE2-4F04-ADBC-46A26281DD20', '4607045191883', '  1% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64421610-A5A4-4572-AAC5-F98683ADC910', 'EAFBC067-036F-4255-A926-35572A365D82', '4607045191890', '  1% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24B728D3-EDD8-427A-8B49-CF977AF55E1B', '3B8046C1-BE6D-4588-A21A-BF9E25A1A113', '4607045191920', '   20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FE8A3ED-C801-41F8-8492-D93F267D1C77', '91A1B50A-6C81-4376-B38F-F9DFBD314F9E', '4607045191944', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BD7EBC5-921C-4981-8A55-09E30A39F8DE', 'C4AFE6B0-38A6-4BEC-A478-6D1D4D865F36', '4607045191968', ' -  15 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80F8AEB0-D484-424F-BFAD-5F5D71376251', 'C8B0F024-08D0-47E3-9483-C0226776CA85', '4607045192019', '  0,6 +0,5  10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B7A0C85-7023-4292-B521-F40C5070B632', 'C8A034E6-080F-4CCD-AADC-D1E28279F3AB', '4607045192064', '  0,1% 8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88B1A5D5-378E-4B53-AF6C-8BD9FDEE045D', '0CC2D065-9A0E-4469-9771-82348BA9D185', '4607045192125', '  2% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86231919-71E2-4359-B129-48CBEEFCA8A3', '99C63EA6-BA5C-4407-9A35-9DF992D365E3', '4607045192262', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('530D42A9-E0A5-4B83-9A41-3E5EBB6D6925', 'A19253D6-10DD-41FA-8A0D-75352E91EE6A', '4607045192279', ' 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1895809-DBDA-4841-A0DA-9B3BD8CDC8DA', '0B323210-DA2E-467F-8B9F-6F22274CAE11', '4607045192293', '  50 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F040704-4DA8-42B8-A9BD-33F39DD12F84', '5E85F2C5-A3E7-44FD-9AA6-25DDB3327FF2', '4607045192316', '  /   /  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28DF8913-4FBA-47F5-AE29-032D7F5F52D1', '917426A3-FCD9-426B-825E-0ADF43AD2410', '4607045192323', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49A993FA-ADAF-4B8E-952E-D5B1F2030F51', 'AA2092C9-3318-4ECC-A095-E1447240E8EC', '4607045192347', '    20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5681B03-B083-4D7B-ACDD-BD139288363E', 'FA0491D1-7C2F-4A85-9BD4-2CFCFF7F912A', '4607045192378', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4326A3F3-E80D-404C-9BBB-0036286D97F3', 'C2B808EC-2381-4D95-8C81-94C7BD3287B0', '4607045192439', '  2% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E8D37F4-AE1A-459C-BE22-8FA21AF41F6D', '847A536A-D750-4688-9EE9-F6B2D23B87AF', '4607045192514', '  12,5  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F56DDD20-AAAE-49C2-8B22-47A7166FEF1F', '9B969A5B-38CB-437A-AE71-40C80EBA41FD', '4607045192606', '  1% 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C688E2D-F9D2-409E-9ECF-4D5D8725D25D', '197A85A1-4A57-4614-AB1E-3DFE8A050B07', '4607045192613', '  1% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72540A8F-D573-4EAD-AA10-42E8BE86A59D', 'C928820B-0992-4B5D-878F-A22343276CCF', '4607045500029', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DD9EB36-5142-4AD8-8D5C-F6C91BB052AB', 'A778F8BD-92F4-4B2C-A92B-802BF137674E', '4607045500043', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89C1B328-EAAE-4DCA-9A85-5B567917AA38', 'DEB451B6-A174-45BE-8A98-44BD91CB2482', '4607045500050', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B7846C3-A708-426F-B269-CD7863ED9B1E', 'B04EC65F-4256-4373-B5A3-8F0F024ECB46', '4607045500067', '   // 2 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54C0C997-0580-4CA3-86C8-17F05ED5658C', 'C928820B-0992-4B5D-878F-A22343276CCF', '4607045500074', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F3AC64C-1091-47DB-8A1C-DA62CEDAEC4F', 'BA43019F-2CCB-4837-9286-592D875453D7', '4607045500081', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A4C49F7-28C4-454A-9C83-0F597B779A7D', 'EB389D3E-6FC4-409A-A75C-CB23986E3CAC', '4607045500098', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3EAAC30-393B-42A6-8FC7-FDEC6AA71034', '0F22068B-2CDF-447C-978C-3D2C98892888', '4607045580052', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FD2A6D2-594C-4D6B-B531-3E0DC21891A4', '87E803E0-54A4-4D29-8FF8-AF1590063A5C', '4607045580076', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('136B5AC7-8494-4CCA-BF89-D48C18634EC4', 'F8647B46-CDBA-4910-B6B4-8F91AEB3028C', '4607045580175', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB67F681-DA60-47DE-A264-2FAE60803C22', '8CB4AD52-60B5-41D1-BA69-215E6948663A', '4607046740271', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8816EE12-C5A2-402A-856A-EA071F4E164C', '1D5F869F-98AA-4A98-974F-86077490F627', '4607046740288', '', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FD89AE4-3768-431F-A0D2-2E80A58F6837', '46EF8E43-EA94-4D3B-B9D3-11E8C8B5F1A0', '4607046740295', ' -3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A074462A-67A3-4523-8FD3-8F20773AB0F7', '10DFE7A2-7EA7-40D3-B974-F200030D8428', '4607046740318', ' 7   70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99593336-730B-4151-ACCA-0A37EFEFC17F', '0B989757-BAE3-4173-BF4C-E29E508D2F2A', '4607046740332', ' -11   230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD3A94DF-5FB8-4AC7-8F20-C4A7DE83E61A', '5BA41F70-3BCB-4F99-9032-1FB381917FCE', '4607046740349', ' 13 / / 317', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0290FC0D-1C71-475C-8814-8709E0627B83', 'ABEBBE68-3BD0-4A7E-B20D-AD409E582C12', '4607046740356', ' -14 490 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05080C65-B1D1-4DF8-83B2-E533CAE317A7', 'ACEA6AE9-C0AB-4547-B30B-863531F92B9E', '4607046740394', '  5 95 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B18CA911-5D79-4F13-8AF2-956E169A8676', 'D81F3D63-CE0A-4BCD-98E7-450590E6E8D2', '4607046740400', ' -7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A4E1A79-5961-4A41-B851-3BC710647FB4', '8BAB47D4-934E-43C1-AFC2-A5DE9F186AE4', '4607046740417', '  -9 230 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C31671FE-D62F-4AA2-B322-7433B3134A8E', 'A7D2DA74-9B65-4560-8ECB-9DE7F572D38C', '4607046740424', '  11  347', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A30FC4C7-F02C-4367-8297-EB68358BCD9F', '4FED493F-D9AC-4B8F-B5A0-FE78445CAD96', '4607046740431', '  13 / /  // 483', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9369314-8400-4ACB-A85E-77FBBA368C40', 'EE42AB80-5206-4429-AE6C-08B4240B313D', '4607046740455', '   . /224/ 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA0535DB-404C-43AE-9044-141E5B4DDB29', 'BD86B200-7AE3-4090-BAD0-528989B594F4', '4607046740486', '  / - -01 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CF11141-0E65-4B22-BE0C-29717375BDC9', '52D1434C-8391-4645-A756-49982AD29469', '4607046740554', '  - -01--2  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53CD65E9-823A-467F-809C-10A73D8A493B', '909CCEB4-A308-47E1-9E38-DBF843FA2709', '4607046740561', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E694E8C5-B461-4DF7-B08C-601F25F8AD2C', 'EB33C063-90DD-45D1-947C-62FAD20235F0', '4607046740585', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AC93BAE-52AE-4363-9EFA-DFC792C5DA05', '4680BD5D-CADC-4533-A19B-46BE412BC467', '4607046740684', '  - 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E7D7077-7C7C-41CC-9FAB-C114C5B0AD39', 'F7CFD550-6576-4780-AE52-A51C71251293', '4607046741087', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4811AF65-5CBC-4A16-A6C4-29C4C9FDCC5E', 'DC7128E6-F00C-4599-8E40-2973DD17C2B2', '4607047720012', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77986080-1308-4C73-8C17-4203824F825A', '2D7EBA00-672D-4F53-8DEB-7DCEC2D4CEE7', '4607047720456', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4F51DA8-05B9-4847-83E2-E7E7309ABE10', '59431894-6C63-45C9-87E5-C47887C2B894', '4607047720555', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70FA6599-60B2-4B92-A75D-5E08E2340420', '5407E7E0-A8C6-47D4-811D-E5303A010661', '4607047720593', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('887C3F16-D93E-4437-BD83-4BBB42D897A9', 'E4AE84F7-3DFA-4489-85D8-832EF9A23CD6', '4607047720951', ' 250  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC9AC689-4709-44CD-A08A-E547FA142E68', 'CABD061C-8492-4672-A6DC-777B70415F81', '4607048350478', '   0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('316DF9CB-3981-4C3B-9A69-5156812CD475', 'E5BD8342-1D3D-4AF9-B4A4-A3708E558DF7', '4607048351963', '    150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2726CA7F-2731-4464-9040-496593D832D6', '75D401F6-E1AC-4505-BA6C-5E6E83BDDD09', '4607048760024', '- // 5% 5 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0737C390-18D4-41BE-9323-FC7D0E1F9F27', 'BF78B54B-26C1-426C-B80F-78259A4D11F3', '4607048760093', '    5% 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4429E505-4EAA-45D5-B355-621DEC11D813', '39BDF8CE-79D8-4400-9D7C-F93C67E1972A', '4607048760109', '   1% 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C13DBAD3-7513-4E05-B156-0B6800C4A6E4', '6CAFE620-CF9E-4177-9E10-F13840DDACEC', '4607048760208', '   5 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB037BBC-7D5C-45E3-BAFD-115F5834D4A2', '8FE7A65C-FD6D-41BA-9D25-EABCA293A287', '4607048760222', '  1%  - 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D04ADCF2-2727-41FD-984D-006DFE661A7D', '25B2738B-0EF0-457C-90B1-16ECF48DBAF6', '4607048760239', '   5%  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55335242-9EAD-48B1-A9EE-6FDAAE5D151B', 'F2EAE28D-6F69-45C1-8D35-EB0EB797C174', '4607048760246', '-  3% 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91B65AA9-2DA9-4E10-AA97-16525B6BD364', '24D69670-B008-44FC-B194-0070EFD829C6', '4607048760253', '- // 5 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B888096F-55D9-4225-A095-266D803C8DA5', '689DDBED-B041-4223-89D7-3B9EC9716524', '4607050179838', ' /   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B938082-D454-4826-8410-4D5A96A98D3A', 'ABAD8D77-9BB7-4417-9D45-A2C2CBCF8124', '4607051430167', '  220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('815796B1-1667-4B30-80A4-AC1D5CDFFD09', 'F1642DC6-B1EA-4B17-AE0A-3AD7784489FC', '4607051790322', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23F96EAD-A441-4DF8-BFC7-F67A2BF8ECBA', 'EE68AFFD-D121-44F4-AEBE-C60AB4993106', '4607051790360', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71E38DB0-E193-4163-A523-0843A2BAF27E', 'A53498EB-0054-404F-BA81-352D9ECB9961', '4607051790599', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE4015B2-1500-4D7F-9C77-6B441E2E9B07', '75D7DBDF-6F76-4DCA-95AB-0A9E26FC8E75', '4607051790605', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED16B439-1452-4CDF-A4DF-B69955DDA198', 'CC5A6DB2-6FCD-44C6-8E4F-1F4D9608827D', '4607051790612', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72E1D93F-96A5-4138-AA0D-0AF93D087057', 'EA540E17-E613-4403-95CD-028D35D6FE1E', '4607051790650', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('072284FF-5BA9-4E94-A131-DDC793BC7260', '5B6F68BE-9A54-4328-90C4-AC7731007280', '4607051790827', '    140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E250CD35-DA22-4A2D-8423-4E0AB2912C14', 'D6C59A92-74E3-45B4-956E-4F6C27224B2F', '4607051791404', '    50', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D54EF133-43FB-4C43-A1A1-08274A2C962F', '56699400-8A04-4C51-A72B-5AB888000011', '4607051791428', '-   /   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC146EF4-583C-4548-A056-EF53F4A16BD6', '0B564060-BBE6-4AAA-89EA-393A562A3ADF', '4607051791442', '  //.. 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF92046B-1B5A-4555-9E0A-FB160187DA09', '9E515D28-6854-4ACA-88AC-13965F36D526', '4607051791466', '-    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A70E85E-434D-4C85-951D-6685997F4FB4', 'AAFE12B2-7F8D-4FC4-B1B0-D0E38B0B245B', '4607051791930', '   // // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E3C4E1F-630D-4C81-8D58-05612F90A1CB', 'DAA2CC2B-2D9E-44C4-A608-3D53327D3E89', '4607051792135', '   // // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('953485C5-F828-4097-83D5-211EFC219B1D', 'BD00B538-95B7-4C12-81BE-C20761049811', '4607051792852', '   () 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B374D5FB-1C43-45EB-9BC0-2F6F2C22E901', '288B4968-DCBD-4E6A-AAFA-38E3814E12C0', '4607051792876', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67CFD284-6200-4B46-9579-BD73D3968460', 'F1642DC6-B1EA-4B17-AE0A-3AD7784489FC', '4607051793507', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DC85499-0E73-44D3-9E41-CA55FCEA58FE', 'DE7D7DEF-E497-44BC-BBED-185BC1C98E11', '4607051793514', '    . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D116F93A-C3EE-45E3-9F66-32E627F81BB9', 'D3A60237-48BE-4A4F-8DD1-148945815C7E', '4607051794061', '   / / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('678A7D46-2B8B-410A-96D5-F3BA827F315C', '2E6B65FC-4FB3-4904-84CE-860E7CE101F0', '4607051795587', '    - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0CFB0A7-DE37-4302-AB3E-C78F77FAFC37', 'CBE68F63-12F2-4B26-B46D-0171FA4545FB', '4607051795723', '    0+75  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DD00F5A-FAA6-449C-94DB-6518D37849DA', 'EA1B7913-25B9-4B11-8D5F-6F67AEA8183A', '4607051795761', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9E77F7A-C3EA-4E90-A6AE-547DB8C365E1', '048CA5B7-448D-480D-B6E6-ED754DA86679', '4607051795785', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9864F0CE-293B-4592-8023-43B40610BEE5', 'F208EB0E-C11B-4754-84A4-B24294B7070B', '4607051795808', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('902E909F-CC5C-411D-83AB-BEC3920DE877', 'E284DCB3-C336-4818-80C8-857853445321', '4607051795822', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24911EC0-6985-4AAC-9742-840F04679555', '1C1F6ED6-3961-4ADB-8DE1-5E4499438D0A', '4607051796072', ' -    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D6BC95C-95F4-4E57-8B71-5ECE94339388', 'F95CB72A-DBB8-4463-930E-85918FF6FC03', '4607051796089', '   . 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67C4737C-AFA1-4082-99A8-9B4E3ED94048', 'EC39A94D-2653-42DC-8F29-329817860EFD', '4607051796515', '   /   //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90EC2A0C-51D3-4CE5-BFA0-8353EE96F74A', 'D8DF7494-5383-4F6E-990E-002AB376D11A', '4607051796522', '   /   . // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0090D0E-BE49-4979-B855-DBB77ACBE542', '2DAB58BE-E56A-436F-B0B6-3B872A4E1F82', '4607051796546', ' /  / / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE34A3BE-BF41-420B-A3DC-7F013CD2DFC4', '66A41A2E-DA00-4874-A221-C89C9D5A85ED', '4607051796553', '   / .  // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('009BA104-90C4-4EEB-8E5E-9D7057D2D9C3', '2A10FAC3-34B2-4000-B10A-63D897271187', '4607051796799', ' /    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B1ABE9A-2C76-4173-B52B-538CD08CE715', '20FE4B50-A095-4D92-B625-3F6B397DDA3F', '4607051796829', ' /  / / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0170574A-E4C9-401E-BEEA-5BC363317A15', '6DB44962-E8B9-4F41-B4DD-5FE48CBE7E53', '4607051797031', '-      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86D1B6D3-D462-4983-9D26-4015CD7CA338', '16F6FAEC-8404-480B-9D20-3D3D731B7326', '4607051797093', '-        50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD5B1816-EFED-4AF0-826F-75DE92A64726', '8DDE9D68-424C-47BF-9FEA-BDFDE748548C', '4607051797154', '    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FD3B37B-957E-4603-84B6-F430FECEEF4F', '39F5C961-0627-4E57-9DD2-2BED3B9B78FA', '4607051797482', ' /   / 530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05B0E060-56F7-4781-9CEC-5EB09EA52014', '34E63C40-30A3-4FE1-8AE5-F83C8AA807AF', '4607051799417', ' organic   /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6111AD92-4EBD-4258-AF52-97CE71C3EB53', '1B6C4AA8-137F-4858-8740-F87AD22733FE', '4607051799431', ' organic  /  -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54101C21-94FF-4383-B2BC-C22D2AC24770', 'E7081063-306D-452F-940A-16D97201CF18', '4607051910027', ' 0,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F81BF825-3281-467E-871C-E844782AE920', 'D9724BD8-2806-4E63-917C-977FA9BBB536', '4607051910034', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B069C8B-D10D-4487-8FF8-78D99E17FFEF', '4737DAA4-45CF-47AD-9DF1-8C877C1AEA9B', '4607051910041', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A4865CF-4A63-4D47-A882-0850A75851BB', 'F2F3C922-1687-49B8-8BFC-60B51081ABAB', '4607051910157', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C5CF881-73F0-4887-AD4D-3C1CC98CC49D', 'D1E429A8-95ED-4DEA-AA6C-A1C670368A59', '4607051910508', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBEEC642-1067-4364-829A-1D82B4DB0DC1', 'DF890007-1AC5-44AF-9A63-4CC4C9BF06DB', '4607053660203', '  0,05% 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2B48864-E774-4E07-A7D4-EC8748C1FDA3', 'FAB2D6C5-CAF9-4040-AF69-3ECB0D40D5D9', '4607053660265', '   2,5% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('961E080D-DC2D-4FE6-BC39-D425BA6D4DD1', 'FAB2D6C5-CAF9-4040-AF69-3ECB0D40D5D9', '4607053660272', '   2,5% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FAB3EC3-152C-4D15-9938-0A1ACC6C2F3B', 'B68259DB-164E-41A7-8068-05FB0F520B86', '4607053660401', ' dermacontrol  / 235', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFEF9D53-7D56-4C3F-BE7F-5558C7F19584', '12701A4E-963C-4B2A-AAAA-A1E65B5E4BFD', '4607053660418', '  dermacontrol  spf30 118  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D781B38-41CC-4F28-B092-4F9035E7A911', 'C7A570AF-B3DD-45FB-B3A6-55F90BCB5ECA', '4607053660432', '   / 15  118', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B50766B-9254-4CA9-B8C9-2AB5B41169AF', 'AAC4F0ED-FBE8-4B2E-B3DA-B5FB7C2E1D08', '4607054703336', '  hunky dory 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('165499F5-46C9-4EEC-8F1E-6FC87787D212', '848534F5-9E08-48F0-9502-C05CB178F7EB', '4607054709000', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21C5733A-BDC5-46E2-8C09-09DBABA48EC2', '78130D6B-0B94-4150-8275-A462B40E0BC3', '4607054709062', '   /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E869E2D-9702-4F06-9758-0EAFF9879C93', 'B4951086-696E-43D5-961E-FA62FE97E352', '4607055130223', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97E8817B-66E2-460E-98BE-7B7A25A5DE1B', 'EB6AFCA6-D3E9-43DE-A215-51BBD46413E6', '4607055130230', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C47D3DA-3DC5-4037-8738-1E38ED3A0A47', 'E8034C07-42A1-4C1F-B52F-0AD91ADC1096', '4607055130247', ' 40  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8E1F562-8CE7-4788-B30C-6EC8AD80A28B', 'B7F3851B-DF5F-4E73-B640-7843E2725A72', '4607055130278', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DBC0F3C-88C7-4A81-BC26-C1D5709BFE6D', 'BA4B02B9-970F-46B1-A849-09BBECD62318', '4607055130292', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0C156FC-4D6E-423A-9823-57A8C8EE58A4', '8FE96B05-DCE4-46D3-BE35-FD4B15D08CE0', '4607055130315', '  1,5   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('208B7F0E-558F-4568-8C1E-399E4EFE8EE4', 'EF530C5A-9A65-4D54-9342-CE82E02D54A6', '4607055130322', '  1,5   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E41DE7E-B0E8-4F82-A6BD-6DE0D0AB3207', 'B580C946-E51C-4B75-881B-0374941951CF', '4607055130339', '  1,5   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48293332-9304-4806-B055-662ED6627AFC', 'EF12E665-0D0F-430C-B00E-DB414CE2E38A', '4607055130612', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72734A27-8CB6-409E-AE75-F6BDE2AEC973', 'BACED20C-12C4-4B66-B702-820DC4BDFCA4', '4607055130636', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7632FD8B-F40D-42AA-895F-686A7B6CA197', '7B00924C-44C4-4188-A429-73CB3CAAF4E4', '4607055130650', ' 40   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73C0C9A9-DD1B-4183-A200-5C46CE67AB29', 'FA9F2244-57B4-431D-931F-D88003993490', '4607055130667', ' 60   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8C5445C-D291-44D8-A01B-323466E45D55', 'BC8E4992-ECB0-4FB1-8697-F8A9735DB750', '4607055130711', '  500  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CFD9BCD-AE10-4293-A9D5-26A56DD2CA6B', 'E162B89B-3063-4245-9C59-26DA5257592E', '4607055130827', ' 75 /  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('019DF0A3-1972-4FCC-9ABC-B71EEB084D5F', '5684A62A-F0C4-46F8-A8B9-69AFE9A93B8C', '4607055130841', ' 75 //  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBCA927C-FA8E-42DF-9045-3615A19D502F', '786E17C6-09DB-401E-98F7-B4899DB7550C', '4607055130957', ' 75  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2FA2012-60D0-4EDB-BDE2-930B944D67F3', 'B5EB6CEA-B603-40D4-92D4-F8ECC11BD67A', '4607055131343', ' 50   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('448FF886-7FA6-4E1F-A7C9-178A61AF9FDF', '4A6FA2D4-04CD-4F0C-9568-4A1A74AE23E0', '4607055131374', ' 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99C8C845-624E-4831-BE4F-E2AB2077BC98', '1DF2E74F-F946-485E-A84E-4EF9081F3591', '4607055131381', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44B97B52-B0AD-461E-BBC5-F72AA541DB4B', '3BB22474-E0F1-479E-9480-6DE25D7CBD88', '4607055131398', ' 100 //.  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AC64CC0-3459-4E3A-97AA-981B7C708B04', 'F33FC1DA-FD0B-4833-82C4-4552EEC81BC4', '4607055131800', ' 2,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5376ECCB-74C7-4D64-AA38-D23281F4CC11', 'B2898158-6676-4AFB-B442-378572274171', '4607055132128', ' 40  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBA3ECFF-2CFE-45DE-AE97-5690BC73BCCB', '69BCB895-EBB4-41B9-A243-93188B1333DD', '4607055132838', ' 200  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('271F2252-F223-42DE-AC36-2BF5C4FC08CB', 'B6104832-0FDF-4CC3-BB29-3CDF51CEBFFD', '4607055132982', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC476ABB-B114-4D7B-A1F3-4C21D1F9C82E', '10EC6849-340A-4720-9FBC-632C6C11AD83', '4607055133002', ' 4  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EB75689-2C41-461B-A645-C42557D6D447', 'E0044D01-C6DA-4B8E-AADE-22BE555A6FCC', '4607055133088', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1052B509-66C1-4ACB-9D8C-95FE904A0BFB', '83666052-835D-4092-885F-48BD1968FFB2', '4607055133101', ' 8  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F845CDE4-FB9F-43DC-936B-1CCDD322E0C9', '733F95A9-1D5E-42E4-8A36-7EE6BC99D5AE', '4607055133194', ' // 2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04A3D648-5155-4B7C-88B8-7B7256C5AD0B', 'CFED03FB-5EEB-4437-9CBF-B91F321DCEA7', '4607055133217', ' 0,0025 //  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E02CB573-773C-4236-A567-220B44B3B95C', 'F06E58AA-FBA7-4B89-81D1-E5CAFA0550D6', '4607055133231', ' // 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1AC9613-A530-4928-A257-3746DAB36ED9', '77237935-D0E9-4DB9-BA9F-3A272F33C231', '4607055133255', ' 5  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED94DFAB-C9EC-4F73-9570-5EEC71CB1D24', 'A4F4C52A-430B-4608-9565-D273BE5C87FB', '4607055133279', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3ED08BB-0ED1-4E06-8B57-3D27E28206D7', 'D54AD392-6AFE-4449-9B81-1ACAFCC7393C', '4607055133293', ' 10  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D34D713-A91F-45B4-83F3-C37FBDCA21D2', '41D9F130-3B95-4C13-BDFC-0543FA6409D0', '4607055133309', '- 0,625+2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E2E3321-11A1-41AF-9083-F6FCAED9C7CB', '114F5FFF-AED3-40C4-AB26-C2820FA986C1', '4607055133330', '- 1,25+4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62910B22-E848-4398-9EB9-7CA3188D8122', 'F8C40CB7-ED14-47CF-B178-E709E7F5FEA2', '4607055133354', '- 0,00125+0,004  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88CBFE31-288D-48D3-A9ED-DBFAB3C6C22F', '9B0C86CB-71C8-4716-B370-D9BC1044771E', '4607055133361', '- 2,5+8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B00334A0-E9F5-46B1-B68B-3230524F84D6', 'D426FE0F-E063-4C5C-AFAA-B95272284452', '4607055133385', '- 2,5 +8  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD1338E5-D6A6-4233-BCD1-045B794753BA', 'C52F845F-37BD-4D2E-BC79-AEA33344F0ED', '4607055133460', '  60  42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F43E366-4BCB-41F6-ABF4-D65B54344FA3', 'A0FEF512-CB49-4A81-B6AD-2F0E3F030FF6', '4607055133477', '  60  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0B99779-EC11-4333-87D7-335E00531856', 'CA0FA6D1-632D-4C5A-BB26-66034E03F878', '4607055133491', ' 10  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1AB8C0B-F813-4D01-8680-47A01B111ED1', '75ADB770-4E1E-4478-9324-D327B564C3BF', '4607055134443', ' 5+4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF285A1B-911E-4671-B670-D8AD46110B9B', '6590B9A4-75F4-469F-9706-ADF767CC7519', '4607055134467', ' 5+4  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B361B207-9995-40DC-A8A9-6F696976DB43', 'EE568A08-FB01-4EDA-930B-16E7147A3760', '4607055134573', ' 5 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC5B6CD7-97BE-4512-8E8A-B63C88514EC5', 'F4F5308E-5ACC-49A1-9CCB-105BC6F6DDEC', '4607055134597', ' 5+8  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B79ABD60-837C-4428-ABC7-FF87FC5E2795', 'D05C0A6A-0362-4DEC-B86F-0C624E506A0B', '4607055134702', ' 10+4 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE689298-50E5-42EB-BA14-4C6FD8E04296', '7F459079-6280-4D83-A113-EB7A39A2E38C', '4607055134832', ' 10+8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F60B599C-4D1B-4CCF-AE7F-785420BDCDBF', '6C683A4B-7055-4E64-8A89-D1AE09A9B2A6', '4607055134856', ' 0,01+0,008  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FE17018-B9ED-4A4F-8358-1FF95B0E987F', 'C80D92DC-F030-4354-8728-ACDC3806AF15', '4607055134955', ' 10  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CD1C9C0-A09F-4C10-A795-AD2BCF1D35D5', 'FF7DCAB0-C2B3-4891-80D8-DC4728B6CDEB', '4607055135129', '  20000  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2622E8BB-11BC-4583-868B-AB46F6AD6EAA', 'BAD2622E-9C13-43D6-B4BB-A1E4381C2D37', '4607055135136', ' 20000  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07DE639F-8782-439E-B6B8-CBBD0672E9FF', '4D8080C7-F9F5-4251-98A3-B5982CCF8D4B', '4607055135266', ' 120  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('676827E8-729B-427B-B266-35E13573C431', '15FA43D3-A20F-4867-984B-37F88E5E5E6C', '4607055135273', ' 120  42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21C09521-33BA-4574-B194-2F840CEAD7A9', 'BC0BD6A1-95F5-46C4-A633-54EF82ED3902', '4607055135822', '  100+25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24F42B02-2E29-4DD1-B87F-FEF9DEAE37B6', 'A451CE65-1FC5-4760-AC09-31896462BB34', '4607055135839', '  100+25  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4B15524-8D68-49BB-8813-2F6CDB9E9459', 'B4CECD50-0045-48C8-8EF1-047E2E3F4C1B', '4607055135846', '  100+25  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD98984E-B738-43A8-8CB1-317FAE93B9B4', '5F2680DD-22F4-4FDD-A0D1-F42F064691D7', '4607055136218', '  12,5+50  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CDEA946-F270-4125-ADAD-E0D750F2A636', '1E3EB92E-55DC-46D2-9C8F-45C67321F73A', '4607055136225', '  12,5+50 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B98A884-5FC9-458F-84C7-6CADB1EED250', 'C80D92DC-F030-4354-8728-ACDC3806AF15', '4607055136607', ' 10  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBD09169-94DE-4D56-B02A-A5B596842064', '8F3204D2-4F41-49B6-A1B2-617A7B03AE4E', '4607055136614', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C81E465-F350-4E2F-9D1E-D2F2876ED305', '88FAB722-5BE3-4AFB-8BCE-09856D66A0D8', '4607055136621', ' 0,02 /  //  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B536051-74CE-4078-BDDC-D79625895390', 'EFFA7973-E085-43DB-8114-2B823ECBF7F9', '4607055136638', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('722E637E-3663-411C-9959-3BC367559402', '62EE0D80-ED60-48BD-8523-EFE718317411', '4607055136652', ' 40  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF278340-A812-4C1D-945E-2D83D11137E9', 'A44DA078-A28B-4D5B-AA0E-69CC996B3C5C', '4607055136669', ' H 10/25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7E8A544-628C-408D-A846-3092A3D2105C', 'C50E2053-F084-44A3-A206-D5D089F901CF', '4607055136959', ' 5+160 //.  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9FD10DD-E0D3-4319-BB87-7578133A4C06', 'C3C4610D-347E-4676-BEF6-CEB6ED366642', '4607055137031', ' 10+160 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE158A15-0A8F-4290-8C20-133F4E855A73', 'BBB130E6-BAE6-4C0F-BBBB-AA4842EFB7F4', '4607055137246', ' HL 10/12,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F4DD979-165C-4494-8370-69B7A3638465', '81A80F60-D014-4496-A773-10E02C26BC93', '4607055137260', '- 12,5+10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2685FE5-8105-407B-A00F-25E27CFB3726', '902F58C3-B944-43B9-AEAD-77DBE15CF6C9', '4607055137475', ' 0,0025  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6172BB6C-21F8-439E-A7F3-2E29C1F33525', '1A785FB6-E165-4F6D-9EB8-6119AA2988D0', '4607055137499', ' 5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12661D6A-BB1C-4AEE-A1DB-1CE7CF11B45A', 'F771ED77-8DEB-4608-9795-1D443619013A', '4607055137512', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32E3B711-9FED-4A14-B218-80C634C9605A', 'BB399AB5-849C-4E6F-B37D-06EC24AC0C56', '4607055137611', ' 20  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38D99546-028C-41D4-870D-1B9C0BEF4702', 'DE1E9E4F-C8A2-442C-87AF-BCD48AEBE6BE', '4607055137796', ' 0,005 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('398366CB-DECD-4915-B9A2-F08D5EAAB29A', '6FDD0FD1-F550-47C1-B3B8-AAF4A4B39BAC', '4607055137802', ' 5  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73614AE2-0064-43A0-B658-B7310D01EBA1', '7733D961-6CEF-4071-A05C-759D33C46737', '4607055137871', ' 7,5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5796584-DA59-4448-9B7C-FC174027EA95', '3BBD96C9-E29D-4342-9ACB-6D7C2484C10C', '4607055137888', ' 7,5  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30A2E5C7-B4A0-40B1-BC96-D4607BD32F51', '53AB0225-56D1-4727-8558-F535FCEDDE7D', '4607055137970', ' 0,04   //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85C2E61F-10DD-488E-9787-35D629D186E8', 'FA9F2244-57B4-431D-931F-D88003993490', '4607055137994', ' 60   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E74C43C-8A16-47EC-8F1C-E6E83C0077D6', '4565C897-3660-4109-996F-6D16B192F34F', '4607055138380', '  80  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E990D63-8FC6-43D2-BF7D-8589D954C79F', 'D9465AA0-797C-4B98-85DC-8D189976B1A9', '4607055138403', ' 80 //.  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EECA487-F42F-4069-BFCF-F67C7B5636DF', '828F0521-E566-4BD1-AA3E-1FF569EABC42', '4607055138595', ' 0,16 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47881BDC-19A8-47B1-AA8A-726D9378B259', '0210FD8A-EBD5-4009-99EF-3A9BE45231F2', '4607055138618', ' 160   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F39FB3C0-5E6B-4295-8145-18696237E3AE', 'F997EE7C-BF21-47AA-8B55-480F5D79F91F', '4607055138687', ' 5+50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8EC05EF-E25B-46D1-89F8-CB43583C2238', '810FFFD5-638F-4A80-9D08-29EDAA8838D2', '4607055138779', ' 10+50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('976D07BE-2E0C-4DD8-9951-31F70387F4A6', 'F12BE90B-EEC2-40D9-8939-7CF9A9513464', '4607055138861', ' 5+100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDB3A92C-CB15-4928-9AE0-E5500A915765', '418E233B-C26E-4F1A-BC8D-BADFD7D67BCB', '4607055138953', '  10 +100   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2169739B-F012-40B0-A347-FAD16062136A', 'C655A160-CCE4-4657-BFF8-02820CA03479', '4607055139608', '  5+5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD181F30-A2C1-4A03-9A1B-F810BDCC6822', '780A1A86-C5CF-4580-82A0-874C1CA62568', '4607055139660', '  5+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C27FB72C-7CB7-43FF-ADFD-16A339FFF12C', 'B42F514E-B769-4EC1-B12E-2A07CE13D62D', '4607055139721', '  10+5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB8EB03E-E12B-414C-9210-E04C73B71049', '305FED42-D0C1-471D-9D1B-D518D4A7A081', '4607055139783', '  10+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('374D7D22-D403-4937-91B2-48952B11601B', 'C7D122B1-C92B-4EA9-9958-DA6275649B59', '4607055139868', '- 5 +0,625+2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A584D6E-69A8-44EB-BFD7-E4EED8416B44', 'AF4B30A5-73FA-4B6B-AABD-3F7D55DFC83A', '4607055139943', '- 5+1,25+4 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1993B80-EC27-40B5-9007-47558AA1DC05', '887E9DB0-3239-4A2B-B286-496A83241180', '4607055139967', '- 5+1,25+4  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F587E30D-3A22-4840-B9FB-0EB9ECEE7D68', '9A4DA8FB-E089-40CF-9337-9F0CA175054D', '4607055560037', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('533A8869-6155-4014-8C5B-82212997C57A', 'EC2B3C9B-DC3C-4A57-AA83-218261525AC0', '4607055560044', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FD13079-7763-4F3C-BA04-BAA3AD4E0FF6', '338C418C-A526-434E-9C2F-3AA442CC080A', '4607055560945', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AEA80E1-E04E-4A69-BF56-117B04F62A86', 'FE3394BC-EF81-4032-9973-30E62170F4E3', '4607055560969', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C90F2A1-6F7C-4022-AF1A-AF583823400B', 'A6E5E5F0-8CD2-4862-8830-F3C9B2579534', '4607055562154', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12E59C0F-C8D2-408B-817D-816A265DF377', '7866ADC9-DC35-42F1-9D94-83913D35524B', '4607055562338', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAAC35FB-CF5A-474E-91D4-425DED79791A', 'D16AC7E4-6E7C-483C-8E48-CEA94EDE1552', '4607055563205', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D78E8171-18E7-44F1-B623-B2C0891789C9', '08B512F6-F5E9-4FF3-B740-F25BDF0A56CE', '4607055563212', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BDD3DC0-7F61-4BB1-8B64-A43758D261DF', '7A546732-EF78-478C-BB53-99FD8DF3ACDE', '4607055563229', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E4AC3A1-EFCD-457E-8C48-81D98DB0367B', 'D3E46FAF-F544-4C1C-9D48-B6662DB3D853', '4607055563274', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45CCEA17-7C50-45F3-B0BE-D2B3CAEDAD9B', 'D16AC7E4-6E7C-483C-8E48-CEA94EDE1552', '4607055563762', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21DB8C76-72F8-4A5C-879A-382032063D3F', 'F31C17CD-9D94-4610-AB1C-B6B5006A02A6', '4607055563786', '    0,8 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8932E348-AB82-4498-94FB-CC6805166DEE', 'BC6C1E6A-DD4F-4974-969E-4978E662C99D', '4607055563793', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41214EAC-C25E-4C3F-9633-209E06E83D25', 'B0BD1F78-1A3D-48F3-AC02-D99FF2838FB9', '4607055563816', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5D63A41-CB36-4194-9F21-7430D8CEC391', 'F612833D-1144-452B-87A5-B96EE7789F0B', '4607055563823', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CF9EB17-7218-4EDF-89DB-F516333107F7', '7866ADC9-DC35-42F1-9D94-83913D35524B', '4607055563830', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72DCE797-137B-45BE-B9CE-3EAB0C199A38', 'D3E46FAF-F544-4C1C-9D48-B6662DB3D853', '4607055563854', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5250987D-DF84-4CF7-A712-39EE476A6990', 'A4F67EF9-DEB1-477F-A131-B6600E4D66CD', '4607055565216', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C633BE8C-BB2C-4B55-9FCE-64051C144902', '9716D711-23FF-4D39-93DF-B4E5B1190EFA', '4607055565223', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B588F68-A5FB-47EC-854E-8F74289C7D9C', 'C40D4AD2-848F-49AC-A2D7-B4B9733317DA', '4607055565254', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C15C510-F2AC-4E92-917F-3ECD31D62582', '72BAEFDF-26BE-4D2D-8B91-4374C37B974C', '4607055565605', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82CA2AE5-E931-42BE-8183-97B5577ACC97', 'E2AA745C-B983-4B1A-BA54-61F2389378B7', '4607055565629', '   / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D70EE245-B3CB-4B7A-92F5-FBDA122FAED3', '1C60C58E-7355-4B67-85C2-5614BA5B92F1', '4607055565636', ' - 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB249863-E0B8-46F9-B02E-41E37EE3D244', 'ACF41313-80FD-4F95-927C-39619E2A4FCA', '4607055565650', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FB0412C-98BB-45BD-BC63-EA8D6DA1A119', 'EC38FDD7-063A-494A-AB50-0602737EEF53', '4607055565810', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AA33807-EB05-4E22-9566-A44E2ACB0E3C', 'F10EDD62-C53E-4BE4-8E28-4207B363B021', '4607055566206', '    // 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('528341A4-5B90-41DE-85E0-D379502D4EDD', 'F9B405D9-D4A3-4279-BDC4-DFEAA5EA6BD3', '4607055566213', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6E7988C-7A18-4C9B-AB63-1131E1F10C88', 'F31C17CD-9D94-4610-AB1C-B6B5006A02A6', '4607055566220', '    0,8 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F9BC32A-7010-4D4A-818D-3CB84D784835', '7855652F-E163-4D70-B822-FDA4C3BCF259', '4607055566244', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD2868BD-E443-4A8B-A7B1-364C63768B8C', 'B0BD1F78-1A3D-48F3-AC02-D99FF2838FB9', '4607055566251', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BECFD0A-A1EC-45D9-9005-02DC1BEE3BB1', '7E33226E-4C97-4C97-A88C-6B7A394D8596', '4607055566268', '  // 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('589291F7-484E-4A1E-820A-D85B00FD51B8', '95F643DC-5125-42CC-A3FA-47BE51CEA162', '4607055566282', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8451276-0726-4987-870D-10D09B8F3336', 'D3E46FAF-F544-4C1C-9D48-B6662DB3D853', '4607055566312', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9736698-E7CA-4473-B983-9035B4875F47', 'A00CB63C-C750-48A6-8B03-CCE2FA452534', '4607056060475', '   / 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FAE66E1-FC4F-49EF-9219-1816966DF51B', 'C092B70D-53B1-4BC2-94F5-DE1806A49FDF', '4607056060659', '   /. 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29D35E7C-4931-444B-897D-3AAEF80FE445', '3E05867A-760E-43E6-BB56-C5C96E2C4915', '4607056065012', '    0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('141E26AB-40D0-4AE2-9177-7055059B3B7A', '85299A6C-DB3D-4CCC-AC32-D5EE8733604B', '4607056260103', '    280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99D80647-DC5C-496A-B41D-024DC8025990', 'B71CBD9C-AD72-4A77-9085-73EF13F1CB27', '4607056260349', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5AA5045-DEDF-4378-9A8C-09E72E4423E0', '60B0B0AC-2CD8-4892-B975-CEC6238540F9', '4607056260431', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7953BFB7-73CB-4A82-95F5-9DC20286F3C3', '937359E3-DD1A-4059-9C7F-0BC0854C71BE', '4607056260455', '   / / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A97F58E8-C0E5-4631-8FED-088A2D36C92E', 'B3F764FE-5E61-4135-9B31-72BDC28E5537', '4607056263166', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDC2BAA4-1F4D-428B-B13E-E05988D54A21', '9566FA6D-18E0-4CA9-A2F2-57A0549A7BAA', '4607056264378', '    120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73CA3BA6-E773-4872-B5D1-A57B25A99C5E', '822EAC8F-2533-4BE4-A746-845C04F03075', '4607056266273', '     170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D51D5DB5-581A-4EE6-AF83-5638EDE26BB3', 'A09D3008-4ABB-4AC8-B2D4-EED106A1EE09', '4607056268932', '   my    170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AD2B9BC-6898-4E16-954A-6C554A3B4145', 'F1B936F2-BC0A-41BC-89CE-960D6100BA25', '4607056520016', 'Optimed  / 250 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A8AB1D6-3E51-4C56-84B9-A3803FCBC735', 'C8E737AC-7628-4883-9F12-EEFA6B52621F', '4607056520030', ' /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B793F148-A786-4B57-B427-FE01845D2248', 'D0F1CD9F-8366-4D5F-985D-9F0FDF19C403', '4607056520221', 'Optimed   /   250 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('219A84B8-6D1B-4D0C-8336-F5DDB8956BB5', '7D8E047D-E60B-4A0B-B4FD-62FE3B541AE5', '4607056520283', 'Pro  /   /  10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9D20B78-74D0-4821-A93B-24357D09F5B3', 'E2BEF250-EDB7-4BAA-9513-48F85D8E6801', '4607059540745', '  120  180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19962A6F-6035-485C-A197-AEEDEA654867', 'BCF177B6-1D71-404E-8388-C950A1FD672E', '4607060100167', '    1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25D0F59C-82BE-490D-A6C6-CA647B38C8B6', '198A5932-2B38-4AD0-9498-645040C865C8', '4607061252292', ' yes    / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA1BA52F-E997-43C0-B7FC-D8E1DED9C5C8', '9CA91E11-061D-4CBC-9B77-49AFABE91772', '4607061252315', ' yes  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53163144-601F-4E0B-AFE0-49BA0D409FF1', '375FBF2C-F4EC-4737-A6DC-8F739D5C9E8C', '4607061252346', '  yes+.   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BB5A728-1604-4582-BE9A-EA639C0D4A91', 'C4893DD0-DD5D-4E3A-98EF-59B9C138B065', '4607061252360', '  yes+   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('771DC434-DBB2-4483-B856-9EAD62A6649B', '6E7257FD-7D48-4DEB-B278-A66268FEE0F3', '4607061252476', '      25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A823EB8-1F54-454E-9924-51453E607A27', 'F04E2C1D-7733-4803-A5EB-51308AF9C3B5', '4607061252483', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('666DFC67-EF2F-4F8B-9996-0354C2C943E3', '1A3DD658-4276-4B26-8B67-6CD3D8C0E654', '4607061252490', '      25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA9C87A4-586A-4A29-974F-CE5DE69BE559', 'EF4D3713-985C-48EC-A92A-055A15C5EC66', '4607061252506', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDC1A095-8965-4FF5-ABF8-2C87219B3C4E', 'DB891D5C-A5C1-45DF-BC79-029A103E3B2A', '4607061252513', '      25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DCE5F67-EFF6-4F5D-B810-B394FC057E07', '783FAB5D-13A4-459B-A253-C4A2D9C33891', '4607061252520', '       25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63A6B759-D6BC-4049-AF94-173AEA8FB7CF', 'B294795D-815F-4064-96C4-FCFE2F7DED8D', '4607061252537', '   /  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F5B0209-43F5-4E91-BC59-75F35A5E401B', 'B936FA9A-0473-400D-BF81-8D48DE519C40', '4607061252544', '      25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F722DF20-DAC3-4A3B-946A-6819F126E75F', '8919AE13-57EA-48DD-8D61-1A21A7060F27', '4607061252551', '     25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('029F3715-F53E-4ED0-9180-5D55126861A7', '8F6F954D-532E-44FA-9289-77EFCB7FE3BF', '4607061252568', '      25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EC0D520-FB02-4086-A971-7A2563812C2F', '4E4F91DF-BE7D-4FF3-A614-C4E1C7D37AFA', '4607061253398', '          25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DCE6424-42D3-40F0-9418-7FA577F7F1F6', '4DDF4F7A-2838-4488-942B-232D37504613', '4607061253404', '       25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9E2EF71-ACED-4D79-B9FB-DE2FC1F63A08', '076B2F6D-F99C-4400-8F87-B33305F5EA1D', '4607061253411', '            25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('580D6915-F42F-4D5B-AEE4-A6C98E7D824F', 'DF74196A-89FC-4FBA-910F-817599C431F6', '4607061253428', '-          25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E0C614E-ED78-4BE1-A9A3-A94FDFC079EF', '505DF9AD-BC44-47CF-8FB2-7DE999ECAC67', '4607061253633', ' ego    .  . 25 3633', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F671C76-7E16-4C46-A473-FC330907855C', '843CFCB2-C048-4073-A17A-CEE79A11F185', '4607061253657', ' ego      .  . 25 3657 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6EB98AC-55DE-45BB-8556-BE17147074F8', '8E732587-FE22-420A-9ED8-B9FA336FF1F9', '4607061508672', ' // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EEEEAE6-C656-40C2-8285-759BD904F9E8', 'DCA08CFB-90DB-4112-ABBD-ACD8B37D1736', '4607061790626', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7AD4C5A-5D54-4F4A-8F88-6560931DFC91', 'E74DCE9A-FB90-4F7C-A74F-8EDC121B1FE8', '4607063890119', ' 100   / -  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AC5D110-C42C-4F53-9597-D0B42B1899AF', '84F06D8E-00D9-4A4E-9586-AF5B8FDB1B52', '4607063890294', ' 100.  /- /  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8639ACF-4C43-4F2C-BB74-060F12075D5F', '47F7FCD0-13A4-447D-9750-1942F0A614B1', '4607063890362', ' 100. - / - /. . 1+- 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A365E412-0503-4023-8087-B29BE779B500', '0A23EAF1-59EA-424E-92B3-82E41020FC57', '4607064291199', ' -      900', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C2597C3-9CB0-4D9A-99B2-BE095D8BE954', '5FF8FF97-451F-4EE1-A29F-18CE55F20B54', '4607064299362', ' / //   1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('739E6F30-EA7D-4F57-84E8-35216980D689', 'BB21B120-6C86-403A-9C6C-607DB1FBEB32', '4607064299386', ' / /+/   1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8605F06C-AFE4-45E6-9BE0-DFE03D96C457', '22C46651-8EA3-477A-B5DB-99F24164E033', '4607065714161', ' dr.korner    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D97FA7C-357F-4AB4-8723-E1AD597BC652', '7D91B79F-FF6D-4C3F-93B2-340BE66A889E', '4607066260063', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C70C047-649F-40BA-91DB-AE829D07E447', 'FD1F9052-B926-4CE2-9D71-4D561037ADEC', '4607066260070', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FC444BE-1A1F-4F31-A267-560192335F31', '8AD9511D-C181-4521-8098-C3A94BABE2D5', '4607066260094', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8C377DB-618D-4949-AF8A-C9E32A5F8D9A', 'E5BDAF90-2AEF-468C-8CCC-39B8D3F7A5CA', '4607066260100', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFBDC24B-B94A-46CC-BC2B-1C284717E9DF', 'B6C9BC87-96C3-4285-9FAD-01189E81D4D4', '4607066260124', '--  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BD65BA1-CADF-4771-8F30-7BECC618DC42', '79291D2A-0838-464A-B613-65D1CD0E8213', '4607066260155', '  / / 50,0/ +/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A04BE7B-4903-4811-86D8-04756F583A26', '64F909B9-C05D-44E1-9AF3-92758CFDBFB7', '4607066260186', '  50 / +/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2201C91-0A5A-40A8-815E-C46311D29AAF', 'DB2FC475-34C1-4270-A042-09191304A8D1', '4607066260216', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8299BC25-9FFD-487E-9798-7883F9675619', '6639917D-62BC-48D2-8582-328689E4395A', '4607066260223', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('890C7543-C520-413B-BD41-BB5C10B72110', 'A164166C-068C-4720-9DEB-AB08681DC2DC', '4607066260230', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAA22484-CA5A-4B47-8688-22D88838E510', 'AA2E326D-27EB-4F2D-8B37-AABC818B1294', '4607066260254', '  //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C32BA18C-0043-4962-BBB7-01F9DDD76986', '6BEBAF0A-3CBB-477D-B34A-A1169CBC41B1', '4607066260278', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4602BD92-5805-4DAE-A978-FD411934CBA3', 'FFB79E56-8CDF-4160-B87A-0E4969F9D804', '4607066260285', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E62021C-144E-4D0A-88F0-CB376747BB80', 'A9BA4798-D38F-496F-A867-EBC93DDD7817', '4607066260292', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA217B34-BD05-40DA-8D28-C9482E1290FD', 'E6F0C991-B0D3-4442-8299-820D8DF11F5D', '4607066260308', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('766D3538-E3DA-4341-A8A9-A51F63DC1E0A', 'ED51CA63-C277-4CA3-8ED3-2D8C65944591', '4607066260315', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB16293A-A08A-420B-84CE-D10CF3A4E4A2', '910D2D34-1ADC-4347-AD22-F183CCDE8E11', '4607066260353', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90367CAC-8A6A-4DB5-94DE-F703D566A5DB', 'C923DCC0-F8AC-449E-A946-09929741D1C4', '4607066260377', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A46FEC4F-6045-4A93-92CE-0B3F4277C774', 'ECC1EAB4-BF04-4A3C-918F-E4A1AF4175F4', '4607066260384', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3EA1739-F988-40E7-90D9-B5D8498B48E8', 'FE686EBB-8723-463D-B2DA-BF15DFF315BF', '4607066260407', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95D358FB-650A-4A07-A53B-6FE2ADCB0F1D', 'F9BD7430-31E2-4F1C-ACE6-A319D067C10C', '4607066260438', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9EAF024-D531-43F0-B0DD-2B14A9E700F3', 'CC3590F1-019A-4ED0-BE64-99DC56099456', '4607066260452', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A50EEC8-0ECC-41E8-97DC-4FEF0A0BAB3B', 'B46927E5-E8B9-4037-94D3-131DB623D6BE', '4607066260476', '  / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB8FA871-1925-417B-8336-BC7F7BDB9618', '21A75E45-1165-4EF8-B8EE-B5D79E987863', '4607066260483', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE526AE6-66F3-4778-B017-14F9F9DF1C40', 'B47E3BC7-9EB4-45AA-9B85-4675A12D6833', '4607066260490', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20A9D913-920A-4F5A-9E59-1C38F735D4D3', 'C08FA347-858C-4418-8440-2FF0B4C6CCC9', '4607066260506', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD58DD27-F561-4B73-BFEF-D1171A8F1957', 'F0BD4526-605C-43F2-B775-2468C9A55D85', '4607066260520', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCA68A76-8ECF-4FEC-8257-5DF91C11C69D', '648D3518-0A2D-4588-B453-15F74760E16B', '4607066260551', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4941FD20-C2E8-47ED-AA32-D64B434ABA29', 'C8B141E2-45BF-4053-A865-05190EB15B37', '4607066260582', '   3 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F102EB3A-6F71-442B-A68D-84A42C0D79CA', 'CFFF73D9-112B-4ED2-99D6-E5CE326C7E01', '4607066260599', '  // 3 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8838A8D-1C26-4ACE-A492-56DC95BC3707', 'D2EF0B88-C701-4DF7-8DC3-00C4B045D021', '4607066260612', '  / / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC198CCA-2BC1-476A-8E1A-F75228883737', 'BD7D425C-7C62-4935-B1A8-2460DBABCB19', '4607066260629', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63E51CA9-0CEB-4132-88F0-247930572BB4', 'FC17E288-366A-490E-B506-0A8E986E750C', '4607066260636', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CEADDE3-000A-41BE-8444-16FAC923D29D', 'CA3D7845-88E0-4D43-8C9C-7FAE83D31D23', '4607066260667', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C306DDED-57FD-4778-A4A9-AEE69B8F6B22', '423AFAC2-3AC2-4C9F-8BD0-CA7DBA707A83', '4607066260698', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5324FDD-6B69-4DF1-BAEC-39B70DD90182', 'D139A9C7-ECC9-4713-97A7-E7A161633A17', '4607066260711', ' 50 / +/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FBCD205-6949-4897-B877-9C3ABEDB43E9', 'DF8E27AE-2944-4C05-A2F1-5057EC2D5F8F', '4607066260735', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EA0BD31-97E4-447C-A9A7-39BB50520519', 'BC4522E2-AE70-40D8-AE20-F09A7882D039', '4607066260766', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4298EE06-0B55-4AB4-A61B-07B732DB9762', 'DD1B9079-AB49-40F4-9D8E-3369A557E37C', '4607066260773', '- / /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57166825-ECEF-4CC7-817A-6014BF08DD36', '59FCD4CC-49D5-420D-A269-072A4A62DF2F', '4607066260780', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A694541-BFCA-47C5-B1E0-A9ED5AEA4BEE', '292B21BD-2049-4239-B983-E3800C7D72A9', '4607066260810', '  1 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('763D6B81-999A-47AF-BDAA-9A9CCA7C5187', 'D06EDCAD-7BDC-491F-B0E9-02A92F5A32AA', '4607066260827', '  2 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('172D4B35-C447-444C-A398-C5F89BFAD04E', '6154278D-C8E7-4DCE-8B16-729AA52523A3', '4607066260834', '  3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CC86778-F800-4905-9C26-465932E93283', 'B6DD2FDA-B5C3-4B51-8AA5-E8042F7F06F0', '4607066260858', '  // 50 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A48D5B23-FA5B-4C9A-A23D-B72A22D6542A', '8F951978-D717-4581-971D-40028BCEA318', '4607066260865', '  3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B968FAC5-A399-4141-B1BC-E272FAFD875C', '5B321315-688C-4EF3-A5E4-AABEC763702E', '4607066260889', ' / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D36FA64-1943-4841-8B7E-65EE7DE4A4E3', 'ADF4BEF2-90B7-4ED0-8510-2909F4843156', '4607066261015', '  / / / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('675698A0-30F3-44D2-BE90-AFAC0F1A7A6B', 'ADEBE4CA-2E6E-453B-B77B-C86C73920705', '4607066261114', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C544E04C-8695-4287-BB1E-866023B61F77', 'ECA487A3-2216-416A-812A-99A1F0EB77A3', '4607066261145', '  2,8 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3380FB7-677F-4DDC-88A9-503902038ADC', 'F801B068-FC81-405E-8838-A141F7F908BD', '4607066261152', '     / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5639C4F-C217-444E-831E-2DF669AF7FC4', '0D4500C0-DDF2-487B-801C-61926E49EA5D', '4607066261169', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D882C33-0F25-44BD-9C64-31FDD7382531', 'EF82CC7D-0CFE-461A-9E0C-B04546511108', '4607066261176', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCE7FC58-F88C-4D04-95A9-CEE79DBC6B94', '72EDD0FD-CB92-4E68-9D1B-4D33C63E9EA6', '4607066261190', '   / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEAD4AB5-6C65-455A-A8E4-50BD262C31FD', 'D9A77BE9-D7F6-47F6-ADD4-144D4A9C3424', '4607066261206', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84E1BBB5-D01E-4A31-889C-8DF2847F5543', 'D6015986-9E3A-45F6-BA03-3CD12F368EDA', '4607066261213', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5720ECF-7023-4E7A-9EBF-CB5BB825092C', 'E80CD40C-DE82-4C7B-925C-B1959A17E642', '4607066261220', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D043D7B-A346-4A8C-940C-2E218C81BF66', 'D141900D-FF41-4E3B-9979-E922F45AADB6', '4607066261251', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B49C0BE2-C7E1-4DA0-B693-9E8E87E4784A', '7BB2CD0B-18F4-463B-8280-55449CF02917', '4607066261534', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD70B321-4270-4B3D-BDA8-3EC6C934DA2D', 'D1BB2DC4-2B5F-42B2-BDDF-553530D0C9BE', '4607066261626', '   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45224C51-3DDF-4724-8639-8920CEEA9D0E', '197DA98D-B024-46EB-8679-E7334E2A74C2', '4607066261725', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34045D52-A93C-40EC-BCE4-8439F63C687C', '1C549674-6BEE-493B-916C-79E2B3F9C1BC', '4607066261756', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B118496-73DF-4F3C-90A7-A0CB455B000A', 'B6A74DE1-8CCE-4A82-A685-1938AADFC6D9', '4607066261763', '   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B8BB247-0118-448C-B88E-C8CD928219BF', '8EFDD397-B1B8-4A52-AB04-C26B8E68828C', '4607066261831', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64F0080A-7BDA-4435-84B9-8EC3031EBEF8', '77F51F02-F269-42D3-B4D2-B6F4D16940F5', '4607066261930', '  2 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('533418AB-EEAF-4C12-A346-53C9E3CD0A62', 'AAAF2780-2628-481B-A50B-33E0D49F06CC', '4607066261992', '  2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AC34F6A-3067-4EBB-8917-A86D64B86C37', 'E7AB6940-680A-4A2B-B12B-66F8C3BFADCF', '4607066262128', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53EAC798-0709-4418-91B3-C4B44600D335', '9A6B5410-1C94-4A55-9DB1-B7846369DA22', '4607066262180', '   1.5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5498DF01-6EED-4CA6-9FE1-C6951338A677', 'DA1ED14F-045A-4043-A4D2-66BF25CCAEC1', '4607066262227', '  2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('193E9E85-2ABF-41F0-8FDE-136ABDAE9345', '5F85F86F-0F53-4BDE-B315-8FD3999BBD49', '4607066262241', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD1C75C1-2272-467C-8986-5B23458607E2', 'DB08C61C-3056-4371-8849-2928E1C3819A', '4607066262401', '  // 20 2 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF7F8546-EE9E-4A7E-B1A1-AADFBA21D102', '36550F8C-0478-40B4-A01C-E724E27F1CAF', '4607066262432', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1052FB08-416F-4274-B3CB-1EC93AF8157F', 'EDBF46D0-544B-40E5-B048-31A38738F0D5', '4607066262470', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B34A98E-8A55-4316-B40F-F01CCF8D2CAC', '2FCA5F74-3D01-44BF-BAB6-82C580133309', '4607066262494', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE2C7A83-FF7B-4B0C-B377-CD984F9B32D6', '4F4CDC19-E2EB-4ED7-A1CE-94C4B309E1D1', '4607066262616', '    35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0CD4820-2E94-43DA-966B-45C2ED734027', '66A5BD05-9C81-41D4-ACEA-7C622E4D8F19', '4607066262661', '  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('235B1394-00C9-4E82-B28F-4B98A550A741', '10E73DD1-6116-4D5B-AACB-031552C80D4E', '4607066262906', '  1 2 20 +/ /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38664D77-E5B3-476A-BC32-5655D27119A2', 'CBC075E8-973E-439D-81A7-B599FA652F70', '4607066262920', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36C26069-79EA-49DC-8AC4-4CAA5F2A046A', 'F2F3C922-1687-49B8-8BFC-60B51081ABAB', '4607066263217', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E507014B-6F99-4698-8743-A525DFEF52CC', 'CBC075E8-973E-439D-81A7-B599FA652F70', '4607066263248', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A8FFDBB-B0D9-4EAC-A992-9A339AC2AA49', 'B396B168-7188-4FC3-84B3-53C13E868EEB', '4607066410420', ' 2  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B61042EF-B359-4EA6-8974-FBECECEB0352', 'D3836306-98F5-48D3-B852-627397DC85F2', '4607066410468', ' 4  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1E62AD4-91E1-4922-84BC-66CEB0C050B5', '96F70CA7-0E3A-49F2-9AEA-392F8748A9DC', '4607066410482', ' 1,1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C92E6BA7-FD94-4D72-87CE-6B0EAFD2A753', 'EB08159D-7724-4801-AD73-79AF56EF0AE0', '4607066761263', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDDA226B-2906-4A97-A67A-6BA437ECB9C4', 'BE5FDABD-AFA3-4AFA-B6E7-68D417477887', '4607067060068', ' 300  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D75823D9-7293-418C-B444-97332F367ABC', '1237FB79-4B34-4554-9451-C1DAFDC5ECE3', '4607067060297', ' 300  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('938F633C-1D46-4009-846E-F6FB51F6BC76', 'DFF3F625-A5A3-41F0-BC45-4B3BBFDF69E8', '4607067060327', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5852CF5E-E1D2-41FB-8EF6-537B70C044C0', '2A9FB3CA-8F3B-4252-807A-DCD1D209FAFA', '4607067060419', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5455C3D-9CB5-458A-AB16-9D7FAF2DF207', '95EBBB68-0BD6-47BB-A692-59E94E0EBE97', '4607067060426', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F03D459-1249-45D5-9A09-7815FC6D606E', '982EC460-D731-4661-97B6-79114B56AC43', '4607067060587', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAD25176-4DD6-4ABE-8B81-8F44E9BD57D2', '419F0D25-50F0-47C4-8174-A1924C1B039C', '4607067060594', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1718CA79-42DD-4E1B-AD13-9FE194D2A78F', 'BBFE5C60-11AE-4C6E-B729-053C4E3081C8', '4607067060600', ' 0,1  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C36950A9-CD99-4CC0-82FC-EC74229D5755', 'D2B18EF5-4FD0-4C44-A579-548AA7A77711', '4607067060747', ' 500  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E876213-8765-4287-8D75-C2D746227DF6', 'D8AC9AD9-D1B8-49E4-AE51-1A240260C9BF', '4607067060891', '  200  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57C94D07-2BCB-4E3A-972A-418D5A4588E4', '77BB0979-AB23-4AE8-9F44-0D56AFD1C2BE', '4607068360037', ' 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D570FAB-A76E-4129-B0D2-EDEA56B815EE', 'D92513EF-AA80-44B8-A2C1-5C9D42B4268C', '4607068360334', ' 25%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31516F57-3722-4F8A-BF3B-FF5642794E0A', '0E952D32-FE20-474F-B309-37CC68279C51', '4607068360341', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06473175-490D-4272-8FC1-6B18DAE05D87', '177E962D-076A-406D-B240-A5E7753ED6E5', '4607068360402', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D817351-798E-4413-8147-BC02A234C557', '2D876CA6-790E-4623-BD4C-FAADC0483825', '4607068360716', '     3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0049559D-4E50-4381-A188-144EE469DEEC', 'A927CBDB-F721-4D3B-8594-34683D3F461C', '4607068620018', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A144CB73-41CB-4122-9D7A-DB1F8297302D', 'DECA2BF5-B2E2-4CFC-AB82-6336D74F1BB2', '4607068620025', '    120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FCBBBB8-5EC4-43E3-B1AB-A1C341BD4714', 'CDE28B7F-98EE-41B4-A800-233E3026C02E', '4607068620032', '    200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC378651-650A-44BD-94AE-97F7E02AD602', '2747C5C4-0EF3-450E-92D1-C91294022021', '4607068620049', '    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB5101B2-5CE5-4BD9-A288-F9672C2011C8', 'B41B1DCE-C7C2-4701-8FF1-17D0E246F214', '4607068620070', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEB2F674-9EB2-4891-91E5-7C9EA1D62227', '8DF94E88-E5F9-4D40-969B-EA2D17C19599', '4607068620193', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AE53BA8-458F-4ADE-A58D-562CE9D09800', '4A17A2B0-CD92-49FE-AFAB-9CF1E5BB0192', '4607068620216', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('251AE862-762C-4FEE-A65A-76ADFE45DFF6', '4A76C734-A05E-4EBC-ACDD-8DF18095C080', '4607068620223', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91E908E0-95DD-4AFD-8916-C9730170FD86', '72E50A3B-5E8F-4880-9C41-4EC56B36E58F', '4607068620247', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1457DA02-D9E0-47FD-A8F6-4A7E717E6273', 'C3F31E20-0D97-40AD-A2E6-D6FAEB2D0A45', '4607068620254', '    /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C049D2E4-2F59-4D88-98A3-6EE487602C55', '62E1B0F3-274C-499F-8331-8CE7ED9B5943', '4607068620681', '   / 72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('679FB401-4D52-494E-B8C8-06809DD7AE9D', 'C8A44C5D-7E64-45F0-ADB5-7E1AA3477BF3', '4607068620698', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CA3C1B6-7BAF-405A-B86B-FCBF8ABDAD22', '5F1967E2-CC02-4A06-99BE-7D1AD3458B6F', '4607068620704', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D981EE8-D7F6-459D-BF3B-0E23532E3E29', 'B31E641F-044C-4F5A-B9D1-CAF15AAA75A8', '4607068620711', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3927B487-50CD-4F72-8BF7-91EA60195995', 'B7A8BCD3-4DEB-47BE-99DB-AD36D81308FA', '4607068620728', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13CE16D5-F326-478E-BBFA-974D49EC8CCD', 'BFE51C49-94F0-4527-B009-1A61E864B67A', '4607068620759', '    160 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE1A44EC-67A9-41ED-B554-BEFEF11F0C53', '073043AC-8A65-4CBF-B560-08B7CB3F288C', '4607068620773', '  a 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01BEEE97-F115-40A9-B44C-B28B96E85BC6', 'A912D352-1E39-4461-8805-EDB126AAAE2A', '4607068620797', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15B9FBDA-EA60-4845-B039-ABB02BB15D3A', '6A2C1E64-394D-41ED-B41F-78EFD8F7D93B', '4607068620803', '   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC7204AF-C13D-409D-B5A5-0176AE05BC78', '81DF70B3-3451-4E93-902D-64BD1178A5D5', '4607068620957', '     300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D34307F6-15B7-4791-BB3C-74B21E8D826C', 'F90CA4EA-8DD8-4112-B4A5-7B4BF5826F7B', '4607068621053', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1572D7C4-98A6-4399-9F31-C9AEC78FB074', 'D836731C-0487-44D0-8E83-718BD4EAB74F', '4607068621145', '    /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55652872-6D7B-44A6-8523-A577CBC80243', 'B13AF1F4-A0E7-413F-9D08-C3014E999943', '4607068621213', ' aura  /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E87F4E8C-6C56-44C0-8A12-0D6B4D90A92D', '98A248EE-0A92-4741-AAD4-E260F13AC581', '4607068621794', '   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52243156-D93F-4ECE-9B6D-C25D02D9C4D1', '3D3E06E3-E0BA-47DE-AEC3-0930A263EAFA', '4607068622623', '    /   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38A20B51-D0C9-4EC9-AC89-6700C8D9C0A6', 'DBA0E168-ECF3-41C6-BD15-A81F3F28EC3F', '4607068622647', '    /     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3F26C85-C8C7-4D75-85D4-7DE8177B33F9', '05835E5D-7F31-48A0-B057-C8BE8AB5038A', '4607068622692', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97095844-379F-4A70-AB6F-AB50590B2412', '156297E0-5CAF-42B2-8956-2F1132FB885C', '4607068623910', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('844C3616-EE96-4E2C-B290-43C7D3E5A799', 'F0B31EAA-6205-4A76-A1E3-A289B5054B78', '4607068625051', '     10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B078D6D-2BA3-45DE-AF12-ACA64F566C97', 'CACBD7B0-C497-4DA3-8E8F-8ACDADF23563', '4607068625693', '       72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D28EF05D-E961-4D40-839F-4A6CE4B5E81F', '26EF5DA8-96BD-46AA-8650-EC59C58CEA24', '4607068626041', '    biocomponent 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('082AA1BD-271D-4272-9B54-30BD67DD21D1', '5EA5B91B-8964-42B4-8E1B-A74A595AC840', '4607068626911', '      //./ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E249CB9-9F5C-4F93-80E8-32F31BBFB5BB', '7638A834-9F57-455C-942B-DA4B4B88B770', '4607068627000', '       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB9C74D1-D2BA-482D-A2B3-DBC6DFBF0FB6', '35E11937-3B02-4823-862D-4EE52524908E', '4607068627420', '      200/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B6C16B3-FFDD-4BA2-B7BB-5F6DAE09DC67', '02420EBF-D896-4010-AF8D-2CB3E4797BEA', '4607068627482', '    6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC789425-DEDB-4DEA-9352-9F4ABD20F8BA', 'DCEDCE62-3BA9-4FA0-A234-BE6E057D02CB', '4607068627499', '      6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00B58C06-2823-4AE5-8E08-9C0A39D1A6AA', '48909BC3-60B2-44F7-9AED-174306A1766F', '4607068627505', '   /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4152A213-A4C3-4CCB-840A-E4B13FC3074E', '884C2897-F15C-41D1-9BD7-98E1B7F20A25', '4607068628168', '        .60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9DDD6BF-8A04-4CE6-AEB2-2294EE20A75F', '210E16D8-E8E5-4B05-9025-8A57899F54EA', '4607068628212', ' aura  / // 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B5E7311-0CCE-4D17-9452-CFCFA49D11B6', 'E37B489F-8044-4DF6-AFD9-5F2966E6E21F', '4607068880016', '   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB8E6E4D-A8ED-41F1-A6D5-3960431D5E04', 'E173082A-F68F-4976-931F-DA771E6E3558', '4607068880023', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4741709C-DDE6-4AC1-B87B-A55C99E9F1D2', '8B10DD9B-02C5-4A85-8645-278345DF3C23', '4607068880054', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5060AF6B-43FA-460F-8DEB-2353256EB5B6', '91AD067D-4B21-43BA-BA73-4A6A12F40F2A', '4607068880115', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E585E1C2-0CD5-4705-8EE4-10E6958FE515', '2A135727-CCC6-4CF0-B036-61FE750C63F6', '4607068880153', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2493B35-2179-4223-B531-DA143D24E727', '36AE183C-9780-4579-BE9B-BA5F012AD206', '4607068880191', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27409A29-AEAB-4CDB-AB85-733DFA3C39F3', '44246D88-29DD-4DE6-81AA-376707768862', '4607068880214', '  50 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('151FDD00-131D-4C35-9944-77F01F3B1D6C', '7CD4582D-BFA2-473B-BF79-FC3BFC83E7E5', '4607068880238', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49B20C9E-6040-47F6-9530-1DCF9EBE92BA', '7CD4582D-BFA2-473B-BF79-FC3BFC83E7E5', '4607068880252', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4E81C98-A04F-48AF-9593-31B490950852', 'C8139A43-9154-4604-83B4-002903C8D637', '4607068880474', ' /.   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F1284EC-94BD-4E66-8FEC-D19A5D94DC2B', 'A4F67EF9-DEB1-477F-A131-B6600E4D66CD', '4607068881471', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A742828-1E4A-4EA0-A60F-C9528156EF32', 'C40D4AD2-848F-49AC-A2D7-B4B9733317DA', '4607068881495', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E67CBE77-8AC2-4234-B9EB-126DC11860EF', 'F4DAD4CD-733F-43A8-B837-75A83145ED9D', '4607068882232', '   200  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E7039A2-D46E-4E34-981E-BA69B25FDD86', '833B6404-7CB4-4B53-A0F3-FA75EC90325B', '4607069190497', '    1,125 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DD774A1-4137-45C4-9363-10B4653867E0', '4DB59774-FA5F-4848-8858-D303D33C7B9C', '4607069190947', ' 250/0,5  / - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB7A20E3-D922-48D9-BFDF-7DA4B52614AC', 'B26E2812-0EBC-4881-8FFD-E6671C5B9205', '4607069220019', '  0,9% 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91D1BAE1-D592-42F3-8C7C-0F373C12CB55', '36D2BD33-454A-46D2-A464-D50A140E5EF0', '4607069220040', ' 250 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45AF05E0-4CE8-4537-82CB-30191F91DDF9', 'DA68490E-4A7F-4139-B805-BC95B424047C', '4607069220316', ' 5% 100 /  (2 )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A85BE07A-5D58-4600-BEB9-61C7A9D9E0E7', '28633068-22B2-49A5-8D08-C9992A223A94', '4607069270014', '     / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD98387C-F06E-41F0-AEE7-06717F13922F', '403B9C79-DA34-4B17-B02B-E5D8621AABEA', '4607069270021', '  /  / / 1 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47F3CE6B-CC9C-4C98-9EFA-3105AE51525D', 'FFB3BC73-2A44-4553-B7DB-9AF7C291215B', '4607069270120', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('679A3510-464D-462B-AEBD-C2069AA1F9B2', 'FF075F48-ABD1-4F72-B736-E4E83C6F2E96', '4607069270243', '     120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEE10AD2-C3E1-438A-BCAC-D43CA452AD1B', '683A8AB4-40F7-4C8A-809E-05D476A8D874', '4607069270724', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC2644A7-3FC0-4952-8A37-E56DCCC43A56', '934AF27D-C2C0-4C1D-9C2E-B5387935C7DF', '4607069270762', '  // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('964382C7-15AA-4C44-BD72-17A76F18F793', '2228ECF1-2F80-4194-A049-E5E7A77FFBCB', '4607069270878', ' // 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C484006-CF33-4123-98A8-635451946D6A', '1A2D48E1-74FB-4F5A-8C74-61B82F8A8E2D', '4607069270908', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('477888F7-2793-4BE9-BC7C-B4DEF2E9D0CA', '362D3FED-93C1-4B49-B084-1A8CA1CB8753', '4607069270915', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('647848AF-826F-4677-B102-2E7B58F43B98', 'D7567B89-B1A2-499F-8C08-2A80C7CE4952', '4607069270984', '     25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FC844B0-23A8-4EC3-BAF3-2A3E95ACFA7D', '2FB17DE2-42F1-42CD-B84D-6BF321D657BB', '4607069270991', '  /    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68A1E526-5F77-4C70-A20A-FD5B906E59E2', '73039532-D399-4272-B832-317464A6549E', '4607069271004', '   /       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2BB9490-37E6-4772-AB21-BA5EE043B44F', '393D63BF-B058-41FF-97A1-CD50063861A8', '4607069271011', '   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A0F12C6-382B-4757-A49D-18C6AEC419E7', '4D4CD064-7D6E-41F6-A03D-007EB7CCE813', '4607070020912', ' -  spf-20   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81A3ACE6-C0AE-4253-BF45-348F485CF60A', 'E503837A-6E91-4B1F-B3A9-ABA8BF4A1B77', '4607070024606', ' -  spf-30   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E98C16E-AD71-425E-9F57-9DEDFD851E5A', '4B4EEB1D-30FB-465F-AAAB-841D30FE7636', '4607070025375', '- /   // 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BA8BDFC-8183-463D-A71A-C328774AFCBB', '775935BF-F9EF-45B2-89E1-73428138F440', '4607070025382', '   spf-20  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32DA1E53-D5AD-40EE-89D9-30DF5345C3DB', '6D9846AB-6943-4785-975A-60199F495783', '4607070025399', ' / // spf-30  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('931AB07B-4DB2-42F0-803C-5912A919230C', 'BD54385B-BCA1-4DD7-9AA5-CACF6850FB13', '4607070025443', '  spf-20   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C8CA746-FA6F-4B01-8F28-5F27A69E1F32', '5338889C-4FB8-40AC-894C-9C86D5A4649F', '4607070025450', '   spf-25   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E8ADC28-BD7F-4D36-9F49-395A525EDAC2', '05F777C8-2101-4210-96E8-07E41B7D15FE', '4607070025467', '  spf-30   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84ED12E4-0A69-4E49-B21B-3AAA20BB7ADB', '5E74C98D-9FAC-49C8-99D8-DB62CB06FDDF', '4607070026617', ' -  spf-35   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF25680A-3798-43EE-89F8-98B9D5D44B19', '8A261BFC-81BB-4D74-9212-D807105163C0', '4607070026631', '-  spf-30  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C338C355-4CA0-4017-B609-F026AD364788', 'DDE617E0-E732-4263-9AF6-710D9BCD2F77', '4607070026648', '-  spf-40  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AA2C4FE-C586-4265-8ABA-314504FF006B', '1E2318E8-8B6F-4A94-8FFA-61C5BF0557FA', '4607070026655', ' / spf-40 //  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38CB197B-68E5-4CBF-BD5B-0389FCAA6CCE', 'AE67CF77-E6AB-4220-802C-E5DD1257DD05', '4607070027959', '- /  spf-60 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C91222B8-8CA9-448E-8802-04B33A725861', 'D7F2AF33-5671-4474-94A4-88BABD8FF59D', '4607070027966', '- . /,,  spf50 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49684AA3-5803-4BB8-BDBC-64520D001759', '929A2544-3820-4CE4-AFEC-94C5E980438D', '4607071772827', '        40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BF4C3E6-1C0F-4900-AC46-F2812FDBE4F8', '8E4429AB-7F6D-468B-B7B6-3E84285B6EEB', '4607071773275', '  -- 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF4F7352-AC3D-49F0-8647-2CD963C0F39A', '989C857C-CB6B-4362-88FE-69D80EFC48D5', '4607071773282', '  --  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('631E085E-7B63-4E0B-980E-618B4F2C2B0A', 'AA4B4F0B-CA43-46B8-A417-B1E3650BA8E0', '4607072020187', '     225', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71FC90AC-CD7D-4C37-B0EC-B02F0907B450', '370835BE-E123-4033-9E49-EF69BA6FA3C3', '4607072020316', ' 22,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D83358D-0BC0-4375-B8D7-C29B874F9659', 'C0F7B7AA-55B5-417C-8FED-9BD79ECBD573', '4607072200053', '     130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8D21A41-C2F8-45D1-A2C9-7EE6353C26F1', '49BABED7-C099-4A9C-A805-25DAB7EF748D', '4607073910012', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0E257A6-20FA-42A8-A56D-BF57DC68D258', 'B6AA7E7A-DF99-48AB-9222-5A181669A751', '4607073910029', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF3A78DB-C754-41A7-902D-2B565C27114A', 'BA43019F-2CCB-4837-9286-592D875453D7', '4607073910036', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D49D00A-DF87-4CB2-AAAC-CA8949356850', '01CBFE3D-7353-4E84-9DA0-665B5A0AC668', '4607074610287', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A62FFA3E-BCC9-4346-AEB5-F399BC63510A', '8FA382B7-D731-40F1-A834-784BDC00B22E', '4607074610461', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AA7955C-D91C-4638-8266-96F8E2D69137', '55AA8F57-9BD1-4543-85D1-B48313EF518D', '4607074610867', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F183873C-44FF-4E2B-BFCB-5C06C42C18D7', '8B4C56DB-4844-4DC6-9F09-E7D3642E3A72', '4607075001244', '     //+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C519153-0956-4974-B977-3EA3AADC42BC', '73D2AF84-333C-4B12-9698-3BF8F2913DD5', '4607075002739', ' /        /bc  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86E865DE-FB12-486E-9C24-BD0BA25ED837', '9D161A31-459C-4215-BEA2-D33B6BD01CF3', '4607075002746', ' /        /bc  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E34496A-A49C-4582-ADF7-009661D9E9DD', '5292D20C-3D9B-42DF-B2F4-676E4ED7C713', '4607075002753', ' /         /bc ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EFEAB40-A1BC-4CE2-A0BD-DD1215B942CA', '9648D826-CEAE-42F8-BA5F-6CB39E8014D1', '4607075791237', '   2 4  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B584507D-1725-4F8D-9D7F-CCB6EC7AFE12', '27F5EAFF-45DE-46F0-A7FB-3C58774CEEE5', '4607076080057', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBE27142-D725-49CB-B988-27E4DD3B15FD', 'FFB3BC73-2A44-4553-B7DB-9AF7C291215B', '4607076080064', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8CD7B5C-CE08-4791-9BC8-C065744305F7', '9BEA4B8E-E29B-4ECD-96E1-B9C4C9FFEF99', '4607076080095', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC5B3C8A-66A3-476E-9F25-07192C45C9A6', 'D44FD6C5-5B5C-4568-996C-A14B97330920', '4607076080118', ' // - / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F22F716A-95BA-4ECA-821D-64BDE9B0D8D6', 'B4E07953-2664-4D5D-A88A-82D6C37214BF', '4607076080125', ' //  /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4649F74-8341-4883-BB51-05CDEB5E8C27', '4AAF216F-7034-4F34-B2B5-2F814C60CBD1', '4607076080156', '  5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FC73ED9-B9BE-4982-AED1-AC9223765123', '46B015CA-9680-4A48-9C3B-A62D2D17C92B', '4607076217552', ' /   / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C2EB586-6517-4027-A6DF-D918DC992354', '364C4C33-3DF2-4D27-AC84-9432DF773672', '4607076217750', '    /   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65AEE191-A943-40EC-A308-13DDA16E3118', '2AD3F965-6D0B-4058-AC1F-4D06F0E7380D', '4607076218535', '      300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C245172-36A5-424F-B98D-DBB652548AAD', '82444FF8-A6F0-4033-9FA3-37F76E5DAB5E', '4607076218634', 'Aqa   /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F9F884A-004C-4A18-A2DC-112E8A0092AF', '9E0D02A5-DDE9-4027-BA13-D51CD73AF2F9', '4607076219464', '        50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87025BAD-F539-49D0-B5F5-2DE3F83968C7', '36530331-60C3-4C76-AC5E-D0052190C7E9', '4607077040470', ' 20% 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA682579-200A-4D45-A1D3-EA9FCE18DF81', '216B5667-20A9-426C-867F-1B95066CB4B9', '4607077090420', '-     / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBDA4212-550F-4BBC-AD78-A7A1A95F25AC', '78C0CA81-40A3-4613-B825-6B7F30FD3C3A', '4607077090444', '     1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8477F86E-B61F-4040-A830-3B7073BAFA7B', '54160FC2-9B15-4C76-B757-8F23D04D60EB', '4607077091380', '    / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C34A3B26-62F8-4BC5-89A0-0227008E6991', '89C5F6C8-7108-41A9-94A8-BE77A8B05AC8', '4607077091731', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2346EBFE-D3F6-422B-9564-A00C89EDF447', '3313D7C2-3628-429C-AB71-1E2F58BFE509', '4607077091847', ' - / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10058277-AEDF-465A-8078-067244481407', 'A2586B3F-1741-4A34-A250-A7E7255EA1C2', '4607077091861', ' - / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEC0A398-90A6-452D-90BA-58A1FA382609', '2A09D1B2-98B1-4E75-BF07-6CA42DBB11B5', '4607077091885', ' /.    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6364831-058F-4CCD-A5AA-A29C129E1658', '6F83F356-80AA-4CF8-912F-D38DDE278200', '4607077091984', '-        200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E234C2EF-D2EF-4E87-89E9-EE4CAF722CD9', '4FF9E74A-ADDA-489C-9752-D2184BABB4E9', '4607077091991', '-    --   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CC82D20-DD46-45E8-874D-D88832519520', 'D0B5BBEF-E184-4F3A-98AD-8DC65BC38074', '4607077092004', '-        200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BACBC1F-796A-4FE5-B3FE-D9D52FFEA1E8', '6F83F356-80AA-4CF8-912F-D38DDE278200', '4607077092172', '-        200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C97C8593-7F6B-482E-AF6B-B43C3B65210F', '82F7C8AA-D5AC-469E-AB31-6C3DFA5ACD40', '4607077730012', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0B49B20-205E-4025-87FB-5A1D24BE04B8', '5C436593-4B8B-4CA1-8B4E-216A88DD078A', '4607077735017', '   / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5219DDEF-41F3-4B00-AC6C-1D482E2D94D9', '453E23F1-D73D-4E98-9789-F90D40411740', '4607077750331', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C3C4E72-93A0-4D62-8A7B-3497C478A77C', 'B0D4B055-79E0-4505-8E74-83D8FA29FA78', '4607077856460', '   / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1475DB26-4948-4190-869F-44C3FD9F0962', '2F70A505-FECF-4701-926A-3E6AC50BE4D1', '4607078790220', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('271923B8-C427-4475-8500-6A856B608229', '4A85B1D7-E314-4EC0-BA4F-5151D44AFD4B', '4607078790244', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C9C7B55-32A7-4C93-8B3F-C7BAA65BADC4', '4A85B1D7-E314-4EC0-BA4F-5151D44AFD4B', '4607078790282', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C7FBE40-FE9C-467C-9118-E90797BA89F7', 'C137A501-3FAF-4943-9CD9-D1CCE6E38016', '4607078790305', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC9CE61F-F8EC-4700-B9DE-ADBF365F3CBB', '322FF0EB-1601-458D-967A-A59320ACAD5A', '4607078790329', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF4B3320-9535-4199-B808-6CB8F0BA9AF5', '15C7E727-9A23-4719-8757-85A149CC5C58', '4607078790343', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC1EDBD8-EAB1-465D-A12D-81107CC01F09', '1F2BAB8E-4B2E-4853-8547-6C61E15CE82E', '4607078790367', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69FA31D0-ADA3-4BEB-8957-15D83952F33B', '14074A93-F941-4D7F-8BDA-24A9E49EC37D', '4607078790381', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E56C054D-3F89-4495-B346-B6D0750C8A69', 'C5DB548C-BCCC-484C-AEC8-77E3BE43E63A', '4607078791456', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F149182-1814-47BC-86F3-55FB361493D7', 'AD9AE2BB-6038-4146-96AD-BC8EF02CE3DF', '4607078792606', '  -- 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE7FFBC2-1908-46CA-9937-A8FD0F4AB27C', '6FC7BDCC-D2C9-424A-B82D-FC11F2739C21', '4607078970301', '         200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE787EC2-E817-46C5-A011-3C41DC992C8C', 'E64CAE05-8F5D-46BF-964F-007581326682', '4607078970509', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D159EC0-FFFB-4A28-BCD7-A839C33AF54F', '5CAF150F-5040-499D-AF81-4B459E1BCB39', '4607078970592', '   3  ,, /./ /3/ 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7943617C-F1E8-47BF-8572-FF231A88A1B3', '18844E7D-6701-4CD3-B055-68CA46F69AE2', '4607078971674', ' -     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61135CE0-EC93-4605-BE15-B3F8AF616405', 'EDA384D2-DC73-43C0-A0AA-492F63FC936A', '4607082670013', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2654A431-8C5A-4898-8850-A4B43C3244C9', '0C6B3EBA-4DFB-4C7A-8CCB-F2F57EC5A0FC', '4607082850026', ' 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8B3C401-1734-4C6C-80AF-65526CD20A14', '5D6D782E-4AA3-4382-A55A-AD2701BC1DDE', '4607082850255', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCAF4221-94BF-4FE6-BDF6-C26B9BE31923', '0753108B-1B05-4982-87A7-8638E63B8B13', '4607082851719', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2206F03-91C1-4132-9B5D-9E8D856FD759', '120F0951-1D2A-4796-8587-D618972666D1', '4607082852211', '  /   / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23EF1963-C816-4F02-9205-EDA542D82BF0', 'E518FA30-B3FF-423E-BAD7-D14EA7EAB28E', '4607082852228', '  5 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('273892E8-D22F-49CD-8A44-8BA69EB3C119', '7788C31A-DF0C-4F24-BDE5-86D200148D1D', '4607082852242', '  /    150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0226DC8E-FDE3-47F0-A817-3917132186DA', '6E11A853-9788-48C1-8E87-32BABFE65BF5', '4607082852839', '  /  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('449562BB-FE06-4F8D-88FE-5CA9FEC675AB', 'EC97DC06-C86B-4ED9-A37B-CE14771966DB', '4607082857315', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('378BCF00-5550-4DA8-B072-9AE82CF3D9DB', 'AF86A882-9127-4D72-95E8-D153CC422235', '4607083104159', '   0,2  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A9D5446-462D-401E-8AD7-1E45947F5D48', '08F490E6-68E1-48CB-8540-83825DE2AECB', '4607083720946', '   210', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03B853DB-C281-44A0-9DA9-3CD8DCBFD5D9', '315659F3-33EB-4D47-9745-F6AEADB70F8F', '4607083721035', '     4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61FE6F8A-7B13-4F10-B4E4-FFD203431A9C', 'BB2BD29D-1E71-4433-AAEE-9D5F23EBF1A3', '4607083721080', ' 410 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B28DDE6-3ABF-4EC8-9447-40A215E80E8A', '95AF46F0-D7CD-4051-B11A-0D623823CEA6', '4607083721752', ' 400  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D01FF0A-0F04-44DE-9588-2C6C99B5ECAA', 'CE10BF90-6AD7-400C-AFA5-AA4385FE5B35', '4607083721899', ' 25% 4  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C6C0599-FA4B-4073-BE03-E3E950641409', '18890FF0-A3E4-46CB-9F51-751C8348FBA3', '4607083722964', ' 20   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F539813D-B723-4DAB-81C9-2D8DAA897B86', 'EED8F235-7AB9-4053-B1FB-2429B1A8FFDB', '4607083722988', ' 400  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B8806C7-74F9-4893-801C-35335A44B417', '111D90F3-59F7-42BA-9A9F-5F764EEE44A9', '4607083723039', ' 3   / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29CBDA5A-4AE6-477A-B285-10422799D71D', '07D886BF-F20D-48B7-B892-4B43091D597D', '4607083723176', '   . 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F369561-C7FA-4F7A-95F1-02DF4BAE4F27', 'A09988B2-E2B0-4232-9A47-77F0B378BC5F', '4607083723237', '   / 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8832C810-EF26-4218-B996-62679BF50C79', 'F3E07DC0-D137-4774-BB43-C2782A7AFDAE', '4607083723251', '-     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03147BB9-9860-4196-9C4C-142DA9B63EE7', 'CE8E476D-5768-4EF2-ADE4-A2EA56764152', '4607083723350', ' / 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6647A85E-4BB7-4216-9CE9-113B6CCD4C3F', '3DDD5BB2-82E3-4E85-BEDE-A5A9D03FAC51', '4607083723848', ' 200   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E48FC8B-1672-477D-88A1-70D731A18B6E', 'B32138C2-8C9A-4E91-ABB2-E5D76C81BA4A', '4607083726047', ' 24  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2F7EB2A-A019-4370-B628-C4BC8045F62C', '71D3F4B4-0876-4B0C-B869-D4EE33232AD8', '4607083726054', ' 24  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9315ADCC-7DF4-4959-966D-7DCC61E8324F', 'CA34A252-11E1-44C2-BB70-4D68E56E94C2', '4607083726191', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B6F69D0-248B-4235-9FAA-BE9E286E73EC', 'FEA57F50-FB6A-4D86-8379-6CE98DAAD54C', '4607083726221', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9796DB09-50BB-457E-AF0A-3A4A335CBD1F', 'A46B4AC4-59D4-4E9B-B565-B464588F419E', '4607083726658', ' 24  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F16E9944-3B13-4B18-ACD4-553E28C36382', 'DB24FCC9-4119-4F46-B608-932A43E1329B', '4607083727280', ' 0,5  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B4C192A-0FA5-4271-8B3D-43B306DCA621', 'FBE1CE1D-B971-4CAB-B7C9-F7E031015F76', '4607083727297', ' 0,5  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C097E82D-FBC1-40F3-AB20-E350BD604C27', '6D0A72FF-5E72-4FBF-8728-C21EEDAD03C4', '4607083727488', '  silver /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('642BC759-1B13-4428-B887-333E0DA9AA6D', '07ACD4E7-3031-4E44-B34C-727F923CDBAE', '4607083727501', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E969B79A-CCE0-4D99-B2CA-D40EEA4A0110', 'B8A005ED-B0D2-48A2-B75D-2CEF0FFFA1D2', '4607083727853', ' 0,005   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8204DE2C-FA86-4ED4-A15B-12A9C19BFFCB', 'A2879440-4A8A-4543-BE84-A9CFEBCC7047', '4607083728324', '   210 /  410/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D014B972-38E2-4A92-81A9-8F4FB1E8C73D', 'FFDAFE3B-4496-4AB4-AB64-364C7EC1A6F7', '4607083728355', '   1018', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F89DB6C-7DC0-46C7-B145-12CBE9CFE3DE', '91271F6B-3AA8-469F-ADA1-67DD0192E0EF', '4607083728393', ' 610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53149458-D759-4CD0-A0E4-C61D0CB9B3E1', 'C1A3F364-7027-4731-B29A-5D2A81BB4F26', '4607083728430', '  / /  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09341A04-72F0-4888-A33E-762E3D41FEE6', '7CF2B861-0AAC-4092-9E83-3B9C560F8B59', '4607083728454', '   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB109336-5BDF-491B-816F-CF06413992C0', '90C5B5C0-4981-4CCD-9AA3-C584C628C7C7', '4607085230061', ' 0,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C25CA65-3EF4-4881-95DC-E6E09C15E4F1', 'D800C97F-9F38-4D61-97AF-EF04994A5DEC', '4607085230467', ' 0,5  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54B8E358-E0C4-4BB3-B721-61FFB63D81BD', '6FBEB63C-6960-4EC6-AA14-CCF5190352E1', '4607085232737', ' 550  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10586C16-CF61-46EB-80EB-3E7F0BED5F89', '05516E20-7D1E-4146-9D2C-90F0AF098ED1', '4607085310817', ' 25  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6215B82C-439C-4A8A-83A8-F04AF5DC2CC8', '40599641-FC6D-4915-AA2F-102290F7E08E', '4607085310824', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11743DEC-4A1C-4B54-875D-78D28670AFF3', 'A520559E-B7FA-4EE6-96F2-3A8F15809619', '4607085315447', ' 20  / 14', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C1ADE4C-BF31-4A36-99BC-87A37335BC90', '1F37C21C-9D69-4D2D-9E09-F669519C5101', '4607085315478', ' 40  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F410007-9700-4C79-823F-755300209213', '0F28FBE2-C4FF-4679-A458-936992A09964', '4607085315485', ' 40  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48FBE7E2-734C-46DB-8700-00AD95B2E650', '21CB4FE9-6AA7-4ECD-8AE7-D502263A0944', '4607085315508', ' 160+4,5/60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21A39D98-EF82-4965-9609-E0D93F64376C', '9F70D7C2-783A-4E98-A741-EE17073FC959', '4607085315515', '  80/4,5/ 60  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E0095BC-396F-42C9-A4F2-D9E735624A37', '63B3063F-9884-4269-803B-4368A2950E13', '4607085315522', '  120  /160/4,5// 1  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8530369B-C5CB-45B0-A21E-608B0024C61B', '48014087-C260-478B-B757-DB0F9AD43DD6', '4607085315539', '  80/4,5/ 120  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('739BAF6C-40FE-41DE-A273-657795DF9DBB', 'A054B167-E90E-46B6-A96A-801A3362CE71', '4607085315720', ' 10  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F88F3BE2-7243-4797-AA1B-0646EAC18436', '973782DC-2098-410A-8E97-B12546ADB609', '4607085315737', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE3AB94F-86D3-4DFF-9BE5-9D9B2D6B3926', 'B037E828-49E9-4060-A1EE-82B7DE218D99', '4607085315744', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04CE39F6-217A-4C62-ADFB-99602FFC9A24', '923BE2D8-5DEB-4ECA-A3AF-A360BEC9C106', '4607085318691', ' 5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9296431-9C37-43B1-884D-55940649D0C9', 'B73F581E-2A73-4C48-80E4-1E02280560D8', '4607085318721', '  100   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBDDDA12-2D78-44A3-829D-DFD7C8AF3287', 'FF91E898-CB95-424B-A751-9F918ABC95EE', '4607085318936', ' 10  // 98', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('689A4D05-71FC-427A-8618-3F9ADC050916', '0D448969-4F79-4681-8504-8489A69D807F', '4607085319100', ' 0,5/ 2 /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10133E3B-93CE-40E0-8761-2F07C4F60D9E', 'BA8D1CEF-B934-459A-AB12-DCF86FD8F685', '4607085319186', ' 90  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5871B94-37C5-4939-A219-9ADDBB10E53F', '55F8694C-1AA5-48A2-848E-0FAF3FA2ADFB', '4607085319209', '   100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A7F0D68-DEE4-4EBE-BD08-71D3D8B74E7A', '8E7DB3C8-D23D-4613-835B-D8B218E8F08A', '4607085319230', ' 5  // 98', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4282E0C-CFBF-4639-9EDA-E983F9464358', '97BB43B1-7568-4E06-AB92-10DBBA982A2A', '4607085319315', ' 400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4271772-FF49-4996-8CEB-77F9D8F72C95', 'A2E47F9F-13D7-45FE-B620-CAA0899898C5', '4607085319469', ' 0,4  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26624A37-B522-4831-AEAB-A7D6BF071B12', '97BB43B1-7568-4E06-AB92-10DBBA982A2A', '4607085319476', ' 400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CE2CC10-9753-46B4-9550-68ED21EE1DDA', 'D8C39397-855E-4A1D-BBC0-2040A34B736B', '4607085319483', ' 0,4  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7CABA20-A007-4161-B403-FA9B1CDDB56F', '58ED91C1-7753-49C5-BB94-4CEC9AFFEAFC', '4607085480923', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60A59D2C-B951-4A6C-AAB3-58C1FBD39A4B', '9923B97E-B96C-487E-91BA-F7521EF30A92', '4607085481319', '  10/ /  50  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E65158F3-E428-48B6-B5E1-4B4FA05E53F6', 'A76E560E-3AA2-4EFF-B397-9EA2BE5C6C5E', '4607085481340', '  0,02 / 50  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83B3E9C9-05BE-4AC6-8A66-2505807C1FA9', 'A432520F-79F7-4459-8B65-EAC3B5AD06FA', '4607085860060', '  / .   .  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC1BBED5-A2A2-4EBA-A5F6-9871FDA8D076', '1215ABA3-23DA-46CA-952C-80E251535DBE', '4607085860091', '  / .   .  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E0128BB-FD7F-4958-AFF2-3485F79B2CB1', 'C207DF1E-9454-491C-A94E-B39A10530D94', '4607085860268', '  /    /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8826A43D-F0CB-43B3-B782-AEA4B994B0EF', '3E66C621-BB77-43DA-98AD-109EE808C210', '4607085860398', '  /   /  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DFE5072-0EF8-4C5F-BB65-01634AF6997C', '2583D8DA-B1E0-4BC8-B9B3-B7188D502FF6', '4607086220948', ' /,    350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE0DD57F-25E4-4A2B-A31A-593355D619E2', 'B60C8BD5-D257-4250-A30F-4DBAD8828DD7', '4607086560068', '     /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17ABFDC2-BBDA-46CA-A237-D26B90F02326', '5FCEB3DF-CDD0-4E33-BA1E-F04CD26B1080', '4607086560082', '   /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('231F791A-0B57-4590-B827-5614657F8273', '76631C08-A780-4217-86E5-5E98861FFD65', '4607086560129', '     /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB06FD81-703C-4D6C-A46E-C777DF1100F5', '05762BE4-AB90-44F0-91FC-49DE11C3A0B0', '4607086560143', '       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57A57863-8043-457D-BA6E-B28522170371', 'C2198DCB-00C3-4DB0-9002-F171F42D8174', '4607086560228', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F902B0D-5E83-4181-9A85-4908ED7AE4C0', '96DE19BF-3EF9-422D-A0B1-933695D956E1', '4607086560242', '  - /  170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A621F272-E6E5-4FD5-BD20-0A6495F7EFF3', 'A37CE828-C514-4930-82E2-0C0BC97F7DB7', '4607086560266', '  -    170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E55561C-0757-4600-9EEA-9774B86B2687', '95881A7F-414B-463E-989B-0687FB712CF9', '4607086560303', '  -  /    170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37F05ECF-B832-42D4-BB50-3CB394E16A58', '70B97141-DA95-431D-94BE-672134E21FA7', '4607086560327', '  -     170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDBB3E3D-8954-4267-8247-BFC4CB51AB49', '06065EC8-EBAB-4C65-83F2-032C41F6D071', '4607086560464', '  --      500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA5ED6BE-7402-40DF-AA49-CE12113F7687', '368E87B4-EFDF-4617-941B-95D8022AD3D4', '4607086560488', '  -  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE0C6894-1A3A-445C-8346-E29EF563053B', '46C7E4A4-D26D-4496-8628-D02E32E1A553', '4607086560501', '       6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31BBC29A-143A-4CFF-86D7-B31F15A4E06A', '23DEF0A0-B012-4028-943D-0CEDF049B53D', '4607086560785', '     90 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C25A386-5133-4C19-BE54-FE70F905FF92', 'B8C61084-AB4D-45C8-8E04-7AD9A5C46CF5', '4607086560884', '    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF906A0D-0759-4F57-847E-AC7FAA7D222C', 'A99389C1-0EDF-4B01-9B8F-E61FC68FB630', '4607086561300', '      6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9CB4F58-4170-4C16-8E3C-B8A52CFAA41B', 'DD2207EF-DFF6-438A-B345-582D4794DFC7', '4607086561829', '    /   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7984D45-21AF-48B1-AF16-9D3BE8BB0346', 'D3C9677A-B5B8-4BF9-BF66-B42B60DF71BD', '4607086561836', '        90 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D60A2EC-502E-4219-830F-BE4ABFE35985', '1335762E-546F-451A-A8F7-5318B00F148C', '4607086561843', '    /      90 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA03C221-E7F3-48F7-A6D9-0AC9CD8120FB', 'D63E0604-CDCE-4132-8404-A154689D85D1', '4607086562123', '    /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('803EF691-EAE8-43A6-8B2F-41B9D38D155E', '762D2393-D8C9-4B86-8C2C-28B45F03A99C', '4607086562130', '    /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B6A5F62-A836-44EA-900F-AB22D6E47A8D', '78CDA7BC-C3DC-447A-8291-DC318989FE02', '4607086562147', '      15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B2ED487-D4DD-4ABC-8349-D3F4A832F9CD', '9C2F5677-E1FD-440C-9604-A3EF54589329', '4607086562161', '  /   15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('856A69E0-C31A-4CE8-BEC3-43C44DB00E37', '23CA0362-A0B5-4AF2-9A01-63B5B6E98989', '4607086562178', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5050287-3EA6-4E9D-A9B4-926127632D84', '73DAE369-987A-4206-8CB9-C6CBEC323B3A', '4607086562185', '   /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAF9B13D-CF9E-4EFA-80B5-CDC201037B5F', '42AA19AC-BFB0-4CCA-A81D-58C715F76161', '4607086562215', ' - /  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EE901D1-AECD-4A76-94F2-DBDE9112EBB7', '8A6D5AC9-0BBD-41BA-A562-91FA5600CDFB', '4607086562239', '-   / / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('782ABF65-3E81-4FA2-86A2-3AD8D469D27B', '3B1C1153-4337-4E2B-AB7D-7DEB08DEBA8B', '4607086562253', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16F452DD-9551-4B90-9BCA-DBB23851315B', '73D9C2A2-B8B0-41BC-A7F0-B3F17A767180', '4607086562260', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4787F8E-B245-4DBA-B6A0-30CE669822EE', 'D2A6624E-5796-4C11-93DC-8963DBBCB4B8', '4607086562307', '  /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC37EA71-DC1C-4ADA-A82F-1B2DFB4A2EF7', 'ECF3136D-92E5-45B3-A0E1-1FF2D99D887E', '4607086562390', '       400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E905E615-1AD2-4EA4-8E8C-6A97ADF748E3', '4A366114-7FE4-442E-B8B0-A6D9548B83C7', '4607086562406', '     /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8B56EB7-17D5-49C7-8C1B-25178CE35F26', 'C5D1D5D7-F8C0-48E5-B1DB-FD6B86A7C068', '4607086562413', '       400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8526B9E-B1D0-4197-8BB2-17A8C6F08119', '434526B6-82B5-4C80-B5E8-BAD8FB3C264C', '4607086562550', '    /. ./ 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8061CA60-0033-4A00-BD34-0511294721C9', '42FB2BFD-7847-4D14-8C8E-EA1FD769EDD0', '4607086562581', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEA86C33-1D6F-4899-8403-147A4EAE6454', '3AE01D5C-DF3A-4971-AA27-EAFF3ED25A9E', '4607086562628', '  - .  500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35EF71A3-4E44-4B61-AD33-DDED8EDA26C9', '812FE9E5-A8D0-498D-A053-D6DCBE7696E1', '4607086562765', '       // 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2B05C9F-FF4A-4DC7-8A5C-830ADA3562F4', 'C70E8CD7-04DD-4BA2-95B9-8ECCB8AAB227', '4607086562772', ' immuno    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8B44500-FBAC-404F-B014-208E16C243AD', '84A0B807-530B-498C-8D19-3A418AA21A71', '4607086562826', ' immuno   210', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88B33A82-7E49-4851-BB27-5204B9524053', '39FDFC9E-B2FC-46F0-A473-0BEFDF379218', '4607086562888', '      10  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FC7D65A-2DE2-434A-97EB-11700A03C78B', 'FD3EA51E-817E-4D38-85DF-4F54A25E0E3E', '4607086562918', '        250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D19C935E-76F2-460F-82C9-F2024AA6E86C', '97AE5EB2-D78F-4537-80EF-C53391ACCC8C', '4607086562963', '  -  /    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64514B0A-1347-47C4-84E2-FE2C481505E7', '86660E61-1FF4-483B-926A-162239B111D3', '4607086562987', '  -  / /  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('496EA892-49FF-4641-89E1-7E439EF625A4', 'E9CFEEC5-658D-4593-8269-7A02638B8E8D', '4607086563045', '     /    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67FB7EC9-9DB2-47B6-9709-1B4C45BCD060', '4185C37D-C7D1-4A34-A58B-10364AA90297', '4607086563052', '     /250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9E354F3-4B2A-46FB-9273-41B8E8F2B192', 'F678C778-CC81-4724-A93D-1D0E73F4E422', '4607086563069', '        400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('364FEC0A-73A3-47FD-8E62-B4740FF864F8', 'FA9CB4CB-AD12-4635-A6E4-448A5914E4ED', '4607086563076', '     /170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFB45038-5DE0-4BC1-8F7C-D41838D4A62D', 'EE2E5AF3-1B21-41FB-A63C-7277CF26C33F', '4607086563212', '    - /              300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('571F2916-EC7A-4471-9E10-905A90B15441', '3CE36E56-F90C-42C2-A232-738E87B6315B', '4607086563304', 'Novosvit stop  -     / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB2B0B87-BFF7-48CD-AF5C-396464EF3FA6', '2C182B0C-41B9-40AD-BD76-2DFBA42A18A5', '4607086563564', ' -  /// /3564/ 460', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07A477A9-6BAA-425B-A8B4-31DFF94E8485', 'D590E514-1981-4D93-84C3-BD1659E67E77', '4607086563656', '  active 3  1 ++   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCCB2340-38BB-428A-87DC-E82300C0B5A4', 'DCAEC1C8-4231-43B8-980E-3CBE8B71EF8F', '4607086563670', ' turbo active    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CB36541-3397-459A-BDEB-5A92637F5957', '496076B6-8CC3-4566-A5D1-3FFB4FD90870', '4607086563687', '   active sos     50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72283838-3338-425F-AF51-3B0434C0508A', 'A297D401-1278-4499-9793-D120E864A221', '4607086563809', '     /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BE5E27D-833E-4A6E-977D-6F40A5968B6D', '25B64D6E-7A97-4D3B-B269-3E3F814490CC', '4607086563823', '  - /    350 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50CACDD9-CC8E-4AA3-8D17-C56E247B14AF', '9F3648EA-16E0-4EC6-A602-DECF858DBC50', '4607086563830', '  - /  350 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D57E0EB-8B8B-4940-A981-651B02F36C21', 'D76A1534-FE36-4A4C-BEC7-940B4198B23C', '4607086563939', ' -sos   /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF8BCEBF-0619-4767-93BE-DA8FDF7E00DD', '0741B985-EB8C-4589-869D-87423F1A4E06', '4607086564004', ' pore vacuum - /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5514B71B-4716-4ACE-B044-85B28E9303B1', 'E835ED5C-68E1-4522-A437-318FB2628F37', '4607086564011', '   /  . 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9E69485-5B3E-4079-9E22-264F52CBB587', '041B8145-1503-4655-91B2-A5165CF115E4', '4607086564196', '    /       300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6325760-E37C-493A-9883-95A604CB5F69', 'E91D8B8C-ED65-4904-8877-CDBA97698334', '4607086564288', ' //   4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9195C2BD-05EC-47CE-BE95-E678D917F50E', 'E2800B52-C0FA-4A7D-A824-FA2CCABF8C62', '4607086564295', ' //     4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16959B4A-D70F-4A09-AD1F-7835A184E568', 'ABAABAED-9150-4C80-9AB3-7F64D8EAF182', '4607086564325', ' novosvit 24  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB2C4ABC-1727-44C7-B4A6-C8EABC1842F7', '2F831466-4B02-44EF-9766-35BC69E3B5FF', '4607086564370', ' agua-  / /4370/ 190', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16B8D864-F14B-403C-93CB-D3DC5BC829E8', '2E8D8AF4-AA33-412E-BC70-057124C83016', '4607086564448', '   /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7368CBD4-14FD-4263-A8BA-2E77083D9AB5', 'CA194F35-04B4-4C98-94E9-0D7BEC45FF8D', '4607086564479', ' /   21 / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36EB74FC-5DDA-4276-AC3A-AD23FD6693B1', 'FCD7FD4B-9FFB-4314-9E6F-D19A9A3ABDE8', '4607086564493', '  /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('364074C0-E033-49CB-9A54-D5FF75875AD6', '684F3D90-DBE3-40CA-B138-AF1F7BE150C6', '4607086564516', '            500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0A412FF-901E-4C38-BA14-773900D2C69C', '0C20F485-F081-4E37-805C-434834C1DA5E', '4607086564523', '    31 /  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B67975FA-4ACD-4B63-9446-AC4D53B29B5D', '45E02A85-5C94-4123-9977-A6435B437C4E', '4607086564561', '   /   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B54D312-354E-41B3-87D4-D52C253213DA', 'CEDEEA21-3891-4AA7-9D6C-441282A0961F', '4607086564578', 'Novosvit aqua-  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE53B44F-91DA-40AD-B5A7-7D68C68C7410', '745DC312-A75B-4183-934A-2FF7B02C11A1', '4607086564592', ' - concentrate - 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE67A778-1AA6-4430-B83E-A0E6A22144AF', 'FE1428ED-FE3E-4A3B-8C0F-728D94171871', '4607086564660', ' pore vacuum  /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCAE1C5B-D886-40E2-8050-E5941C4FED4B', 'B094ABE8-9309-4853-8768-506A0D2C1FDC', '4607086564738', '   /  460', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE52CED5-3957-456A-B11B-62C2C01EBBAA', 'D377E0BE-6CF0-433E-BA90-297AF245C60B', '4607086564776', ' - concentrate   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24A040F9-5FF1-42BB-B169-4B2C2B7E2E01', 'F2F5321E-A1AC-4E44-B001-A03909EA531D', '4607086564844', '  /   12% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('743954E2-3AF1-461B-AA9B-4D6912F4319C', '8E07064C-2E3A-4E16-A23B-C43716F6D75B', '4607086564851', ' estetic red   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D94B8276-5AB8-4613-9FF1-D9FB797F3CD5', '8E62695E-C1D7-4936-BD10-598B47281298', '4607086565087', '   /,      160 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74279CA8-FEB6-4AB9-8C91-A05F2F6591B3', '9E48193C-A60C-4FA1-9D39-502EF0F5F4B5', '4607086565100', 'Novosvit - /, concentrate  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F650B1AE-41F1-45A8-8AED-C03C5667F403', '9E6ED5F5-89C9-4877-80FC-BE24BCBFABA1', '4607086565353', ' volcanic clay +   / + 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('699C0F30-2FBE-48A4-8FDE-7AD02390794C', 'FC16BCB8-3F5F-4D4F-9007-87A10E049023', '4607086565391', '    /.. /.././ 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD6D72CE-996F-472B-A7BE-00EC5892CCD3', '16E7C5D2-EC9E-4EE1-A181-C30C437CE9DD', '4607086566121', '   /   4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D9F695D-4B5D-4CC7-935C-3FAE189999F7', '1006537F-AFDC-4247-8C68-2AB60FBF82BB', '4607086566138', ' pore vacuum   d-   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB6371DD-650A-42DF-8399-3E314759935C', '0A5011F2-55CF-40AC-BCA5-8E536FCE7F37', '4607086566541', '  /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A614FB37-5F1C-4971-8140-8FE482E1BE6A', 'DC28DF82-453A-4FE9-909B-F590F390B2FB', '4607086566558', '  /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34ADC173-3CEA-4FEB-B6FD-E12037878F61', 'E9F26614-26B4-43FB-82FC-369054B804EA', '4607086566565', '  / / 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('834EDE2B-D3DB-4742-9B0F-00D141155E02', '0A4265CF-F59D-446F-920A-8C9F6980568C', '4607086566633', ' - /   , ,      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('394F3127-7AB6-4166-977A-2696D1D7DF8B', '6903A293-9EE3-43F7-BE39-0100172BE509', '4607086566688', '  - nutrition  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D324970-202A-4888-AE67-BA1964616500', '65F9626F-9F49-4033-A636-F6C30EDB9BB2', '4607086566695', '    + 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6BCF629-1436-4194-AD1A-02CF24AD9F82', 'FF23CBB7-F9A7-4FAA-82B0-2A8A1F995534', '4607086566701', '  - nutrition + 170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7D78F43-EC2B-4E91-AED4-95E7528AAA4E', 'B4DEA72D-CFE8-454E-ACF9-1C49C4232BA7', '4607086566718', '   intensive nutrition + 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('552665CA-FF29-49F4-A779-78A6025AD603', 'F66A00F8-4352-4FAB-B91E-3A0918F85D28', '4607086566725', '      + 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B72BACD9-4DA9-41DD-B75E-59FE592CA86C', '84928D6E-3CE8-4DE7-A814-4744E525E71A', '4607086566732', '   /   + 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('445F1F5C-BF6D-4566-AF16-1C9270735CDE', 'E14CCBF6-9FDE-4560-A797-CA2A0A0D5CD7', '4607086566749', '   filler  + 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8744721C-B157-44E6-8476-917D1E5E2F6D', '2F58CB73-F82F-4EBF-A449-DAB6ECB22B77', '4607086566756', '  / -/  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63D83C11-5458-418E-AEEA-8A4569558DB4', '1ABBD660-472F-4654-B92E-C3909DB7F7DD', '4607086566770', '    + - /. /  / /6770/ 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA7D620F-F63F-49C2-B96B-476733F1E9C6', 'FB39834A-9A37-48BD-911B-0FB035AD0244', '4607086566787', '   /   + 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CA3081E-5039-44F1-935D-80ACA8F8C4F7', 'CB5C1CAA-D644-4CB2-8340-9DC6693F41A7', '4607086566794', '     + /. /  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F4EDC4F-6442-4F25-851C-F9C5455B739F', '3576166F-4E98-4D07-8A98-F2CAB68CBD04', '4607086566817', '   /  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC0339BC-5854-4A6C-A111-22AB1987A2A0', '24AAD6E6-99A6-45D1-A59B-959AC97464BE', '4607086566831', '   / /  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('161F08AA-473F-41B1-9CF9-039B1F214295', 'D7FEB826-7DCC-4D83-A9BC-904B9A9B2E0C', '4607086566879', '        /6879/ 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD65C1A5-1B22-445E-B88A-81DD28477EBA', '17774EB6-3281-49C4-B97D-DAFA4AFB9C2D', '4607086566923', 'Novosvit aquabase -     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE9C7B38-F3E7-4F3B-93EA-BA4224B98929', 'DF74C4D0-5547-4F78-A81E-3E80A198D8A4', '4607086566930', 'Novosvit aquaboost    /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E762C9BE-DB81-46FE-A074-BB44A112BCF2', '44D7F076-215B-4AF3-ADCB-148A16039665', '4607086567005', 'Novosvit aquafiller -  /  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCD54C9E-6208-48F0-8DBC-660A514F6BEB', 'CA929AE5-69B8-4C80-82A8-7F67F9AC6921', '4607086567166', '    / /.     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94F0E7E1-1F34-4077-AD9B-E7DB0150BF48', '43EED191-94F6-4362-AD4D-8360E3812B3A', '4607086567173', '    / /.      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AF1E17C-BD36-4DFB-9579-6487B38B2423', '132802AC-0A05-44EC-95EA-5CF1EB1B8A38', '4607086567210', ' novosvit  /   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('151424ED-3261-45A3-B9B3-34F80FC7D978', '901D2ED7-070D-4604-9F84-536466DB4E49', '4607086567265', 'Novosvit  - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D49CBBB-B97F-4FB7-AA2E-3801EFA4ABEF', '063E7031-893F-4A56-BD8D-9B3951283DBB', '4607086567272', '    /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80764036-DCD2-408B-8738-BADB57BFC31B', '56EB56D3-925D-4D79-89F9-82DA062D5791', '4607086567289', '  -  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D07E35EB-F1CA-4B8C-89CB-484F8409CE9A', '6FE075CD-0036-4917-BD85-509392904DE3', '4607086567296', '     .190', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B51CF54-47C2-44A3-8C7A-BE15DCF5F8B1', 'CA507993-CE3A-4C85-B65F-A8F0039A39E9', '4607086567319', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B37EFF3-6527-47D4-BDAB-43AAED771D22', '30089985-C25D-4750-9C01-DA06F95B6A75', '4607086568118', '     /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3C06DD9-661A-4995-8FE0-D93A0C2A8471', '4804F684-20F6-4412-A37C-26033171744C', '4607086568125', '  /.  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DECF807A-83B5-4A77-A289-600814708866', '242D92DD-198C-4AC8-AA6F-C5B4ABD9B11A', '4607086568422', ' novosvit la mellar   / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E2EA6C0-6BAD-45DF-A265-F879C5E926F2', '3587E87D-E66C-4EFC-9AAC-D97EE1F18148', '4607086568439', '  la mellar      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EF705F4-57B2-4BA3-A1C0-942613E1DB09', 'EB396691-103F-4986-8270-A334E5E9BD9E', '4607086568446', ' novosvit la mellar  /     20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4A5DA9F-AA2C-4734-A9B2-3EDEE8637688', '7BE7A2B8-6930-4FF1-A01C-30277B25572F', '4607086568453', ' novosvit la mellar    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5003764-BC8E-49D6-8C63-0DE3E0668834', 'DA8DEC19-CF2B-4F58-BD4F-0865089BB0B7', '4607086568460', ' sebum stop -   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADEA8E3D-34C1-4AD7-8447-AC5FE2528889', 'B6389108-9AFA-4D1A-B2CE-19FECFEEFBAB', '4607086568477', '  sebum stop - /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B72754A-F5BF-4149-BF93-05B5951FF2C8', 'EEC3987E-256D-46DC-B233-F84C7A32293D', '4607086568613', ' -  / 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E864EF2-9D40-4D13-B949-3DEC5B034691', '3FD3F542-928D-4DA3-9813-00EF8C5911FD', '4607086568682', ' estetic red zinc oide -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0119984-BF32-479C-86CD-2BD58E490D59', '4EB62984-E3A1-4DB4-89A3-3C13688EB467', '4607086568743', '     / 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE2388BB-32A1-4A5E-8FB5-D123279871E1', '4709A33E-0E57-4B19-B486-059B066F698F', '4607086568828', '   /  260 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF5F449B-94C1-4D80-A26E-4B6C270AEDF2', '7486D89E-5CC9-42AD-B088-B503AC3E3645', '4607086569214', '   /    31 110', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38D29872-1EBB-483F-8DFF-39696D2F3CDB', '3BA2A18A-208C-4024-9C0C-2E0E3A005583', '4607086569306', 'Novosvit - 3d     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B32E7A78-7234-4B04-A126-0ACB9457ECEF', '1C60CB4F-9391-4D9E-924C-B5505E774421', '4607086569313', 'Novosvit - /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B545CAEA-4847-4C41-97B5-56F87756CDB1', '92C3ACDC-B3BD-4AB4-9E30-8B79F436FE8C', '4607086569320', 'Novosvit -  /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F1AFF74-B9BF-4B4C-A564-08487B30D30E', '0D077F3D-38CC-4309-ACBB-088D891A78D5', '4607086569375', 'Novosvit ,fkmpfv /   12% 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A9BF801-9D3D-46F3-86D8-1DBF92A0AEAE', '65FA540C-EA25-48CD-9863-A603C7281B71', '4607086569580', '       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A013D692-1DEC-4DEA-BE0A-0130B77D6882', '6182FEE2-2987-4872-89CA-D641F3EF800B', '4607086569603', '     /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3031A436-7C57-43A4-A659-4F8DBFC52987', '61E66E9F-2401-4106-B06B-414A466BE42F', '4607086569610', '    /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D818F435-74ED-4DE6-8A00-0FD04620A0C3', 'A834A86A-F24D-469E-886F-8139AF8F87E8', '4607086569641', '  /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22D10E22-9962-4D50-8886-92FC89042AF7', '8DD9CD9D-81C3-400E-9C38-4C934000EC4F', '4607086569658', 'Novosvit  /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27137C0F-9E75-47EC-8E26-05A425DE0131', '28B1CD74-7617-42E8-9CDF-ABCF43301B30', '4607086569665', '   off  190', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13081E04-CBB1-4E48-B0CE-D04DE654D4DA', '798A9947-032E-40AA-AED7-74AD4471C33B', '4607086569832', '     ,  /   clay illite 400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F67EC95-6E02-4F93-93D0-A5BCBA81D6C3', '6FD05EDC-C4BF-4C04-80E2-85C69DE6278B', '4607086569894', ' - /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEBF121A-5CBA-4A80-9F55-57B94178F8D0', '6ECEE2D7-D79B-4B54-99FD-FF0575F69AA1', '4607086970027', '-   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('105E68B7-5A40-4750-869D-4EA6E2A53EB9', 'DF82F8CF-47DC-4A63-A969-25C968BF0EAD', '4607087856566', ' velvet /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('672DA2AB-15C5-4589-9ABD-2114A09A55A3', '84D68EE4-655A-4BE7-96DC-E699197190E0', '4607088741458', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E7E79E8-9EB4-4259-B155-BBC1ED8B247A', 'D1E26D18-8794-405A-9D16-9AEDE6F3ACEE', '4607088741465', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BB9E692-2004-440E-A775-7353B25A3DBA', '1475825F-7518-4F6F-AFDB-C83484617C68', '4607088741472', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01F50A0B-C2EA-44AA-9C8F-EAEA639CF723', '2430D753-DC71-4301-8540-BE63FFFD8ECE', '4607088741489', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E088CA19-1C5C-4B71-B6B3-5C9CEF6A085C', '34A0C23F-8E2A-41F0-84D1-ED0EAC758D47', '4607088741519', '   / 80 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('201F3D9F-37DE-42E7-AA45-135E386720F0', '5FE32741-8345-49AA-8A31-B161CB6C79B5', '4607088741533', '    80 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('265A04CD-0778-4A88-80DF-6D9EADBC75B8', 'CA8AC2A2-9002-4EBA-AA29-90F6AA11A822', '4607088741595', '    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3766734E-27B9-436B-B19C-C168BCD051F8', '885A1B08-7B0B-4247-B0EF-765F484DBDEE', '4607088741649', '        70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66837C04-D828-4AAC-A4C1-C604FC0D69F8', 'BB19AD64-F5D4-4164-93C7-F1BDCDA8A258', '4607088741656', '        70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2D32CDE-890E-43A2-9B0B-084A59021D13', '3607B177-521D-4115-A001-F6AACD9699A7', '4607091481075', '  /   intimate delicate 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CD79D3A-96CE-4AB7-B941-A6C584045F0C', '521D18D0-2647-4BD6-8BBF-416A311ACDE6', '4607091481235', '  mon rulon  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E46310AD-C542-41DC-881F-2BD461DF60E6', '4C14E5E1-4971-4A84-A903-044566575CC5', '4607091481242', '     80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('372BFB42-312F-4E64-B19B-003CDC3FF455', '91C53F81-F3E1-4292-8E34-5E5C58AAF106', '4607091481310', '  opticlean / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F27807C9-34E4-473F-BF8C-1861C63911CF', 'E4B29506-C80A-4B52-AEFB-04D1E6B1E5B9', '4607091481501', '    mon rulon 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('219DA893-E983-41BA-A853-272DF3F31A0B', 'DFD08096-2C87-49A6-BB52-CC6494F4690C', '4607091482041', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B11684F-79D1-45F9-A888-9E246BB1BE88', 'E4B29506-C80A-4B52-AEFB-04D1E6B1E5B9', '4607091483291', '    mon rulon 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B94BD56-31F1-4291-878A-7720FCDC362A', '9D3ECAD7-7E7F-41E9-94E3-741799716504', '4607091483307', '   / school 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79A136D8-BC73-47FF-AC2F-A9449C048114', 'CF7F4F9E-A886-4662-90D8-8E94FF124E9A', '4607091483970', '   / 72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DD23237-BE69-4B97-8DEF-0572AFFE21F3', 'B0E3E508-4790-4387-82DE-ABE5590A3E9E', '4607091484793', '   mon rulon 80+n15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5024B2A0-A512-4D9F-9EC8-683B0869C6F4', '5BD33540-D3C3-420F-803C-2526E0DD7DAB', '4607091484823', '    50+  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C87913B-A0A5-4B9B-84B9-277726CC5B20', '75EB7324-2771-4C2A-B56B-D365309B1722', '4607091484977', '        2 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D475EC8-F11E-4CF9-9EE4-A355B9EB05FC', '51A369C2-67AF-43C2-BBD0-BA137FCB561E', '4607091484984', '    503', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('335C5659-D85E-4DEF-A018-70C0884101A4', 'B28C4E81-F4B3-493E-9103-938E39BAE206', '4607091486087', '  9580 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A88137A1-9246-44D6-A53D-02740F2AD531', '7BD1BFB6-E0A1-48ED-931B-9CDF1FDF67F2', '4607091486407', '    /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F964CFF-FBB2-4C0A-B58D-E5FBA0ACE747', '901EA9A8-ED4D-4DCC-95B5-1F3808C06AD7', '4607091487077', ' salfeti  / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E7C6C49-9B10-48CD-BFFA-3602B056AA3C', 'F970132D-C1A6-4652-861D-D172985E7785', '4607091487121', ' salfeti   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB963EB3-B21A-4E4E-9110-5D38DB8F5A37', 'EDE085C3-6A57-43C2-9E24-621C4CC19BFB', '4607091487206', '  o vie /        15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('356223BB-F77A-41AC-8FCA-768F3C38A6F2', '53ACE79D-93BE-433F-93F3-2A5C620014EB', '4607091487237', '       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('938EC9F5-A132-43E0-9CDD-6023445264FD', 'FC04DDCC-1A8A-470C-81BE-D855006B7F12', '4607091487343', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC7F8FCD-3E36-493C-8382-F049CA0B2C33', 'C2A042BB-2447-4BE8-99C8-432EDEB4D9D4', '4607091487695', '   / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52E94D99-A69F-4DDE-A96B-E16FC64C6B07', '8DEDB15E-C9B2-4386-860A-57C9E677952A', '4607091488395', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53B559A0-2B6C-4794-9F7C-2F17D17D8A2B', 'DBA9B569-CDA5-43C9-839C-1A185BB7D19B', '4607092930107', '  0,9% 500 - 1 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3642C91-82C9-4B72-AE50-0615C358AB77', '35D09C13-C7D0-47FE-8988-94C2D0E83E79', '4607092930459', '  0,9% 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AE9D5C6-A4FB-4FEC-BCB1-7BA1D023CBE8', '15476363-1D54-427D-8C83-814D80712AC7', '4607092930497', ' 5% 250 - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EA0986E-0A7A-4C93-BE01-2DB40964E262', 'A9533040-D1DC-46AD-9E68-0CF4B01C1766', '4607093920107', '   0,75  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A43D8FBF-38B3-4A07-89BA-266942639A13', 'C4111EDF-E144-4307-A0EF-155B0AD60E3C', '4607094170020', '   /, ,  / 0+210mi 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEBDAA4F-9BCB-435E-BF5F-46BE34C2B94A', 'A915AE8C-FDB6-4F08-94F6-E671B0E2EC25', '4607094170150', '      0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6F0693D-82C4-487C-BEFA-387A486DA5AA', 'B7F74130-2146-47D1-B9D1-F688C1DE0325', '4607094170167', '      4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72020B36-A0E3-40C9-B3CE-EB5EC84AB9A4', 'B722D7E0-1533-4B0E-BD4A-FAA0713E6F48', '4607094170174', '      6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB954703-5AAC-457F-B4B8-BFAB2E35B05F', 'EF3B68A5-DCD8-45DB-AB03-37F98C5A0A9D', '4607094170358', '  /   4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3143DA2C-C427-4780-A3F3-1C752DC96A92', '26F76DDC-B66D-4EFE-9EB5-C0EEE4484DDD', '4607094170433', '  /   4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('341A3FCA-A39B-49D2-A026-BA3CC9B85B76', 'C22EEEFA-AA02-4AE4-A777-297281C5B182', '4607094170440', '    4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D215D6A-47EC-4B95-A90D-6C49D51C55B3', 'EEEB8AF9-95F6-4E90-9F30-FB6DA6A39902', '4607094170495', '    6+ /414/ 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB4DAE43-9A77-415B-8693-AF20E96395B4', '27BB74E5-D97B-434E-AE67-E0101CC87F23', '4607094170662', '      2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F33CF1AD-DAAC-4C8E-B62D-DB25B7FAFA9B', '99810F02-E3E2-4199-A8C4-354AC05917AC', '4607094170679', '  /    2  0+517mi', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('042E9A2E-012A-4EE0-A46C-A18A909E0D3D', '745A18B6-1168-4939-A546-8C6451B69FB9', '4607094170716', '  - 12+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6279FC5-B9A3-4D44-9650-A96909464902', 'D96C6CE4-EEA9-4321-9157-913B6A801173', '4607094170723', '  / 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7BA916C-E013-4635-A301-E6C161FC6E60', '994CAB45-1A00-4C3F-995A-C5E6BD1A9B3D', '4607094170754', '   /318/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8407AF24-5C03-4386-BD53-CC36F53B3C5C', '1DC970CA-6BEE-459E-A7A8-D1B0E8FBE1E5', '4607094170785', '   0+/ 718', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F7E33D2-D355-4139-B3F1-FF15EB2E97EA', '6DC7202B-D515-4158-AEF9-D26D891F25AD', '4607094170976', '  12+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C37482FA-1824-4D01-82FB-75CC03EFAF75', '67BCC19A-9C65-49A0-A7B2-AC7C21B225CC', '4607094173564', ' -     6+140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A06800D2-7750-4A0A-9131-D3C625EE3526', '5303B6C6-EC4A-451F-BE14-022E00BAF56F', '4607094173977', '   2    4+/2511/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BD1B76C-AD2D-475A-9114-8106F1CB144E', 'EC7D2A7A-025C-41A9-A800-AB11174ACE3B', '4607094174103', '      1013', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7557C821-1F34-485E-939C-121FE0938D79', 'AA614AB2-0740-4F21-A52A-418C3C19949E', '4607094174127', '      1113', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA60AF7E-B41A-4FFF-A358-FD6752952E54', '36C9C19B-9177-4A57-A0EF-2DA3BFA4B028', '4607094174455', '     1 8219', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B823E4C1-7F16-42A6-B898-995267CD1E45', '69D831FC-9CF7-40F6-98E4-DE30DE71CD64', '4607094174622', '  /   0+140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('662B6C0A-A389-4880-B15E-064AA189B196', 'B3D77F20-63C1-45F1-BEBE-D5CBC84CAC52', '4607094174646', '   ,    0+140 /3010/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA9FAE06-5A9E-4268-9485-750FF7CC708E', 'D94A15E4-3D62-4DEE-955C-88AB860FCC3A', '4607094174660', '      6+/ / / 240 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('482B7E28-ED30-49AE-951C-E99BBFC77A28', '605B7D7F-9FDC-47D7-A7F0-364B10BA016B', '4607094174677', '   /   6+240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C0BAE66-6271-4883-A05A-65174DAD654E', '046D5F41-2724-490B-9D75-B8C525633403', '4607094174721', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2705F147-03EF-48F9-9065-2B1DCD55FA8C', 'F1AF95F2-B479-42E0-AA34-88EF72C1169F', '4607094174776', ' -    0+/ /3612', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53953936-584C-4198-9971-539C8BBA2784', 'E9486917-81A1-485A-AA19-8948C0962822', '4607094174806', ' /    /3717/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5F791B0-108B-4CCA-A323-12E971C900E9', '9BF4811F-BC6F-418F-ACC4-75AB5BD78B17', '4607094175155', '     6+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4033C0C-CF10-438A-BFEB-3D80E1CB80B9', 'C4FAF66C-9D8D-45B5-979A-20D74A3F6BB2', '4607094175162', '     4+/4612/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('727331AD-6C47-4D82-AADA-87D773AD168C', 'D261C4CC-B565-4A27-8632-B498341EDD2B', '4607094175179', '    , ,   4+140  /3410 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E832FDC5-F679-41DC-BDE0-3B5CDA46365B', '48251584-6028-4E99-87A8-E7C7290998CC', '4607094175186', '     /, ,  / 6+3510 240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAD0A017-3C4F-415C-8408-F546D834426C', '5488D5A1-C8B3-4C30-BC82-E0B40742DE06', '4607094175278', ' -    0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C864869-215D-4C7E-BB69-F93EB622239C', '435EE4DB-1244-4034-BE56-FBA77A95F35E', '4607094175285', ' -  4+/3912/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C21377BA-74A5-4E3F-A3B3-668F9878B584', 'F3448C8E-DE6F-4661-B164-E60074482C20', '4607094175292', '     0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20FFC98D-57DE-4BA5-A4D1-36B4D28F9678', 'EBF83655-B00C-455C-8DAE-744CFFA838AA', '4607094175308', ' -    4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6FDD233-C742-48BD-99D4-4E8E5807E327', 'EB0CEEAC-EA62-4591-BEDF-8BF398F4C76B', '4607094175315', ' -    0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('064A021E-C59B-4991-9BC8-9D82D4EB84BA', 'BBFA521F-0A8B-464C-917F-9F33841F096E', '4607094175322', '    /, / 4+4312', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0057BF1-0BAF-4A64-8359-06B6CF3637A7', '21638B66-45E7-46CB-87FC-DE2F93E4B356', '4607094175339', '     0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C59FCDB-F717-49B3-9F06-EA13831AABED', '5BAEEAC5-4015-4FA4-9916-05F981C433A8', '4607094175353', ' -    4+/4512/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEC5E9D3-E09D-439D-8272-AD8F7E82E4E9', '958E1CA2-A70A-4666-8D9A-6C80CCC36383', '4607094175483', '      0+ 2715', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D88070E-60CE-47BF-B7E3-5EC215B1E2B7', '8A7DBCD7-0EC1-4983-9CB0-62EBF76ED1AB', '4607094175728', '  ""   4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EC98A7E-9C40-4CE7-B030-3B2F194DF34C', '9F049C62-C4F4-4A52-823D-4AD85CB60EE6', '4607094175735', '   /   3+ 2918', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6053522B-04DF-4168-BAC4-FFBCBCB73D99', '353CE6AB-AAF6-4CAA-A039-81FA3F9F66DC', '4607094175889', '    225', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('802E3AE4-EC48-4F8E-BC7B-8DB202EBFC3A', 'CF599772-3C73-4E0C-BD5B-888117A71C27', '4607094176152', '       2 4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6703DF5C-E644-4F22-8F72-4801CE178CBF', '12179C90-ADCC-497B-B2A4-E4221292C4F0', '4607094176190', '     2 /,  / 6+3215', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82DE7A2C-FF53-427B-AAAB-D14D2F078818', '9D1827E0-3E7C-4CFA-8041-9820DB98F460', '4607094176473', '  /-  0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43F07203-E9EE-430D-ADCB-653D9718F1C2', '961F95AE-230C-493A-8C55-048DFF4911E4', '4607094176480', '  //  0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2CFDF3C-24D5-4BA6-9BD0-B8FFF17517A9', 'F7D1DB93-D292-4094-96A8-E37352998BFA', '4607094176497', '  /  0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFF25954-E1A0-4F4E-9A23-AF0D4D0D4FFA', 'A7252A8E-4E9D-4504-890A-32F86BD2D0FC', '4607094176534', '        1 /,  / 6+3515 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB5E336D-DFBD-448E-971E-BE8415441732', '30327FAF-CB2E-4224-9442-BED93215069D', '4607094176596', '    180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F52775E-77FA-410A-A925-62906AB03234', '92ED1FDC-38F6-4E69-9D80-8B9F3ACA2C2D', '4607094176657', '    6+ 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A4DEB00-4033-4174-BF86-341597F043EA', '27401F70-103A-4DBB-BBF4-572ED79F7915', '4607094176800', '  /   0+125 4010', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC9A9242-95CB-4AE7-BEBF-DF262A94487C', '4C52DC9D-0FBF-4562-A186-CB4F2DF632D7', '4607094177005', '   1 30088', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54F2B9E6-66AD-43C2-B355-9A4688234790', '4D80A370-0073-40FA-B858-DF8A337F3CDD', '4607094509479', '  - 0,9% 50 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13558425-F7CE-4234-879C-6905A4C422D4', '92E925CA-A38D-4918-A534-C213DAA04CFE', '4607095330034', ' 50/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('681A8882-A096-4D5C-ABFB-1A714DAC1365', '8AF83E29-F63D-47FD-BCDF-206643A59977', '4607096870331', ' - 0,1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('514CD075-70B0-46FA-BFE6-4D6803324869', 'AAA6CF5E-19A6-455D-A699-704FC7F3D9C6', '4607097010583', '-  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDBA8A5A-E6E6-4495-8281-4BDE616B73DD', 'ADA441C0-CDEC-48B0-BD95-CCA41850FAE5', '4607097010590', '   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11A15921-B6AF-426B-841C-77ADB44C0E36', '08DC1F30-D50B-4942-81B1-4D915CD0A5BE', '4607097010606', '  625  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('311A860F-5094-451B-BB0B-17DAB2EC8318', '25938073-BB41-43F9-9E3D-25C61E807158', '4607097010811', '-    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42C87C93-4A91-4067-9761-9A2120B82A7F', '7FD9D5BE-82B6-4858-B580-385E4409A539', '4607097010828', '-   650  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E64C049B-463F-45A7-87CD-AAFE904BB061', 'BB705251-E682-46CA-A23F-860308F544EC', '4607097011481', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78AFB52E-3EC7-41B3-BC52-2CDC18C7FEB1', '3DDC7E86-C140-45B7-93A4-4F62CE0D3396', '4607097011498', '-3  500  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45938EC3-6094-4ECE-BBF0-131596479AD2', '867099E6-5D4C-4DA9-BC6F-F32134F6887A', '4607097011634', '  /   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3D7E191-96EE-4D24-AD85-171010FB4C3F', '243C3673-5227-41B7-BF79-69E46223D093', '4607097011641', ' //   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86391E23-8B43-4E1E-8650-054AFFC90B5F', '89CF6646-4BA5-4BC2-9C56-B5711E385925', '4607097011658', '   // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A0F514B-4391-4910-A86A-24ED320F36EE', 'DDD70436-03D9-45AC-8D8B-F1D9ED538F20', '4607097011665', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('325C7D46-376C-494D-9508-06DDA811AF10', '5B15C9F1-48E5-4D8C-A2BA-9C664DA8C6BB', '4607097011672', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DFE887A-3FBD-4105-B94F-B0A7319E3CE2', 'C052994A-F24B-4895-B8E1-36FCB3AA1FFA', '4607097011689', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('658B3D4F-BE06-4E20-88CC-163AE1E976CD', '3DAB297E-D16D-42F6-AE40-8947721742A7', '4607097011801', ' q10 700  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A966D9A2-96B6-4925-800E-1B1204D356AC', '99C660D5-AB3D-424F-A5F0-1917B71A834A', '4607097011870', '         100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C296675-D87E-43A6-9D76-C858C09F2818', '9C78AB0B-971F-47AA-84A9-710E508B4B6C', '4607097011887', '    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('349CF6A8-E906-4543-BC90-082053D977E7', 'ADAAFE29-7C5B-45B5-A0ED-8059EBA09625', '4607097011894', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2309FA76-9AEF-441E-9B86-786C24EE4DB1', '6AF69D7A-4302-4CEF-8811-54B445B710AD', '4607097011900', '    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4A9D1CF-CE78-4299-B0F8-15CE4DDA1B60', '5643359F-2EBB-4CDA-AFC4-0B6CBE0E31FD', '4607097011917', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FC7066E-DAD7-4CEE-A037-3311198E43E3', 'C4B7ED73-C5BD-4007-A4E9-105AD88A9639', '4607097011924', '  0,33  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05DD5FD9-F8B6-40D2-85BC-DFB6FFE03DFB', '23F58CAF-46C5-4F23-BF2A-E584809F784C', '4607097011931', ' . -6 330  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F82BC080-151B-4002-B4F7-736326930101', 'E407E4A7-5EE7-413D-A4D9-9127849E178E', '4607097011948', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1F2103A-B082-4CFC-9261-A19B5A734BD8', '6470D535-A687-48FD-B7F2-2FEABBF45B37', '4607097011962', '  0,34  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('814EDB55-BD5C-4CCD-B0C5-37239A4B83B9', 'D8630A75-9A9F-466D-98DE-A16D54E3E68E', '4607097012198', '    0,4  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99650665-AEF1-4540-AA1A-B9B756DFB560', '01761B34-9FD7-48CE-9559-B7C46DF9DCCA', '4607097012594', '-   / 1+1/  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('576503AC-3B40-4B5E-BBC8-206D873B1CCB', '9AC00093-DF41-4039-AB49-2E3AF592FB5D', '4607097012662', '        30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7318032-6998-4660-B677-579DD7889EB5', '56B3CB51-4445-4DD0-9B5B-AD4981EDF578', '4607097013430', '   --  400 -   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27227AD5-A495-4BCE-BC28-B5B72D6F1649', 'BFEC6DD9-B7E9-4782-8CED-16273352BCFF', '4607097013447', '   --  400   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AE4164F-005B-4A98-8103-B77B177AA22A', 'F4D4E9EB-9F50-405E-970C-7E2F8EB341D6', '4607098450012', '  125+31,25 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8697931-D4F3-44F9-9F58-72898BABB94E', '3762256F-79BA-4CFD-B4CC-3BF151828319', '4607098450098', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDE96FDB-F0F8-4DE3-B130-2F66AA1C47EC', 'BCCFE2C5-C11F-47E4-84ED-873E15003CE5', '4607098450111', ' 10 //.  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0FEBA50-8827-496D-9219-113C17896026', 'C1CBE67A-9B1F-4677-A895-6454D7828C83', '4607098450128', '  400  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EAF3530-EA56-43BB-BB04-BC930BD61A86', '748D11A6-BF94-4555-A385-EF154E95E405', '4607098450210', ' 0,1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('786F79C0-F20A-4A0A-B386-DDBD779ABDA6', '317C6423-C4DA-4C9A-B958-B7C5D59BBA6E', '4607098450388', ' 0,4  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A49DC05-472F-4AC2-B2FC-02F3DB95F4CA', 'A7FCD798-C0F4-4400-B3BF-8DBAE486A20A', '4607098450463', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CEC849A-AA5D-4135-AE4B-928964242733', '4D460964-16B1-4409-AF82-EC455D0F86EE', '4607098450470', '  2% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4EAA5F9-B335-4C9A-949C-0E8F4662DE0F', 'F6DE4F28-5C0D-40D1-B159-1CAEF39D4ADD', '4607098450487', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEAC547B-7AD1-4E59-9CD4-B8B780DF0406', 'D8771173-DD8E-43DB-A356-900CD43E8F00', '4607098450494', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D5CA03C-98B5-409B-8799-C79A1CD99C8B', '64A91E92-9CD5-47C0-AA81-8174033B209A', '4607098450500', ' 0,5% 3,5 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB08AFC8-5C8E-4A75-8419-EB49A1701799', '2E8403F7-8027-4EDE-ABDB-FC7687709933', '4607098450586', '  0,03% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C293DAD-7FF1-4A88-B959-FEDFB88370D3', '91E38B6D-7C64-404B-BBA8-85A8F7BEAA6A', '4607098450623', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECCA7B65-D8A7-47FA-A41D-61097FBA4F10', '80AB18E8-D096-4EAD-9377-56059D39C773', '4607098450678', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE3FFA22-341C-4CA0-9F7C-0E30A9174B48', 'D7A671F2-6C6E-418B-B8CE-CD40770F7399', '4607098450685', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F98E48F3-3091-4D3F-9A68-9FB7CF3A8662', '9B2AB298-BC19-4DE8-8C8F-0BC509C6DEC9', '4607098450753', ' 0,1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F34523B-2059-4228-9414-E5DA2A665C8D', '9CEF3D72-6250-472D-9DFB-A4AEC7A84A71', '4607098450791', '   875+12514 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBB24011-4A8D-461D-AF7A-FB24C62B66F1', 'B0A43B32-3916-4856-A18E-7EDF79E093BC', '4607098450814', ' 100   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF08BA68-3319-4E0E-B521-CB825CF3014E', 'F768FBE3-A587-417F-982C-43961D281286', '4607098450920', '  0,1% 30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76E11C15-29D8-4207-9642-8541CBE77C13', 'A8FD6E5A-C5FB-4EBD-9818-974DBE55E208', '4607098451217', ' 100 5  / 30,3-35   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00584D64-165C-4D0E-BB72-4757C6926CCF', '6EEED415-3E88-48B3-B507-03A54354EFBF', '4607098451224', ' 0,4 6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53CE2068-6644-48F3-ADEB-61B7305E1BDE', '5BEDA9DD-F571-48AB-8D00-82E6EB1F85B5', '4607098451316', '  400  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB5A32BC-DAB4-4755-8ACB-B12A3BED4A53', '9F7E6F7E-9C3B-4881-9E99-3AEB730A70E7', '4607098451385', ' 50  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC3B4B02-ADBD-4645-9D4D-2DC476F409E9', '200183ED-3656-4BDC-B6E1-AAD598D11B2F', '4607098451408', ' 6+0,4  . . //.  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD16DAD2-B084-4354-B427-02B2E63B71F4', '1E105FA8-F1FB-4215-8FA1-5161A9F57FBC', '4607098451415', ' 0,006+0,0004    .. / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C74E5F9D-BE16-4889-879A-0C42A9EC6582', '06696A90-7BAD-4573-BB4C-39E9145A7627', '4607098451477', ' 16  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BEB5DDD-A53C-487B-BB50-42ECFD07F0D3', '4F2F1EAE-28AF-40CA-9F0D-92E0F74CE8B9', '4607100621096', '  . . 0,9% 500 - / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1B6A65D-1B52-415D-8733-BF2F6596D846', '5A961A85-8333-4F57-B86E-8D4C47DE6DE4', '4607100621294', '  0,9% 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25ACE993-5ECF-48BE-8731-903764B8052A', 'EBD897DF-1242-415D-B0C7-A95415E6A89D', '4607100621300', '  0,9% 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('345160A0-24E9-4CA4-819F-FDD92B0C3363', '144DD464-81E6-453A-AAEF-B6FA02DDB922', '4607100621577', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4132A73B-7AA5-443D-8789-7CD4D3CBCEB4', 'F272C6DC-FFD7-4BDF-B7B8-7F1660531E1B', '4607100621584', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DBF8F02-488D-439A-8DD2-2CFA4CFC24E5', 'E5AF47AF-3402-4416-897A-F21C124B6BE1', '4607100621676', ' 200  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('647EB4DD-F788-47AF-A01F-1C4EA541CAEA', 'B0CF804F-E3CE-4C9F-9F4A-0A9685469357', '4607100621744', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AC8898A-C417-41BD-9B04-383AF0229631', 'FBC2B143-7D55-4D7A-BB6F-0CA0AE9195D9', '4607100621782', ' 50  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C75E70FC-61B0-4602-9326-A1F630583B6D', 'DC61172D-F5AD-435A-9527-CCC4FB34F4D1', '4607100621850', ' 25 // //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8918C48C-7B66-464D-BD5A-DDBEB894ABD1', 'E474DF38-0BF9-482C-8581-8F12A2E77E13', '4607100622185', ' 500   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05A56F03-21C0-43BC-8F5C-0A7BF35BBAE0', 'C611E7C4-F7B8-4E4B-87F2-5D421BEA1417', '4607100622215', ' 40  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39BBA561-45EB-4AD8-9F5C-5909132EB1C3', '021CD599-FFB8-4EA4-951A-32F585A4E48F', '4607100622222', '  40  48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('666613B7-CDBF-46B3-9AC5-856DDEF1EE79', 'F9B826CF-4F31-4843-B5B0-C55083207F8E', '4607100622277', ' 100   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9380B731-A3C7-4BFA-8D0B-16A4CAB2A187', '1ACDDF49-A413-4867-9DB6-1EE4C961969B', '4607100622314', '- 500+100   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32E9DA26-19A6-4B0B-9F8D-E78D125B61A9', '43275E05-8E1A-4150-A11C-8C7A57206CF5', '4607100622345', '  0,25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E08DBBF-0CE7-4E8C-BB1C-75EA03099EF7', '138EB404-F55D-4322-BFAE-AA74A86B0C39', '4607101200160', '-    "".  6 .,  230., , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53B744F4-F7AB-4060-A1DA-1A4184931661', '1A3F0600-63DC-47FD-8DD3-129530F27986', '4607101200184', ' twist .    6./11836 320', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DB3F444-84EA-4F33-9079-036588717A73', 'C0FC5209-7B39-4300-8C8C-9129C4CF0EC0', '4607101200443', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('860BB399-A0C6-46F4-B8F3-F6F2C3A5058B', '15160F0A-FECE-41AD-903D-18F7AB3E0804', '4607101200641', '- "  ".  0 ., ,  , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('559D911C-8207-40E7-88A2-E05559392548', '0158EE87-692C-4FDE-8BA8-E4ABC9C325FF', '4607101200658', ' "".  3 .,  ,  , , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7306C0C-3FB0-4A49-A37F-932DFE148359', 'F57CC1CA-31A6-4734-B5D5-8014FEEF74E0', '4607101200733', '    4.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9A6D901-02D1-4E76-A527-8586CE11338F', 'EE89A2F8-4357-4E9F-9902-9CDC9BDF5307', '4607101200818', '  /4541/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C64DD24-3110-47E5-87AA-4D8C81F5AD36', '3C3048F9-034A-4113-88D8-995DB6C8C4D8', '4607101200825', ' / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A00E91C-A02F-4E74-AECA-1CEFC12F47F4', '789DFFB9-E847-4A27-8128-EE29A547FCF0', '4607101200832', '    /10472/4543', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A26D69F-3614-4293-9655-581CCF9D3ACC', '367D793F-2FEB-45C2-A40E-13E1FE3B23C0', '4607101200917', '-   .    3.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3F1CDD1-CB70-4832-A5EB-BB4896AB74D2', 'FEF0580C-A7F0-49F0-B632-2387BBC7090E', '4607101200931', '    3+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('398FB806-760F-41C9-AF05-8527749E6A5D', 'D2A0D914-0BD6-4803-99F2-81640C3C5483', '4607101201068', '    3. /14781', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A2BFD7E-C7EE-494E-8E8A-D21F472E74DB', '42A05323-A58B-408B-8EFB-E59522E3218D', '4607101201488', '   ,  4+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('860DC7EA-302C-4505-886F-C83AE0990904', '36A582D0-96AA-48AB-B592-1655B8DB92B5', '4607101201686', '4652/144/12   "LUX  M".  3 ., ,  , 2.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE412DE4-5B4F-4824-84D7-2A0560BAE633', '4590CFF4-E093-4DC8-9F95-109DE8B3B717', '4607101201716', '4662  .    2  3+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62E210BC-791F-414F-8578-FFD7F2684C95', '75F9BBEE-4AD6-4482-8735-152E24DB7F2E', '4607101201815', '      0+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47263C8B-4525-45FB-B1D3-B2E1E1DA1852', '7077FF29-BF9A-4A6D-9E6E-21D0229AEF4A', '4607101201822', '      /4655/ 3+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('171225BE-096B-46C4-95FD-FB7EB2A782A5', '6E1D303C-9D71-4F18-95F8-EAD282510593', '4607101201839', '4656/144/12   "L".  6 ., ,  , 2.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1359B337-B49C-4E09-AF4F-C3FA8A23CE03', '19DCF23C-50AC-48CC-A3BA-DDF3B76460E5', '4607101203093', ' LUBBY . ..  6 /4517/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51ACBAF9-017D-4D2C-ADD3-2A82CC0E1DC4', '44ECA5A2-E64C-4651-8063-82633456E8FD', '4607101203123', '    4688', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9228E00B-5C8F-415D-BF63-89BF618EF0BA', 'A92C3FFC-12DA-42FE-A3C9-00DAAD96BF96', '4607101203598', '13661/144/12   " ".  0., ,  , 2.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A907155D-CE03-44E7-9052-918E08A82DB9', '733471A6-580C-4CAA-B965-809F10540CA9', '4607101205028', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0672DFE3-4D2E-437E-B266-A6682084AB20', '8550AB4B-B4E1-404C-905F-361784CF261E', '4607101205097', '13695/288/24    "".  0 .,', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C368A66-8E7E-426B-86EE-FE13F526E6A3', '6411AB63-8C96-4112-8D2D-9F2AB7F95B0D', '4607101205240', ' .  -  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1137040A-D460-44BA-83F4-47277D281375', '14D30D17-8497-4F75-86E5-2A91BA55313C', '4607101205257', ' .  - L 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BC07795-C600-4A8B-842E-94D396C8A337', '78B3B1B4-DE4B-4EE4-B4BA-DFFBAD90F205', '4607101205318', '- " ".  0 .,  /11399/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2931B34D-8AE4-468E-899C-FDD531D4010D', 'E4403F5A-D518-4746-92B7-DA8EA99A3CA3', '4607101205325', ' " ".  6 ., ,  ,  ,', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD41912F-6C08-491B-BE55-AD2AC89B3A84', '97589E3B-F054-4DE5-9024-55BB86CCE7B8', '4607101205332', '11401/144/12 - "  ".  0 ., ,  , ,', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92EF96AC-5044-4B57-8741-33D8E64212FC', 'EDBE8E0D-F5B5-410A-9C30-76131F5A094D', '4607101205356', '  13696     4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('272F56A0-6F7C-42C4-A0AE-46670E8AB702', '8EF8D797-FF18-42CE-9C33-5B6BE23B43EC', '4607101205400', ' benovy    / m - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93B9C1AA-BD56-47D2-8E99-C8BBF67086F6', '3E4B8952-8876-40A0-9819-6C79BE4D7069', '4607101205424', '       0 .125.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28768B3D-A403-4412-B917-8CEA032CA523', 'B62A3FAC-2079-456A-88E9-660C6C377E1E', '4607101205431', '11391/144/12    "  ".    ., 240 -250 ., , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2FA8D34-6B9D-464E-BFC8-DD6AF49A49B5', '10BB1FD0-1C10-4D94-99FF-2434B49ECDE6', '4607101205516', '- "  ".  0 ., ,   7287', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE7C1713-B534-4BDF-80B3-D4F9148216C5', '2FECAEF0-8050-423B-9202-F44C2EB80FC0', '4607101205578', ' .    6./902015/7293', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C653F38-09C0-41D5-B9BA-C1DE1C2FC915', '38F402DE-7FF9-4922-9AB3-A927CF90FAD8', '4607101205639', ' LUBBY /. (.) .  4./7300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7237535A-533F-42AB-AFC1-E043844E3512', 'E8EE1373-E52C-4BC9-989E-DB15EA06B33A', '4607101205806', ' LUBBY 250       6./902003/7317', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('418E114F-5D0B-4F61-90AD-553BB8163A3B', '46A1A396-F303-4208-99A8-AF5CFB9C709D', '4607101205837', ' "/".  4 ., , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AC76D58-B17E-4C91-B3FE-46F3B52FA6BB', '5AE80B0B-C929-4EB3-9337-9390DF8729CB', '4607101209323', '       0 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4A80E98-51B8-4076-93F6-C70206D2D8C4', '2AC856A5-5452-4690-94C8-C401A000C71B', '4607101209361', '  . " " 0+ .,120 -125./12013/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE922CBC-0E6B-4DAE-8867-783B8AAE41D4', 'DDD326EE-0E8F-46EA-B5D9-27548837FE9D', '4607101209385', '     250  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('048372FF-0900-4166-BB18-AFA19731AB59', 'C238715C-39A7-4DBC-99E5-A4FB49AD7833', '4607101209408', '12019/144/12    " ".    ., 240 -250 .,,,', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FDC0799-4D0D-4106-A1B0-ADB57B21DFF4', '68080BEC-958A-4482-86A4-9C6A7A5927AE', '4607101209521', '11861/144/24   - "".  0 ., ,  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A63991E-54FF-4D11-8958-B32B8EFFE76E', '9ACFF621-7110-480E-9150-D9044C0FEC58', '4607101209705', '     2 /12011/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F3CC536-5A25-46DA-8949-4D463AF4977D', '1B3B60EA-9F2B-4611-A5D7-F94AD005FCE6', '4607103830013', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C736A773-C135-4598-90C4-BD45A1E6F9DE', 'E32A1BFA-CDD0-4D03-8BB4-BB57D6C92E75', '4607103830020', '   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D40AD59-021D-4ED0-A0D2-67F47F1F61ED', '393B3D62-86E3-4F55-97DE-647F324D77F5', '4607103830037', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09E5C718-E022-4479-AF2A-20B1C2E7D07D', 'EF318AD7-8449-4EE3-AC8F-1F6A86086E27', '4607103830044', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37F6803F-57E5-41DD-AE27-250DCA7CB20B', 'EA45E89F-609E-4D20-8972-E4DF3C4737BB', '4607104090263', ' - - au 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3624EC7-AE18-428F-A389-9FA3C81C07C8', 'DEEA7D1E-8834-4B2A-93A3-E3604C2CE228', '4607105370012', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F1DE0E9-6B17-4906-A7DB-CABBD6763A41', '8ED140F0-DE2E-4019-9371-95E3C807E0CF', '4607105370029', '     -01 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B23CD3F-322C-4F11-9F05-576E51E2F95D', 'A5D286D0-34D1-4B1C-A29B-9BE8E5E1E473', '4607106000017', '  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A583C808-3425-4DBE-B05A-D7F068E2CC4C', '98A99859-7CD5-4C31-A044-96049157B9B9', '4607106000031', '  1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('931DFDA6-309B-44AC-A573-153F8051F8E3', 'F7BC6B45-58F1-47A6-9ED4-E8EF7AAF1D34', '4607106000055', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFEF2DD7-F743-4A16-93AF-2427A696527B', 'C38F1EAF-8DC2-46D3-8870-0E1016A4A9AC', '4607106000505', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AC475FD-B380-40E9-84F7-BA31A5AE08AD', '341E35EC-B846-4C30-9899-B2969E0FB70E', '4607106000529', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EBFE734-0F02-4816-991F-D21CB251D62F', '23E9BB85-7438-4F16-9172-CE064D550C8F', '4607106001007', ' . / /  1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('369B2144-7A0B-44A0-AE77-661310E793D6', '74B71356-3227-47D2-8DEE-062E36B894D2', '4607106001106', '  meridian', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F7690FF-6EED-4B63-8BB6-18C45796EED6', 'DC235C11-9F64-4AC5-BE99-2598F47F5637', '4607106001342', ' 1,58 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A950E482-5F9A-44BC-8DD4-AFE4D1860ACD', 'FD23FB9B-8DF6-47AF-8BBE-E88035F8A07C', '4607106001441', ' 1,510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('639DE593-A722-4F88-BCCF-56133FE2431C', 'EAF05799-2E34-488D-9337-94781425E9F6', '4607106001465', ' 210  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6E4C95E-338D-460F-8E19-DAC377753994', '2BEC317C-0737-48E9-971F-A043659FACFB', '4607106001489', ' 310 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9733BA85-45ED-4726-8ADB-3C25271ABDE2', 'DE1B3FCC-8DF7-4CD7-9532-1CA03B02F11A', '4607106001830', ' 310 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A55D712-1100-4792-AA2C-35AA9C9780A8', 'B1F2BF8D-8644-47D8-AAC2-1CF91EDEEE8F', '4607106001854', ' 20 3  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89DDF8BE-EA45-4252-9010-E45EF1FE759A', '992F8499-1D01-445B-9745-B6F8FEB10541', '4607106001939', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79F41C29-93F0-4CB8-9946-B646419E372F', '4600C35D-9222-4234-B9C7-309DAB423B73', '4607106002141', ' /   /750 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68B50E3F-A588-4E16-A30B-8F4BE604A193', 'C072EFF1-76D4-4F60-92A0-FC3465E41EF6', '4607106002226', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86F2CF9E-1E53-491E-A3F6-F63186E1711F', '08991D22-D5AD-4948-AD3A-16B709B06566', '4607109401750', '   / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5C60075-D479-4E14-9006-76611E59A84B', '181D030C-9D80-4DE2-B69E-8247A23D3186', '4607109404171', '   /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6B9AB64-B4CB-4B32-85BD-BD05027901A1', '8B6C923D-AF5F-4256-A134-063DD1CEE93B', '4607109404423', '   / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54EC792A-4F56-47C5-AF67-71E6811D3B3E', '1C135CF7-D8CD-4EF1-AD1A-3B82FAE53182', '4607109404690', '   / /       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('764E66D1-17C1-40F9-BB05-09B8097DEB41', 'D23258D0-67B9-4F4E-8727-93F6BC5FF99F', '4607109404713', '   / .  /   ./ 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14EC3735-4BB6-4234-88BE-3A0167CCB882', 'D3516A90-B3ED-4A90-AEF4-83BA90559F53', '4607109405956', '  /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC1300B9-A506-4281-9E0A-64DC181EE3CA', '535898B3-91D3-44D2-A7C7-289C93867C52', '4607109406298', '  /   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E699475A-41EB-42AB-9103-B7963A6ED6BE', 'A4D62722-DAD6-4870-8CF8-0C6B8F6CA060', '4607109406915', '   /250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D84CDBFD-8556-48A0-B60A-2F614A6FED08', '1C262A3A-A6C6-486D-855E-44503D76A606', '4607109406939', '   / /      250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A48AEC50-4FC0-43E9-911A-69E57A48F7FA', 'C511C221-F655-4234-90A3-55BA60DE9DA6', '4607109406953', '  /  250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A210D4AD-F990-4355-8B0A-0388FAFEE958', 'CAEB4FF3-6506-4C7D-996E-30A0BA1BB23D', '4607109408308', '   18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63639D0B-84EA-4ACB-A1CC-C945F2B71EE2', 'F251F40F-4A71-4CD2-86AD-C86A528F6410', '4607109408322', '  lights  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71871384-BCD7-40E0-9BF0-730D18730CCA', 'A1646A7D-A34D-4497-8725-636714007AC3', '4607109408667', '    /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7972E42E-0314-407A-AFEC-4DD3CD580FCE', '21BD98B7-830E-469A-A275-23EB8B4FF559', '4607109409831', '   play vibration', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6504C86-C8E0-439C-980E-0DF4153DD115', 'DAF0AAFE-0E07-4F9A-8D9E-C3196753BC2C', '4607109409848', '      play love flames', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C3ED087-CC9F-4138-9AC9-F88E51465DE0', '89BAB4F9-8657-4677-8CC1-735EAFA65478', '4607109940310', '    0,9*1 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E849AC52-9F02-4AAB-8A7D-47BFBFA1E002', '3467CDAB-D052-4608-A1D1-5931DFA6FCC9', '4607109940334', '    0,9*2 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5F43AA0-01AA-49D1-9864-185DBDCEE579', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4607109940341', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21493EF5-0449-48FC-A743-B435A84FC304', 'C9FD621A-0A8A-4BF9-B655-87163A8F3A38', '4607109940358', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D84F67B-B2B9-44CD-BB09-57FD92DE9CE0', 'CB06A0F7-EC68-49D2-BA4B-29F8AA329F7A', '4607109940372', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F84F08FD-6306-4D07-A5D4-44301A4EF485', '7FF5C5A4-0702-4523-A630-B66CB1CE9364', '4607109940471', ' 50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E69C1690-4196-44B5-B178-CA2984FA249E', 'AF4A0261-868C-4AEA-9523-BC9A8CA3450B', '4607109940488', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BEA5EBA-7987-4109-B6AA-72B365DC3257', 'E7F9F3B0-A3DB-4208-A17A-A41F8B640B5F', '4607109940495', ' 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4529E024-D02C-4A90-B61D-D273A440937C', 'F5CE284C-BBA4-489D-866E-52F32B094EE3', '4607111072832', ' 1,58  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('013C4BF5-0B43-4608-B54B-BCE40FA8CBBC', 'E0CE916C-DDED-44DC-89DA-09708B98A021', '4607112248366', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B61893DB-494C-4BD4-92D6-892EDCEC0CA1', '2EC3387B-91D7-4CB8-8F8B-2695347D6B02', '4607112249714', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3703E85B-28EE-43FA-91CE-259232EF0081', '82178A56-C306-4D57-8B67-8543DC32556E', '4607112720329', ' 99   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E648338D-26BF-4C9D-825E-FD57491DB062', 'BA79C680-47C8-4E3D-8923-AB4DB489357D', '4607114290028', '   / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70AE7700-17C3-4EAA-95C9-3BD2FC093ED2', '961FD0B4-BCEA-4FC1-84FE-0AA01D89913D', '4607114290042', '   0,2  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6174755-BC8A-4331-93B4-A260ADEE46C0', '4B5E71F9-44C1-4B8E-8571-E7E53E2BEFCB', '4607114290110', '     .    0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F9F4BFC-FE1C-447F-92D7-F8150978ED1D', '2BB6F381-4FD7-4CB0-86F8-E9AF0D32D2F8', '4607116940037', '  0,9% 400 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA97C4AA-3DDB-49CA-8F47-898F588845AA', 'E49E7E0B-4EAB-4CED-AE50-274E66ADDF7A', '4607116940044', '  0,9% 400 - / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9F60FF9-5A71-47AE-8DC8-81A718C7340B', 'ABA61038-0446-4963-86BF-936353B39743', '4607116940174', '  5% 200 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C625BC0C-0A68-4968-B560-BD84273312A0', 'FBAC9F86-4A23-4F7E-9700-756D78B4CA46', '4607116940181', ' 5% 200 - 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('005C2686-DE35-4011-95A1-BEA410A9ED0C', '87A93CE2-AD33-4FCB-9B7B-A2B10ED89613', '4607116940198', ' 10% - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E3CC3DB-AA2E-43DC-B2DF-938D264E5DB9', '605D6E0E-3B98-4439-B367-D02F3B738166', '4607116940211', ' 5% 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDAE62EB-2E45-46C7-B856-78D82E228976', '8F4650EA-08CE-46DD-81BF-1B5D71CC27C4', '4607116940419', '  5% 100 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09C03134-916E-425F-B9EA-04EBADAF37AD', '25554982-DCC1-4A24-A909-8997765D1FA5', '4607116942574', ' 200 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CB65FC4-B8B6-461B-8426-2C6512102B6F', '4896F318-FFDD-4E5A-8EC3-E06DDF1F5D8E', '4607116944660', ' 5% 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFCA5B52-99BB-4F24-8022-A4369B54918A', '766DFD75-657C-4FA9-8BAF-56B9334B7476', '4607116944752', ' 5% - 500 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69A86C05-755D-46D1-986E-8730AA8B840D', '0B4DC3A3-03E7-496A-9651-435C4B5EC6CB', '4607116944950', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('911858F2-EAEE-4B2F-8272-CC4B836D0082', '740E4341-12C6-439C-81DC-1298721FB199', '4607116944967', '   0,9% 250 - / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED30D666-FFFA-4453-868A-7F8DF4ADA9C1', 'C1B488E0-8905-4161-BABC-B66CC695B2E1', '4607116944974', '   0,9% 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D191C17-E3D4-41F2-9BF0-1583E3E16D3C', '1EB06581-3A0A-40C6-A15A-DBFD84102A06', '4607116944981', '  0,9% 500 - / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAE16343-5750-4A1A-B3AE-61335B7816D8', 'F3E1CEED-5BF2-4C22-A5CF-2A9542C9F429', '4607117340348', '  200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23F6397E-3346-4A79-9817-58A22DBC849B', 'EC2EDA59-F2BC-41EE-A07E-0F6F32F337A3', '4607117340416', '  200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A0299A7-716C-4CA6-8D46-6C8827998EA6', '18089A75-BE89-4F32-8341-119074C67272', '4607117340942', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('810C44FD-F792-462D-AE9C-D17F99BB15DA', '375DC7B1-698D-4278-8148-2087DFBBBE9B', '4607117341765', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('725D9100-616A-4612-8FED-F976EB84083C', 'E05D7E88-8DD0-4DC8-8BCF-F136081F153D', '4607118050383', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A7FC97A-1341-4C76-8B88-A546F3F8C3F8', 'B996238C-AFEA-49BE-A1B7-7CFFAB80B870', '4607118050826', '   /2%250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7678901D-2E36-41D7-B50E-8377FAC0F27A', 'F62C6A3A-5168-4DD8-B48B-8F15DDCD74CE', '4607118053049', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2BCBB29-AF0E-4207-A135-098421539EAB', '75352BCD-5D78-43FA-82D7-6AB40FA4BDFB', '4607118053056', '    ..  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B88E6F32-B7AA-4FD6-8220-F22563076742', 'CD019761-5C89-492A-82C6-B4B6B1EA8690', '4607118053070', '     0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAFE5391-A91F-4F91-B211-CE3B6F85B852', 'F10C0BE8-09B2-45D1-AF94-A6B768873E70', '4607118053094', '   / / 100 0,37', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('520166A6-6547-445C-A256-4E87B0345A9F', '8B9AB090-790E-4B5D-BB57-36AB3CFF4609', '4607118053100', '  ,  0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4819866F-2C6B-4964-B5A8-CFBA17F99D99', 'C0B0C45C-17E3-41AD-B0D6-92AA25B98F55', '4607118053117', '  /  /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AF31847-21C8-46AE-8A50-9097797518B5', '35E4FE57-ED71-4991-9EFB-E62BAD9A1BB3', '4607118053162', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BCF1E33-CCE1-429D-BD5D-833A83600003', 'DF32FBBB-9EED-482D-9F03-4334470158C8', '4607119620066', ' 3%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B162F95-8784-4725-A03A-F65AD9D4C799', 'D3E84C2B-7730-4943-855A-1C00A0BBB039', '4607119620073', '  3% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36463780-0B04-4DF8-84B4-4E178C16477C', 'DC70549C-1302-4DE0-99B8-F32BE115E961', '4607119620158', '- 20  3%', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFC99446-3722-46E5-84F3-BCAB067E7E00', '87FFA145-B485-4949-8D1E-6A0C37B9A38E', '4607121690439', '     / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCD9D83D-34A6-4A81-A386-A95D5BB6F609', '9C04E66E-967D-4412-9CEB-E26EA98F024E', '4607121690514', '   .  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6759032D-8BE7-4E02-B6C3-625F0B7FE5F3', '135F62DD-1109-4A01-83A9-A23502648C88', '4607121694130', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C56C1246-F8EB-4DE8-B31F-C1B4EB1E181C', '4B497664-3619-4085-AF77-B8DB34AD834D', '4607122560403', ' /   4 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEA35F42-679F-4BE9-8D62-312453752639', '4B497664-3619-4085-AF77-B8DB34AD834D', '4607122560410', ' /   4 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75D9CCD8-82A8-4C70-A208-92FB4E839859', 'A74C260B-81DA-4F53-AACD-DCEE46DE1E27', '4607122560885', '   7  / /5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5588E0C3-65DF-4138-872D-D4C12F528123', '8782AD20-E45A-445F-8C2D-D9E1EF38A701', '4607122561622', '     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD5F60CC-C6C6-4C06-BB8E-ADD4E30121B2', 'C17BFE6B-164D-46FA-A0F4-3FF6A1B91FFA', '4607122565477', '    6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDB21E59-04FB-405E-BD3C-E9325BA2F29F', '3D7007DD-E4F7-432B-BF03-9B204B861E1B', '4607122565484', '   9060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('611B4223-3389-434E-BB86-E619AF4F8285', '92062739-E0E9-4161-849E-3498C429E180', '4607126030841', ' 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CA9F900-AC34-4CBC-9B0B-CDE9DD1E9EFA', 'F1CE0542-1A45-49EC-8A14-CAD0E28F1153', '4607126030902', ' 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCEA7576-2274-4291-B0DE-645A8F26C790', '17CC392B-0F90-4641-88E7-6486639A9B13', '4607128160386', '-  -   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0650626D-9060-4DCE-9016-250170471467', 'FD4EC610-EF06-404D-895D-C5C50062BEBC', '4607128160720', '   60100 /300/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DE0EB95-A6DC-4285-8061-5CF7B559E524', 'D3FF1799-F6A2-454A-97E5-1E89D6440648', '4607131040125', '- 150/1 3,3 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8B1A8BD-44BC-4B2B-877E-6C13D11B636E', '3E9C178C-57CD-40E9-8C85-96C3C8CA5F83', '4607131040224', ' 0,5  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81BD4B62-B86B-41E3-A8D8-3B8E6FA098D7', 'E05C395C-503D-4004-B10C-D510203F3F53', '4607131040231', ' 0,5  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C03E1598-97AE-4B7A-A18B-20B024A26E36', 'F0E297DD-B0E3-4567-8F01-8F3EFC37F145', '4607131040248', ' 50  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D8851E9-33FA-4336-B29C-1EE979971F82', '441AB825-DB61-440B-BB2A-75CD977C283D', '4607131040330', ' /. 50 5 35  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD52EC69-B787-4925-9DC8-6DEEE97BAB1B', 'A4770679-8BE5-4F7A-9622-80C22FE248DB', '4607131041603', ' 150  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F49D40F-79B9-4133-B9F9-BBAADF21F955', 'A35FA478-7232-4DDB-8286-8C2B6D49C777', '4607131042044', ' 0,005% 2,5   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5DF1839-3A60-4DEF-B04D-71DBD4E1A534', '8D0E43D5-D263-43E0-AB77-99C76885824E', '4607131042211', '   / .7 /  2% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18A5501E-251D-41C5-8CBB-C41E47921A6F', '655A5513-F4F4-448E-A0B1-47CCE781EE7F', '4607131042310', ' // 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1A4955C-1A47-443F-A8D0-A0BA7B713A42', '3F3B8E34-1204-4BEC-A44F-DFB1B377E258', '4607131042327', ' 10  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B176893A-137A-424B-8FE4-2AED0D6868FB', 'CB4C2093-0CAA-444A-BE4A-DD378405631D', '4607131042341', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5045E579-5BCC-44B7-8024-4CE788BDF83F', '4B6A68BB-795F-49B9-AAFF-93E44C0F8FA8', '4607131042389', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9FB3988-ABF1-4C8F-BC58-9CC98B2A05EF', '7BFE7C25-D8D2-46DD-90DE-C56A421387F0', '4607131042426', ' 80  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD2BDC77-6D95-4689-8A46-6261066803D5', '77E26179-6F2E-4A12-A954-357462DC932E', '4607131042471', ' 150  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4C01463-EC38-4649-A812-695EF9D07F42', '06A13B9F-1642-4A34-AD6F-F183000FAA3A', '4607131042488', ' 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9411EB1F-9AFA-4A3F-9C3D-141CA52C6962', 'FB611A5D-956F-4927-80CB-8339BDDB77A5', '4607131042495', ' 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F5D8688-AC42-4000-ACF8-7CA5AB55B670', 'B7FB6E54-94D3-4C23-9F10-B5384BADBC47', '4607131042501', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E9F07EA-31A9-444F-94DC-8CF9838F7975', 'BB074DBD-721C-428B-81EC-F1B115DC0299', '4607131042518', '  0,5  11 + 1 14  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4EA0723-18E9-4150-B43C-4FCFF06EF5FC', 'D7691315-287B-462D-AD20-0DD3F02A5CB4', '4607131042525', ' 1  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA1D73D2-86A3-4369-B4D3-3BF31BFEC5A7', 'D204775C-753D-457A-9CC6-5C8D9E5A17A3', '4607131043287', ' 400 1+200 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17E26C83-3467-48D6-9ABA-82A29BAED862', '20E59E62-3AE2-402C-8736-5560E3523AB7', '4607131043492', '  /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AFB5ECE-4B72-45CC-BF60-EF8CBBAD809D', 'A67627FE-4592-4966-A5AD-25D6BCE65423', '4607131043546', ' 25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B80B681-36BF-4B56-B2FA-E56349591678', '6202C54F-6154-4818-BB3B-A8A211E72285', '4607131043553', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0684DEE8-2975-4A59-9190-369B11B8E6EA', '442F3208-C7A6-40F0-9C02-A1611E4FFD8E', '4607131043812', ' 50  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C2FF30C-E89C-4F2C-AF0C-18630481177C', 'AE06743E-2F3A-4DAA-9045-68B7A1E0F1A3', '4607131043829', ' 50   / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8513B12C-7647-4EDC-980C-B51D4C0BD030', '99D79921-D6A5-4942-B0EA-C9A55FE673DA', '4607131043850', ' 100  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58525C44-5A89-403C-A76B-FA4B062E8FC1', '4C4361A3-FFA2-42CA-9E6E-6EE71DCEAAA1', '4607131043867', ' 100  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CCB52EA-C65D-4945-B59D-28D45D67F2E3', '97E5A12C-4FD6-49C5-8FA8-2130AE373B55', '4607131043874', ' 100  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('976600AA-8BBA-49C9-A093-13DB7305A781', 'ED570FA0-B2D3-4159-8B27-78EC40C9790A', '4607131043928', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77364326-B72A-4458-8A8B-427F5BA2655D', 'F12C2C13-4B4A-4CDD-B77E-5D3F30B29A71', '4607131043942', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC76F9B9-A037-4D20-8050-2505D53230A4', 'E2102DDC-D681-4B14-8936-1275B1634E7D', '4607131044123', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEF257F2-2E6E-4CC0-8D63-285DE7C6D590', 'D68B9591-AC81-497C-B6CC-1A4FA05B7511', '4607131360544', ' 4500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FE13F54-6A2D-49CF-BFF4-3CB84E5492AA', 'B90E6184-A56B-4084-B96D-BDE36CE8E440', '4607131361275', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5444867B-B7A8-41B0-BAD6-D7A442819F62', 'BF488BB7-3F25-40CD-BAE1-E9F91C657290', '4607131420552', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('367436C2-EDC9-464A-B007-B73C5B1E89F2', '9D4BEDEF-2AF5-4FA5-90F8-98F22F64D412', '4607131420828', '     150 ', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79E6A95E-D9EF-4552-A9AE-8903257A7394', '4B2206D3-3F31-4B8C-BA31-4936A5900A43', '4607131420859', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F6E9126-D1EA-464C-85B6-64102AA76EEF', '2D4FDA0C-586A-4065-95D8-99942DBF14BB', '4607131421115', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAC2BF25-182D-497A-B339-4118F46ADEB3', '8818BC9D-E851-4751-8319-DD7C600CCF39', '4607131422389', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DC7BB0A-9DB2-4056-B248-CCBA6842D2BA', 'A5EE5A6A-96AB-4C16-B42F-3E412BD86510', '4607131425434', '      7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34B10EA3-B4FA-483E-B5CC-8285279B94C5', '378BB7CD-C0E4-49A6-B3AF-BD1C2A654D80', '4607131426653', '   / 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0499F33E-39A5-4E70-850B-9734368904D8', '61B34DE9-A98C-416D-9B39-394CE83DD55B', '4607131426660', '    +  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8582287-05BF-42D3-AAEC-4DFDC90148B7', 'EE667230-48A5-4E93-BA80-7A025D81335A', '4607131426851', '  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D380D4B8-3AF1-41A8-A68B-9A3C0E893CC0', '43B51240-8071-4BAB-BF61-D706E2F2D0BD', '4607131428275', '       2-  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40AAEB94-DB2E-4A28-9D3A-D0D4779E3884', '658861F5-AAF1-46B8-9604-0511F2A28587', '4607131428282', '      .   150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BB6B8CD-6050-4326-934C-B2521A80681D', '6B2FBA20-C7FB-431C-9863-DDBDC0C2E9AF', '4607131428305', ' naturin -   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14D59A1A-0848-4348-A349-601788414288', '2C6205D6-23D9-491B-9D54-639E01D08F5F', '4607131428312', ' naturin  / /   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C11A8856-5137-421E-8D66-99474DDAE55E', '6644D9EE-AA34-43A2-A62F-C43B714A4303', '4607131428329', ' naturin    /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBEDAD87-A6D9-43B1-814B-E3580F2504E0', 'F447BD58-F7CD-4A6E-A95C-5E574FB3B92E', '4607131428343', ' naturin  -   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DC0FB6F-C634-4808-B4D9-0923FA81F301', 'BC7237EA-4128-4C99-8C51-3A6018919486', '4607131429913', '        // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E446885-F3A3-4439-9611-B1BBD9F5B242', 'D9FB1E26-6406-4B37-81B2-4CF45A88E5E5', '4607132560677', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A8068A2-A2B6-4D4F-923B-CB2AD4C95EA9', '47236C50-16E7-4C22-BC59-33FC51779BBB', '4607133450090', '  linia veiro 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7114C21-1530-4304-8285-6A5A5A5EE440', '5DFB18D5-005D-488F-AF5E-60503624ED37', '4607136210011', ' /  120 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C06899E-86AF-4051-A9B9-523187EFA6A2', '902D0474-D34E-4BAC-9166-F4CC4558125F', '4607136210035', ' 2000 - / 240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C888890B-177F-4313-9F53-EE13E49A5BDA', 'F7669371-5FEA-4847-B635-A3303165AF66', '4607136210066', ' / . - 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F13FBBC5-535D-4330-AE27-4C626E3DF7E5', 'F3D75B37-A24F-40E7-BBAD-8BAB42A9CDD6', '4607136210097', ' 2000  - / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA4C030A-7283-442E-B4A6-1995D97F5842', '5DFB18D5-005D-488F-AF5E-60503624ED37', '4607136210103', ' /  120 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63F06EA0-6FB5-4A52-A096-716BA5D70578', 'E7F0D3A7-0736-4CF4-9B64-E69E9797D087', '4607136210110', ' 2000  - / 240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('659A40F9-A368-4400-AD4C-4AD8EF2920C0', '82EDEE7E-C139-4BB5-AFC2-3B522A64A979', '4607136210134', '     18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54C36035-A5F0-4DF3-BABD-945B8A5F3912', 'FA5C850E-071B-4054-A4B5-F8E1002D4EB2', '4607136210158', '     18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07C78524-38A8-4064-BC02-885CCEDCE06D', '88D13F26-9A91-4383-B3F5-2DEBD943CEAE', '4607136210196', '      120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7F51C8F-31D5-4B01-BA13-8E90F7851371', 'FE214608-D7D8-47D6-9C9B-0371DE2414EF', '4607136210462', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47F09A0F-4464-4E9F-9FD7-056F086EE980', '994F815A-EDE4-4BD2-B3E0-D5D7C9B3259A', '4607136210547', '  - / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('582F0654-75F4-4C3B-A0A5-5B1988C4152B', '5DB5DDFF-7B30-4C4D-8CD2-C6A0CC5E70C5', '4607136740044', ' . 300  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F280B88-C46A-4B39-8753-F5CC77D178B7', 'B0E1B5C6-8D08-45EF-9140-F977B3EBA618', '4607136740068', '  300  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85A5597D-18A2-435E-8287-0B53D5FF202F', 'F5641919-19C0-4CBE-89FA-52927B8FED26', '4607136740075', '  0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32DA5558-10E4-4AF2-8039-E1CBC2E90C30', '075E2305-9332-4AF2-B3FA-0B5F78CFFD95', '4607136740105', '  0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('285A9795-5764-4847-9BB9-1660CA70B1EC', '961FD0B4-BCEA-4FC1-84FE-0AA01D89913D', '4607136740112', '   0,2  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3179A31B-8043-40CC-92FF-E41ED9FBA116', '4B8B18BD-4FBB-401A-A536-88251B220B17', '4607136740136', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06923B5C-0580-492E-B8EF-C58CECCD09DF', '3DAB297E-D16D-42F6-AE40-8947721742A7', '4607136740150', ' q10 700  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5029B966-152F-43B7-B00C-15F3CB0AF1C3', '0E715CCA-98DB-422F-A9DA-CB9BBFBE204F', '4607136740174', ' q10  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97AF6A33-8538-45B9-B51B-9A98F2A989DF', 'B1D51382-3B72-4A6C-AEF3-01525EE68036', '4607136740181', ' /  /    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6C5B8E4-44F4-4C48-8115-939D37C1C6AA', '573F31E0-D93A-45AA-985B-8F862145F1AF', '4607136740198', '      90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13A6E0BA-4148-4EAE-BE38-91C1D8583E89', 'A3894CD9-7106-491A-B5C1-9CF16F28E6F6', '4607136740204', '   / /  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('207D9932-FE32-4FF8-80CD-92CFB7DD6103', '47CE7AF1-7BE3-4BB3-B0EE-62116E79DA1B', '4607136740228', '  /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47031F1A-BCDC-415E-81DA-8FCB923C0A31', '22CE09DC-3A6E-4105-B06C-20ABE36FCF5A', '4607136740242', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7C95F52-08A8-42FC-A8CF-0A5F7AEE5EE8', '00D2532D-4DC6-4DC5-832D-45152C0341C1', '4607136740327', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6EB9802-903F-4488-A873-C6266BFCC7BB', 'CD019761-5C89-492A-82C6-B4B6B1EA8690', '4607136740334', '     0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E008CFB2-573B-42FB-BFCF-154000AA6C45', 'EA7CD73F-ECC6-4998-A434-333E81D5449C', '4607136740358', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('564B3763-F16F-4470-A9ED-AC391FC2A083', 'AB49F557-91E6-478C-BB31-8ECCD0EFE723', '4607136740365', ' - / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7CA987A-3D86-4A65-BAC9-FA4BB4578A7B', 'CC43961D-4B80-40FE-8FFC-09A2A76C4F1D', '4607136740389', '  0,7   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('828E8617-5517-488C-B96C-AE04DDED2CA6', 'C0B1300F-87AC-4D4C-81DA-CED81E620C17', '4607136740396', '  1,4   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3797300-5825-428D-84A6-FBABAC89C120', '2BEDD626-F5AD-4CDF-A20A-7F08C3F3BF10', '4607136740402', '  750  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45FC3430-7386-420E-BC87-D37C0439F3F1', 'B13EB535-F0AB-497E-B3CD-FE7FFC1ED403', '4607136740457', '  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48FEAC6D-C8B5-4446-88ED-90A60D2B1FD1', 'C2A26687-429A-418B-8A4D-5F2C6297FF67', '4607136740488', '  600  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C89DA092-29D9-4FF0-93EC-EF6C49D6B491', '1417F8DF-A157-432E-A793-490A73BDF4DA', '4607136740556', '  100 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBA51BC5-ED7E-4D09-BF7B-C952DDE1E08F', 'AC635607-0DE7-4A96-8821-C1E54BCBFDF5', '4607136740570', '  / /  250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01E042FA-DA03-451D-AC37-8F8B64C0D971', 'A16179EB-F3EE-4E8F-9D4E-C27F6AF5A554', '4607136740587', '   100 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1876512-894C-48D5-B2DB-51EA60B1CE3B', 'C0423A3E-0FAB-4414-A281-4DB20D5A8519', '4607136740600', ' 200  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE3D49D0-387A-46B6-AA42-68DD74654DF6', '366323B6-E2DC-4CB6-8415-437718651ACD', '4607136740617', '  400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29796707-D5C2-47C2-BF82-52BED212C265', '0149EEAA-96B0-4CF7-BBB9-D3F2C96ABC6C', '4607136740686', '-3  1,4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('465A65CA-5E80-4F60-A866-98953AA4FFC9', '5C1CC5F1-0BD9-47DA-A099-A11BAC4571B1', '4607136740693', '-3  1,4  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('766FF175-C7E6-456A-8EBC-4AF8180B91B1', 'DA88214A-D3E5-47BE-B342-152793EA8724', '4607136740754', '   500   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BDA02E9-3B06-4581-886F-5897EEFC82C3', '1A7807E8-8DE9-487A-8C9A-B7D43136414B', '4607138078275', '     /  3//  46, 95-100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('957B54A4-07C8-4499-B942-E0F350CF58DF', '6C8C9F74-70C2-45E5-A0B0-FEDA3757E23B', '4607138078299', '       /  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80F7D765-9E6D-464C-8FD3-B9B99D636499', 'F97D13A5-4BC5-4827-BD58-4DB65B94C311', '4607138079845', '   / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('345B9E73-4EEB-4E60-861C-23EF7995A97F', 'BEB0E1A4-EBBD-4929-8D90-DBA368E5BF05', '4607138079852', '         250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DAF8DBB-62E6-4ED9-8921-D81C6039D6CD', '3DF02616-26A4-4ABA-BCB3-2F24F4DD7E60', '4607141120763', '     70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D54D0AC5-8CCF-4E57-8E37-2000746A3D34', 'E35D2FE3-89D0-4F58-A2DC-9968863E9598', '4607141120961', '    /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4EBBF0C-D868-4CE0-A7E0-8E728A3CC760', '5BD56794-0EEF-41F5-BB6B-863116B3015E', '4607141994241', ' 75  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA49F678-044C-4FEF-842F-9BCEED45AFFA', 'A009D5CF-6D7B-4358-8867-50E9503BA196', '4607141994258', ' 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('095E67C9-0ACE-4CFC-A07C-EAAE762036E9', 'CD0D640D-6433-4E32-8682-CE09A74A720F', '4607141996030', ' 24  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E22C2C2-8E4C-483C-B5FF-E52407E8F78D', 'A0526900-2778-4254-B735-AC24FBDDB0F8', '4607141996139', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB5D5F33-8644-4696-8138-E383B70BFF26', '9F3AFCB9-4878-4CF5-B48B-688DCC6C91A9', '4607141996238', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24C90BB6-FE30-464E-90B8-F6C7AFE6F7BB', 'AB29FE73-FF5F-4619-B970-7FF456C38EA1', '4607141996252', ' 5 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBAE50F3-2F8B-44C1-A784-9F51399C7814', 'DFB9062F-ACBC-455E-8F06-815453D250A4', '4607141996269', ' 0,01 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A34A4257-4209-49FA-A3B5-6365DF4C0F9C', '43F670B2-880C-47CE-AFB5-C712A84C84FB', '4607141996306', ' 250  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('219DF63C-DA26-4E56-BA38-4ED52135DE81', 'A85221EE-95C9-4895-8FDD-1C324235FB1A', '4607141996672', ' 2  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00255C84-02EE-45FE-967C-82B53A662061', '95FD43A2-D8D1-44BC-BCA9-5A40954DD11F', '4607141997099', ' 5  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CCF99FC-E45E-4FA5-8B0B-E602C0B8874A', 'CE6C6BE5-ECBB-45D2-8C40-75B4975624FE', '4607141997112', ' 10  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CBE14CC-073B-426D-B5C2-740E1AC5653D', 'CED5FE48-C20F-418C-8AD0-3EFC537BCF0F', '4607141997150', ' 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38B9EE1D-333A-4A12-9D5B-0B0A1D6DD78C', '606F73F2-DB77-4447-A41A-FA3B66AF4238', '4607141997174', ' 100  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADD48DF0-860B-44E6-A09C-ADC4D521FC8D', '782E3D90-7C91-43EE-8A3B-76BD01F63C52', '4607141997181', ' 100  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B6564D3-6E29-43C0-8C45-D7C473F576FF', '0AC03F51-CB00-47E4-A376-92B19D4984AD', '4607141997310', ' 500 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADD3D98F-0CC7-4DA4-813B-655342D0EEBD', '9DE02F31-04AA-47E7-B91F-DF2AB83D8B41', '4607141997327', ' 500  // 42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F2D3577-9A97-40B9-B48B-08BA431E5FB7', '4BDC0043-13B3-4973-9D7A-58C229B3EA6E', '4607141997402', ' 0,2 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53AFE130-AF5C-43E4-B55D-BA7DBA94C9CC', '57468503-3849-4DDB-BF78-C4DA323C91FA', '4607141997426', ' 0,4 /  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C4F5FA2-1216-47A9-B498-E3749543998A', '39B14F54-5895-4EEA-96A8-19C44FACAE54', '4607141997617', ' 0,01 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5706C9DA-8E75-4F02-B701-89AE006C4223', '4F175F7B-56C9-43C8-89DC-5A36A1C450B7', '4607141997624', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A2C93D2-8F1B-4C64-86C4-0399DFD4CC5E', 'BEFB58D6-BB75-4A9E-868D-E0EEA9296490', '4607141997631', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('295DF045-01D5-4451-8EA2-659E4B05BD56', 'CBAEB21F-59C1-46E3-9154-84F92CC48FB5', '4607141997648', ' 20  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E752CD77-37BB-44E3-8F51-8EFD98F21005', 'E9075584-6598-4207-B80A-D801BA893C82', '4607141997662', ' 40  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02AA4867-630D-43E6-AAF8-C6C02E06BE35', '554E8B72-B3CD-4A37-B894-AC7B2F829EDE', '4607141997679', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25D4D8C4-7866-40F2-9D5C-0361FC331A75', '77088307-42C7-46C8-9A96-D91EA584139B', '4607141997686', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68B8EAF8-724E-4F63-A951-202A3A872CE7', '8D2724BA-8F04-4D6B-8120-71F592DDCE71', '4607141997693', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('920E638B-A401-45F9-8ED0-C4A57146BC0B', 'BDA51988-12CB-4F63-8AD3-2C572B6E78E6', '4607141997754', ' 40  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02603CB6-44D8-4FD0-8E48-3BF9BD40AE71', '0BBF2389-6114-481A-B469-21408ED7CBD3', '4607141997761', ' 0,08 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECFB21F0-C479-4390-A72D-495846473B1B', '956817D2-8B0B-488A-9C68-EFAF8E62DADC', '4607141997778', ' 80  / 98', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AF9683E-6813-4D0B-B0A2-993E4B1DEBAA', '702A8BED-43EF-4625-B820-DFCF18458800', '4607141997785', ' 160  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67F3ACBE-8EF8-438B-BD7C-370BA3A2C77C', '0DDBF5AC-78E1-4A37-B22E-F1A7E10F231F', '4607141997792', ' 0,16 //  98', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDBD9E5F-049B-4BB2-BEA7-27A54E49EED9', '654220D0-C42A-4E75-A691-63B6FAF77A76', '4607141997808', '  0,08/0,0125 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8352F6E-1A47-48C7-87DD-1426C342180A', '48885C7F-C565-47B4-B7D3-1B30F1A24150', '4607141997815', '  80+12,5  / 98', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5709DF32-B9E4-4443-A43D-818BE3B8E904', '7DDEA531-DA35-4A50-AED4-790E79D8DA90', '4607141997822', '  0,16/0,0125  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B85A3EC2-95A1-4A76-A502-5783CF70FD78', '9B984651-A3F4-4BB3-8B9B-07774EF96832', '4607141997839', '  0,16/0,0125 //  98', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28487DE3-06EF-451E-9855-AABD8B319FA1', 'F1CE223D-2D7C-4EF9-A5B8-2D233F7E3503', '4607141997846', '  0,16/0,025 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A2308D2-33B0-473C-9F8D-E10BA245566C', '9598C440-FC23-491B-A3F8-8FFFD4115AA5', '4607141998119', ' 5 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB2BDEE8-E03E-4CC8-ADEC-895366E133E1', '451B5ED4-6869-45B6-80DC-CC75C58F53E9', '4607141998133', '  5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8177067-02FC-400D-B43D-284B127C7DA6', '3F0668FE-DB24-40AA-AE04-FE4494951599', '4607141998140', ' 1000  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AACFE7F0-8CE6-47A5-8616-6C8062382F96', 'B052D5BC-971E-4B5C-A7E7-61C2BCB9A4C5', '4607141998218', ' 0,5 100  - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('143D60D5-4FE3-41A7-808F-C382D53279E3', '6F5E1494-6ACC-4812-804A-1E975CB0DBA4', '4607141998393', '  25 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A56BAF8B-27A9-4337-95C6-CD9FB2E5A013', '0CCD39CB-0BAE-4D40-8768-401B7DFFB76B', '4607141998423', '  50  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('115E22BB-5351-47D7-ADBF-DAB8397A878E', '7612C49F-00A9-4A55-92FA-527147C916D3', '4607141998522', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('428A4264-1E68-41B0-8FDA-8CF25D7685F1', 'C501CF99-EA6D-4221-AD56-C39E8F50005B', '4607141998584', '  20+12,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6492DE20-A81C-4CB7-872C-1B55C29FDA39', 'FFCA5D3E-5EBC-4BC6-A787-F372F32F8E81', '4607141998638', '  2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B03A780F-418F-4F76-BED1-CCC0642429E8', 'DAE8435A-62A7-43F0-B6C2-7E99FE320083', '4607141998683', ' 75  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C13F8878-9296-42B6-A8E9-235D4EA3C7CF', 'DD498090-D7AA-4559-908E-25CD3D8A9A83', '4607141998690', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3D3FF9A-84C4-4682-97AE-8859ACEC24CF', '9CCD7619-515C-4CDF-A741-1E09004369C9', '4607141998768', '  320/25  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75EEC660-3581-4338-9E5C-478B7080CDF0', '25F5A859-0D59-4B5B-BD7E-1242769F2C43', '4607141998799', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E386C79-7E70-4F66-A6BB-70361DEA90BA', 'E549EC4E-654F-4220-ABC1-1F2903DF772A', '4607141998829', '  4  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83ECE737-E418-45EF-8701-5C3D52685823', '1C685487-76C8-4A4F-838E-A0BF4B52DD6A', '4607141998898', ' 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACB007CE-720E-4AC1-8F47-5843EAE81F08', '45CDDCCF-6BF1-4C1E-B50F-B9C33B351265', '4607141998904', '  10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('215E156F-5C16-479A-9949-2BF0D80420A6', 'B052D5BC-971E-4B5C-A7E7-61C2BCB9A4C5', '4607141998928', ' 0,5 100  - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55A20AAA-9158-4EE0-9E74-A13C847BD665', '8198010B-7541-4EEC-B9EE-52B7A1E6C36F', '4607143560154', '   5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CEC2E6C-10D1-49A3-A249-54EC0748E9AF', '7A521097-95D4-46FC-970A-68331A417D68', '4607143560178', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAD6BAE2-E34E-4173-87B3-3A6F66718FDE', '34037D6B-AF70-4036-B274-4AA2E707E12B', '4607143560192', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4D38EF3-B16C-4517-A567-CC8D3CA3B6E2', '08B3D075-3589-4E3D-B15C-32D336A5A8D2', '4607143560215', '   20/2.5   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A75FF76-A039-41BA-9BD9-1B9AAD696CB1', '5A0F3C18-7A71-41F5-B284-A0CDCD98CD54', '4607143560338', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('008EDFF1-5B11-4640-B829-665AF3457883', '461A1E38-597E-4892-9479-4439AEE9BAC6', '4607143560345', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45474415-5721-415C-B3DB-002F066619A7', 'C040541A-53AE-45C6-85E4-93B98C013EF6', '4607143560352', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4184BFAB-A23F-4C45-BAA0-245C92347A0F', 'FB6FF834-3CD1-4B24-8A60-5AB176DC3B94', '4607143560369', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E744E35-8FD6-40EF-9DFF-93B2FBAB4B8E', 'DEEF506B-DE83-4CBB-8DAB-FDA810401698', '4607143560376', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ED8B6E3-9E50-4968-9E3F-1851CA5BC120', '743A1696-4931-4AB7-80AC-29EF4C406FA3', '4607143560420', ' 0,02  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E9FA326-65F8-44C2-8A1A-512CC7440EC8', 'E6FC26D6-BB66-42DC-A573-57F04C16BFBE', '4607143560437', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1A13B36-D427-4F20-A79F-6C0CC0E838C2', 'EA7C5695-9725-4864-9674-7543449549DB', '4607143560444', ' 40  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D923F7EF-46E1-4067-9BDA-156FF32349F3', 'EA7C5695-9725-4864-9674-7543449549DB', '4607143560451', ' 40  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78507BF2-25DA-4499-BD36-F02D9F163189', '9CC9DE90-8060-413D-8491-1D0981DDD1D6', '4607143560468', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88FA8669-28DB-4FBA-95BC-C444CFF0D455', '62C9FCDA-AB11-4B63-B15D-6484CA273F12', '4607143560475', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DB035FD-B0A6-4C14-ACF2-01E172620F5D', 'E5A9E034-AE70-4D4C-8081-BA4AD17306A4', '4607143560482', '  1,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1D63B12-87D7-41FE-B600-7E1195D7A811', '77B6EE49-AE83-4B43-BB99-87C241F7AF31', '4607143560529', '   4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89082661-DC9A-4047-8097-6EC7E7D3A3ED', 'A49E7413-5013-4DDE-8E73-4E4E292FD8AD', '4607143560536', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B65AD2F-B916-4F3E-8E52-8F1BE38A277E', '1AD4D9EC-C2CA-4AE5-B4AD-1129E0BEA191', '4607143560543', ' 5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7969CDCB-5C28-4260-9047-05E17C286E7B', '2166C8E0-6ADB-499F-ADE3-FBEEB0029611', '4607143560550', ' 5  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74E9D224-77BB-4E22-A823-68D3769D01F2', 'A136B9F0-A41F-4F86-ABFD-390EFF79DB52', '4607143560598', ' 250  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45990C7E-C5C2-4644-857E-005288333368', '7F0EB2CE-C20B-4152-A1A4-65B043C13728', '4607143560604', ' 0,025  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15005D46-6B98-405D-A636-51D7BCDCF393', 'B0B58BC2-4827-4387-9D31-EBDC5DAB8E45', '4607143560611', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('134EDF60-B20C-4D23-AFD2-56D9396B1DF2', 'EC3157DD-C9F0-436F-8396-BB0D56F45283', '4607143560628', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0809C795-1983-40C1-BFF1-A15061545A1F', 'E51A5E6B-A748-4323-A9EF-1F8363E34C6C', '4607143560642', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9055B5E-84BA-402A-B97B-4C61A7123480', '5AE9F6D1-F08B-4E92-983A-B3C9D50AD0A1', '4607143560727', ' 2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62478BA4-C855-4625-B0A7-5D923FB95310', '58604B3C-AA64-4C42-9715-824E8E94EEE3', '4607143560734', ' 75 +15,2  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5299BEB5-DAA1-40A8-8BA1-599500499404', 'B2036E47-3720-4245-B740-FD039B3F3C62', '4607143560741', ' 75 +15,2  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4425C0D2-482E-4B4D-BEEC-C1AF9D2D3160', '2D9F6DBE-EEA1-419A-B2D0-8566616BC183', '4607143560871', ' 0,3 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90ADA5D7-751A-4471-AB8C-80784711003F', '242B487B-9D17-4D72-8502-756266C9E6D7', '4607143560888', ' 3  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D86ACC8-2862-4049-8AC8-1495C3163253', 'CF64EFF5-7D4C-4B06-99DF-0FFCA6546F01', '4607143560895', ' 3  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49DAE346-CF51-406C-932C-F5CF11334762', '24C78228-CE42-44D7-88D7-7355B4E123E0', '4607143560925', ' 16   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92D6619E-A2E9-475F-B2D5-6D3E419029CA', '7E73996E-3C47-408C-A4A0-F7915A4F5914', '4607145260014', '       / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD1B9154-056B-4077-8952-A6DD27FCFD77', 'F21F76A7-277D-46EB-948C-F7DF75739C92', '4607145500066', ' . .  2   . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8017D13E-B71B-4931-A20E-AE3938ADFF13', '8A9EC105-0F80-4433-BCEF-439FFDA1AB10', '4607146760117', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE8254B5-2396-462A-B85D-9FB02250D05E', '65566E47-073A-4962-87B7-F3536E805326', '4607146760261', '  500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('637C8D51-D712-47B0-B09E-0B78F09A2F53', '2AEC0EFE-1260-4377-B5DB-B749A15003A8', '4607146760315', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B7715F2-105F-4C3C-B3CA-CF9EBFC8C38F', '681844F9-EA6E-4A71-AD58-86EF66A70310', '4607146760322', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A1C3C19-A3CA-4288-8BAC-ADB5F408DD5C', '8EAF69BB-3500-4A24-9E87-D1F36499F685', '4607146760360', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6315146C-0B39-4398-89F8-9D0929E09E56', 'CD55CC74-830D-44C2-BE30-E49E9465A136', '4607146760377', ' 100  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C95ADA82-0F57-4DB3-9571-4D205D4BA252', 'ED336A56-EAB5-485A-AE26-9186B45B0AFF', '4607146760469', ' 70  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A652251-C047-4E10-A16A-7B777A07BBFD', '16E9EB34-35B3-4519-8A03-E6FC971BF7C3', '4607146760865', '   5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C88D506-CD78-48E1-8738-136FA500AF04', '80AC0F86-21DC-470F-BA71-4EE9D967BC7A', '4607146760872', ' 0,0125  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCA54FC0-FBD4-404B-A45D-F9F53B361D5A', 'E6ADB4FE-F7CE-4BCC-91EF-EDA0E6A6FABA', '4607146760889', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('406C9E94-F9CF-46D8-92E2-34A96160AC0C', 'CFB81857-8300-4AFD-B0E2-B911A4FD609B', '4607146760919', ' 10  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EFB61A4-6770-454D-A9E2-F11F42C08465', 'D4AF8540-C9D2-4A21-9BCB-EBD5C9E85D44', '4607146760926', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FF3F948-E19A-4215-9CE8-F3752EF0148F', 'FC5AF4B5-8BDF-44AB-AF13-B7E8A6DB48B3', '4607146761022', ' 5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F23814DB-3D24-4B11-B86F-E0D74ACB5801', '5848486A-009A-4790-810B-E9C4D8E360AB', '4607146761039', ' 5 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6DAE225-E918-4261-B836-7F913E71EE20', 'C71100D5-2435-4108-9447-1F1DF1970F81', '4607146761053', ' 5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('619DB7E8-A3DF-499E-9938-A4F593731D7A', '8726057A-8869-4D9C-9A20-D93227D82125', '4607146761060', ' 0,005  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DBF1184-8CF6-4560-A341-AC6DAECFCC78', 'CF05C525-C6DE-4CB5-8D78-9A856E80C330', '4607146761084', '  10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F627F535-CD94-4D23-9A3B-EDC98AFD938A', '8BD84BD4-2695-4D92-85C6-6DE42E953B82', '4607146761138', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2CF7BC0-FE43-4997-9E68-D7DF0E123DD3', '7FA501E2-B3EE-465C-810B-FA40C533408B', '4607146761152', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CF571A6-CEA6-4147-B22C-4612F6ABFE45', '0BDE0537-AABB-4203-834A-FA84AF79994B', '4607146822051', ' stoppr.  / . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B193D30A-BF9F-4E56-81E6-08D699D8FAC5', '8F0502F8-E3D4-4B8C-8934-EB108AF8433E', '4607146822136', '   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95936506-1C58-4E4C-AD61-6178F22A68B1', '235BD3A3-D2CA-44D0-8E8A-78C174614EAC', '4607146829579', '     3,5 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59462FC3-CB35-47FF-8BAA-2D2CAA8616A0', '349A2EEC-E05B-46A9-81E8-52EDB097DC2D', '4607147330067', '  190 / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1C3F766-1FBB-4361-8983-847B8CD625DE', '0074EACA-E954-458E-880F-311315B99E60', '4607147690062', '  0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CDE31FE-97A2-4C5E-AF64-0D3819CCD134', '33B5B534-F2B1-4028-9DD9-D1C020409635', '4607147690109', '  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4EAA3CC-E428-4DCF-AC28-705F84A64955', 'D18DC729-1D42-455B-BE3E-6E187CB4C669', '4607151710107', '  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4368E545-7D94-4D41-9AA6-262C38047EDE', 'CB06A0F7-EC68-49D2-BA4B-29F8AA329F7A', '4607151710251', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E14A410-6115-4FEE-93D4-0AD9EB61E9E1', '9DA60AA9-05F3-41D4-898F-FBDD559DD4A2', '4607151710299', ' 714 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D802E099-49C0-41B8-A6BB-C2D121A3F716', '144B69B8-C5F7-42CA-B470-59A807B5141C', '4607152730111', '  rocs  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08509131-7DBE-49AC-A9E4-87394174AF08', '78D60C17-7A24-468E-A632-637207220E39', '4607152730128', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B762A9C-10D8-47E9-8000-DF766C0F38BC', '9E0ED962-DE7B-4A19-85AC-BA8D282E7BEC', '4607152730135', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBFCEC22-6270-4184-8EA8-991CA4F55CA8', 'EC7A0842-6879-427F-A30E-CC5542FA0C55', '4607152730142', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAAB54FB-F82B-4E24-B74B-45A07DA2D2E6', '353641FA-396C-494F-9985-55A22EB7AE91', '4607152730296', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF7C9AA3-2FFE-47C8-B66A-70994C0FBC1D', 'CAFC2581-15C7-4771-BE29-8767309BF8FB', '4607152730326', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2DFB774-073D-4439-B2B8-7502A6C12835', '5FB4AF81-3C9D-4D02-85ED-EE3574FE0267', '4607152730333', '  r.o.c.s    0  3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D62BEFC-BB13-4DB2-9B1D-D988CBEC7A15', 'FD0B6E3D-408C-4843-86B9-8207AB2068E2', '4607152730425', '    edition  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FA25C2B-16F3-420A-9D9B-DCAFAD732C7F', '9677DB99-7D81-4442-BF33-ED36E964C804', '4607152730463', '   pro    0-3  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('966001D0-F3C9-4CDD-AB00-0085E49EE259', 'E8CC02A9-BCC1-45B9-949E-2EB4D75BCCCB', '4607152730494', '  rocs red edition  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2173E0F-F400-486B-8D14-E2FF7EDE66A4', 'D835A2F1-D710-48FC-BDF7-3030CD23DFF7', '4607152730500', '  rocs   3-7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('854C2054-063E-42D2-93A9-ECA234779FBD', '5032361A-3D15-449E-B19E-08C174C3F0F4', '4607152730524', '   pro  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68ABC020-1EE1-48BE-B170-98815D6E0F59', 'F0E40FEA-F9A5-4480-87E0-252DC2C9C026', '4607152730593', '     /1+1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A3883AC-90B5-4188-9EE1-EF21A630B209', '0134064E-AE88-4382-8FAB-C2C8215C5136', '4607152730708', '   pro /    - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('475B213A-A5B7-4A1D-8AD5-5FBA9458141D', '609F99C6-A27F-4DCB-BDAA-ECBAEEF77943', '4607152730715', '   - pro  1+1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12D113BD-0091-477A-9289-31E838C18786', 'ED44EBA2-D3AF-415B-9FC4-492E14C132AF', '4607152960020', ' - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21B1C16B-D63D-4A84-BD03-81EB31573263', 'A0A9030A-322E-46F9-9C92-CC09B47D09B5', '4607152960082', ' - 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A662F1A-E720-4B70-AFF8-D828684CC9B3', 'FE3D2F4E-AEEC-418A-8055-BA6DB82DD73A', '4607153456607', ' - 20  -- 2,9  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD9316E3-9A51-4F11-8884-B2E307E43AB8', 'F1684B15-8ADD-4903-B045-2B6DE8FBEC07', '4607153456614', ' -     -- 2,9  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('989CADD8-6BA2-4CDC-BB43-E4BA3C4099C1', '677A9561-7925-4C75-9D8B-F039BC844740', '4607154692738', ' ++ 3--1    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBA1B75E-F696-4BC9-9F14-817B040E6AFD', 'F4CC0301-9E98-4B24-9425-88F5E502B327', '4607154692868', 'Bath bubble party  /- / 2--1 /      400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6A3A3B6-B541-45CE-805D-5984D2D0F356', 'E3882165-5931-4924-8E6E-7B5CB196714E', '4607155210016', ' 0,1% 3  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F48A6B45-FB44-4BE8-A39B-07A4DF490D53', '1DF06754-A2BA-46BF-9BCF-B96C4E56953D', '4607155210030', ' 1% 3  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B70F0CF4-C41A-4769-AB21-159A013491B9', 'B35F2EB4-C09B-413D-AC3D-9D9835E54CA4', '4607155640097', ' 3250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03EE4216-8C1A-42F2-8F54-0BADB58E8498', '94A9C2D0-4D1C-435A-925C-F715F1116ACA', '4607155640158', ' 5500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8162A4D-4362-4A76-A091-EF4A95569A12', 'DB12D152-CFAA-4433-81FB-51C32B82E178', '4607155640974', ' 610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07BE7D01-C1AC-45E3-8D73-10CED84C4C9F', '2CF1F885-1019-4819-B421-25E290819130', '4607159860033', '  0,035 60     /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D71D002A-3318-49FC-BEA3-6D2427592D64', 'FCE52D40-D221-43B3-AF2F-B50377D4FBA1', '4607159860071', ' 500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('790C23C6-815D-4504-84FF-F7DAC89DEDD1', '404788D9-20D9-475F-A9FE-4095DCB200FA', '4607159860088', ' 0,05  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E14DF1CD-F5D9-4D1C-8F57-92D3469B06E0', 'F6BF2D19-5276-46FA-A8CA-2134F4116C32', '4607159860200', '  2,5+0,625  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86C7C7EC-8DDD-44D2-AD6A-94CB7488940B', 'F6BF2D19-5276-46FA-A8CA-2134F4116C32', '4607159860569', '  2,5+0,625  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B06AEAC5-FC11-4BED-87B6-E97FBC80CC72', 'B3B6658F-49A4-4A8B-A6F2-5989E1F252CE', '4607159860606', ' a  5+1,25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E697523-6CFA-48F6-AD4D-4A6CF8B168DB', '16A3ED79-CAC9-4375-AACC-F3D1431C7BB0', '4607159860828', ' 25  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F6EEA71-2F4A-407A-AAE3-C3B4F5EA58EC', '9C8546A2-269A-4E84-B511-87727D638812', '4607159860835', ' 25  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C0C73E1-B843-460F-BD1B-0BABE9558EB6', 'FCE52D40-D221-43B3-AF2F-B50377D4FBA1', '4607159860866', ' 500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B77C7B85-3B22-4FD3-8611-ED428833DCB8', '0CB19DF5-237C-4AAB-8286-198E467C24D8', '4607159860873', ' 500   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC96B93C-72AF-498D-908A-967367EE0D80', 'E2951B99-31D4-410A-9C93-56D658F9909F', '4607159861054', ' 5+5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F124304-0528-4930-B545-82467C8D5A9F', '7F18CD7E-E01E-4939-AE2B-F6CD347EB140', '4607159861061', ' 10+5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B64C603B-845A-41CC-98BC-7737BD2BC9A8', '7F18CD7E-E01E-4939-AE2B-F6CD347EB140', '4607159861078', ' 10+5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0108C837-B2F4-4713-8E18-303F629985B6', '27640F2F-2526-4891-A523-AD837D14E3D8', '4607159861085', ' 10+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF60E176-ED4F-40F4-B5CE-9EA4F1EB9671', '3BBDCD74-175C-4A96-B882-4667C29134AF', '4607159861108', '    10+2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B832E422-7F2E-455A-9209-581A9F3CF741', '145EBA7D-E042-46D4-8D6F-ABB98C7252F0', '4607159861290', ' 5  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14371FF0-EEC8-49FD-88BB-AE46B4A4634C', '4F8D0A5B-D20D-4CB7-B3C6-2CFE868662CB', '4607159861320', ' 7,5  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7460A924-A822-4BCA-9919-6CC37E0F44C7', '34BC1841-FDB0-4BE8-88C6-E6AB2E5AC44D', '4607159861443', ' 5+1,25+5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7555EE4F-E1A5-4CC0-926F-F0E11F28D29F', '72AC92F5-9764-4DD8-8A2E-878C5BA0FC89', '4607159861450', ' 10+1,25+5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC14EDCB-0566-4953-8FED-05EF1F2CA352', 'B611D082-4B5C-429A-9F8C-DE8CAA187B7D', '4607159861467', ' 5+2,5+10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67EAA409-F2FB-4B03-B946-4EED1D68CA7B', 'D94F8A94-3D6D-44F1-987B-0045445CF175', '4607159861474', ' 10+2,5 +10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6A82777-5A42-461C-B4F0-13F08B229D4C', '8F0B0905-D8AE-400C-9485-E26D40EF1B72', '4607159861641', ' 1 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC9372F3-75F9-4A9F-A913-F63A3F462C91', 'D62E1C0F-157E-42BB-AF24-F60DE8DCD551', '4607159861658', ' 1000 //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A9A0542-FF40-46EC-B340-6544070BC25C', 'E2951B99-31D4-410A-9C93-56D658F9909F', '4607159861771', ' 5+5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D968DFD1-B4F6-4096-9A3C-B0DB94E70BFB', '26FF3E31-F21C-4892-A335-3CE4D69725AA', '4607159862464', '  60  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5389D4FC-3ED5-49F5-BD6E-9DC6B1BFD854', '558C6F29-380D-4419-AD6C-BDAB5A5032AA', '4607159862495', ' 50    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D88BF09-B299-436F-83F0-C833258B256F', 'CE7AD8FA-8900-4882-9B7A-00749AD89A4D', '4607159862518', ' 25 14 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB4017C6-F611-4F80-B80C-33BF112EAC48', '9C8546A2-269A-4E84-B511-87727D638812', '4607159862525', ' 25  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57E7A4D0-D7EB-4E4B-89CF-20CE1622C72F', 'FBA844BC-53B3-4CA9-B836-98C4BAA46C30', '4607159862693', '  5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94366890-53A8-4998-8F96-0F915BD6365C', '1DB56A0D-A0C2-4469-968F-127D102C954C', '4607159862730', '  10   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('759EC605-4625-405C-932C-33FCA0ACBFB2', 'FDEDDE45-8899-4072-84CF-DC43CFAAE779', '4607159862853', ' 1000 //  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E734341-D261-44A7-B321-6A05A981BAE6', 'FE628BFA-2FA1-43EE-9A6A-800E3533FF9C', '4607163090150', '   125  /.  4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA24A865-4987-43F5-93E9-F40C6F48ACF8', '5403B504-FCFF-491D-A93B-D3F4D8CC84C2', '4607163090167', '     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CE3BADB-45EC-40E5-BE9F-158E4E50CED0', '42E820CB-2C5E-40D4-BB5A-31DD000BF164', '4607163090174', '   125  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('750D01BB-8999-4BEC-8ECA-CF87965870AC', '40B92B6F-F482-4E27-9604-82CD65E94EA4', '4607163090181', '   125  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60D29079-1973-4C3E-8082-2E8375CC19A8', '00485174-EC76-4617-8A85-0A734DFECCCF', '4607163090204', '   125   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D445460-5117-4442-B736-8C50302010C4', 'A097754C-480E-4182-8AD2-2DF3A2A4D179', '4607163090372', ' ˨ 125   /.  6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12AB9291-2D3C-473C-B9EE-491574AF9BCF', '1299ADF0-EE93-4AFC-8BF7-414CB7ED3C32', '4607163090389', ' ˨ 125     /.  6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32EB3605-3C85-43D7-B7A7-26347B4A0BDC', 'F5AF9239-AF35-41BD-8D1D-027FEC22DBFC', '4607163090396', ' ˨ 125     /.  6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B93C55F-5F88-4A2C-AF43-C31BAC025F28', 'D0345107-3E3D-453A-8C2B-36B9E4B89C75', '4607163090488', '     3  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0958397-F0E3-4555-B0E2-CC016BA988A0', 'D5F171EB-E390-4237-8C10-27DC4EEC40D0', '4607163090501', '     4  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB32B46D-3144-4DF0-97D7-7566F5612EBB', 'D53A240D-84E6-443D-86BF-4943C7A2136D', '4607163090518', '     6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3F9DCD2-88E5-4786-B2F6-D1EA5BA88145', '289AD49A-CF82-4D81-90E9-4902AB473C0F', '4607163090556', '    / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B302E22-761D-4539-95EA-482C1F49EEFE', '2D70527B-9433-489B-AA7F-D601975EF439', '4607163090570', '   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1CECB78-8F8E-490F-BE5C-1CED6E081ECF', 'A50E1360-07B0-4555-ACCB-3D1DDDF5E991', '4607163090709', '      . 0,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E822E108-7FAC-4330-8F77-4F9C513B3517', '4196232D-ECA5-4855-835C-F2ADC45EAFE5', '4607163090754', '   0,125   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('660E030D-551B-4579-AEE5-093983E72522', '2D4C35CF-35BA-45FA-8BDE-35A412F20629', '4607163090761', '   0,125     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E50DF50E-79A2-44DC-BA81-8ADCA1F077BC', '8A643154-F263-413B-A828-C7F770913619', '4607163090778', '   0,125    .  5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E3E1CBC-DC49-43B1-8A42-13AF34667D95', '687F839D-FE0F-454B-BA53-0EA2D0286FB6', '4607163090785', '   0,125    . 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06E6934E-9301-4A2D-9357-A11971227B96', 'A18DF1F0-70A9-4C1A-8F9A-4CFFC4C090A6', '4607163090792', '   0,125   .  5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2468C4FE-CE72-4D1A-A13A-1C79F0AF0D76', '404470B9-9B1D-447F-B008-25434BEB866B', '4607163090808', '   0.125   . 6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5705AF21-6AED-4292-A2EE-969504337D42', 'AE9A30DA-D58C-4DAB-84A0-21283DC78BBB', '4607163091331', '   0.5  .. /.  3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEB04E71-9F0F-4620-83B9-0291E5C536E8', '119BAF7E-02E7-4B1A-BBA4-F3E124E701B3', '4607163091355', '   0.5    . 3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFCAAC08-03BE-4733-89D5-EC130CFDDD59', 'F3080F28-C024-48D6-9A3D-1720BC4DFDB1', '4607163091386', '    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83A23B74-7F26-4970-9B28-69010219DDA2', 'E59591BC-1D54-4C1C-B3A2-C1DBD78FA038', '4607163091560', '   1,0    /.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F61FEB20-0AAD-4C55-9BD8-C37EC0DD3450', '407E9E68-1444-4D56-9620-A5FB86EC15FA', '4607163091577', '   1,0   . /.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0A872AD-83DA-4CF4-B7BE-807481FABD88', '97C96D15-AF70-49E6-AD23-8028511E617D', '4607163091584', '   1,0    .  3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59936289-A01F-4919-81E7-4C8C45766FAD', 'B6C49853-2A4C-4B04-87F1-9D2A7BE13F22', '4607163091591', '      .  3  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05B74DA5-7624-4E97-AE90-F283EAC620D6', 'EF9F46B5-6B69-4969-8CBA-22E9FA172B04', '4607163091621', '     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BC4C20D-E4A7-4E57-B085-14850A6D1257', '54CA581F-E99F-4EDF-A52E-09CC86613058', '4607163091652', '   /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D55E93FC-5696-4CC9-9B76-59C8E94672FB', '8DF931EA-60AA-477B-9653-D918968F60F3', '4607163092574', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1090404-706A-471C-A4DD-C9088B719774', '31BE003A-70B5-4852-8B92-909310A891D1', '4607163092703', '     6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55AFC492-893E-4707-B2A6-A015781CE384', '05503E32-E4C2-4313-AAF2-95616AC23F70', '4607163093014', '   1,0   /.  3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F4AFD89-FB98-483B-87B9-13C1FA078E3D', 'D233EAB5-C5B6-4A07-B959-7495DF3D73E2', '4607163093038', '     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B9DCD5F-1ACF-4E6C-BD6F-BFCDD71CCC02', '8A95522E-DBAE-4503-848A-21645E6047BF', '4607163093076', '   1   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E755963B-5784-4384-BC43-59DA7BCE84DC', '50153B2A-DBA0-4045-855B-0F1A847D5A5A', '4607163093250', '     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A9BD816-3074-4C42-B501-AC1358884016', '4F323E45-D827-4275-B19B-DDCEC32ACC41', '4607163093366', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('037575F3-3DDA-4B7F-8393-EC9E0A4CA970', '54F9DE65-62A6-41A2-8B38-497506E3BAEA', '4607163093472', '   0,125      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('073538F0-27B0-4E74-BEB5-31085C23C88D', '503F132F-E432-4949-913F-9022C2415327', '4607163093496', '   0,2   .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8029C8F5-F9E3-4901-9F53-6E5252E0FC82', 'F5228AEB-67A3-4AEF-9062-786F427A1DD8', '4607163095742', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('262518F0-7266-44FD-A6D1-2FF88BE04167', '681C2628-0A49-4BE2-87B9-0E3997AAFA79', '4607163095797', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AB292CD-F1C8-4FD8-B8A8-A02C4FF15F11', '44738321-E4DE-45BB-8943-EE7BD5C07EF8', '4607163095803', '     12  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DB71560-7B13-4F89-A779-93CB23763F1C', '719C4F98-FE73-4A8C-8823-F6EB4C30FF36', '4607163097036', '   0,25   +4   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5421A6D3-1423-4D2E-A1AA-A41E42424B80', '7E1228A6-A277-499C-851D-06685E7B81E9', '4607163097487', '   0,125   . 6.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F508ECAB-B36A-41CD-BA1B-3488A812D0A3', 'FAEEA50D-CE9F-43ED-9777-0AC6C99BE5E0', '4607166380098', ' 350   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('739A10D1-ED3D-4F13-A79C-7647B53588E9', 'C11B08A8-32BE-43E8-946E-CF94CC5C4354', '4607167150195', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('120B5833-6BDF-4CE3-BAFE-75C076E6064D', 'DAC1078C-93C8-4351-B726-DCDBEB584218', '4607167150263', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAEDFBC0-475D-43E2-970A-28E41EEF2FA9', 'D035627E-2003-4EFE-AF1B-81DD30636D33', '4607169220711', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D973308-6A43-4F87-85A5-0D96D23CE28A', 'E2A5D7E5-EB23-43DD-AB80-527AD50B3161', '4607169220742', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4263DF12-82E0-42F0-8048-AC4A82FC28C9', '8F63EA2B-1CC7-43A8-857B-9368AF3A681C', '4607169220759', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1B08F4C-EDB8-4751-B743-7AE2DCCA43B0', 'F8DC2957-3E49-4E61-B3CC-BF46E262DC02', '4607169221701', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C530C14-08B5-4B7F-9939-BD691993DE83', 'AA420606-3937-4139-BEEE-0C85C7FFA5B9', '4607169540055', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40817214-AE4B-42D2-8256-3D572FC2909D', '3EB98E5A-8163-4583-A512-C09AD641387F', '4607169540086', '  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDB3A4EE-9950-4E25-A156-A3C2FC640323', '32DAE38C-42F2-4BE8-9C16-1CC431930F05', '4607172371219', '  1  50//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BDF9048-30E5-401E-B46A-FB1D2A555750', 'EDF52599-0FB7-4C6C-A784-94BCE6281112', '4607172371295', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('658C2406-6CDC-4D42-A5BB-B7B71A1BD6C8', '0D8357A7-3358-400F-B52C-5FA33E4F485D', '4607172371349', '  700  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D9DCE76-EECA-4F97-A5A6-C6ACB64446E9', '400AD489-061E-421F-9E02-E8F969F23217', '4607172373282', '  14  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3E69980-6B28-474C-97DB-F7F751065909', '55369D00-AD69-4682-AE74-92347C760C51', '4607172373459', '  1000 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92D81F4C-B42F-41B0-9BEF-AC2E0C1069B6', '9AF035CF-4F0E-49E2-974E-CA7B1796C2ED', '4607172374494', '  500   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D792E0B0-7307-4EAA-A690-231BC19FF33D', '4EAF125F-05B2-4C97-9DF5-48D3E3092A33', '4607172376207', '-- -     zn   3-7 , 860   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3E9FCE6-89BA-4650-8183-B519B89E74AB', '45DD7AF7-FD6D-4283-9762-470926201B40', '4607172376221', '-     zn 630   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CBF8D9F-109E-4918-8AC3-4B715A4012C4', '35A4D3E1-BD1E-4F79-BB2A-7E1AF594FBFA', '4607173030061', '  0,25% 10 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC3755BF-389D-4FC2-91D8-A0DAA39FBDB3', '820BADE3-0BC8-4A4C-B3CC-8BE33C40DA5F', '4607173030078', ' 0,25% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7519AA92-365D-4D49-A7DD-F4E1A7B5B00E', '3F96AD08-F8B4-49FC-8672-3F7F61D45BCF', '4607173030092', ' 0,25% 10 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FBBE030-030E-4C24-9F41-467B60310F30', 'BA2A46B1-B81A-48F6-BF7C-9D676DDDC31A', '4607173030108', ' 0,25% 10  -.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0283624-AB55-4DAF-BA0A-17A2AD49C9F0', 'B9423416-9CE0-49BC-8BA3-3C6A356E9394', '4607173030122', ' 1,5% 5 - / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24299222-20B0-4653-A385-53FF32EB650B', '586C2D47-0034-4869-9F8C-8330D5E5766A', '4607174430655', ' natura siberica  / /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C18E2F84-CBAF-462A-AD12-2A6633D58DCC', 'DE8D6BD2-D7A8-44C2-8623-72342FACF1F6', '4607174430662', ' natura siberica / . /.  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB7F8622-1464-4525-9FC7-BEDB28024474', 'B1209FDA-B729-40A9-B97B-E8EBD171A2A5', '4607174430709', ' natura siberica  / // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('527DF5DD-E196-415B-8CC0-5102D7FBD9FA', 'A37F88A5-FFF9-440C-BDB8-EADD1DEF65F9', '4607174430716', '   /  /  .  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97E52A22-4BD8-4D7E-9289-356EE16B18A3', '6D9AAFD0-2C41-4FA7-9D99-81FCBF140320', '4607174430785', '   / / / 550', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06C16E26-95AE-4F64-BDEC-6C261C72B510', '8E91AA19-C5C3-4BDD-96B6-A20553AF6949', '4607174430792', 'Natura siberica  /  / 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98C37B54-2C83-40AB-A406-E5A8ADB0B64B', '3CE47BD7-AB11-42AD-861A-694FB871565F', '4607174430815', 'Natura siberica  / /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16E90B03-28CC-46FB-8C3E-FED04CF9200C', '93E4A0C5-9D98-49CA-9179-03CC8210CCF8', '4607174430907', 'Natura siberica  /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('338CA849-B79D-4099-BA5C-2C4FDC21F70D', '5E9E2CE8-1B19-4F24-8017-8BF74CE0468A', '4607174430990', ' natura siberica   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC9E3F60-083F-4207-86F3-52DBBA757D0E', '5DF0109F-45C4-462D-AAF6-960AE9A809DE', '4607174431317', 'Natura siberica  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93545CF8-DF84-4DF5-AE0D-AA545879D28B', 'AFE3035A-C505-4540-9AD7-B542B662FC0E', '4607174431331', 'Natura siberica  //   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6BD9D91-B9A4-4303-B526-B5BE5F341EF2', '039C3B3E-69E7-4E05-BDA4-5C12E91ACC54', '4607174432437', 'Oblepikha siberica    /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56169E1B-6E12-4EA2-8D1D-C3C9BFE4E48D', '0FFCAE8A-A800-46A5-846B-67217F569566', '4607174432451', ' blepikha siberica  //  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DA2056B-DFED-436F-BC16-2CFEDE78F9AA', 'D7D45279-5209-4F07-ACB8-6D579900C1B0', '4607174432543', ' oblepikha siberica /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('785E7D49-E5D2-4EC4-A691-1E529124D6B6', '8DECF68A-5E63-4AB9-A7D5-03728945D77C', '4607174432673', '  natura siberica   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('661C5A2A-31A0-4BC8-8743-555676A0C6D1', '1B9796C0-B25B-459A-9FB3-E2CE6CEFA954', '4607174432697', '  natura siberica   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52CF6902-D665-48E1-BB26-1B6AEB3BD4BC', '6EDDC0C4-77D7-4A12-9A1E-CDF3D11A5655', '4607174432703', '  natura siberica 7  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('274229AB-EA61-4742-9427-86D652487431', 'B45C0EBD-7D3D-49CB-A0A2-2ED3CF4475EC', '4607174433793', ' natura siberica / /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12B1FD9A-C421-4A8D-A413-7C3235869948', 'D612C971-2891-453B-8534-05AB1DF43736', '4607174433816', 'Natura siberica - /   21   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D369610F-EF0E-42DB-81CE-E7233A01BBD6', '58D3FCD1-883C-4989-9C1B-3B05F6B0A157', '4607174433946', ' natura siberica /   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A05524F-BA43-4EB0-947C-B362B2338D34', '3E252263-0641-4213-AC96-771B1E02EF53', '4607174433984', ' natura siberica /   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6A40F0E-0FCE-455A-8006-DBD27FF0055F', 'B2D14D77-FC7C-4034-A510-886A76AED2A7', '4607174434387', ' oblepikha siberica  /   / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF13530C-9ABE-4CB0-86E2-539045A4B122', 'B7857D0A-D7F4-4E16-B163-8E46827034DC', '4607174434394', ' oblepikha siberica  //  / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96140852-B50A-4D34-8EE5-9DCA4F74624F', '90C2F587-D02B-4AF6-8232-F19255A42189', '4607174434400', ' oblepikha siberica  /   / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7A4821D-AC89-4E6F-93AE-B49B1DE3E9B7', 'DFAACC3F-6C70-47C4-AE01-850C0CF4F0D3', '4607174434417', ' oblepikha siberica  /   / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99FDBBCB-E8A0-4C0F-AF6A-25AD924125BA', 'C0ACC801-416B-47B8-B4C5-48A28E4E1297', '4607174434424', ' natura siberica /  /  / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96FCB603-47FD-4775-8BE1-8DABE2BB5F14', '00BE825B-F148-49A2-8022-943A215D4D01', '4607174434448', ' natura siberica //  /  / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E848C56B-3726-492E-BDF0-2EE2B95118AC', '49148137-EF58-4AD6-AEA0-DF79F3EFE2EE', '4607174434479', ' siberica rika  / - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C60410B1-615A-468E-8065-0DB77096FF89', '2F031F74-0974-4AFE-98A8-2B363A6FBD42', '4607174434585', 'Siberica rika   /  -  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC1169E9-72C4-4D74-AECF-EB76B989B309', '5BBF33EF-F814-485C-8AE8-14CF7E859362', '4607174434639', '  siberica rika   3-    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48303404-B1DC-4A13-A8DD-EF3C969683BB', 'C8239606-C63E-4F94-A80F-47FC49880E0B', '4607174434653', ' siberica rika /     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAED2A0A-CF0A-4D35-A7C6-2B2F3D0AEA54', 'B3BD0885-A219-4C0F-BBBA-508550C47F00', '4607174434707', 'Oblepikha siberica  /   / 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49420F9C-4E6A-48A8-89C4-4F7C74AF89C8', '028935B3-AE07-4991-90B6-EFA22DD623C9', '4607174434745', ' natura kamchatka       280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE156EBC-AF52-4F1A-97CE-5FFDA1D0124A', 'AA4C89DB-489D-4EC9-A7A0-2EEB8D029FA0', '4607174434776', ' natura kamchatka        280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('131052B3-94B7-44B1-8FFA-353F59B815AC', '6F0FDEF6-D4AF-40BF-A3F3-C21CC2857DFF', '4607174434820', ' natura kamchatka        280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE6A5755-476D-439E-ADDC-BC77914ECB6D', '56B64345-36B6-4CC5-A6FF-E7EC4735EDE3', '4607174434851', 'Natura kamchatka  /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6308527E-2E07-46BF-8436-7F02760BF7C7', '50CF469B-F155-4216-AA8F-B1E146F55CFE', '4607174434868', '  / . /// 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B82B1BE-C529-44C2-BD06-FAB678655874', '55919A4E-4D5E-41E5-A0F5-ED56BB4E8BC2', '4607174435780', 'Ns thalasso     6 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('546BC562-ED8B-45EC-AFB5-4B7905208186', '3248C8A9-112D-4E80-B561-9EA1C465A865', '4607174435964', '   /   180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6FD8051-56EC-4E32-B737-3B2B5249699A', 'E93D9934-C584-4398-9962-41E4CFFC550A', '4607174436121', 'Natura kamchatka  /   / /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38D01B27-8A11-4719-82CB-07B81D1159DB', 'BC42858D-AE0F-42C5-8F75-4DCAF698D6D2', '4607174436138', 'Natura kamchatka  /   / /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B3DEC22-5425-440F-B60E-B192F88BE908', '4F740D16-6815-457D-B516-554CA32F741A', '4607174436145', 'Natura kamchatka  /  //     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('186C6E7B-CA3B-4485-98EC-9F25E4A101E0', '1DA884DE-B60D-4B3F-A4EE-707D81042FD3', '4607174437036', 'Tuva siberica - /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46BDAD59-BA18-498F-99D9-74749DC917B6', '6F4D0FDD-90F9-4647-B6D6-51D44AE62AFC', '4607174437050', '  -    300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DC61151-034A-42FA-8EDF-EB2DB82ED43C', '44D56121-08B8-42C9-8D33-46AB7C2EA35C', '4607174437234', '   /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12FB0458-1B2B-41E1-8F50-EA58E9DE7895', '7545F24B-8215-4D08-BD11-9B219F170EB3', '4607174437241', '   /      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B303C56B-D189-4F8A-81BA-FBDC0C24FFA3', 'C508F39C-6D6D-4A92-8739-28363869D863', '4607174437449', 'Tuva siberica -  /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F99F90D1-5E8B-4650-B9C1-376C8AE6DCCD', 'DDBB4F5B-DE45-44F1-A889-B1B5B8FB58EC', '4607174650305', '   110125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8D48517-0CEF-4799-8D1F-9C5EA5CC3FF3', '3635246A-F2AE-4BF3-98D6-24B8F0DD1271', '4607174650312', '   60*30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB0B5A40-AE42-4AAD-B3BB-75277BDDAD85', 'EF11DA28-BF54-423A-9841-DE5867A5E362', '4607174650541', '   60100 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CC6757D-AA0D-4BC8-A7D3-C00C897DBAA8', '531C37C5-32F4-4CB1-97A3-840FFBB7FB13', '4607174650619', '   135185 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBC62907-A74B-49BB-87EE-BD821B55062F', 'D4573A64-F2EA-4EFF-B338-302B7DA702D0', '4607174650633', '   60100 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCEE0BC3-A038-454C-B25E-C7011FB6A96F', '2F3F311C-4DE0-4C3C-837B-1BC20112D5DB', '4607174650954', '   60100 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6564CBD-7071-4162-97C9-D02B9E4DF2D2', 'B54B90DE-7E45-47F1-9A5E-2FF0B006841B', '4607174651036', '   135185 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C58CFA56-5D7C-4160-838B-522F868F7D91', 'C1D2F196-7887-43EF-8C60-897C6B9223EF', '4607174651197', '   3060 800', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A40B22B8-34CA-48EA-93DE-5F8767B44583', 'FBD21EE7-F0F8-4466-8A1E-C993C360F837', '4607175610216', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('970E44B0-E88D-4896-A29F-9657E6524B6E', 'D9724BD8-2806-4E63-917C-977FA9BBB536', '4607175610360', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('660DBCFD-8999-43DD-AEFB-48556CECFD1A', '555BF7A8-0F3B-43C0-828C-BB76A0B4FB8E', '4607176000016', '      / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10498A30-2324-4AE2-A1A3-89A57CDC8D29', '45570761-355C-4A82-A3C2-50B2C1866762', '4607176000030', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E3FD27B-821D-42C8-85D1-525569F8E0D7', 'FD7C873D-863D-489F-B079-F064D5F32A44', '4607176000139', '    // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD5DE993-A546-4D1B-BD89-9564CFAE9BFA', '3D415CF1-0BC1-4A28-9BB7-54A2512D296F', '4607176000177', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACE5A9A3-5548-4EE1-813A-1EBE4C442FE7', '539566FB-772D-49CE-9138-E7614ACC9BBC', '4607176000191', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E3DC1B5-3442-426A-A19A-C8DD313C0679', '5A825BB3-01A1-4FD4-80A0-1418C78DDC05', '4607176000214', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57663BD2-9B70-432F-BD64-4FC5E2424729', '1DF51FE4-0D0B-412F-9BAD-4DF566D2C1FF', '4607176000313', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83DAA07C-70DB-4762-8386-FFC5DF3F6220', 'FCF19C72-1B3F-4BC4-83CE-2A995E268ADE', '4607176000474', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90F81C4A-E251-4549-A2C4-8805DB7FE848', 'A1394973-9678-445D-BD18-1694D989B31E', '4607176000511', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('974EBDDA-C40C-4623-B1BF-2ADBE5DD2D8C', 'C0C484F2-1929-46CB-A8CC-CC4D05778E34', '4607176000610', ' .  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E2C0F56-C07F-4716-A295-A0C198A63CA3', 'B4804B0B-C000-426E-A33F-37F25C4DEC3B', '4607176000658', ' .  -. . 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0FF0152-5B1F-43A3-B70F-A8400DB53F29', 'ABC179E0-8F14-4505-98F6-F566BE36A721', '4607176000832', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A8A6830-83E6-49F2-AE24-02863153B37F', 'AD40FBD4-A503-4E2E-B9B6-B749E651D6D0', '4607176000856', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ABE1693-8018-4D95-ABF5-61DC3EEE79CD', '35DECAEF-555E-4D50-ACD4-88E21E4B7239', '4607176001938', '   / // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDCE82D5-A760-43F6-9634-997C62A92FA2', 'E1B97B61-5C54-41A0-B594-BFFE4408EB3C', '4607176003376', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91FCF822-5038-4C88-98BF-5D21D2411715', 'BA9289A6-389E-4E96-A868-D2F15DF0F019', '4607176005059', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F87A901-A738-4F28-8B52-EBCD703FDC25', '3E36B152-2002-418B-9FBF-6DA645B81CCD', '4607176005370', '   / // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06CDB934-E6F3-4674-8B4E-B04F95754DEC', 'A90235EA-76EA-4DC1-8FDA-5D7BB697FD25', '4607176006414', '   / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B47A8FE-F693-406A-BAD4-3B8ADA868C06', '2D011BE2-1617-4109-BA17-BE9043B7CDAF', '4607176007053', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE4C7B2A-BD46-41F4-80B9-0707D17AA6E1', '0293BD1E-DFF8-43D2-87E2-549A79D609A3', '4607176007275', '    / // 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F31EE701-8E22-4CC4-9A76-1BFD298AED80', 'CACF1395-694F-4C35-8C3F-CA634BA44E22', '4607176007459', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF0FD17D-90BA-404B-8A86-AD45552E50EE', '2ECE38C1-A8AB-4503-9BDF-A11F4E826517', '4607176007619', '    / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('244A0175-49E0-455B-B9AA-DE26D7E7182A', '5C494F01-9A90-46BF-B8ED-59C2F95CD4DD', '4607176008814', '    / // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A6A1B54-4B1B-4148-BACA-DC8A1E4DB521', '9C36D7F2-DEE2-4989-8048-823C3CF4F4A9', '4607178950357', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B07ECF7-5D60-456A-9936-4F7A7CFE8FEA', '66244021-BB4F-491C-8ABF-3746C0FA3925', '4607178950388', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05033015-E858-47A6-A3E9-FFFAA46C7E9F', '1752E336-0536-40C8-A37B-A025E3BA3C11', '4610004310904', ' / / 3/ m/ 76-81/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B5ACD05-D378-4D7D-9750-C22774134D62', '8FFE1FD4-E2A5-4186-9D44-1395D32E267A', '4610004310911', ' / / 4 l/ 82-87/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98907C9E-9C4F-431F-A128-8B5F2885DC79', 'CD7EF170-E331-4FF9-A49D-9FFD3BC27AA3', '4610004310935', ' / / 6/ l / 99-109/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09F8B88B-5DDD-45CE-B455-8C543DA23EE4', '1EEA7F70-D018-4FE7-9ED6-BBF66529FC70', '4610004310942', ' / / 7/110-120/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B55BA00E-9162-4EC7-A6B6-0A1835BB1711', '70980D9D-E102-4B44-B677-23DA71F30824', '4610004311024', '    1 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6209308A-9376-44B1-A88B-889253027936', 'A835DC25-8E65-417C-9899-A49E1DA0DE46', '4610004311109', '    4 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0999BE4A-C9F6-45D8-9435-876241D9CD20', 'A437C7AA-D2BE-4A03-8734-E0406A04D289', '4610004311345', ' / / 3/ m/ 76-81/+ / / 1+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A603E499-F6D3-4631-BD7C-B85D33EF4142', 'B1327D9A-D56B-4150-B143-3E9A2F27D292', '4610004311352', '  /. 4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('991D7B08-CDA8-43FE-B1B1-0EE7537450C5', 'FB829850-4BF1-493E-B17A-B10CCC9B8250', '4610004311376', '  /.6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB15188E-F96B-4500-AB51-C0E38FF9AE48', 'CCE844DD-3E43-48B2-8ACC-27E01E7737EF', '4610004311383', ' / / 7/110-120/+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5994FA96-8012-49F6-AC55-47B66E5C91F6', '8D2AFA0C-5D29-45E7-AA25-42E1C8F7FE9A', '4610004580079', ' 30  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C4F8844-6CD0-4872-8191-30A34256DFEE', '255C5DB7-9FCB-4D64-A70A-53D7442D851D', '4610004580352', ' 300   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('809AF5A2-449F-4DB4-8E4A-E3E477BFCD05', 'B222516A-4CB3-4DDB-80C8-5C3A55201574', '4610004580369', ' 200   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F74D1B7C-3FA2-4AFA-BF4D-C296D1C1DE9F', '719E1F99-D2D3-4A8F-9978-BD2E3AC528FB', '4610004580826', ' 100   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F13962A-560E-4D96-95C9-6DCD20FFCD75', '87962EC8-7187-4794-9C17-25DDEE0B5816', '4610004580949', ' 100/ 200  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13BF8691-3812-452B-A541-8901E751BE36', '2253579F-A0F6-42A1-9F08-B13A4AC13753', '4610004580956', ' 250/ 200 // / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4011A2A3-D383-496F-944C-DB6D33945DFB', '9004C841-FAEB-4C53-92F8-3FA1A2B8984F', '4610004860010', '  /   /6/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D60AB104-6DCE-4401-94F3-63B3701750B7', 'E384DC78-1985-4A59-8E61-3FF89E7055E7', '4610005630049', '    ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('632AD791-51BE-4E94-9C9B-BAC7568ECC7A', '42FD72C5-6F35-4DBC-89A9-8F9B8D8B7D88', '4610005630056', '     ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8300F712-340C-4025-9F55-EB13066AE96C', '33025638-5FAD-4FB0-B50E-36CD87F43CE4', '4610005630094', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D417044B-3354-4320-A80C-29729BC98688', 'BAC0E06A-082A-4457-AAD0-A9DC3CBA5C47', '4610006202092', ' 500  // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E41A7A7-BFE0-4409-9AD3-269A3AA95523', 'E3055A33-A212-445A-8675-DE14D5ECD520', '4610006740013', '  -   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8163A33-92D3-432C-B625-759A1913BD07', '69315F1D-706F-484B-9213-42548239EB58', '4610006770263', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('753D7EEE-C31A-4475-A052-6DCE5D326664', '47469477-1980-4120-B6E6-D8AFFDB09540', '4610006770737', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB5FDD97-E260-49DE-A0F8-1514E0D9F419', '1D06CB03-9153-4F9A-A971-46A252834589', '4610007620215', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2799AC78-55AF-4FCE-A91D-F5BF4BC71399', 'FD2E3765-44FA-42CD-B2D8-CD38E0B5AF02', '4610007620222', '  650  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F480F710-B302-4E8C-BB51-89852761A00D', 'D5EECAE6-0FB8-4704-8904-D773A402E1BE', '4610007620239', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('113BCB95-9402-43E4-B774-6DE42A01B165', '8D60A40B-BDDA-4221-B3A7-1F8B9A5426B6', '4610007760010', ' 445  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2918A4C4-81FA-469E-AB6E-3366CC27A076', '66BAF8A5-EB70-490A-A3E6-8F0E053197EB', '4610007760119', '  / -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD50A9AF-1694-479B-B239-C5FECACB8FB2', 'E262FD6E-6667-4DB8-8367-165F8FC046D1', '4610008490480', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F08618A-2643-49C3-8EC8-3CFC888F2ACB', '24218A6E-7CC0-4783-8334-87932F88F869', '4610008490862', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D52E4039-D58B-487F-8372-BDC383A9A355', '18E940F4-1C8C-4B19-973A-AA5703BAAABD', '4610008490893', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF1E7396-27C5-44B1-9EC6-51A48065A8EF', 'EAD79467-3716-4EC1-A27D-BCDE07E6545C', '4610008491661', '  - 5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE10F064-EAEC-423E-A900-B991D55C4293', '05B96895-BBD4-48FD-B732-943D48669AF2', '4610008492873', '    // / / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69876D55-4D11-4C92-BF9D-CA325653216A', '2397C18F-2A7C-428D-AB02-7C742AAE895D', '4610008492897', '      / / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A25198DB-20B0-407B-927F-10AC431E34D3', '76507BD5-C05C-4069-B7A1-B9A43A217DDD', '4610008493344', ' -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27B4A08D-10C9-4643-B3AC-F7CBD1B45099', 'B431AA01-D8B1-43E1-950A-60C4BCE65AF7', '4610008493443', ' 0,4  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5A85B0D-D5FC-4749-B118-3CC22F16E14A', '4930F6C2-33AE-4E9A-8E20-4D64C98A8DB4', '4610008494587', '    200  45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90E37677-A52A-4A42-9731-CD7AC499D5AB', 'C895394A-C0AC-4710-8E1B-5D423712ACDF', '4610008494754', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('015019E7-1371-40EF-A43F-0D2E6CCEADDD', 'B95908AB-331D-4DF5-B28E-04AACD96D622', '4610008494853', '   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A135BA0-3BEF-4037-A7F8-EA78FF5AE59C', '862B6019-3DBA-45F6-99FA-933872E338F1', '4610008494884', '    3-  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A4F6AFF-084D-4E69-90B9-AA8A29CAFF1B', '69CFFFCE-7756-4DEE-B41B-8C8C4D693593', '4610008494907', '   c Fe 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A5B3D83-02F9-4A2F-A009-3A20D93D95CC', 'DD30CEE0-DCE9-4C5D-81D3-CFA5C86A43EB', '4610008495133', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2C25C60-1428-4C00-9726-8618D0CADBBA', '79C7FFF8-4205-4A25-8261-E1F85F2C8378', '4610008495201', '  3   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F9104D4-9108-41E2-BF1B-72B7852FAA1D', 'C67B3009-D674-478A-92DA-3365780B43ED', '4610008495225', '    3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5F5F0AE-BF9E-4B49-9C7D-4B490FE1137A', '79C7FFF8-4205-4A25-8261-E1F85F2C8378', '4610008495249', '  3   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0A653C0-54C1-41C6-9DE0-CFBC0BAEA57D', '4FF66C9D-B9AD-4E36-90C9-CC561A99595A', '4610008495300', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A209DFDA-916A-4F80-B46A-844C44A6635B', 'BC375812-E0F9-40F5-92D4-FE417C1621E9', '4610008495430', '    40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EB1DF15-44EA-4206-96EF-C465D7350F60', '79C7FFF8-4205-4A25-8261-E1F85F2C8378', '4610008495645', '  3   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4785308-9006-44EC-A90B-2A8A65713F20', '2A828200-8844-4137-A5E0-B71662D23B9C', '4610008495669', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5F68C70-ECA0-414B-923A-7A67B177B9D3', '6281E26B-5CA7-40A9-AB31-F6E1FC4AE6DD', '4610010010034', '      2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFEFFD72-474B-4CE0-9FF5-36B54F4B2004', 'F73D7174-37FA-4241-9C80-16F704B56DE9', '4610010010119', '     / / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E6B0A95-E0D6-4839-89BB-80AC3F16B888', 'F533525E-68FA-4FD9-9139-75C4778EEB94', '4610010010386', '  1   / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4D903B5-4581-4503-9F77-285E90EAE5E4', '75512164-6FF6-4DDF-8D00-FE498C52EDA6', '4610010010393', '  10  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D4D20C2-0A22-4AC0-B16E-F71886A24790', 'F533525E-68FA-4FD9-9139-75C4778EEB94', '4610010010553', '  1   / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C226B89-360D-41AA-B71B-D14468421347', '70092556-BEED-4028-8B7B-8EC16417E652', '4610010011031', '   / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC0241BE-BE5B-44A0-BD42-7A3ECE2949F3', '9C99922A-16D2-492A-9CC8-3569A25011ED', '4610010011154', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C364B42B-31CA-44B0-8433-4891CFA16DC2', 'BD4CD2E7-CA88-4BA4-8DA1-3AAD0C36F6BA', '4610010011246', '  dailee 6060  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E92AD22E-168A-446F-881E-F0A107FD472B', 'A049753B-22A4-4341-904C-48C58D303CCE', '4610010011253', '  dailee 6060  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53A14C7E-526A-4E02-88F5-41E679D4AFAD', 'EE3303F2-4AC1-40B0-B302-6F118220C869', '4610010011260', '  90*60    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7329CD91-F5DB-49C8-9BBF-33F9E2C984BF', '94B14DE2-EE41-4A0E-9542-D30AC19F4DF4', '4610010011277', '  90*60    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('165047E1-55DA-400E-9308-02FAE3221B91', '0DAE158D-AA61-4862-AFEB-B2022BC9C191', '4610010011369', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29536AFF-2372-4681-A4D0-B77F8E7CBA87', '4507951B-6413-4EC4-B2B3-6AD93D8D09D8', '4610010011376', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE8F8388-0AC1-4E0F-90AE-55F024A26985', '54F79934-B18B-44C8-AFC9-77E937AAB99D', '4610010011383', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76D7624D-426F-4BED-873F-F123BF4637CB', 'D67D7BC1-30CE-4070-9CD6-E8C27BEDE7F1', '4610010011390', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF6761EF-9CD7-426F-AD38-EB609A3164FE', 'CF2E2CC0-2E70-441D-9847-D37E425C3784', '4610010011437', '  // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('865436AA-EA05-48D0-A352-98C3DF2F4A2A', 'D99E914E-15BD-41E3-A923-73BA3BF3D861', '4610010011444', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B68E954-73F7-4806-B4A5-849D091D93DC', 'DB790FCE-5738-4B50-8840-0E3243E83D23', '4610010011468', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DD02976-3A71-445C-8D52-0536DD96FD1E', '5BFA0DDD-DCF3-43EE-8511-C1AE170BF3FE', '4610010011475', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('841B51CA-9CB6-4226-BEC3-473EA9D5D90A', '28B72DBE-66B4-49C6-94B8-8B3C32FA65AD', '4610010011482', '  //  /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6B8B5A4-2F1A-4E21-9E1B-66265AE822FB', '84FBE0F8-9511-4E92-ABCD-9DAB35CC4A56', '4610010011499', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59089CE9-49FB-48F5-9D06-491AD0C6846E', '952976EE-6B3B-40CA-8F17-0C3DC538B7D0', '4610010011505', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05497702-0CFF-4169-9777-0D5FCA6F441F', '788416E2-4A14-47C6-8ED6-0ABD80B76BCD', '4610010011512', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08BA05C0-D672-47BC-9DE8-B1A2467C39D0', '40CA2910-963B-433C-9DA9-4CAB44D582AC', '4610010011628', '     2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B074EF41-50C2-4932-A0BF-5F0546D479DC', 'B5C5D15F-B0EF-4052-B7D8-0E0B9C008EE3', '4610010011727', '  -   //.  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('039A2A5D-B8A5-4B71-B771-E26110A2C90D', '32F90EB9-C6C8-4B24-AF33-EB2DEDC37710', '4610010011895', '   / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2837406-DD15-4F1D-B9DB-DD84B4E7818C', 'D9309003-C67F-4A08-9F65-46B877030EB1', '4610010011901', '   130  (-)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC1C0582-AC41-45D5-A57C-4E3F0B73EFAE', '6685A269-2C2F-43A5-8D11-66129E823E7B', '4610010012199', '     130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30B152B3-1B5E-4BF1-9E8A-2396750ABB4A', 'D3C58AA2-89D3-4402-8742-13B1EA280B69', '4610010012205', '     /   / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B119939-74B0-4B61-9B30-1BB960332F2A', '79438B27-02A3-4149-BB7A-02B78447157B', '4610010012281', '    /     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BB92888-A1C8-4DF8-93F5-34A4B8EF8321', 'DB3F02FA-987D-47EC-A84A-C27799B45D7F', '4610010012298', '   /   /   / 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76921A6F-9D4C-4BB6-B9B9-9F66DCBAB5B8', 'E1B97B61-5C54-41A0-B594-BFFE4408EB3C', '4610010012359', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74C6DC64-838E-45E0-AF40-AC056AB583B7', 'B0CB250A-4761-46E9-A39F-7FC9C4B57FD7', '4610010012366', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6940328-6BA5-4184-A831-050F5979B48F', 'E20309AA-0A6E-495E-980D-8641DCE07704', '4610010012410', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DCBBCAB-009F-42D6-AE80-A093E2C4FC64', 'C373949A-24F1-43E6-A7C5-25F5666ACE18', '4610010012427', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D4B406F-D92B-47EA-87B2-F0EC4051248A', 'B8136726-DD39-479F-AD0A-AC60C8B2BEFC', '4610010012434', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D0280B5-3924-4DD6-B8F2-7FE00025137C', '3C03E7B4-4C7B-462E-82C7-FC8D83541F85', '4610010012700', '  / / 3,25 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FCA5AFB-95F4-4471-B7C4-70AEF2E91B3F', '12FE5E38-D975-4B5B-B15A-5D7601A774E8', '4610010012731', ' /  120  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13411659-188F-41EF-9111-663E49755FFF', '06EB2283-557F-4AA7-ADEB-4ABE54CBC9A8', '4610010012779', ' 3-  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE4662E8-F846-4724-AAA8-B680C6FE0955', '661CC04E-F28C-4D6F-9731-14C1A5A0060E', '4610010012830', '     / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DABC00AE-1C88-495A-8F6B-67A80F7B12F2', '6C5E3526-C766-42EE-8B5A-4866F5B49009', '4610010012939', '-     - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C5ED047-F6CD-4994-8963-D18474C4BD2D', '1CD7618E-AAE2-4E56-BE9E-65B87AE06C27', '4610010012960', '-     -   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93D2B675-98A3-403E-B1CD-0A6D8170FD3F', 'C9B3CF2E-7088-4810-BAB5-6F03007F2705', '4610010012977', '    1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7DAAF2D-9BA0-4970-A825-9CB921199538', 'D350A2A1-0478-425D-8A39-7F3B12A0F92F', '4610010013295', '       45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47B50059-C98F-4F05-AD7C-0F582BBA4BA0', '9A37DBD8-9829-4D3C-A1B3-AB2037E4CDA2', '4610010013301', '           45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C0FC9ED-73BA-4319-89E7-14930496896D', 'B1151F2A-1F02-4C7A-88EB-BE4EF129CCA6', '4610010013318', '   ./.   2,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CCB40F6-B0AC-496A-9739-EEAFD9D3B782', 'FC158C21-CACD-42AC-B860-A01A7BE6B287', '4610010013325', '   ./.   2,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8865EF9D-DD57-47E4-BCF4-53AE92554142', '0FA80A7F-B30E-4D25-9E49-B25C31CD4D0F', '4610010013387', '     45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFE317D8-F723-469A-9D3A-3F04AFE40BFE', 'FB2930EB-3403-4B1F-A61F-68A122B064A2', '4610010013394', '   /   /   /  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('538E221E-133C-49D5-A4F2-A87E56AF57A9', 'CB7B1911-A381-48B6-AE81-A1B5975DBD9C', '4610011880452', '   10 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9E9B3CF-DF52-4546-AB98-9EA81CC1A987', '3CC2D787-0B19-45DB-8EA2-94A466255E46', '4610011880759', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4CFFF55-9B5D-46C9-A402-35EFC97748C5', '37DD5908-DBE4-4E64-94D6-61943CA078A1', '4610011880797', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04854BD8-3C1A-4D39-95DD-0F3E53D7B645', '4E4BB32E-1392-4280-9324-550463856521', '4610011893414', '  1,5 / 20*', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9608900B-A06A-4852-8BED-B467F109F9C2', '89AE1364-DB4B-4218-9E7E-911B6A2BFAFF', '4610011894800', '-   1,5   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07A4A2AC-8112-428B-9C5B-4A52B74765A3', '821F1D82-0A14-4D0B-B737-7E8CCDB5A82F', '4610011894824', '  / 1,5 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FA37121-5E52-4589-B124-312A9B59924E', '24C78228-CE42-44D7-88D7-7355B4E123E0', '4610011970023', ' 16   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD7034B3-6588-4E43-9BB3-7338DFB30F10', '87648939-B8D9-4BA6-935B-38FC6A8479CB', '4610011970054', ' 25  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26073AA2-34A3-4466-8694-8B3DA1FB6CC6', 'E51A5E6B-A748-4323-A9EF-1F8363E34C6C', '4610011970368', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D219AB0-CB17-4438-847D-7405F0B55BB1', '43D656A1-96A0-4B51-8CB2-506169D41F18', '4610011970429', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD09BB7F-AB9E-4763-AB41-00E882E6796A', '3AEAC4F0-D016-4D89-AB05-676FBE2B8EDA', '4610011970740', ' 0,3 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DF8E01A-A693-4CFE-9EB9-BCC6769FF836', 'CF64EFF5-7D4C-4B06-99DF-0FFCA6546F01', '4610011970764', ' 3  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FA3698E-B395-4B12-BC2E-13AF39824A46', '2D9F6DBE-EEA1-419A-B2D0-8566616BC183', '4610011970771', ' 0,3 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B9FCE3E-7FB5-482C-943D-09B372A997BA', 'BFBF6258-9CBD-4C67-8549-8D7FE4ACB4AF', '4610012020093', ' 0,01  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56A260F1-96B7-4B74-A9C2-ACA1524EDD9C', '93FC821B-68A8-433B-918E-32C2EC585FE9', '4610012150332', '   / 3 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E01C9CCC-E801-4E96-A0E9-C545EB26C827', 'BF9C3D5C-1FC6-45B7-A633-1214702619E8', '4610012150370', '   / 3 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95CA87E3-D4F4-4B71-A402-7678039161F4', '457D0EED-C753-4F2A-B684-4D8380CFD0E9', '4610012150677', '   / 3 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACCBF855-84DC-4470-B840-704B29159310', 'E84C0BC7-5147-4EBC-8143-DD80038D76B3', '4610012280015', '     65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83D53054-B546-40B5-BC7E-2D1FD3E80373', 'E6DEDBD7-368A-4F91-B195-AA1F25FFA28D', '4610012280053', '     65', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFEB7988-F7FE-4F60-9B65-5FEBE1A18802', 'E107EDBA-34FE-4370-A5F7-2C3B771B641E', '4610012280077', '     65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF9B5FE8-C8BD-47D0-9B6F-464ACBB93BE8', '5A7CD60F-9086-4222-8D50-03B500AB1225', '4610012280152', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3916B412-7EBC-4478-8D7A-6D6CFC03F753', 'E6DEDBD7-368A-4F91-B195-AA1F25FFA28D', '4610012280374', '     65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75262AE0-157C-4F0E-A819-10DB652ED6B1', '4C8AABE6-2435-419F-9FE6-DABB7B806C39', '4610012305152', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDDBAA93-E527-4200-91F9-730C963CC86B', '9E44B410-7CF3-4275-9729-940195EDAA07', '4610012370457', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55645B5D-0E2F-4215-BF37-FC4A999D38D3', 'B83001CD-B98D-4B08-ACC8-4B59E86A708D', '4610012370471', '  /. .  molipants  . 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0B812F9-CF72-4133-BE06-F28C5ADE7249', 'FF3644B7-D174-4640-BA6D-739DAE51BC9B', '4610012370488', '  /. .  molipants  .l 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C74E2CA3-1B6B-4D67-AB0A-EFDF24B2EA83', 'C02C5C90-7163-42EA-86A5-B012EEDDAF80', '4610012371638', '   6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('082E9BED-A626-488E-970D-4B2BBFCC5678', '0A8031C5-DEC2-49DE-8E87-84F5B79F5630', '4610012371645', '  6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('287DD654-F92E-4863-8713-3B344EE6C12D', 'BD278ABD-605E-4C23-BAA9-CEAE9D9824CC', '4610012372666', '   6090 /809405/ 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D72DE65E-7FC3-411D-88A5-2EB79A19AB6C', '5EA112A5-3920-4594-BD09-12C5C419A15F', '4610013580015', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('258707D9-9CB2-409F-B205-65FE8944DA75', 'B1223618-E317-4F66-9F84-ABD6AFEFABF1', '4610013580022', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1546732-4ACE-4BE9-8B39-FCAE1131A877', 'FC6B9EC7-7FB4-4776-BE61-5735EA5EF439', '4610014590204', '  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9A872C2-738D-465C-AA20-B0660EBAF6F4', 'A2464521-2EF9-40B1-892B-27FF5B56E0B8', '4610017192511', ' filorosso     50 den/ 2/ 1//terapia', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C770C5D7-AB32-43D0-A2E1-F49AFD8599AC', 'C05414B2-B578-42DD-B334-EE36507C1927', '4610017350140', '    /  s  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E59FA095-CE7C-4DB2-A706-CEE93EACC4AA', 'DCB74A03-472B-46DE-B71F-5A699DC52CCA', '4610017350157', '  benovy  /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6E4995F-459E-4A67-B65F-F52E1D8040F6', 'EBD2C15E-CAAD-4C36-9411-A104F27B7C12', '4610017350669', ' benovy    / m - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('167B3CDE-1D8A-4796-8ADE-65499A685A6F', '8C33085D-0AFA-4EF4-9867-4DC477B1862F', '4610017350690', '     8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60C65C5F-08C3-4D4B-A1B6-024465FB91BE', 'C69C782A-19DA-4F4A-A8F3-B3FF3F248A49', '4610017350706', ' benovy  . .  /. / /s/ // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7F2E10A-4DFC-489B-B666-F44F002F7E66', '894C358C-B053-4B26-8420-C68CE8B170ED', '4610017350713', ' benovy    / l  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C32C41DB-C005-40A2-929B-F40A53B5CD48', 'A126E59B-B13E-4006-ACC6-572211D65406', '4610017350751', '     m - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E04A40B-5DD6-4DF8-B123-1E27247F67A0', '71AFC121-8D12-4D97-B71C-50F78572F460', '4610017350775', '    l - 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DF84074-03E0-4B1C-9024-6B1ED7256E7C', 'EE48B6DA-1B30-40D4-A077-F4DF53DF40FF', '4610017500019', ' 850  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE182F2E-B8E3-4FE1-A100-5F9DF57FE7DA', 'FBCD1B38-6F47-4F68-AD5E-EE276BD7FFAA', '4610017500026', ' 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F265501-2584-45A4-B7E6-9702B73EE52F', '9D77D51F-582B-41FE-9199-DCB04DC412B9', '4610017500033', ' 500 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF9369F2-7577-42A4-AE32-C2BDEDB42C3E', 'FF2A6465-C1B1-4DE1-AC5D-B96BC6DDD816', '4610017500040', ' 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B081CFB8-CD89-4419-ABB9-672CC9D20BBA', 'B454FC44-252C-4EC8-899B-2E589D6C7064', '4610017500057', ' 1000  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01183377-99A8-4F9D-865B-F0EB4ECC75CC', 'AB8432D8-E514-4327-991A-5E4FA0EE7E0A', '4610017500064', ' 2,5+400  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('764B4F2B-BA04-4EAC-A9FB-BD3410526A62', 'EFFD0C6A-83C9-405C-81D8-626A567B814D', '4610017500118', ' 0,36  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41C429F9-EC07-4BD2-A009-F9D2E03E26F7', '13A48B88-A73E-44AD-92B8-C8F1DD0129DA', '4610017500125', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C94F5930-AD5F-4704-A3EE-6D4BC8D710DB', '898F9475-8694-491D-9745-CE26D65A3091', '4610017500224', '   250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19156F08-49F4-4BF9-9B2B-9F2F06BE2C16', '3F78DCAC-7911-4313-A862-3C9B0843712F', '4610017500262', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C215D72F-166A-4E44-BA25-13CA8420E72C', '623550FA-3D1C-4B58-8992-8AFBA814980D', '4610017500330', ' 50  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92CE0D15-CCE9-4FD4-AE4F-08B7955ECC3D', 'CBD8D3B5-CB62-411F-B337-6395AC380C5A', '4610017500354', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AFCB1FE-6AF9-4610-83E9-EB25C8750159', '291E5036-C89D-458E-863D-AA879C1C6166', '4610017500484', ' 50  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C3BF34B-A250-4A33-B64A-D2C12F135F49', '6F867A70-2B9F-47CB-9126-23F03C5C1D18', '4610017500637', '- 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00ED71D4-3DC3-4150-ABAE-8789CB37E476', 'FF2A6465-C1B1-4DE1-AC5D-B96BC6DDD816', '4610017500774', ' 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C71EC124-ABB2-4E45-8123-72D900C59D55', 'B454FC44-252C-4EC8-899B-2E589D6C7064', '4610017500781', ' 1000  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A440C87-54CA-4F6F-A90E-ED022B381B6F', '5EA1EE30-A779-4FB7-B178-011220605E6D', '4610017500910', ' 253,4  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DC9902B-F119-44B4-A8E1-7949FFCB4D33', '74E61D45-7701-484C-9AF8-BAA0E1AA038B', '4610017500934', '   / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19214A6D-C96F-4A06-BA2B-99900AB26BBC', '933EC964-37BA-400F-875D-9765E20C0C41', '4610017500958', ' 300  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D02F04C-E6C9-4128-9EC4-CD5261BB6575', '344D5435-EA7D-437F-AB47-B713F6A56640', '4610017501016', ' 0,1  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12530B7F-EE80-4261-A33E-85E738E8D84B', 'F70E3E3D-4640-410B-BE77-4247EC47CAC6', '4610017501030', ' 267  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3D03C55-C9F9-4553-B6CB-17BA4AA40462', '8E27F8AC-09D8-4824-A60C-9397194B208B', '4610017501047', ' 410  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5ECDCC1-540F-4697-B671-457FCC93325B', '7F7A4A8E-E756-43D1-8206-89C73D896E4D', '4610017700051', '- 5 +2,5 +8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87FB56CE-175A-4B23-84C1-4E304A2BB4CE', '16722C95-EF07-47A3-BD30-D6FDF746FAC1', '4610017700235', '- 10+2,5+8 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32B1F651-AFAD-497E-BEE6-DF8C4E73E2C6', 'B2822F6B-692F-4478-95D6-F71A06813BAB', '4610017700556', ' 40  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FAF7FCF-68CB-4E6F-98D3-5B09DBA96640', '7406B8F6-64FC-4BE7-9F75-270CA47AFB95', '4610017700679', ' 500  / 32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5496930-E819-4138-A55F-AB1CC52F36AD', 'CF433538-6AD6-4B2F-A13B-D15DCC87281B', '4610017700686', ' 500  / 64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BCBE166-0F61-4BA3-95D1-8B62010C127D', 'C3C4610D-347E-4676-BEF6-CEB6ED366642', '4610017700709', ' 10+160 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCA7898D-FCE1-4AB4-9F6E-8392BE3A44D8', '16FDF325-8C12-4E10-B613-15BF9BBB22A4', '4610017700716', ' 5+160 /  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E98187B-31C6-4096-AF98-26770C839969', '33E7D644-570E-48AE-A50E-D16E04A0DF8C', '4610017700723', ' 0,005+0,08 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F65799E7-8E65-4D11-A67A-341993BB8459', 'B3E0241B-030E-4E43-8C75-7138E9B43BF7', '4610017700730', ' 10 +160 90 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74BF48A4-BAD1-4D22-B8A1-68BAD6E73120', '1D6A79AD-5E69-4432-9D52-AA998E654B94', '4610017700747', ' 5 +160 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F03FCD8-87D1-4316-90F8-150DD523FB94', '776F37F3-5F19-4D74-99B2-4D57FFE83888', '4610017700754', ' 5 +80 90 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78887AC5-1742-48B9-AF86-A7020E233861', '74B2A23D-477D-4F50-9454-9A20EF241109', '4610017700761', ' 10+100  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('691D92F9-595E-4E20-8956-2EDBFE07F208', '063ED44D-2BAD-4908-B8AE-33C7DF8D4C14', '4610017700778', ' 10+50  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40208DDA-4EDC-4319-8D97-9E29EE1421A2', 'B5CE0FFE-4C3E-4890-AE09-B6081C50EA6E', '4610017700785', ' 5+100  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB103C53-EBA9-460A-8B13-EA52A9873E60', '778303C1-632D-4ADE-B229-64A06FE4CA28', '4610017700792', ' 5+50  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7013B142-2C6F-4567-8EF6-FCA4F0133C57', 'BE73D23C-151B-4CAC-9E86-5799394E60E3', '4610017700808', '  80  80+12,5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27638D36-9711-41EF-85D6-9E596A4D1D83', 'B9A3AEEF-F43C-4B48-AFE8-018DC40354BB', '4610017700815', '  80+12,5  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB6AC5B4-5A48-4A82-B092-6FBA4F5A81B9', '6F19A1EE-EFC4-4570-9BF9-71F963C85C35', '4610017700846', '  160+12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6B5E270-7304-400F-9D84-F444F942E887', '467652D9-F95C-4059-A6EC-9B0AA46D2BC2', '4610017700877', '  160 +12,5  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF5F8DC1-C733-4CF7-9488-7AC3AD28A3A1', '448CE24D-8190-4162-AC6A-279C69875428', '4610017700884', '  160+25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4F6CC8C-C93B-40DE-BCFA-E09EF9D2B4F9', 'C38C1A76-64C8-47AC-AC8D-1B1C99AD90C2', '4610017750513', '   //  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4B22CCD-1DDD-4E4D-BB68-3D30B2D07799', '831EE9D4-A207-42B3-BAED-D4B90939A3E2', '4610017750537', '   / / // 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64FDED8E-F99C-41C8-83AE-A0163ABB24D5', '02152A27-FB87-45DB-842D-EFB817928E23', '4610017750551', ' in time ribbed  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D8B996D-08CE-4FAC-BDB7-945350BB932F', 'D9020136-8C46-4B6D-9B03-7400C7CAFB58', '4610017820803', '    test 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86842E9C-C017-4A02-ACAA-05B4772A177D', '4D6C277E-90EF-4FDF-A3C0-4B69F8A61EB4', '4610017820810', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A9CBDEB-FD61-4F93-AFC2-3FF65A8354A9', 'E5CD4B84-596A-4059-B399-6270DFC0EC26', '4610017820926', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC1C0145-41DF-4179-90FA-CF870DFE1E58', '705E2AA5-F927-4519-8143-1E0479A1D64F', '4610018820017', ' /   ` `  4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00E80BB8-5B28-455B-B721-C5EA60ABA540', 'BDE0292E-11CB-43CE-9530-81047BB95345', '4610018820024', ' /   ` ` , 4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4192FF6-865D-47A0-AC4B-58ADE11CBE39', '1D1CE9DF-488E-4EF8-A0AC-4283E2A2D383', '4610018820031', ' /   ` `  4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8B23CAB-83AC-4159-8C49-1773842F986C', 'B9500329-949A-4C72-98BE-CE4BEDCD88AE', '4610018820048', ' /     , 4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F739B781-F5C7-48CA-9CD2-9344DCC65C97', '36B3F190-8F38-4B80-9610-736592B49B80', '4610018820055', ' /     , 4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62AAAB6E-F77E-46E3-8B40-B39E3AD490A8', 'B735CBF7-A520-45D3-828D-7116FF2B4AA2', '4610018820062', ' /     , 4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('153278CF-2819-4845-A88D-9718E033057A', 'AA91E716-67EE-44BA-B875-9B025D870626', '4610020540040', ' 12  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8C20DEF-1A02-4AB5-869B-6A86D95C6307', '8CB3143B-3EB8-4600-BB8A-DF5F6429E3C7', '4610021170048', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D351E7B3-A118-4CCC-9E61-D2F8A99DA792', '5ADDA3B8-85ED-47EA-8365-10C05C7B938A', '4610021170093', '   320   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C437481-9868-4FD4-BCEE-3F07AA80BDE5', 'BD2FEDBE-D830-4118-8A3F-5401391738ED', '4610021170116', '-    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD7144D6-E7AE-4881-BC09-5DCD5FFB1EF7', '0926D53B-BB4E-446D-ADBB-0B945D788213', '4610021170178', '-      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('258AB5A3-5FA0-4ECF-913D-E96FEC627FFE', 'BEFF5D8C-99D9-4ED7-84E3-14361CACDAF1', '4610021170185', '- / 1-4 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66733C37-161E-4E40-AABD-CB0752C05253', '6C65797E-0005-4D0E-B6A6-DCED5FB74892', '4610021170192', '   // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70E5A609-198C-4D87-BC6A-F898B8A7485D', '13CAE97B-3BE4-4E39-9A52-407F95F4D8C2', '4610021170253', '-   0-1  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E8B15B3-14A4-4C53-8F66-8705C996B436', '59F07936-B89D-499A-870A-AFD100A48226', '4610021170277', '-  +   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DF01742-AACF-4208-A0E6-C1C0D156C999', '5BC5BD15-8FF8-4F43-93EA-EFBD23A8E400', '4610021170284', '-  +   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68B5F23C-5967-423A-BD3C-9D3F23FEDAA5', '89D5E81A-DFA7-4CC1-B0F4-E9107C4621AF', '4610021170291', '-     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9498087-BB35-44EB-B28C-1B042A664A05', '3F8DC229-16D0-4615-BDE1-A7EA53A10637', '4610021170307', '-     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBF3B552-13A9-44B1-AD71-39371533C27B', 'F7B16272-17F3-45B5-B8CB-85AE20C3F1B3', '4612586500445', '   /    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08EF6B10-C4AE-4BFC-BE95-FA636D4F7621', '614E966D-44ED-415F-B727-FBB5D3BBE3F1', '4612603500021', ' 0,2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E879DEF-5B4A-4E26-B38E-6B51D89ED3DA', '8ED8B378-BEB5-4B22-B64D-303A126CBF25', '4612613500134', ' -  2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14BEC23B-DD15-4C2D-9959-94F2AF576072', '832EDC83-2CE3-44D1-A2C3-8DFFEC7EBD57', '4612613500158', ' -   2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF1AF59B-9C43-46A2-A4E7-ACE62E8E3DF7', 'E1994BBA-6EE0-4D61-87E1-A4CE75813CFE', '4612613500165', ' -   2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF799F10-3336-42F6-9B14-107AB3E76473', 'BEAD1196-B778-45AC-9DA8-5D5D14365DE2', '4612726400017', ' 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6744AED8-9C06-4051-BE01-E0375FA462A2', 'E26A2490-DD44-4231-9F22-E0A6322F28EA', '4612726440037', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB9191FE-5AF1-4355-8C30-01BF9763ADEE', 'EE633CFD-E7FB-4953-9C0C-8848F9940D8A', '4612726440044', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3E98F85-75DA-4E18-825D-909D588A9BCF', '5277CD2F-AD26-41D1-8E47-1FCE8525EF35', '4612726440068', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E05F1443-A6CC-4266-8CD2-585B473CB4CF', '5D41EF6F-8AAC-4C17-BD1D-47DCC471A618', '4612726440075', ' - / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('984981F8-A01D-41B5-A0B7-6EA2888FB7B1', '98B54C2C-F53C-4859-A5AA-A511A1CD69DD', '4612726440099', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DB21BF0-0637-4BEB-9CD3-BA5F38EE8366', '3C729189-C1E4-4358-8093-9E51B7E7F507', '4612726440112', ' - /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FED05B2-5111-4C2B-9B4D-7789C06EA5AA', '0A56F1E1-9F9A-4DFA-8599-8A7F0E1DF7CB', '4612728690034', ' 103  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6501E13-B415-4A0D-B5F1-B0ADDC4D3CB9', 'B7EC30A1-92D0-4206-999C-C8FA2D7CF002', '4612729880069', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED4992CF-AB5F-48FC-AE39-ACE5BDDA4A9D', '82A5F8EF-4F16-42AF-89E8-75ED7454FD7E', '4612729880076', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E34A0F8B-761C-4B5B-A3DD-D91DFC7623B5', 'DEF89606-91B3-4922-9A40-C73F6D968BEE', '4612729880083', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99258EF4-DE36-402D-8454-D001362CE12B', 'F35B75F6-81A8-43A2-9DEF-1DEE9E1E0ACB', '4612729880090', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88D4112A-7A18-4E4A-B022-C6CE2AC2441C', '515E6213-CC79-4DED-AC55-906694F342C2', '4612729880182', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8FCCDFD-F627-44A2-8694-FDAAB542AF23', 'E2CBD021-A10D-4824-A807-56BCF3946ABF', '4612729880199', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4848134B-E51B-4719-87BD-E8717590FA3A', '755EF828-1580-4EBC-8544-3BAE1F7BDD51', '4612729880212', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8464E8D-D07D-4770-8FB5-D62E9105124E', 'A0AFB6B9-E12F-4490-A19C-4F40A7CC20E1', '4612729880274', '    3-6  // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('300D19C4-EEC5-44FA-8208-29B5132391C0', 'EA4C0D65-59C4-4B4D-9B29-8B54A7675280', '4612729880281', '    3-6 /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A786ECD-90CC-4BFF-8842-85063A9DD3D4', 'B1120E43-5403-449C-A02A-9BD69F2C31E7', '4612729880618', '  / 115', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40C8158F-FDE6-4465-8A76-D5523AC50884', '1830B280-F63D-46C4-9F80-FC0170494933', '4612729880632', 'Pure by presi    / 115', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B616D8DE-A2AE-47A9-A101-B81D8987173D', 'D7BF9083-74ED-4522-9C51-747E6BAF79B0', '4612730250073', '     2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3172296E-06DC-4A37-8BC1-99CE0B37974F', '2EECE9CD-CEDF-4AB3-85D2-A2ABECD6AE7B', '4612730250080', '-  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66012136-B8DF-453E-9B1B-5330E61791E2', 'CFBB4C1A-B73A-47A1-8F25-FF7A83D28485', '4612730250097', '  -     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4F88840-CBC0-4084-BCC6-9C75CCE6DA21', '45FF4B5D-14A3-4E6B-915A-0EFE5B3248F9', '4612730250103', '-   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A587C24-4E35-425E-AFA2-C1D8B2301488', 'F242C2E6-25E9-477B-ACF4-C84E8142B50C', '4612730250127', ' -   +  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B58A9B5-7E04-4D0E-8374-6F33244189D2', '33D0D89F-AC33-465F-BBEE-4637522C2FB2', '4612730250172', '-   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6250C76-2BA0-443C-9F9B-3592901FA88C', 'A82B1AEA-EE7D-4DBD-8E25-F398D57FFDFF', '4612730250189', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65A17C3F-CA14-4CA7-B0A4-3A78584C1A0B', '170C70E7-362C-4E68-A3E3-938DC0D67012', '4612730250196', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE1D5E9D-9B62-4C32-92F4-43DAB9A014D0', '403C14A1-04F5-4909-A628-F72D06AF9702', '4612730250219', '-    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE25E947-ACE1-479E-AD42-4C9AD70808A1', '72C68E88-18C4-4825-8C4E-2F38E34D7BB6', '4612730250226', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63C7DD66-87C3-4C24-A386-AD2530FC7F8A', 'FCC67039-95FD-4BC0-AD5C-CBFF6C0381A6', '4612730250233', '-      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4005B761-B4BA-47E4-BAE2-3198A9FB7F79', '04470FDE-44C4-4252-BE87-BD798B7D419E', '4612730250240', '    ,  .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E95757A-AF2A-4D2C-92F8-0B275DA48A3E', '88C11758-E62C-412C-A64E-46FC236881C4', '4612730250257', '   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42E94271-39E1-496B-B1CD-F60CE720999B', 'FB8315CF-C072-4B74-9626-9935A7B2C3EC', '4612730250356', '    +', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4334EAD-26CF-40C0-944B-9D76E6AC56BC', '14FF4A41-2DF3-4164-94CA-4C289B69E768', '4612730250370', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2F03E0A-815D-4EAB-8FB7-0DC0B33DC5D3', 'AD803A15-02E0-4526-B478-BDD4C34C82B8', '4612730250745', '-..    1716', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E33F65ED-4DA5-46E0-8394-ADCBAC6B7756', '6360A6A1-487F-4D8E-864A-4BB750557B82', '4612730250769', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F2EF54B-964A-4A6B-9F6A-8671FDB0CD29', '566C20DB-7CC7-440B-934D-E6519ED8D4B0', '4612730250776', '     0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F295305C-3144-4F4C-80C2-30064D3F2EA9', 'FBFCCFC5-EC9C-49AA-965F-D6945268FFC8', '4612730250820', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6405CA85-44D0-4068-9E7B-44F2831AD973', '41D6ACDA-303E-423E-9B6E-3AF990B90739', '4612730251148', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22A1C3CC-E7D9-4818-9B5D-083C449BF9BC', '4E5BA176-7474-440C-9EB0-A1C65D0DFCF2', '4612730251155', '  -      /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DCE6C55-8CA4-414A-9AAE-56E7D8EE9379', '0ACC4278-3168-4900-BE46-3E4D03E2CF8F', '4612730251162', '  -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC4CAD21-7C2B-4F9B-9A25-8BE41A89C638', '9D584A58-D232-4048-BADC-5F12B5D2ABB6', '4612730251179', '   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1E8468D-0CB6-4A50-B02A-DFB95D638F35', 'DAAAD972-651C-420D-925F-7B06DB31B6D6', '4612730251186', '-         / /11414/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22FC00D8-4B46-49A4-8C1E-7FBB29543F25', '42A489B7-C627-435D-AA86-BB197C8A02AD', '4612730251193', '-         / /11714/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9C7A6BD-DF10-449B-89E2-D3C43DAD0EA9', '06B0EA3C-8CEF-4616-B70A-1F3BE207D361', '4612730251209', '      0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6496B2EA-BF7B-4539-9588-EE37C702B693', 'FBFD5F22-0890-469F-A02A-3F7A1ED08FD0', '4612730760329', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B04246C7-E752-4E0C-BF11-314CF6F2F3A5', 'CB225992-551A-4C37-8107-AA0850898D2E', '4612734310063', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F992B96E-762B-46DF-99F1-271DD8C14F8C', 'FA7CE7F9-5EE5-4149-B7D3-A5E0CB22EDEE', '4612734850026', ' 1500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83F4BBAA-E663-49DF-AC54-5C54C8F7C287', 'AF843FB2-87AE-4D4D-AA5C-66568FF11F22', '4612734850040', ' 2500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D33E19F2-ACAB-4EE9-98BF-D794CE07FAC3', 'BB572A02-5B12-453A-A53A-CDADFD0ABFFB', '4612734850064', ' 3500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3973EA76-5FEB-429D-BF17-F50901C3358B', 'D68B9591-AC81-497C-B6CC-1A4FA05B7511', '4612734850071', ' 4500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A98DB69D-9218-4C01-B3D5-5A7072DA00F4', '7ADF4EB5-CCFE-4CBF-A640-39826AE985B5', '4612734850101', ' 410 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AD84758-CF2E-4444-9064-09D1D850DC2D', 'DB12D152-CFAA-4433-81FB-51C32B82E178', '4612734850118', ' 610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70A7C6AB-4AA4-4770-AE44-CAB1E9EBAB6E', '88AB566D-14D5-4D4E-96E9-AD9E73081CA2', '4612734850170', '  g22 0,7*40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92635AA8-8043-413F-9C89-4D7A5F903786', 'F8CFA5B9-F38A-4A58-8AE4-0DB81A0F4D49', '4612734850248', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D0A970E-9083-416E-A4B7-1BD6DE0DE6D2', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4612734850262', ' 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39FDD20A-0002-4C08-8FB1-AEE1E7D6A53B', 'FDE0599F-116A-48BB-8868-331C9D2DB674', '4612734850286', ' 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B740490E-1868-4552-8AD4-5C998DE9BC29', '1FACF77D-3569-4EA7-9546-0CEB4EA01555', '4612734910423', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('961E95C0-1D35-4FB7-9B44-480234F67504', 'AA3FBE43-38EE-47FB-976D-F526059453E2', '4612737420264', '     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D70E2444-9336-473F-8380-D64385E27EA0', 'FD23FB9B-8DF6-47AF-8BBE-E88035F8A07C', '4612738370285', ' 1,510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B546B698-9DB1-4719-A675-4CF03B8B0289', 'EAF05799-2E34-488D-9337-94781425E9F6', '4612738370315', ' 210  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('529D1EC5-DA29-44DA-8656-49AAEEF6C05C', '2F2E7A2C-C667-4B90-B843-250A5CA2AC02', '4612738370377', ' 310  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B24C9DD-BC23-4D99-931D-C0B5BD6A6921', 'A9EDDF27-9185-46A5-BBA2-ABCC8B107E45', '4612738370407', ' 3,510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E5C480E-467D-40DF-9A41-8D03E0752E10', '541A4DB5-4F31-431F-A6CB-BD848A0E132A', '4612739990024', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EABBC3F-B111-465D-A586-0994D942B477', 'ED73EE0E-714F-4408-B183-1D68874EBBBD', '4612741480186', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('004740D6-5522-4384-BC5F-056902E148D1', 'F323C19E-ED3E-411A-825F-22C33FA89C4A', '4612741480209', '  5 5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('662E0CD6-1F8D-495F-AB4D-32FBF4E0DB06', 'FE8CC123-A5C1-4EE2-9392-E6D75263143A', '4612741480216', '    12  7,57,5 / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA67A2EB-BDF0-4861-A9D6-BCAEE3435CBC', '8594B632-DBD1-47EB-98A5-82CE7E59EB59', '4612741480353', '    /55//12 /10 /../', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B79851D3-F55A-4DC5-BCCB-B4B3C4294A83', 'B3241352-5C12-47FA-8F8E-359187E8554C', '4612741480452', ' 710 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4B14A02-4A7A-4110-95ED-B1607652E163', '6A492E20-5C83-4DB1-9519-280930092035', '4612741480476', '  1614  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB65DE55-B5AD-436C-AD76-11B1C4537AC7', '421060A3-0D54-48C4-BFB2-64BF873E81EB', '4612741480629', ' .  1010  (..).  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89D194F6-4AAC-43EB-8B23-2F6BC488F84D', '2DB0F24C-AA1E-431F-B4FB-A9C96F84F7A3', '4612741480636', ' 510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('615A17D3-2D94-4D0B-AD5A-ADCEB700820A', '9DA60AA9-05F3-41D4-898F-FBDD559DD4A2', '4612741480681', ' 714 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC42C65F-063A-4B78-8F23-BB6E16883414', '624CD9B7-DA51-4BA0-9EB7-A456FA877605', '4612741480698', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF8B6490-F0A7-45C0-802F-1218E3D52B46', '624CD9B7-DA51-4BA0-9EB7-A456FA877605', '4612741480711', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6703056A-643B-4412-8C1F-939C3F98E314', 'CB06A0F7-EC68-49D2-BA4B-29F8AA329F7A', '4612741480728', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74B15037-E77E-41C5-8C8E-C004A08290B3', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4612741480735', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('732329E7-3898-4A57-842B-3A030B530A80', '703AC993-44BB-4898-BC75-A66AFAEE6A49', '4612741480759', ' // 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F7F6B8F-2677-465C-A20B-736E5DF5CBC8', 'CC7FE342-25BA-4C45-B0D4-B6E63E57587F', '4612741970021', '     1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEDD610D-DD00-44D8-AD27-8642A4C69C29', 'A5B090A2-C1EC-401E-8193-6C12B3A3A045', '4612741970045', '   o2  1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB3A9164-DCE7-4570-B42F-F064D728E6EF', 'F29279E7-1EB0-41BB-A0F3-862A6F230AEA', '4612746210450', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52B6A87C-5F7C-4522-8180-CB813E8F8930', 'A7A171BD-47C4-48D9-AE85-27DFE0D07DCD', '4612746210467', '  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0251C88E-3B18-4313-B066-4C14405E451A', 'ED42BA0F-4FDF-43F7-85DD-1A6224F782CD', '4612746210580', '             20 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75BBA837-F56A-4C55-A297-B692D95059B6', '6265796A-4B24-4058-8FCB-D5935A682397', '4612747430390', ' .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFF83FB3-27E9-4AA4-BE30-473E8205213F', '8549D80A-AD27-4D73-B1D6-7007FA8D440E', '4612747430444', '    /   m - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1162267D-53E7-4E4E-B5A0-AD0F541DC0D0', 'F952BC7B-FEA8-44EF-943E-DC36A1E24E80', '4612750380026', '   -02,4 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('789298FA-2074-4484-B671-B1D56B8133DB', '5DB0AD36-DF32-4B28-AF74-15805B7DC4A9', '4612750380033', '   -02,4 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5071A5E-1790-41CB-BAB5-D6A128D2E2DA', '68933F85-E2DC-43F4-9DDB-8D02E18F3BCE', '4612750380101', '   -03 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2425991-CDB3-44E7-9F2C-3141BC6DF5B4', '2033F36A-4997-493C-B246-A46A8701613D', '4612750380125', '   -03 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('837A6259-55CC-4643-93FD-29C8E18618DE', '67859830-6957-4A6A-928B-F633B8B90578', '4612750380132', '   -03 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2DE8128-B574-4329-9A35-84F1C90B8790', '9DB66258-31FF-4287-957A-17719CB3CCD6', '4612751230030', '   1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('779C8F56-CB39-4FB1-8F4C-1DD5FE412979', '1EE8027F-7960-43DF-9160-923F9B6C7D84', '4612751230085', '   /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F99467F-7ACA-4771-B1F1-CB8196B0B356', '0A2C73B0-A9D5-4357-BC54-1117AC59042E', '4612751230139', '  50/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FFA1964-0D8C-40FD-AF23-5D8630AE543D', 'A7A171BD-47C4-48D9-AE85-27DFE0D07DCD', '4612753320012', '  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B0834D6-3FF1-460F-8A36-FB8D614E7C32', 'D254606D-B238-4835-9639-8F7C0691A998', '4612756300011', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50CAA7DC-6C51-4DB7-892F-9C97A89CE039', '31C6B5B9-E816-4FFE-8564-6A3881015C6A', '4612764400017', ' 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('793C3674-F1B2-4A40-8C23-7DE95E3CBE0C', '3D88B64C-39AB-4CF9-855C-C82F484B610F', '4614171333346', '  /.  /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55E09EAB-A286-420A-A53F-F79186CA8C94', '1EFD1B45-9CBE-4E5E-972C-B5384600BE0A', '4614171337153', '   /./.. ..500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B126264-BB41-424A-9047-D9E84D539645', '230FC66D-E2B4-4761-BC32-E30FBF151FD9', '4614171337177', '   - / / / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A26FBC5D-AF77-4057-8552-84087C53258F', '404468A6-D185-463E-A768-E87499C1FF06', '4614171337313', '    /. .. /./ 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4952246E-666F-447B-B27B-DB03FB59FF8C', '0ADFB077-AD9B-4FF8-97BA-FC0D0FD129E4', '4614171337320', '   .-./. ...300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA527EC4-1BEC-40C1-A77B-960328989327', '4B99A14F-1421-4ABF-9381-DD77DD16351D', '4614171337412', '    /. . /.. / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED81D59C-8900-4D64-ACA5-00D1A04C037A', 'D48681B1-5B27-4878-A5A9-277B52E22C6A', '4614171337610', '   / . /-/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0BDC25C-1A8E-441D-B2B2-C5EE78B93DF0', '47EABF36-6329-4B80-9040-A8206C6961DD', '4620000840015', ' 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AB38469-B57D-47DF-8DFB-B286C7852FFB', '0B9F379B-FB21-4EA4-9EBA-22228B749333', '4620000840022', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B733DCA-AD26-4A7A-A2A0-171DCFC73DF4', '23187E1A-C0FA-49B1-8CC9-021E36103180', '4620000840428', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6822D1E0-FF68-41D4-8947-EC947E41E779', '9AF5A9B9-8519-4950-839C-047BF8C0B18F', '4620000860020', '   /  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBD294BD-8E04-4CFB-A7F0-EB835D1E9915', 'D4DA58DF-D615-42CD-A4E3-C1714855B295', '4620000864028', '- -1 / /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAF4844F-7F03-4CED-BE16-0BB5444EDC7A', 'F3D18F04-35ED-4E4D-8EDE-497FCE37CCD6', '4620001090013', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19447693-DB4F-440D-9992-47157647DE06', '890E650A-3385-42CF-BCCF-3FB0DED1C310', '4620001090020', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D2C3758-CC55-42D5-842F-9DB74DFE6E0F', 'FE60E019-2F58-4594-8790-48B113AE4729', '4620001090044', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E750A60-638F-4E81-A076-99A40D20578D', 'D2F4BBA3-3622-46AF-AE7F-ACA2985A077D', '4620001090051', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDD12776-B403-4F56-A149-1E848A61E3DE', 'CB2E957B-79A0-444A-9581-6F546DFEA5C8', '4620001090068', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72E338DD-6157-4940-AD72-FB2819B81BF7', 'C6675EB6-05CF-4167-9BB6-B907932D086D', '4620001090075', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA37802F-D986-4A7B-98A0-7D67617CF92D', 'AB80BA6E-930A-4861-B266-0E7EA00F6B29', '4620001090099', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83A0D099-AB3D-474C-A214-8175C2781D6B', 'F9471987-916E-4378-87C0-C1F119D6EB39', '4620001090105', '-   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E42A552C-BC8A-4D0F-84BE-F230DF1A241B', '8E32A0E5-90F4-48D7-9CA6-7B46D4AE96AE', '4620001090112', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAD7079C-DFC0-45C8-A245-9B50727FBADC', '1C029665-7A69-448A-92B1-5F5F36329B73', '4620001090150', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4D20C7F-6F03-478F-B613-0100D5D7EA7B', '6C741D75-166E-4873-B6F8-8E286B487C06', '4620001090174', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9E0C6CD-4544-45A4-B74B-72996444F366', 'E9EF16F1-4386-4C58-8B3D-753A164955BD', '4620001090211', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B50464B2-0ED4-46A7-BF92-BC274DA309AB', '7EA1F6B9-304A-4188-9EF6-778ED86335C1', '4620001090228', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56558710-0EB6-4F82-BEE0-469E8C9D64A3', 'ACFAE0D3-B556-4193-B68B-E7664E670A74', '4620001090242', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6EE00BA-C00D-4034-940A-57395526AB67', 'D99E914E-15BD-41E3-A923-73BA3BF3D861', '4620001090273', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EE9B787-368C-4D93-B252-52625CAB3F46', '56DA435E-5C47-4EA8-9B19-89F0903AECFB', '4620001090280', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A59C99DD-D56D-43B6-801E-593C400070C5', 'C153CE3C-8957-4BE6-9E33-6D88BA35078E', '4620001090303', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36FCA77A-9656-4915-8BF5-321A2BC4189E', 'F22934B9-69A8-47B6-8C81-8E44CBC83F41', '4620001090327', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A004E615-D14B-4E8F-B6D6-5E8A52DA19F8', 'E2AA745C-B983-4B1A-BA54-61F2389378B7', '4620001090402', '   / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC608BB1-E142-4214-8709-C8E445781353', '83E055AA-5071-4C09-BBDF-AA71CCEB1851', '4620001090433', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAA7E7B8-B37C-47AC-BE64-C010CC6E81B5', 'E3C6B81D-E7BB-4B7F-9842-4968D00E281C', '4620001090440', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F67C0FBC-4BB7-4C65-8DAB-CEB94896C885', '64FAC60E-06F3-4AE3-833F-C021B09DAF8C', '4620001090488', '   / / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('073435D7-DE0B-4699-9315-E20CB1B8D0AB', '2DBE6237-A85F-4306-AD6D-C0BE797DC7DF', '4620001090501', ' 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('963D295B-CF2D-4D9D-B6C7-5C9C92F597C3', 'D498C643-FA04-4913-BFE4-35CE1F363383', '4620001090518', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AEEFCDE-F4D0-4912-89A5-79E0E1D3150F', '5AFC1A95-105C-42EF-95C0-718A37FF3BBE', '4620001090556', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A835DD1-191E-4C9F-8898-F0C994ADF750', 'E5DD7918-55DF-4364-B593-9471A16D4272', '4620001090563', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEBAC203-8ED0-4132-94C4-4619446E18FB', 'B5E2EDDE-E270-4CAB-80E0-335C65B6ADC7', '4620001090570', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1992AF4-210E-4E1D-9080-964B587B9DBA', 'EC373944-746D-4683-92BD-C15185456AA7', '4620001090587', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0EB90A2-73DC-44FC-B1C6-2437951FB0D2', 'DA2A2EDE-0DD8-4255-AA3D-A6DDBC9A5C72', '4620001090945', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A857969D-43BB-4733-B014-F0192F90C763', 'FC1C9E32-3709-4D74-B79B-34AB429573A4', '4620001090990', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A690742-E410-473C-8519-BA0C438CE280', 'E40F11B5-C6DC-4D71-B4FF-B807F2F84DA3', '4620001091010', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD835351-C564-4D00-9DA5-2D2DE35F34DE', 'DAD16679-2A33-4BF1-AFA6-7074661E02F2', '4620001091058', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95CFD240-EFFB-4983-9540-A0E9E17F1BDF', '83D78222-5AC2-4415-96E9-FD0E0D7F7502', '4620001091119', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('659BDCF3-1D49-4AEA-9C15-A88C9390E686', '6AEBAC0D-2CCF-47D5-9F00-29192F02F594', '4620001091126', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C17E13D5-DFB5-4933-85AC-9F77CBB6CD99', '0177FB62-BA77-41A9-BE53-457DBE05F9D1', '4620001091133', '   / / / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11A244C6-F13E-475A-AD25-46284AC5B94E', 'F95B113A-B637-4D87-A8C0-DCFE602AED85', '4620001091317', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C564E98B-A341-4AE1-A50B-216CF2623F7B', 'B2FD4B3A-38DC-4AAF-9914-5A110A332752', '4620001091324', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2563E25-31BA-45D4-B6A6-F2E4EB151966', 'EB17AB67-FEF1-4BF4-B660-0785D4769CDA', '4620001091331', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4C53D7F-BCAF-4288-BF81-C10F141E8437', 'B0A86C16-BC91-4137-8144-E9A2EF0A8F74', '4620001091348', '  . 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2A7B20F-FFE1-4B9B-B48B-DBC171976F86', 'DA4D0E4E-3FB2-45E4-A47E-8EBB6E105316', '4620001091379', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15ECB803-6A98-488B-8A7D-C41F826A5F90', '1E9BC517-D392-4583-910A-1B65B72CD15C', '4620001091393', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D2321EF-362B-44CA-B558-F1E685A1429C', '754B315A-4419-43D0-8472-A7D25E6F2CBB', '4620001091409', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9321957-2C52-478F-BF98-59566E2F5E26', '8AD111C1-B4AA-4F69-8067-8649D7969475', '4620001091553', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E6D7850-7E6C-4EBC-B002-174357D6CFC3', '5111190D-F5D4-4D7D-9D2B-B77C1CE8D8A5', '4620002180010', '       50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CD1202C-22BD-4BCC-B919-D1AA6158DB02', '0648AF90-4841-4724-B8BE-42B5755AEC6D', '4620002180027', ' - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('393344B4-0DCA-49B0-A0A6-83C13864FE24', 'AA727EBE-0B5E-4131-9D9D-881912E0089F', '4620002180041', '   / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6EB12C2-31A2-4F9E-B714-A21C44B3A794', 'ED7AD0EB-0BB6-48DE-BD32-12595E4182CB', '4620002180065', ' - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98CF1FDB-56A2-42BF-A415-1AD9CB79B176', '7CE627B6-4C7A-4DF5-B93D-1DC829A5CFEF', '4620002180133', '  -        15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A99DF1FD-F9F2-4E9B-8B8C-D082FAE022A2', 'E0EE429E-2BB2-4380-A3FF-F6563296731F', '4620002180256', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B619744-0CB7-4C74-BDBF-3EB148B545E7', '25431D5B-1248-4CD8-A3B3-08DDA66CC1BC', '4620002180348', '   / . /-03/ 500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D971BB1-9867-4752-A973-303BE610109F', '9A6B94C2-E22A-4F32-8C8B-DE247FE795E4', '4620002180430', '   /  1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26F2AB66-E924-49DD-8C5B-5A618639F491', 'D982F37E-8F91-4D48-A984-1D23B6F4A25A', '4620002180447', ' 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CDCBB10-6063-4C71-8095-CC9B6095C57A', 'A6EE3043-9E1E-442C-9302-E61825916BAA', '4620002180454', '  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3582F26B-CF86-43F3-B104-7A06290ED4C6', 'DE2E1E77-FAA8-4770-9935-2169065B38CA', '4620002180546', '   / 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADC8C268-2E0E-4C8F-8666-88CB8B6BD828', '7DB4197F-33BA-4995-96FF-94475190BCF5', '4620002180577', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF1E5A2A-366E-43A0-8EB4-39902F0F112E', '6FB29BA7-7AE0-4039-B231-149F6784674B', '4620002180584', ' -  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0437A695-6558-4144-A469-5E0BF816D0D2', 'B3E5C68A-3299-4339-9ECE-38E430044BC0', '4620002180607', '   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE8BE883-EE16-4327-8E4E-39A0E228CE97', '17BEE8C7-812A-4AD8-8993-AED245875722', '4620002180614', ' -   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AFED809-EAA3-4C3F-96D0-18F11BEC4964', 'BAF1BF97-9C98-498D-A5F4-0383533FC77A', '4620002180638', '    50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38B4934C-9EFB-4C62-A987-470141800CB1', 'D817A990-916A-4852-B9A3-E1B007D871A4', '4620002180669', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56BF766C-B573-4CA8-9745-74F3717235B2', '9A8A55A2-F250-4564-ACBC-36FE4198F7B7', '4620002180775', '  (++ ) 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D09FD2F-4F08-41EB-9A67-5D6543B751AA', '9777EAFE-400D-4A39-8B55-C067DAC691DA', '4620002180782', ' /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39FA42A2-E65B-474E-B9ED-457D1D04BBA3', '4FE043AA-E417-44BB-BBA5-9DB4F39A6AAB', '4620002180805', '   /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8FA2562-494E-400F-B08E-5C8303FD3D4A', '65798381-0635-40F0-A880-8CCEAE22AF1D', '4620002180836', '   /   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9D2CE1D-7E19-4C7E-9E83-32447082F2A9', 'A6EE3043-9E1E-442C-9302-E61825916BAA', '4620002180843', '  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7DFBD4F-5C0D-49E3-819D-E4746FC6CD3F', '29714616-DF64-4E70-9EE8-C67D23FECA25', '4620002180867', '   /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0828EC29-80B1-4BDF-92D9-386B9084296E', '76C4512F-1300-4B7F-8FEC-057BCCF8E53F', '4620002180874', '   500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1AC41F2-D29E-4994-995C-D9685C790DB3', 'BDCF2AA2-27BB-4AE4-AF11-486313644DC6', '4620002181208', ' - /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8428ED72-52F1-46C2-8FF1-94449C4647C7', 'DE97D447-2207-4176-AC6F-E0092D9C46D6', '4620002181437', '  -  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('333844C4-1A18-413A-9338-16083BDDD968', 'B89CF45A-4B03-4000-9262-49CC64781260', '4620002181505', '    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF8723AA-6959-41B4-B33D-1C48247B12B0', 'F20203A9-8C2A-4B5E-B836-AAC9BECF0D47', '4620002181529', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40834242-750E-4AEB-AA0F-B6B21E786FB8', '39B3447E-0AC5-4F6F-A827-BB9F86025637', '4620002181550', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8B4D502-99DC-4572-BDEF-6C74DE55E9E9', 'AD7E1379-DD2E-402F-9391-2B88A57AA4FE', '4620002181611', '   /     150++ / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D785840-99DB-4B43-B58A-ABC060F863F9', 'BD636E13-2EFA-49F4-8119-11628349909D', '4620002181796', '   6- /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAFACD85-D1D5-4481-973B-AC4958A8FCD3', '5D48DFFD-FE1F-42F9-8FCC-5F9A6F87FFA1', '4620002181819', '     2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1737B3CE-594D-49F3-A29D-578582F4ADA0', 'FFA08788-F5AD-4D7A-BC83-02872A487445', '4620002181826', ' /2 / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B646D59-3602-4CE5-A0C5-93FF72E381FF', 'ADA85892-CCF9-49EA-A9A3-0632FD18DA57', '4620002181833', '      2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B41B36ED-B8FF-4CFC-988F-7ECA56953A69', '3F304B74-2089-448F-A260-85622212BFE0', '4620002181857', '   4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA77C3BB-E790-4307-A8FF-BFB9F084D4C0', '6FBCB461-AB74-42DD-9C15-ACE4A0CDF16E', '4620002181864', '      4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B2E054D-2EA4-40AC-8E28-AE46AE4DEF22', '373A08F6-8823-4F66-8238-998AB83EF574', '4620002181871', '        1  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6171FCFE-EA23-4A02-8FCE-FBAF1DBAD80D', 'E9B8E840-8126-42AC-8532-130880557CA1', '4620002181918', '  . - //  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7006C218-3AF1-47A1-9DDA-6D31C359AA3F', '3FB6B8D7-2F0E-4FDF-8815-6C7D803CE830', '4620002182083', '   250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B4C3021-82FA-42E4-B43C-195C1C772E2B', '18DF698A-C4EC-4130-A681-78CFE113F9B0', '4620002182090', '   250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B07F0417-D062-4064-952B-27854D88F0EF', '96482E67-074E-4D12-B564-05636C2EA67F', '4620002182106', '  ph- 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB491555-27AF-4D48-A155-E8C0942444A0', 'C2463840-FCE0-4FD2-95E8-4C443866E514', '4620002182182', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85717C45-8C55-42DA-83C9-9240FBB278A4', '1821103A-C62A-4334-8780-A92891C0011C', '4620002182250', '    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A06659AC-12F0-4B8F-87E5-A4BA6F248D8F', '6CBB1CEB-BEC3-4A06-A13D-4949EC569829', '4620002182342', ' . e -. /  1 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6267104E-570C-445E-B618-212E4A1CBCA6', '756D1B56-8CE0-4F40-90C4-DAB7463ECDE6', '4620002182403', '     3  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('798356B9-6713-46C4-81C1-F28747BD4E0E', 'A07F2C75-2661-4EE9-8C9A-AAFC73AE4BEE', '4620002182410', '   18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('915E8316-F763-4B07-A8CF-37B3318A131E', '7DBFA469-6D4F-42B7-8FDD-E317529D75E3', '4620002182465', '   -   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('263A2F99-87DE-4F58-B553-30B36CC49217', '5122BA3E-3006-4B26-B3BE-9590980A1C38', '4620002182526', '   /,      50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10847253-A91D-42D3-B46F-77F509C3910D', 'F5CD5934-0F8C-4651-A9EA-F5CB05A4EBED', '4620002182533', ' /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('487C9F13-82F2-4ED6-80B3-7E66FDD1287F', 'A6FE9204-EE2F-45BE-84EA-8D21F147FEAF', '4620002182540', '  0,2  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EF10355-2398-4690-A752-5C54B5492E8B', 'ED17CAB7-247F-46DF-AB4D-D23E409B902F', '4620002182557', '   0,2 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E27062A-6D48-440B-9375-55D6BA15CDFD', '683A8AB4-40F7-4C8A-809E-05D476A8D874', '4620002182564', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2DE9C10-2267-4355-B164-DD28708572AA', '126189B9-0357-4183-B498-C8106C34ADAB', '4620002182588', '  / 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9C9F554-21B7-40C1-99A6-1EE9A77EC1F8', 'A5BC2C17-63D0-4F5C-BA8C-353CECE4A2EF', '4620002182595', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C810BAD6-7FBA-467B-B13A-DB688AC65637', '356C648C-4DA1-4DA0-9B1F-B2078ABE2173', '4620002182656', '   / 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72674679-1432-446C-BF6D-34FE18A831FE', 'E13ACDA0-0216-4424-ADA2-7D0D4DEAC81E', '4620002182717', '   /   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28990AEB-D261-44CC-9178-12F49D492FFE', '822312BC-A5B0-453A-BD19-A340BE024E03', '4620002182731', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C799388F-04AE-4414-8867-A088275E5663', 'F791CFF9-2F45-4156-B9CA-7D1C5985361C', '4620002182779', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B683E1F-CE59-4319-8AE9-F552E58EDF26', '79D8B073-ACC9-4180-B710-51C8A14F0C16', '4620002182847', ' - 32 1,2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBE26488-411F-433A-A603-E2DFACB0AE53', 'A42FFE31-FFD9-4543-BE01-820E846AEA77', '4620002182854', '  -  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC71956D-2CBC-44D3-97A8-27D6FB00710F', '597C2A2D-A0D9-4592-977B-E48BE139FC89', '4620002182885', '     4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18D82B27-DE57-49D5-BFF5-B69D70129F0C', '3EF304D2-5D3B-45D4-AF3D-841351DB4819', '4620002182892', '.    / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2D452DF-919D-4342-A500-7B5ECBC583EB', 'D9A04A8C-822A-4B29-9E01-5FCF6CB38019', '4620002182908', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7A58A19-D611-4A91-99D2-43C65E7693BA', 'FBC0DDD9-C381-4332-BE08-C00969CB28A8', '4620002182953', '  e - / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C0BCE06-FB15-41E5-B109-8D09014BBC79', 'F251E3FC-D482-4BE9-A47D-53764F05AB62', '4620002182960', '    / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49BD93CF-5422-43F1-9856-70E0B0C054EC', 'FB054363-6A25-42E0-B412-8C85134A58F3', '4620002182977', '    / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E6C0ECB-1F02-441E-AAC3-847F5E35357B', '57A8D2D1-8282-431A-99E7-946CFCAED877', '4620002183059', '   /   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C949ABBF-5D6D-49CC-90F5-E4FCD264913F', 'E0A39319-C80F-4FC9-9C61-F341124A0D50', '4620002183066', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CBFF56F-E721-45CD-B929-781962F43044', '70272E22-751B-420D-8709-D5281DD8DEA5', '4620002183073', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C850F098-1AC3-4614-8113-031AAF6BDDC7', '6ECDBA93-DC10-4865-89A1-B7BEEA5BC209', '4620002183080', ' /.  130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80E2566C-8920-4913-91FE-9D0C2E71D62B', 'BACCE93B-F220-4AEA-9851-809AF9328E25', '4620002183097', '   130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C872628-7272-4177-88A7-D75F14FE264A', '185F633D-77FC-45FD-A946-72112C19E628', '4620002183103', '   58', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ACD344A-C1EA-434E-9B4E-218DEB0C511F', 'E00D373C-5B1E-4FDE-9250-38E88A44D24D', '4620002183219', '   125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08F4028A-F93C-41DA-8E44-22FD04EADBBA', '3C90191D-2947-44D4-9E1A-4DF35C20195B', '4620002183240', ' - .    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D62B7D9-6E00-4AC0-B424-74B58BB9D66D', '05796878-5E43-4675-BD5F-3C36F1E6C72D', '4620002183295', ' . 3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91DEA29F-ECE7-4993-866B-BAE9C8367EC9', 'DD555CDC-6F05-46DB-ACD7-D63BF67458BB', '4620002183370', '     ,   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6DCFADB-7DBA-442A-B0D1-F5D971A661C6', '8C9969F9-381B-493C-AAB6-553BCC572136', '4620002183387', '  - /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83C7FB9C-CCA4-4D08-A9B1-239344DEFA1E', '11E7F936-5100-488A-9ED2-678BEB7D3022', '4620002183394', '    / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F06A9CA9-2DB7-424B-B8FB-6198D9869464', '6BB9542B-ACB4-4F37-ABB5-22E569BFFC44', '4620002183400', '   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A20D2561-3078-4A77-99D0-58F4E36A73B0', '7957A7E9-B438-4DB6-A617-CCDA326144B5', '4620002183417', '   /,    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A0091BD-BB1B-44C4-9CEB-9BDE400A66E0', 'FDE7F058-D21A-4DBA-A408-8ED7A8A7FA4D', '4620002183448', '  -    1 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53BC653D-60DF-4B4B-966B-0FD39F6D2DB4', 'D955B1B5-9FFD-4F23-84B0-840075ACB0B3', '4620002183455', '   f 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A81B01D0-8217-44B5-A43F-ADDDAF0797AE', '2011B903-3122-4E26-A040-EEDC706AEBC2', '4620002183493', '   f  /.200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33E445CB-7BA4-477F-B1E0-28D6DF8A3306', '039C491B-75F1-4E61-B325-00AC2D8F69E9', '4620002183516', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B13F9089-6B7B-431C-AB75-B254134DA6C7', '316E5644-5439-4F59-ACC4-D0BF84BB6195', '4620002183523', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85B1A72B-3A60-4A5F-A33D-71FB8EA48CE9', '5DDE229B-F29C-40FF-95CC-F06477B0BA33', '4620002183561', '  -    1 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F2706D4-7D22-4FB9-A9D8-A494520ACD91', '8DBEA380-FC0B-4754-A67B-05087BE64B79', '4620002183677', '   - 200   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81B6CB41-A0BE-45B6-BE2F-6F56B16BBBEA', '63881BE9-BC53-4B58-910B-A4510046CF9A', '4620002183691', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('457C04B3-22E4-41E7-90AD-CC3C31B01B8C', '21FB7680-E64A-4E19-9B78-0B1C85BF1299', '4620002183745', '   bb all-in-one 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('843F0512-BAF1-44B2-BB6E-336C2F614FCA', '6182EBA2-7FC5-495E-98A6-AB73B2D3660D', '4620002183776', ' -  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9855EEF-345C-48B6-B57B-4FCF8B813E47', '012DA72C-CAD4-440C-9564-434D49F8F211', '4620002183783', ' /      200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E80CC7CD-143C-42C1-BCF0-0761AF06BAE3', 'BCF8B5B7-6C6E-42FC-96FF-9726D2653870', '4620002183790', '      20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A848354-0E28-4472-9C32-683A2886CA94', '03314302-B642-4D4E-BCA0-CF83BAB0DEF0', '4620002183899', ' /   / -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4533546B-6161-4B87-8694-359552BC3D4E', '39A8C7CD-CA17-48C4-918D-338103D2D7F7', '4620002184025', '   - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2919DC78-ECD9-4F48-9B4C-DFA8E944284C', '7EF92EFC-F937-4A83-90CF-7F8428516BF3', '4620002184070', '   //   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D991CF65-863D-48E3-8B9E-51A2A85FE858', 'FB6284F6-70E2-498E-9A47-1FFB043A9AEA', '4620002184155', '  / sweet kiss   +  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4373B36F-5EF1-44D0-B942-48C6CF724FCD', '45799E39-4656-428B-A5C7-503D49CC9D09', '4620002184209', '   . .   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8328A73-289C-48CB-BF08-387CE6AEC0D1', '2E0BF4C3-6E74-401F-B217-791205CAF1AE', '4620002184216', '   /    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54C5DEA0-876F-4A59-8B8A-69E3EBABD916', '2644F6FC-AA22-401C-B3D9-F61A23CF4082', '4620002184223', '   /  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98B5A5EC-58C8-4F9B-ABD3-39FF0DABE6E0', 'C89101B0-96C5-4910-B375-A5B34380628C', '4620002184230', '   /   /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA9214B4-D33F-4473-9AB2-1AA10D04165B', '65AA6C64-2AE2-42D5-BBF3-FAD666C42578', '4620002184247', '   /   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A668F1D-78CB-45A7-BA60-03B73BFB54DB', '632A1B40-F986-4527-A452-ABDCDAC6F055', '4620002184254', '   /   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60F37E17-AB30-4831-BE96-88F9B378DB99', '72A05729-4B89-4468-A830-2936E2E3E796', '4620002184278', '    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAD9FB56-5F1D-484C-89FF-2DFF131D453F', '738020E7-79D1-4802-AAB2-0394A674A01C', '4620002184292', '   - /   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CA04A6F-5501-4C53-AB11-823FD06B2D81', '72A3180E-12FB-45C7-A843-168B338C853C', '4620002184322', '   /    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2972E265-F994-4F89-9C27-E0C1F03BD83C', 'F58A784E-9357-4011-AFB5-005FAE387B74', '4620002184360', '  . / 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('127DED28-B97F-4B1B-8467-520859649088', '80AE7829-E580-4C5F-871A-EF4B7B1C1920', '4620002184384', '    20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC9D9565-5BBE-491D-AEC9-F05814CB539D', '07C33BD5-F23D-4A28-A51D-48704441D1C3', '4620002184445', '  /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77ED6755-6E21-4915-B779-37F6142E94CF', '51D921E0-C3AE-4ED0-AFD0-04123DB1B6D6', '4620002184551', '   /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('895BA8A8-4715-4D54-A558-2B5E22BB5BBB', '5C0009F7-BFBC-4C51-BF04-9BCC5E9FD78B', '4620002184575', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC1889C7-2450-425C-85AD-66C0A44BB5F9', '5B78DE80-B4B5-4EC0-921E-3AF0C55BAF01', '4620002184582', '  /     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89CE2815-C832-4362-9AA8-16AE82CE8D78', '544C7B94-41D5-44E0-8612-4E4181B9E219', '4620002184605', '  /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CCBE83E-809A-4032-AC85-D1B8FBC368ED', '556FB2E1-3A46-4564-9C9E-4B79FF94CC57', '4620002184643', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FE9D00A-8988-4ADC-AB45-A2B607977E08', 'F9FAA137-2F4F-4310-B532-5E6FE18A4CCB', '4620002184650', '   /  miceclean 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C30C8F8E-B5FB-4D2A-9BF2-AB57AE938FEB', '9333548F-07C6-409C-819A-603845B17CC5', '4620002184704', '    9% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AADA5BF-1CBC-4549-B611-09265A4CF65A', 'C7F39023-6EB0-40E1-90D6-24C4F7147687', '4620002184780', '     30 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C95E6B9-A3EF-49CF-9A61-965119C44B83', '16820A6B-A62B-4A42-8714-3F01766FF141', '4620002184797', '     30 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FB989EE-B3C0-453F-8ABE-A5608E24AAC2', '2FEBBF9F-CB73-4174-B81B-7DC4CC5440AF', '4620002184803', '     30 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D05B3E02-D78B-4C0A-BAD5-343DE5FD9492', 'F88DCFF8-6FBD-4B3F-984B-5A2F3433441E', '4620002184889', '   3d  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C8AC882-286A-4DD6-AE33-21E3BF753BD7', '7D2B3048-A51C-4857-8C60-916F69E410BF', '4620002184896', '  3d/.15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05DCAA09-94A3-41DF-BFA6-77C83A367783', '47B15B5B-9325-4286-8354-CC3308B05115', '4620002184902', '    3d  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BDA24F9-43E2-4AF9-B17C-D2ACBBBB32E7', '85677270-9138-4E3F-B900-D28AD65098F8', '4620002184919', '    3d  / spf15 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A41075C-7285-4003-92F8-BD20BB8F4C3E', '92135A5D-92D6-420C-AB97-689148639005', '4620002184926', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46403B39-DF01-498F-9F7B-261375215789', 'B6D89BDC-D35D-48D2-A702-2357FF44377F', '4620002185015', '   /   10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B664079F-EF75-4B26-B88D-A2D78BB5A9A4', '73362ACC-9BE6-44DF-8232-6DA50BFEA15E', '4620002185060', '      .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1FDF9B6-F4B3-4FFD-B065-F7BD148298FB', '7A07D997-197A-415E-BB71-F1C9F5096E95', '4620002185206', '    - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1C747F3-DA83-4691-ACE0-89386E6CAC80', 'EFC26572-0925-4828-8CAB-4DFFBECAC82D', '4620002185213', '  31  - /    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('026686E0-9E66-41BD-95A0-6C7D2516AB9C', '9DABE14C-2FCE-4B73-A38F-8B9F18C5F660', '4620002185220', '    -      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('636BAFD2-5C9D-4806-A1F1-1D64F627B13B', 'E2C243B5-81F6-4C3B-8900-B31B09158F03', '4620002185275', '   /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A3E55A7-F296-4B18-9976-636A17476328', '2FE76932-6B19-40AB-8F2E-6E789346A058', '4620002185312', '      5% 130 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61D099D7-968A-4AC0-AE37-F790335AE9E6', 'A85B31AD-0EFD-43A5-8736-D47CADCBC5D8', '4620002185329', '    /    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8E5BBEE-1DD5-4916-9723-1A65E4D5C1D2', '2AEF8C5A-0970-405D-BB87-E57AE5840665', '4620002185374', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43772817-8585-4AC2-B281-8D91D4523827', 'B1A8A061-3DF4-429A-9697-046669FBDD74', '4620002185381', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97BC954F-EA1F-4C2E-B184-3E81E0C73ED4', '33AB2CE7-0D31-47F6-A2D6-1E9EB6A8815A', '4620002185398', '   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1442751C-E7B2-4840-8007-32A544B1FC39', 'AEA4FE19-73E4-4952-9C7C-3C68B881FE80', '4620002185442', '   /.   20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E20CE90-BD0F-4143-B749-74A2D5FC1C41', '38692CDF-216C-4089-B0F0-9E8E0F549922', '4620002185480', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79FEF41B-679B-4192-A7AD-10C606B2BFB3', '4964F049-9C37-4ED9-89D9-81847A94AA15', '4620002185565', '  - 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAD09264-2224-44DC-A0C4-B8B0FDBF9E49', '1EA31B74-1609-4F82-B9F4-3EB206B95A60', '4620002185589', '  - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8298388A-EA68-4D9B-9DD5-5357CEA68266', '99D4EC4D-FCBF-4D97-B506-B82423AED116', '4620002185664', '   /    miceclean 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24503855-E84E-4D93-936A-6F105FA3E3D7', 'A05B683A-A8B7-44E3-B3B5-26AAEDE7F820', '4620002185671', '    - / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66ECB5BF-D272-4708-BDAE-D843C256E27F', '480E1DBB-DD16-4991-82E7-F94426268054', '4620002185688', '   / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2526624-C79B-49DE-AF8C-3B00F1C73B77', '4E278E3C-6CE2-4358-87FE-6669A5840958', '4620002185800', '    / /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED36CE2B-DC96-4A07-BF2F-74512A712C4B', '9584708A-DA43-4ACD-92F5-7F7E5B1B9029', '4620002185824', '   120  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22F24646-DB14-4D43-B119-8407BD915D69', '07BCD7D2-1235-45B0-9143-44BE8FD6126B', '4620002185831', '   /    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A3584FB-E091-46F3-A9F3-E1986A2EFFDB', '1730A737-3542-4D50-A2D9-C13D5FA5D4C1', '4620002185855', '   /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50F1B20C-A442-4B5F-9175-1BB25ACEF777', '375DEEC3-FF71-4D89-9DFD-69B3B8928575', '4620002185879', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A03D3B00-D679-4E19-8E7D-1F2CAA900E69', 'E41F7631-7E0C-4B67-A389-625682C5A3DB', '4620002185916', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3027423-60E9-482E-A3C1-5E219470FBCA', 'AE96656B-1489-4013-965E-A8D8513D9F1E', '4620002185947', '   // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('002E6BF8-6519-43D0-98B0-8AC6AAA9A0CB', 'B10BDB83-5155-47DF-9B35-DB3A1E49E2A2', '4620002186029', ' brg+ 3     /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D4E7F77-CE98-48C9-A004-2A251D3ABDEC', '21D52B09-2148-45A1-993D-9B4AD992889D', '4620002186050', '  / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51E349CA-D9BC-4A54-8995-9A59BA651929', 'ADA85892-CCF9-49EA-A9A3-0632FD18DA57', '4620002186234', '      2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4A9CA8B-1E19-433D-8D15-A9B2D9425330', '8D0388D7-8B23-4DAD-B82E-72000C274761', '4620002186265', '  -   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC843F0E-2D08-4980-AB40-AA26240E2EB3', '8E2E0AF3-A4AE-4A37-9175-071822D8D81D', '4620002186395', '   120 +  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E04E2AA8-BBA4-4F94-9C9D-BC2F631BF0B6', '4F4C17A6-7C27-4407-86DA-84C7CDC433AE', '4620002187002', ' - /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71B2FEF0-7F30-4EFB-9720-61FCBEF42DB6', 'E84F00EA-62A3-4A85-B306-CF1C79912C53', '4620002187330', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76356182-A8EF-493C-BD9C-254C32437D6F', 'A366A3B6-C1CD-4F5E-98EA-1D7E423DFA9C', '4620002188054', '    spf50 50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA565C19-1296-43A0-9576-7CD822EE9AA9', '48036A8F-6642-46BD-A880-22AAA64C05D2', '4620002480233', '   . /7-8/ m', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1020F20E-C51F-466F-871E-08317F9837ED', 'F55E9E40-68FA-4557-B10A-209D05568A1C', '4620002620042', '  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('871B57D5-3B0E-48BB-A5EE-AC9BD0F2B591', '5BFBFAEE-508A-4F88-B8A1-D2466FC01EC9', '4620002620059', '-  600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D780481E-FCE0-4286-BE34-C33705F39AD5', 'E02FCF2D-E23C-4FD1-9CC1-2850CF0A59E6', '4620002620820', '  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43A8F3C9-0494-42DF-94F2-22D155792A79', '7427A626-A84A-4EA7-B654-3647C0BDC812', '4620002620837', '  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAD191BF-E5F1-44C1-875D-E5273BE44389', 'D817A990-916A-4852-B9A3-E1B007D871A4', '4620002620981', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4356845F-F13B-4F52-A8DB-EBC0DFC911D0', '9338E4D0-9852-4EC5-A9BE-0D26DAE00E8A', '4620002620998', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCA1B89D-0630-4DFD-A5AD-66735936825E', '98872085-320C-4727-95AC-BBB35AB32287', '4620002621070', ' 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A811C819-7806-4F0E-992C-638FAE8113C8', '1200E482-0932-4BAD-B8A8-09A277E9D0C7', '4620002621094', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20BFB69E-7D6E-4EDE-9C85-11C1F685C6A6', 'B88EA567-5E05-4BFD-8E69-8D50F2D7DAD8', '4620002621100', '     250,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B64F857-B7D8-43AC-AA71-3DCAB78A3915', '605566F8-5571-4192-9833-513005C573B2', '4620002621117', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83C029C9-34DB-46E8-83A9-6AA5D11F40E7', '01EC83ED-A193-4F5E-9838-6DCD0F0887E3', '4620002621124', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52B07C69-5DEE-422A-B70C-663A7FB6E45F', '4415EED3-8470-43B1-8476-FD485C12267A', '4620002621391', '  -/ /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39F59EC4-B7B7-454F-A5F0-876D4C732F8C', '828B6AFC-A8BE-4479-BD4A-0824CBA76273', '4620002621865', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E313EE93-D450-41DE-B290-66DFCA2C7F0B', '53ED9C72-A203-48EB-8158-8DDDF763364E', '4620002622077', '  /./130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A74902C5-CBD6-4493-99EE-7BBC336E1899', 'D6ED39FF-A4D6-47C0-9D2F-76B893D77589', '4620003080012', ' /   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E62E2A0D-4A9D-4587-896A-3E4271F6C578', '68E54EF6-F285-4290-B04B-845474A76397', '4620003080029', ' /  know now 5 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14E24573-D7C3-451F-8BA3-2ECCC6C33885', '166B38D6-AD87-4B16-AB27-0DE61D88B258', '4620003080036', ' /   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B00BFA68-A4B4-412A-B5F8-8CB94CB78B1C', '20FF42D7-F9D5-4137-9905-B6FF532E8265', '4620003080043', ' /   /+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00B169BF-B439-4EF6-BD0F-FA9CCDD70A70', '9EE2CFDA-71B9-4DA7-B57F-00D7DC53A5D2', '4620003080050', ' /   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E00CF9F-DDC6-4992-A240-FC405E8CADFD', '09E4E3D8-0D2B-41CC-B6BD-B203D95E42EA', '4620003080067', '    / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A947E171-07D7-4A62-8DA9-D0B64505780C', '73B92E9B-333C-45C0-9CBD-C73BFC9EA6AC', '4620003081330', '      3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0110B596-484B-4781-983B-B2FF57A5B1FE', '2066B13B-1990-4945-A194-8B8D70B9F137', '4620003081361', '      3//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB7E5172-6B09-4EB3-B384-D26B1A131D20', '920407F7-AD45-4EDF-8B8A-9CD25C0EF7F2', '4620003081378', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73C4C87F-8B99-4C59-8C07-977F28B0342E', 'A66BCF53-DDA6-4626-9750-6DBE4E7E9CA2', '4620003081385', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94E07671-1F1B-48DA-AFB9-60D6506DD3B3', '5DAF999E-88FD-47CA-B65E-45D7D90904AF', '4620003081514', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E26E92E1-2152-47AB-9187-D0D56EC3E389', 'A44EF385-CFF5-4C16-A8F6-BD2D37F6E602', '4620003081538', '   kiddi test   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCC7E27F-666D-477E-8ECF-EF3FE1F0A6F2', 'D9724BD8-2806-4E63-917C-977FA9BBB536', '4620003220012', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4835DE8-84C2-4A81-8E0D-5C0D9E76CA16', '1A00344F-FB69-4B40-81FC-8598FDFB1117', '4620003221910', ' maneki chibi-neko 6-11 62/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('005059F1-2BA5-41C7-8AE6-CBF2F6E79556', '6A49C8A9-D8B7-42E4-AF4D-F292AB43784F', '4620004520012', '   sey life aquamarine  10 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ACDC83C-3050-45F9-9DB9-8E7DD7746AF8', 'DB1AA6AE-2A97-407F-86FC-226F96B068D8', '4620004520029', '   life sey 10 22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BD3C10D-3471-4F9D-8EF7-1F1A66576E33', '66C5F98A-1451-48D9-AF03-C6D300DC3011', '4620004740038', '  0,05% - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FAAB551-C630-4923-B189-32E7F444525D', '5AE58B31-E2B6-40FB-8D72-6CDF881634A2', '4620004740335', ' 12,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5698BF91-79D2-495A-A3DC-E5E78597B5E2', '232BD13F-B38C-44BD-81B5-C560C26AD023', '4620004740380', ' 2 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2A1F987-2760-4945-8E5A-E496F5551EC1', '41E50A1E-5DE1-4EBB-A510-E02ABB2A669A', '4620004740410', '  /      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C78993B-090F-479A-9D3D-86BFF3096D52', 'BB06A4E6-93CA-4671-8117-0EF674A060B1', '4620004740434', ' 0,1% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C053C76D-FBAE-4EF3-9BA4-E0E3E2B27F26', 'E7A451DD-AEA4-4839-8FE9-F716A33C41C9', '4620004950338', '   /  250  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55ABE656-A7C4-4242-A246-5F25425169B6', 'AE46A61C-B290-49F7-896C-776F515CA16B', '4620004951229', ' - / . 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B4BDCA5-50D1-4745-90D1-0B0A29205694', '007C4F0A-799B-4042-B6D1-E88A317DF3C0', '4620004951489', ' /   10 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2FEC6BD-D2EC-4EFD-9F5C-E8B38BF61A21', 'A07A9E2C-23B9-47C2-BD28-EBEF61D9F74C', '4620004951502', ' /   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C399A301-E701-4BFE-AE2F-656244EB3010', 'F52ABEA8-6260-4A95-805F-9B7EC94A69FD', '4620005260030', '  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51D9EDF1-0CDE-4A7C-81EE-D33AAF0A161C', 'CCD80476-C60B-498E-A023-BC8DD837332A', '4620005260061', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF3B5966-4A63-4576-8085-B0238A05A40C', '8FA382B7-D731-40F1-A834-784BDC00B22E', '4620005420038', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DFC7127-56B0-427F-AECB-BF34BE3AA594', 'A90809D9-DD5D-4A9B-9F04-F91A2D2A0868', '4620006110440', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14CCA523-79BE-4F75-9DDB-FC4357BE62CC', 'FE494E9B-76D0-4BC4-AF89-663386258915', '4620006110464', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2127C815-D9D8-4960-9673-D2242F624A05', 'A5173C97-8E7B-4922-900B-0A90DB96884E', '4620006242042', ' / /-327/ - 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF29184A-766D-4AEB-943E-0F412326EBB5', 'CEC0D53B-CC0C-4EE2-8DF7-73F6F554C2A6', '4620006244831', '    . 1, F-300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A85806DD-5D16-4DBC-81F0-D7999D9AEA53', 'A31D6AAB-FD12-4618-A75A-203215B9116B', '4620006245098', '      /F-225/ - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ACD8193-012F-40DA-BB79-3285714D7C48', '91C7AE22-873C-435C-B9E6-C65C0D577B7F', '4620006245456', '    . 1, F-203', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDC59B30-E85E-4C1D-99F4-1ECFADBFD012', 'D8CD7336-2C83-4A18-912D-F0BFB5BFA287', '4620006248402', ' -80  / 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8916B997-07C4-4362-8A43-D8B52F9C3D09', 'B16FBA64-275A-4F95-BED8-19548DD58CE1', '4620006248488', ' -80  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('312B002B-B613-4CCE-A25B-BECF069F8922', 'DD91A925-222C-47B6-8AB0-9F1578633634', '4620006256254', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FEC8506-C1AB-4563-8045-7C045204CB53', '8320927B-7CA4-4765-9759-B71735D0F6B3', '4620006257084', ' /  /f-700/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78DC48F8-ECEC-49D2-BD55-45FDCE27837E', '9E838EC6-93DA-4AEA-9017-2D21FC43D144', '4620006257718', '  - /-502/4/ - 6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BC6C2DE-DB1E-4C2F-817A-493FDD1D09EC', 'E058FAAC-3DDB-451F-8A12-B207CFAF8F84', '4620006261968', '    /F-520/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3763B25B-844F-44A4-93A6-C063077B5EC8', 'C0A2FB58-E7AE-4D1E-9BEC-4F09B189CEE2', '4620006272605', ' / . 4, f-414', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A4145AC-C65A-49C5-BC79-7F6C00C0381D', 'DAAB0344-A924-456C-ACF5-E40489693586', '4620006273008', '    /F-320/ - 12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0E04698-3471-46D6-AEF8-18A0E86FAF31', '3838E2CF-1B07-4C96-BD20-A9D439A3A269', '4620006273572', '  - /-501/4/ - 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB344BD9-F737-4609-8C86-F782DFABD0C4', '4885D43C-E0FB-43C4-9F37-B134AD548E78', '4620006273602', '  - /-501/6/ 4  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94E4EADE-5844-4286-A3C4-5B3655E628AC', '8709CE36-284C-4CAA-A8AE-B2B2F23E756E', '4620006274449', '    . 0, ., F-301', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D6FB862-56F9-4931-A343-463D6E57DE4D', '90963444-4E9B-4F1A-9946-5719A1D443AC', '4620006275095', '    /-514/ - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59398CB8-108A-4C53-8995-2EC0C54897DB', 'F4DC71B4-1E2C-4C95-8D60-6B7880459044', '4620006278355', '    . 1, -800, .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A80912F-B324-4719-9FA4-B440875C4E78', 'DEA66018-0683-41DE-9001-8A50A689CD33', '4620006500050', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5C63567-0FFA-428D-B773-C004EB1C004C', 'FDEB511C-43F6-4EBE-A2D8-D6B4E791DF14', '4620006500333', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00A1273E-17EE-4342-AD04-CFA09F94221C', 'D2903262-FA62-4258-94C4-B766A720D380', '4620006500753', '  2,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFE48ABB-0DA3-47D7-BE52-CE75F26379AC', '8AEE9D01-4204-4D50-B3DE-67E7B0F335FF', '4620006501156', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E011BD29-7B11-4ED6-A47F-155DB6464F36', 'FA179778-5BA9-4A39-8FA6-EEF50330FC40', '4620006501163', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51027037-5BEB-4A95-9578-D16AABBAC696', 'E9E2CDED-9180-4B7C-8F98-935DD4983ECA', '4620006501170', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E394F24E-F61A-46AA-9483-9C00723496BE', '42B55D6F-9231-4F26-8008-729872EC603B', '4620006501231', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F857D6D-44D2-4040-B4AC-FD362BE1AD76', '5CFE1350-A624-4FA4-B623-C2E0926C0093', '4620006501248', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCAA3A43-BCAB-4F3F-8F06-C39968729059', 'D6BE81E5-F97B-442F-9041-53BE57610A0F', '4620006501255', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D3D3D81-24DD-4508-805E-26F77C4CADFF', '0E98B43D-F4D3-4462-990F-BAB406A2344A', '4620006501491', '  +   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EA4C0B3-FE11-478B-A005-9C38FF702600', 'F94917DF-8BD7-43E3-B76E-9FEBB31EA7E8', '4620006501705', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('482F64B0-0177-4BB4-AB14-3B5F148E8882', 'F3BC84E9-6A8F-4916-9DFF-7D743587985E', '4620006501743', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC21B2D1-9982-425E-B193-C8CD6F42C3A1', '81A805C1-5DCE-4668-AB09-A7CDF4D8F0CF', '4620006501750', '  3% 100 (.-)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01EF4B54-4FB6-4786-BF58-142343F32641', 'DAF49BFA-39EB-4264-B7AF-C92523D4881B', '4620006501798', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01622708-625D-48A5-99FB-D133BEFC8049', '5BD67432-F3C6-4FB5-939E-310F99402B8C', '4620006945615', '    // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15984C83-F9CD-46F4-BCE3-F8A8CF5E42C7', 'B7FDFF52-4615-46AE-A376-CB98A2C3C2F8', '4620006945950', '          6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D1599AF-C5E1-48F1-AFAF-90339A14F5C7', 'BF4DA1FF-047E-4B9F-A9B3-934559FF7F79', '4620006945974', '   //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DACFB471-4B21-4A77-940D-15EEF0C9E8C8', '7D79C326-FAA5-4A06-8E22-008B01BA1834', '4690624008542', '     / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3555245E-B7B6-4B31-8F98-7F80CD6E3CCE', 'B6C3CD28-6568-4E39-8BF4-AF80EDC4E856', '4620006945981', '    . 1,97,2   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78CEF53E-D695-4033-8164-97BA30F2CBC9', '990BCF67-F9BA-43E6-9078-75A10FE02D5F', '4620006946155', '--       . .  3-  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('066EE27C-01F7-4A22-A793-97A9C13AC046', '49A9A4EB-0889-444D-9D49-5D4B29F9EE7F', '4620006946162', ' --       .  3-   2 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD3C3738-30C5-4FB5-9B7A-B5209CD737EE', 'C8F4567C-D818-42DC-9136-89CAD6847187', '4620008620039', '*  0,05% 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4615606-7D71-41CB-8B53-94063E0677AB', '01730BB6-65F3-4CD6-8668-36D13B7446AB', '4620008620374', '  .- 0,05% 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF6B854C-3559-4591-BB28-F3AFE2967249', 'FAA0DC91-19E0-4496-A659-FA28FD9FCBA8', '4620008620725', '   / - /. . 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('416034D8-C8F2-41E7-8BBF-5853147B0147', '91C608EB-E3EE-4310-9655-D2C333C64089', '4620008620831', '   20 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07607703-B7BA-4B0F-8D79-3B02A12703D4', 'D0A97B75-2757-427D-B26F-B133D08C37C9', '4620008621753', '  0,05% 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06207BCF-C6A3-4EBB-9966-9CD54428118B', 'A43DDE67-9690-4953-B54E-D2D9A2ECE1A5', '4620008622910', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AD655A5-9546-41DC-8C60-A0B96290751F', '9015A993-23EB-4FD8-BA3B-29D1A44657C6', '4620008622927', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CB8BCF0-F127-44B8-BC80-1A1D11CD5562', 'EBE9AB82-60B0-4ADE-A662-22FF64B482F9', '4620008623597', '  12,5 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A79D7BF-6292-47EC-A217-DCB3661C19F1', 'D0BE3EB4-B3A1-440F-8DC1-AE7D7C31B3CE', '4620008623726', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57685A32-18CC-4400-93F7-1D2CCC0D8DB7', '4DB0D203-B52E-4CC6-9F5F-CB1029F6BF73', '4620008623856', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48B9C10A-368B-40ED-9654-14C28663EE46', 'D9954802-3229-4858-BEF1-9C90A195200E', '4620008623863', ' 5  /-  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E8FB3F0-CC24-4E39-82BC-62D0319D1192', '4D3DD68E-0C48-4236-8455-F3297FB8B85D', '4620008623955', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36C5BCA9-2308-4E66-8A55-E43E84100D3C', '88FC8ED4-C700-4D5C-81B5-50CDA176A577', '4620010796494', ' velvet / 51/     / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CE04340-C45E-4929-9CF3-70EA0EA8FEBC', '855FF414-4193-4E00-81FB-B556471EE5A6', '4620011580924', ' 10  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2F71F0E-6168-4A60-AF6A-ED9A1F664C3B', 'A79F135D-87D4-4461-9AD7-B0B3F90824D6', '4620011580955', ' 20  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7575EA01-CEC1-4B23-B461-94731C5CDC4A', '8A0D71E1-A3E9-4D68-AC77-8F741300F5D9', '4620011581136', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E177C392-A823-4DBB-B74B-BED165BA008D', 'D2E2C143-8E09-4F99-B2AC-42A1AA767FC1', '4620011581310', '  /  20', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EDCEDC9-56C8-4D2B-A6C1-1379BA0A1DBC', 'D1A72F09-11B5-4C1D-B925-DD114A2D93ED', '4620011581419', ' 50 //.  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F699ACA8-E81F-463E-BAB1-E493AF176AAF', 'F930A139-3AC5-40CB-A4D3-D6535C68721E', '4620011581426', ' 0,1  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6E54E7B-7ACF-48CE-8037-330B5EAA7A82', 'E60A57F1-C1E2-4DBD-9190-896CDA5500C9', '4620011581433', ' 0,4  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37B9292D-A253-4580-A6E0-2208BBD63B0E', 'CEDB6EDE-2DA9-4CA6-AD69-E20154396B26', '4620011582645', ' // 500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7462F8ED-4121-440D-BEC0-A280FF662A0B', 'F5DBA9E4-DF0E-4BBB-B288-9D11B97F4D13', '4620011582652', '  1000 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B06FBD54-4BEA-4DFC-978B-AE304B33BCAC', '7429C0D9-F888-45A0-A0BB-8DD235237C4E', '4620011582867', '- 0,2/5 /      16,74 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7485A4FD-0512-46B1-A860-0A501BCAB5BF', 'E8DD9096-8553-4CCF-91FA-8F2BDCA7922F', '4620011582928', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57D79901-BB9D-4EC4-9B38-8776B0CCA68E', '6840CFB5-075D-4225-B1E6-E16BA95AA6AB', '4620011582935', ' 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DF5A09D-31AA-4A9F-9962-645B82B186F2', '3C71C477-252C-47F2-997A-EB4A07696718', '4620011583123', ' 400  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C705F9D5-B7A5-435D-B57C-1E3E54D1F30D', 'EEF11B25-C880-4606-8206-BA278CF49F16', '4620011583154', ' 200   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0B0EA1F-EE2F-4262-86E3-D905B96CF9D2', '2CBE8E7E-EAF2-4AFC-A09D-B35CEABDC6CA', '4620011583451', ' 400  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F21A4853-BE35-427C-BAD9-56FBA2CFE6F0', '79AEF1BA-6204-4609-BB09-01484E96C5A1', '4620013730013', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82D60A0D-10C3-491B-80B1-C176C12F0F4D', '3FAE734A-61E8-4FAE-BFCD-25AED976A50C', '4620013730037', ' 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BE20D70-6C79-4188-BF9E-C313AA01A6EA', '7FF1ABAC-1D82-4B81-A96C-B69BCAE7625D', '4620013730051', '  1000  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22B03A9B-D7FB-4001-9B4C-0FDD9B4A8EB9', '252DCEEB-9CCD-4B5E-B465-642D65EC3B11', '4620016240014', '  - / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFA65CD5-B358-4BF3-A2F0-DBC78D04BCC7', 'F06E9BBE-2719-4F17-9953-E849D7EAE0E3', '4620016240021', '  -500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42D01771-5F86-4636-B5D3-5583970AAF63', 'E3C857A9-5991-4DF4-9ACF-973C128C0929', '4620016240038', '   /     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D3200EB-D257-4C8A-8367-627223D81603', 'BC4BC067-EBBC-4681-A8D8-06002C4D5D69', '4620016240045', '  -  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BA8EFF8-9343-4F67-B1B3-91A2216C00E9', 'C74C4942-E20B-4E63-ABB6-408119FC45EB', '4620016240052', '   / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C39C541F-D6DA-4058-AE18-49384D4FC83E', '5C81AE54-0CBB-4084-BA13-2F28DA054230', '4620016240069', '   //  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('047C10AC-5F74-4124-A425-91906A0652CE', 'B7C80863-5519-40C0-B6FE-A855A2FA1657', '4620016240076', '   /  .  .   . 1 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA195300-6416-497F-96B2-8AA85A6D0FB4', '16E366F7-63D7-43BA-8594-761C6D2B1B1D', '4620016240090', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45C3BC92-5906-40AD-B35F-F18684F9A199', 'A6117531-E1C2-4F48-8B3D-B9EED3FC44B1', '4620016240113', '   / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BCB3D73-AEBE-48C0-B5D6-FD4F9F8DF22D', '14AF2A43-665F-4801-A28D-D716FAFDB4F5', '4620016240120', '  -     1000 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2DA35FA-5CFF-4BAF-8397-3ADEBA52552F', '719FDDF6-98F7-4BBB-A9F4-E51F459D4B7A', '4620016240168', '  /       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E6B0EA0-56B8-4892-8634-C52C29AC05AD', 'B1E032D9-F471-4DA3-AB1D-6654A1CEEA73', '4620016240199', '   /       17 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9105A5C-9648-488B-AD18-70544CD4E769', '9DB85403-2E1F-4181-99E1-8B800FC64007', '4620016240229', '  /  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BE873EF-A5CF-4671-8270-28F1D0F1D5FC', 'EEBFD0E3-E6C2-44D2-9E64-41D9F6960500', '4620016240243', '     / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11961A05-B39A-475A-9555-468417537491', '47B2F40B-BFB5-4E6A-B397-BE37DB241161', '4620016240298', '   /     /    500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('279272AE-8778-4F85-A2BD-F1ECCD3C0CEC', '5CC45849-A0AC-47C7-998B-E24FE14DF18C', '4620016300015', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA442A8D-3048-4997-8730-0C9B884D9720', 'AD7E7B9E-B817-484F-A7E4-7EDBFDC1F415', '4620016300022', '      64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71185F33-E593-4754-A512-20A4C8550FC1', 'B8CF03D7-1B61-4795-B32C-602983CC76D6', '4620016300039', '      15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71F9C349-0B09-4B71-BFB1-B0AFACEE3021', 'AEE56598-0A2F-425E-9AD3-3CD633FDF8A2', '4620016300169', '   /    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FD466B0-BD8C-4B0F-8127-D70BF1DB708C', 'D26FF3FC-AD34-49C6-8376-10C579633039', '4620016300237', '     64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B46EB4A-F301-4C25-96DC-D01DE521F66F', 'EFFCC409-96B0-4F62-8072-3A875EAB5931', '4620016300244', '   smart /  70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FD7D0A6-8054-4C6D-A883-CBB7A344F86A', 'FFB29F98-1437-4578-AEC0-C9B9FFDBA8D5', '4620016300251', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E8C2B2D-EA63-416E-93C8-B42DA255B9D0', '22D53F8A-8EA3-43F4-89F6-193F852B53F9', '4620016300268', '  /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C928D40D-42CC-4818-8D65-055348AAB467', '3C78ED1B-ABF8-43D9-AA39-07424D6AABD9', '4620016300282', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52A7077F-3CF1-4026-A40E-596FA51845FA', '117D8538-164E-4275-B3EC-1642BE0DCFFD', '4620016300381', '   peppa pig 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D82D2A0-4972-43D4-B24A-9ADD4CB89FDC', 'E4B29506-C80A-4B52-AEFB-04D1E6B1E5B9', '4620016301067', '    mon rulon 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A169ED92-320E-404B-8424-E988F2F1D2FD', '089A9EE0-0BB7-4078-AFE8-49BA05ED2037', '4620016302835', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0343137E-8646-412A-A6E1-F5F378F62673', '85043F28-FFE6-4590-8931-6D76C7B49EDE', '4620016302859', ' angry birds movie   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('975D6CD4-7F81-4D28-9ECE-98DA463B02E7', 'F175ECF6-14F8-4ECD-BE2F-898CA74B2D97', '4620016303504', '   +0 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CED2C9B9-578A-4C9F-AA21-FFD1671608C8', '21897850-E4E4-438F-B270-500AC3F5624A', '4620016303511', '    64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29ED0F67-CCBF-4F3A-9106-1C84DE28DAF4', '8D20F9C7-4A64-4565-86CB-D880D9ECA795', '4620016303696', '  /  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A87A0E09-474D-4B0C-BE00-EE1ACDFAA940', '4EC2C3CF-4317-4A77-B471-7DAEA855C20B', '4620016304815', '   60100 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61E9C965-AF08-45DB-945A-127936FA72ED', '3E83EFC0-64F1-418C-AA5E-1FEF0BF49EEF', '4620016304969', '  6060', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22566EBF-0B36-4B66-8BE1-52653E880BB8', 'A36A683D-9CDE-4A39-B749-008B31864FD3', '4620016306116', '   60100 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACD406F7-63F5-455F-A85B-0F7D765B48F8', '4EC2C3CF-4317-4A77-B471-7DAEA855C20B', '4620016306130', '   60100 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26165B37-6AC2-4B9C-8EDD-9A6B1E2F3513', '23BF8366-CA81-4DD1-A5F5-D46D24207D93', '4620017180036', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3487AA78-DB6C-493D-A0EE-CA717B4C2DB5', 'F90632FB-A4CF-4EA9-9106-B456235F3409', '4620017180104', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1C6B238-7F80-4412-BA22-9C4EEF1AD4A7', 'F47E8F3C-117C-41C9-A4D4-A653CF68E83A', '4620017365099', ' 1614  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61D18AED-953C-49F4-8ACF-0874ADB01E57', '61044564-369F-4A3E-B6DA-65E66758E152', '4620017365235', ' 710   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6965EFB0-26F0-4ECA-948C-076179B5358C', '099DE56B-E303-4DC7-9CCE-61772910C76F', '4620017365280', ' 510  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3143FC24-E4BD-40D2-8868-7CB5778F6DE5', 'F03D0789-4783-4AA9-A4E5-46B4BFB06FDA', '4620017367529', '  1614  2-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('261E0D1C-1A6E-47B1-89A5-C026E87DEE1A', 'AC14FA8F-FEDC-440D-A2D3-156CE8ECDF10', '4620017368069', 'New life    510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E48543F1-5E38-4D68-952A-CB6438B94D70', 'BED51AF2-F715-4C55-AC1A-D8C81D4A2061', '4620017368175', ' 5 10 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86D2B21E-56E7-45CD-B7CE-1E21FAE3CAA6', 'CB06A0F7-EC68-49D2-BA4B-29F8AA329F7A', '4620017368274', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69B3CC43-56D2-4F35-B798-F7773193E580', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4620017368298', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8CE435E-578B-4F0F-B715-628ECDDBA78F', '73900934-E6E7-4283-9C47-AE05D21ED400', '4620017368311', ' 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BC6920A-E77E-4267-94F7-40E8447DE70A', 'A89D2AC2-8BDA-4F0A-8051-3431B97C0C34', '4620017860730', '   .. /2  0,9% 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1A03FC0-FC6C-441E-93B0-6C350A19495C', '8E2F6F13-76B9-4579-8E73-6F8B776F5424', '4620018140039', '   / 2 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0ECE732-C62F-4F35-8AF1-8311F23794D7', 'C9FD621A-0A8A-4BF9-B655-87163A8F3A38', '4620018140046', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0963754E-1B2D-44EB-A271-9342BB56E7CB', '9DA60AA9-05F3-41D4-898F-FBDD559DD4A2', '4620018140060', ' 714 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB6EF1DB-3C5F-4810-BD7E-225D843FF3D3', 'F1B51764-529A-4E37-AAF2-8FDEF49B374C', '4620018140411', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B24F3891-4933-486A-A576-F32E50CFD423', '510DFD57-FCFB-4196-834D-FA14AE918702', '4620018140732', ' 510 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FF722DD-19A1-4984-B909-F43F32042D49', '87FB6B64-5854-4450-AB8F-9E5695442EFE', '4620018875160', '   /  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B4F8228-392B-4A10-95BC-05AFFEFEE88D', '4E5098CB-AE35-41CC-A5BE-230B50C3DEDA', '4620020890014', 'Rilana  home  /        300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6552365C-7C59-42E7-BE1C-F6847D8C81A9', 'F7944059-F05B-4F9F-B72B-F4E10AB2E925', '4620020890038', 'Rilana  home  /       300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('870A2B20-3995-4D96-AE94-E7FB2F4BA793', 'ADAFFD93-4643-424D-B65C-FC86062D9BF6', '4620020891417', '  /aqa baby/  /      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4304E60-5E5C-404D-A34A-E015A12BD2F1', 'D198DA87-1275-46C8-AAC9-DD2828231D78', '4620032230013', ' 0,1   /  9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E90E748E-D54D-4790-91A5-B40666973DC5', 'F3F805DF-C766-424C-A844-B3151E92C8C0', '4620750540081', '    25   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA72E3DC-4644-4340-AAC2-1CBE7577A5B3', '110AF732-3AB6-4372-8358-C6DA23C9E06B', '4620750540135', '  25   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E5814F1-BAED-470B-A603-E6A0B079D248', 'A8821A48-47D2-403D-8000-50576AA7F78B', '4620750540173', '  2,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B009DFF2-5344-4CFC-AA68-C87D21ED7B52', 'FA179778-5BA9-4A39-8FA6-EEF50330FC40', '4620750540265', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('698E5BD9-8BC8-40CA-826A-6448482C0B51', '0B5F24A4-F2AF-4490-8251-1E8C730BF6EE', '4620750540272', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DDB84AB-ED2A-4AB1-8A6A-4722E376425A', '8741F812-52B8-462D-A011-F3E0CFB2B5D9', '4620750540326', '  25   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DBC966A-262A-492B-BF61-0B05AF951049', 'A9A1334A-DBA0-4CBF-869E-8188488BB77B', '4620750540333', '  //   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B61B15D-1780-48F5-9DB4-18040B5662CF', '0555F6A3-F4BB-4A81-9929-85DCE687491E', '4620750540340', '  25    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('611C6565-9683-461E-98C7-70AD9611281C', '7C49A6FD-A943-4903-BB4B-17AECFF2A602', '4620750540357', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A5425E6-05B0-4090-8599-CFBC3DCCA925', '21A287D8-FFC0-4D9B-898D-68C6BF933F52', '4620751419782', 'Babyline  /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F949ED89-DC9F-4678-8823-2A1A22E932CB', '989968D8-5B01-47DA-8223-007240781108', '4620754640022', '  . 410', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FDE7732-5B2E-4FA6-9789-7F3C64BB0E1F', '9F5BA276-76A2-44AF-8D67-E016298B7D0A', '4620754640053', '    410', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95E90C2E-DEEF-46B4-A0DE-03E2A7933A41', '8E204C8D-CAB2-4403-9199-59AE0AD17911', '4620755670141', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BC048E4-E2DB-407E-8541-3E634CFDB3ED', 'FF989D66-B24C-498F-91D0-0B78425A5B98', '4620755670158', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEDC7DFB-313A-465D-BE20-394171E1C36E', '5358A6DA-A7A4-40F9-88B5-8EEAF1487B41', '4620759220113', '-1 / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8446F566-E088-4399-985E-9638990AA724', 'E0D65B26-81DB-42DE-A15C-2765E588891F', '4620759290017', '   5% 250 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1A863E4-45B3-4781-AADB-495FF7B7D420', '7B9A13B9-6ECC-4617-AD3D-E7D76F3F9714', '4620759290024', '  3% - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('071EF619-749F-4659-A88A-74A68FF9BECD', '83269A02-FEC2-4358-B27C-97DB6D3ACC0F', '4620759290086', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('745C88C2-0474-4B0E-A568-03136AF5F1EC', '748D34A7-62EA-4272-9F8E-3E4FD73D4A67', '4620759290109', ' - / . / 2 / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA4B0A9B-1B29-4446-9281-C2ECE5FE4FCA', '3EEABBA2-DF3F-4BEA-97BB-444662EBB7DA', '4620759290116', ' - /   / . /  1 / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84B531F2-DD78-4759-AFF4-D1FAC2C4CFA7', '590BAA85-E7F8-410A-B0E3-67EE6045A1F3', '4620759290130', '     35   2 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2023E16D-95D0-4AB9-A875-9B0B9AA30905', 'D4B6A2EB-7D28-4B81-91E2-DEC438F5A40A', '4620759290147', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CEC0907-D039-462F-8078-84536CE999F9', 'BDA34CD5-DFE8-4027-96B0-6642A419EB38', '4620759290154', '  /- / 3% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EA040B8-C9C0-4198-BD76-E3B8C48C1741', '0B216C82-6510-4313-8183-67B6B8116C7D', '4620759290161', '   3% 450 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A00268A6-1635-435E-A66B-B0B2DB6948E3', '9FB2D09D-7959-4066-AD6E-C80C89B2A021', '4620759290178', '   5% 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65128E30-B427-4106-95AD-4F6825E6BFB4', '50FB224D-1005-4A0C-AA18-4FC4F4FE412D', '4620759290185', '  5% - 450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D92A602E-DBB3-4AA0-8DC8-1775B31CE49F', '47282F71-A18C-4615-ACD2-6AA8748F89D8', '4620759290192', ' 5% 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31ED4251-7364-4378-AF29-DD13F170E773', '0079DDD5-A91A-4082-80D3-CEBC5B778DDB', '4620759290208', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B53FBB02-E75A-4E20-866C-C9FB34A31EE0', '753474AB-F2DD-4F88-83AC-15E08D456383', '4620759290239', '  5% - 100 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EA66D6E-CDFD-4C13-83FB-5D5709EC5396', 'EA19FE4E-68EE-4294-8551-471CD931B6AA', '4620759290307', '  -  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F4AF5EA-AE6C-4A9B-B783-9BC4A6F1379D', '92758231-31B8-4DFB-85AB-1A431C498E10', '4620760950528', '       12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B147768-44A3-4231-BE44-3EB1C98001EA', 'C2A9DCFC-92E3-4BD4-A1EA-C0C1B8FCB6BF', '4620760950627', '     16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2EDCD36-48D3-4150-9AE4-78E06E61AB38', 'E3CDDEBD-0855-4281-8D82-98549ED459B5', '4620760950924', '     16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51679E43-280D-4CF3-BB3B-61CEC9FD3CDD', '0EBEF79F-7F96-4B76-90D2-102AC3827EF1', '4620760950962', '       16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58D24E6A-F8A0-4256-ACDC-F14903DC3467', '53DA0D09-C73C-417C-B335-CA8E998E0DCC', '4620760951822', '   /    9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F27F136A-D850-40E9-B329-43D18EC23E37', 'B0AF4FA9-8EAD-4482-AB88-7A24612C01F5', '4620760951846', '   /   9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07FC8DCA-F037-41BC-9723-90D2711BDB52', 'FA7CFA1E-D82F-4062-9CFD-08A1D51351DB', '4620764310144', '  3-   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F565B0E-1489-42A4-97E7-9EDE65D165AA', 'C39394E0-C76C-422F-9FF5-1C23F59ED414', '4620764310199', '    .  400/2000 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('303D9E89-842B-478F-BD29-3CEFE51CD312', '2509616E-9492-411F-A466-A1549D75CB63', '4620764310205', '  3-    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F41F103-E27B-46AC-A802-DF0D1DA9FED4', 'E81069A8-4B81-4FD2-8F7B-FB52AF605CFD', '4620764310267', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F222277-D50C-499D-9635-C3DB7205561A', '85070797-5AA5-4006-82D2-66E487BE1622', '4620764310441', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51C30B2F-726D-485A-B1FD-6773C86D3C82', '2F248983-1905-4054-98EC-7FFB96BFF59A', '4620764310458', ' -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('224AD5DF-06E9-4DB8-AD36-AEC307632DF3', '4B53FA50-F57D-4F51-A77E-A1CE7E78DA08', '4620764310601', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34DED2D0-D586-46F7-9CD6-328BC980C5D5', '469C80E1-7691-4E91-B90B-3749C18E4592', '4620764310625', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D4461F1-007B-41A8-97FF-794036073CA6', '46254CCB-98C4-46CC-88DA-1A98C0C541A0', '4620764310632', '   //  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0706BDF9-38C2-449F-A885-18D11AF8E611', '2076ABEF-CACE-4093-9595-388E4F25213A', '4620764310724', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27511CD6-ECCC-47A8-A75E-ED90FC0E9598', '0417E9D6-B1C6-4D10-97A6-D87EB31B2E48', '4620764310731', ' tore  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED7A73DB-884D-41CB-BFE9-B0AB6C997CEE', '93C74227-9D36-4C44-B90F-E2C5BFFA4163', '4620764310748', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAF75696-4165-471D-962C-0A18CA10056A', '4F8AD411-B591-4690-A3C9-F6030B949FB4', '4620764310755', ' tore  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40BC6701-2031-4AB0-9215-7A1598F2EC34', '87398331-7ED9-4FD8-A2CA-8B8E8DB36178', '4620764310762', ' tore    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09AC86C5-926D-4FF0-84A6-FA01F76013C1', 'B2F276B3-7477-43BA-8F2A-222DE209C6DA', '4620764310779', ' tore  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('282E446F-C710-4B4A-8F84-34DAC347BABF', '9741738C-079D-4EF5-88B6-7366BF481693', '4620764310786', ' tore   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1777369E-42D9-4071-8779-6D2F948597D0', 'F7B174E4-21F2-47AA-9128-F47AB6A1D4F6', '4620764310793', ' tore   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38FD4181-3D80-44CC-AA77-4884B4A602A6', '0CC2F31A-538E-495E-834C-69BA0741DE30', '4620764310809', ' tore  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C61FD45-FF5A-4830-83F5-4D2D3A798469', 'C4F820E0-6179-4C71-98A5-F3C453F9AFC7', '4620764310816', ' tore  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D7B78D8-7F2F-4551-8D29-FDB935CC45AE', 'DF13F689-5974-420F-8F50-1D697BD65CDF', '4620764310823', ' tore  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC8841C5-400E-42C7-9EDA-20DE288B4647', '60A8C0F5-62FE-4F92-A6B6-9E031497F627', '4620764310830', ' tore    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02556694-8BC4-4C9C-A145-7399DE8156C9', '4424ED1A-E1CE-4E43-A773-08FC3195F77D', '4620764310847', ' an 310 l sv    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2981E4B-4316-49D2-B159-E20549FB76CD', '01B14482-262C-4EE3-822C-7CD6C5ED5C95', '4620764310854', ' tore   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58F68868-CB2F-44A4-B6F2-B924C69871AF', 'A874109D-7086-4129-ABD7-74098C98FB00', '4620764310861', ' tore   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('918B487D-C27F-4205-9977-C20BF55D708E', 'ED17E481-958E-42C2-BD97-CE243D3C8472', '4620764311059', '     3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8A21116-7903-4240-889F-48170E5211FB', '0A42EF1C-B3F7-4775-8BCB-E973DD69B29F', '4620764311073', '  3 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2708E8D5-A390-4478-B0DC-ACE44A3313C6', '795C7B4A-91A2-44AC-A3E4-3A1D595FF85C', '4620764311240', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25302D44-6B98-4906-832B-139E520139BB', '7CA0BFB1-421F-4389-AC4B-70CB25326B3A', '4620764311332', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6C0D7F9-8DDC-4AEF-B1E9-F61275E628CF', '46094AEC-C281-48A9-999C-12A780468E5F', '4620764311349', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F1D01B5-0ADC-4EA5-BAC8-AAFE90ADABC6', 'FD66F9F8-8EC4-4004-B9D9-6A2AFE1BEED5', '4620764311356', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E0445EA-598B-42B9-9B81-7E2893865047', '9CAA3B81-DEC4-46BB-AE51-0419DC15D4D5', '4620764311585', ' hasico   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C066110-1C08-4D5B-9B0A-3DF5C43C3C7D', 'A9808410-95C4-4CDD-8EEB-BAE47C10E5E0', '4620764380154', '  /   1010 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80555E9D-D1E4-4822-A91D-52B97AF8020C', 'C8C1EE56-DA14-4F23-9E75-3E097B98D38F', '4620764700501', ' - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F717FDC-8E90-4E51-B662-6F2F88CFE7D3', 'DE053CC7-C07C-40E0-A5E8-5572EF79592E', '4620768931079', '    1025', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('483034F5-FEB6-4F0A-924F-0C3235D72FD3', 'FC511222-BD29-4DF9-B136-C029B34EC060', '4620768931826', '        20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01E57081-A97D-48CE-A493-DFF3355C177B', '2A526187-377A-4740-969D-56E8D8ABA15A', '4620768931840', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10E6C944-EC79-416A-99CD-DF02006719BE', 'D1797A37-C0FF-42C2-9AAB-DF76D11CDEE9', '4620768931888', '     / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB35DABA-D329-47A6-AC93-B447E80E1B74', '7B2EA73E-B52A-48B6-AAF8-60C0255450CC', '4623720770433', ' /.  125 (109)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2429026E-C421-4762-9C91-496A3E202746', '44A6415D-4239-4898-BCE8-8E0090C3B5B6', '4623720770464', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1A7457C-488A-4E80-8515-C580FCAC19FE', 'C888D884-9492-4406-BF20-29DC330FB67B', '4623720803285', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D64F5DCC-CB05-4B18-9CEC-5BF7BF08C19A', 'F37CBED9-60F7-43BB-AD45-0C2525BA270E', '4623720803308', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('679448A6-85AE-47DB-B0E6-0E514574A157', 'BD2BCD7F-8D3E-4F9C-AE4C-292ED6659D58', '4623720803315', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41C332D1-7B85-4955-BAEE-9DBB7AE95C1E', 'F7AF94A2-4B2E-47D5-A445-5A28CD4F6B32', '4623720904791', '   /.+./', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04EB0B83-F6CA-4301-9FCB-53A1E7745B9A', '5DB1F437-22DB-4F7F-AAB7-E4ABFE2D4131', '4623720904821', '     002', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FED4F50D-B387-4BD5-A5AB-321574D7B809', '7D4292F5-3599-4590-AF97-E2A12C85A8D4', '4623721006289', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E590BAC-4C20-4577-AFAA-85723A8459A0', '55B2CF22-8E8D-4FD2-B377-01790426C11B', '4623721115301', '   q10 0,35  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C37C2B6-486B-4917-A1FF-1273149D022F', '5371D355-3684-40A6-A86F-B5B8D9062BE3', '4623721427336', '        . ., . , 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74AB71E7-2855-4518-8360-AEDA87C646CB', 'CBC2784D-7B9A-457E-AFB8-4923D50FF640', '4623721427350', '  .. .  125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C61BC6CD-4BF1-4951-B949-1D56B5F1D3BB', '785E87DA-5272-4BC6-A628-370952553015', '4623721427374', ' /.  60 604', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0D5AEE0-FC75-404C-8E04-8AF09ADF77AD', 'BE3DF989-BA5B-44EE-A336-B9C8C185FC8B', '4623721427404', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B085E05E-A5C7-4699-A6E3-A042A91CFE5B', '7E09C918-DFCA-4E4F-8F16-2309A141CFED', '4623721566561', ' - 330 1121', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('479B38A2-0083-4BEE-BEF1-96B0C8510B72', '1186413E-1455-4610-8E1D-6228FAEF5C4B', '4626016681529', '   . .  p.S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28D6110B-57AE-424B-B3B4-A475F07182F5', '7B5B1629-2798-441A-83E7-0020EF0DFE17', '4626016681536', ' high risk  -  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3B3DE6B-6B97-478E-8DAB-C00EA78184F6', '0A68208B-86C5-4605-85C1-096015F688D5', '4626016681543', ' / .  .l high risk 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEF4C070-DC2E-474A-AA38-95A6CCDDFF5F', '7FA59CC4-550A-4668-AD68-137E9A791B29', '4626016682724', '   / -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47C98EC0-208C-499D-9152-922E8CA533B3', 'BC88236F-866A-4DDA-8308-459F35274524', '4626016683981', ' an 310 m sv    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0182951D-4604-4C85-9687-5EFB23DE07CA', 'BAC0E898-1E65-4AD4-A3E5-4313436BF618', '4627074810050', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18942D17-9CF2-4F68-AC5C-640D7EA844CD', '0AC32712-EB09-4105-A2D3-6A7520D01D64', '4627074840019', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4298DDD-9EB8-4624-AB3F-8359FA53902B', '6636DA33-5941-40DE-AB41-14CC75192F9F', '4627074840071', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3713AA7-894F-41E8-868F-6069F019E346', '94D1B18C-0C5B-41D2-A82C-554BD0DDAF7C', '4627074840088', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D13E341-2830-4779-8E7A-C3AB50D724A9', '5150DA93-47B5-4607-8726-F9ACA33BDA38', '4627074840118', '  // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10B5AAF9-840E-4FD2-A2F0-8DA2A412EA8F', '9FB5C094-B428-4CE0-AC95-88A2CAB17588', '4627074840125', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('587BF2C7-AA64-4AFE-B8DC-FDD043D6EC7B', '64760449-BB8D-4364-BBB5-45BB45563558', '4627074840163', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F06F43D6-DD6F-4193-817C-2090E3978320', 'E1B97B61-5C54-41A0-B594-BFFE4408EB3C', '4627074840170', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66DDD00C-33CC-4E34-937A-0EAAAC365C2B', 'F9471987-916E-4378-87C0-C1F119D6EB39', '4627074840187', '-   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5ACC7CD-FE46-4F88-A5AE-7C151F79C7E1', '7D1D4978-1EB8-4847-94BE-E681D2BCF7B6', '4627074840200', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AE6CF22-7C1F-4320-B0BE-37ADA380286A', '2CFB7885-DCC8-4126-8CF1-3C5669E02374', '4627074840231', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0697CD60-C99A-494E-9156-20F3492C40B9', '32F17874-BF58-4D7D-B651-5923812D196F', '4627074840255', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78C5F486-12AE-43DE-AA9C-1B6C41BA620E', 'AB8D4F61-0FA3-4F43-B728-F07534341F5C', '4627074840392', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('270540AC-46C8-4158-8B30-8B2409AFB1FC', 'B8136726-DD39-479F-AD0A-AC60C8B2BEFC', '4627074840477', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F0BF98C-9922-4CEC-B780-C177A2AE130C', 'CF2E2CC0-2E70-441D-9847-D37E425C3784', '4627074840545', '  // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C1E909F-C20D-421A-B624-E2508E585C6D', '7BA6736F-5C54-4F69-AB49-19B9D2315F1E', '4627074840576', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55A83F1F-4AB7-4142-9E89-1DE00035684A', '25693A74-C97B-40D6-A861-32856C65B304', '4627074840606', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCF97040-FC1A-4ED9-A473-37E3C44F83E5', '8D79F03B-6591-4AA1-8449-D0A6968D414E', '4627074840613', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67F5D93F-5A0A-43A9-A01E-40B4B4E08D2C', '99F9EAE9-9651-40C9-BFDE-305476A7ED35', '4627074840620', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1146838-0F34-45A1-8353-68A7EDCFF155', '7C490D40-465F-4B1A-9F4F-BE829E207C80', '4627074840637', '     10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFE1D96B-7B1D-4D8D-B795-1FEE6CC01683', 'A11EFDA7-9BCD-4AAB-AEA2-32B30CF2BA47', '4627074840668', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F035F204-4883-47A8-B6C5-BC72B7222E57', 'B73D3825-9670-453F-B647-FCA16F4DC2B7', '4627074840750', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EDD78F1-38BB-4638-A644-C924CE29E1ED', '7D594FDB-1C63-4CBA-9C96-48A088C9BFAF', '4627074840767', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3107F760-2C54-4964-B9E9-F43218E98F10', 'C153CE3C-8957-4BE6-9E33-6D88BA35078E', '4627074841023', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1478FC4-CCA5-4FC6-A1DB-578C0A80AE2F', '59AA6A11-A10D-4976-9212-086475A64A24', '4627074841030', '   -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A39B08C0-63F9-438D-809B-CE5B4013ABD4', 'D2F4BBA3-3622-46AF-AE7F-ACA2985A077D', '4627074841047', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E79E0BE8-1927-4433-A232-E9387ACD8DEC', 'E3D76251-8983-4F66-B385-8BD98A00FA96', '4627074841054', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41FFF5A7-3A97-4034-8F95-E9846DED22B5', '6577D424-12C7-4511-92AB-7EE005EDC514', '4627074841061', ' .  -  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21905F44-14F7-4FF4-B5C1-8255BF7BB090', 'DD060E32-F9A2-49D6-8554-FB717D00FF8A', '4627074841085', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7222086E-45A3-4771-9880-2892A3861DBC', 'BB4EAF6D-C6E0-4D67-89A9-1A1AA86C7F93', '4627074841092', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02F94EA8-863F-412F-A2E5-A8A991B0848D', '6BF98CAD-2A76-4BBF-8D99-37B77416247C', '4627074841108', '   -. 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7609CAD-ADF5-427B-A711-4AC77A0DCB81', 'D3D01C4C-F591-4768-B467-00E61F183C6C', '4627074841115', '   -  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('952DEA90-7EBC-4E1A-AEDB-AAF4A63A9D6D', '5BA8500A-9398-434E-B73C-4B665C4A2134', '4627074841146', '   .  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBCA15A0-5C80-4006-94C4-4183608738F6', '8CBDB7D3-B3E7-4D2E-8825-B44625AD4383', '4627074841214', '  1,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('142F4BEB-5521-4EE6-9B2D-4AFE60B8425C', '01AF53B0-944A-4865-A917-EEE26329550B', '4627074841221', '  3,6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A138E0BC-0D11-452A-8BA1-C120BDD00889', 'D8979835-11E3-4C4A-ABC2-C2CF875DB4DD', '4627074841375', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BBC3911-AC7A-414C-9E6A-D8A9825667C3', 'F34E1DE2-2425-465A-92CF-E95746B0672C', '4627074841382', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('171AEAC7-E8DC-4290-8128-54143468C784', '540A10C1-E46C-4BCB-AE22-98F74313F866', '4627074841405', '  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('163A697B-4922-4AE7-8556-2C51DFE11D4A', '40E4FEAB-FAB2-49C2-AD25-DF443645C558', '4627074841504', '  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BCC8A64-E2E1-4B0E-900B-3DA3B7D5591C', 'F6DD47E4-5F60-4426-B650-3AD2495CFED8', '4627074841566', '   1,3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3367BF43-DD7A-4B7C-94D2-A7A902D840C2', '0FF35AC2-A73F-4568-A921-EA81B062234C', '4627074841870', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('388B1E32-1415-43D5-B824-17723ACE1017', 'A9083BB0-AC95-4A99-B234-C2AD7462EC41', '4627074841900', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38F12D31-57BA-4F2A-B3C0-D31A5EC4311D', '7B5B3485-8B4B-4DB8-B11A-63533B4A4041', '4627074842174', '      30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91E7190A-AB4A-4408-8E1D-855965FA3C45', 'A22C184C-C1BD-4C6A-84E5-4A630773EE8F', '4627074842181', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C2BB8A6-CFA2-400F-B2C3-53052F334332', '31E1B1EE-81C1-42B5-B972-DAF4FDE1D95A', '4627074842204', ' ..  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBB0E3D6-2926-4A51-9F4D-C5BACF21439A', 'CDAC0F96-1699-40DA-A7FF-37420EC64CD4', '4627074843676', '    10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F89F04EB-9994-435D-B92F-B4C6B79C1B66', '7C263D62-049B-46B1-8CDB-A688BFA2E78D', '4627074843751', '    10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('518CFBE3-1434-49CD-80A2-BD9FAAB0BB4E', '35CCEC86-5326-4B44-8966-857645ED7013', '4627074843942', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CD532EF-FDB7-480B-B033-F097E9755F9F', '8BBD9520-2500-4318-AA5D-54BA643D5CB7', '4627074930017', ' 0,05 / / 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A491B2CE-625E-45C4-8A85-F52D1022C6A7', '408699BD-481F-4063-B4AB-F4CB320B7186', '4627074930024', ' 50/ 5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76D78478-15A5-407B-B03A-BBFC06A27627', 'F5ABDA31-4952-4E43-ADE4-A6EFDD6843F5', '4627074930086', ' 0,25 / / 4  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8B59FDB-20E7-46D2-8709-41ECE87A78DA', '6CFE410C-F216-4D1D-9906-CA126CD60FA0', '4627074930109', ' 0,25 / / 4  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57DD37E4-B41B-4CC3-908E-42B0A20A8152', '14F68839-81E0-4449-BEB1-EBD0E60AD14C', '4627078980711', ' Gess  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('862DF4FA-590B-4959-B6AD-102A4D7F0037', 'B796280C-20F4-45BC-9F2A-9620B35CA6F4', '4627078981497', '    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94C6A5EF-1FBA-49F1-9E23-F28D7581640B', 'F62C6A3A-5168-4DD8-B48B-8F15DDCD74CE', '4627079640010', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5480B797-14CE-4F57-B4B1-1E37E0CF6E44', '75EAAC67-9B69-4CC0-9AA4-1389EC41835D', '4627079640027', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D5A832B-6C22-4F3A-B55C-E5FCB6860F6B', 'C0E2ABA3-3B9E-4649-BA58-0EA9C866B335', '4627079640034', '     /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('186E6F40-5458-4E87-B97C-C4DA9CD49D5B', '4E44E26D-3D47-4077-8F7F-A79B683B2BE6', '4627079640041', '   (./) 0,3 100 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D79264D5-03E8-4801-BEBC-90215AD9A5AB', 'F6CE1110-DC65-42DD-84E4-C58EB0CD3CA0', '4627079640058', '         0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F0495D6-E8D7-4F92-9AFF-AC131884E042', '0FD72BD5-5272-4AA9-9092-52411D03F07A', '4627079640065', '         100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9B31150-2253-4ECD-9845-E65171CEC706', '6C44B729-14F6-4BED-BFEE-CA869B92494A', '4627079640072', '     , . . .  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FE0A68C-8F56-48DB-AC87-A8E1C571033B', '8B9AB090-790E-4B5D-BB57-36AB3CFF4609', '4627079640102', '  ,  0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A321BC5-89CD-4DBA-AA37-921865229DA5', '618C0404-2CAA-45D3-9E3C-3EBE66910FB3', '4627079640126', '    0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('081EA5CB-74A1-4CD0-A909-BF5B3C197DC5', '0B687EDA-657D-4231-8665-EBEC19F541CB', '4627079640133', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19AF1592-6B8B-484F-9FB1-7BFE11790487', '4BA71CCB-F6BE-441E-808C-72A0CA6B08DD', '4627079640140', '  3 d 3  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0DC7460-E2DF-4BC0-804C-00FD54907401', '7D30BAA5-2174-4AD7-852B-5F0EC7481D52', '4627079640164', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9DF4634-E988-49CF-A930-EA4E5041902C', 'A244AF4F-CD57-4045-B4FB-B08A0981EA11', '4627079640188', '    .   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A340529-BA75-450A-952F-C250E6A2DC95', 'AA55C568-ECF4-4BFC-B96C-57F286FAF78B', '4627079640201', '      /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ED59880-45E6-4D76-8F1E-825310BD3C7D', '7CFC687D-4FDC-4845-B671-37F9ED5382ED', '4627079640218', '    /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('073B573D-C870-438B-A85E-C97672D6945D', '60E9A9E1-CC05-480E-A8F4-D2001D991124', '4627079640225', '         50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8760FFB4-59C9-456F-A522-5C1C4BA994D2', 'F6CE1110-DC65-42DD-84E4-C58EB0CD3CA0', '4627079640232', '         0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F0BBA5E-FCCE-4F4C-9E88-9F9582E08E9C', '1E24CC09-91E9-4143-BEF6-1FE2E97E2AA0', '4627079640256', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CC6BB11-0C22-4F57-847B-C0CFBB79F6ED', 'C022C4F3-14D8-49FB-B043-A10C37FDF026', '4627079830466', '     250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B84EA85-4DBC-4A21-945D-CEBEE9618970', '01A9181F-159F-43A5-ADA1-F631DB83C271', '4627079830541', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC402102-0A49-4321-AD12-75673FDD74F2', '9E55A5CF-AC9E-45B3-80FE-9D487ADAC21E', '4627079833511', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FD3D54C-2B73-4AE3-8AD9-B6F77D83DA06', 'E2F7A253-16D9-434F-A3DC-AAF140D43468', '4627079833542', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8F1B7C6-7922-4D59-BAC6-63FCBF0D2AD4', 'D8B01D57-E863-4832-ADCF-3B40AAF0756A', '4627082100037', '    9398-001-89972233-2016 .0009 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39F6C235-7056-4CAD-A7B8-EB0CA3E686AF', 'EC908052-AFC6-4C4D-9EA7-D200F6F91D2D', '4627084350065', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B34D1B72-0C9F-41A6-AAB8-ED912DF0EE8A', '61B29FDF-51D9-4242-AE0B-C1B2E34870FD', '4627084350133', ' /    / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BDB9DB6-D070-49E4-8836-6ED8C32FC8AA', 'C188D348-DF29-4861-944E-058C663256BA', '4627086700066', '  /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43549C5B-35A2-4075-859F-D346C0934293', 'CA3DAAFC-DF25-4344-BBFE-204C98887321', '4627086700189', ' /    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6F3D2AA-A4C7-4CF3-A844-99636F60310F', 'F5CBDB63-9371-4DAC-8A03-2B17AC1CAF55', '4627088980084', '   0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('369F5BF0-0F0C-43EC-A48F-D80FDC6665CE', 'E53085D0-E0A4-487A-AB39-5F4A06B5AC63', '4627090493046', ' pellesana /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E824FDD-9AB2-41E8-9995-78D22CC80FFB', 'A2A351D4-7E12-46A9-BE0A-CAA981932BF5', '4627090497129', 'Pellesana biohyaluron     15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B4EEEE6-7641-4A64-A364-D87ED956E101', 'AB243F33-14A8-427D-A619-998AF79E512C', '4627093273737', '  2- . -14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10BBAFD9-8141-453F-8869-48E4858F0245', 'BDED7255-2606-4101-8887-B47CDBA584C0', '4627093274451', '  2- . -18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3BF4972-3E33-4FDC-BDBF-FD35E331CD32', '0D212BE1-E6A9-49AD-95C4-DE3C270D4E12', '4627093274475', '  2- . 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90BF78B4-417F-4A99-8FA4-390FD2AEE10B', 'EEBD7971-7AC0-44EF-B0E4-A0FF75C2CF1E', '4627094770013', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FA48EC0-ABA6-4F31-8F3A-D33A9F84C430', 'EEBD7971-7AC0-44EF-B0E4-A0FF75C2CF1E', '4627094770020', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33E63D63-9115-48EE-8FB6-F9BF118261D2', '83D14D28-E541-433E-8833-3C2E02ABCBF9', '4627094770037', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC49AF03-A0CC-4A64-A513-0F669B904228', '50AF3DEC-6071-46BA-AC7B-9ACEB8BAB652', '4627094770075', ' / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4E3322D-FE77-448C-8D32-17CF024DA457', '7A2437F3-490B-4787-BF26-35CBC1E4282D', '4627094770174', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29BC530C-B22A-46AD-812F-C1E6FC0AE8CA', 'A9BAC142-163B-4275-BE96-15FB638546F2', '4627094770181', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E7A55C4-1EDF-412C-8758-088EB8FA1033', '38D82928-23D8-47DD-AC07-908D6F4AFDC0', '4627100132033', '    spf50 /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('515C360A-7AEC-4EDF-8057-F9CA57C1766A', '94B47CE6-C9C2-4B17-87BA-1183643EE483', '4627101570025', ' 30+  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B15F5C4C-17B8-4939-9E40-4C630F02CB49', 'C214757E-C350-4900-BA96-F717D3E0F0EE', '4627101570032', ' 40+  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0960C78C-D71B-4FDE-B848-B5B524446779', '21DD1998-952B-452E-8720-2A46D0C6896D', '4627102710017', '-    /   // 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C440DE8-5F42-403F-ACE8-BE92DD3257F4', '9FBCC8E7-D4B0-463A-AEA8-E686C64E47A0', '4627102710062', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('335ED12E-8654-46DF-829F-29E7C55E2B5A', '253F94F5-C574-4341-9597-B81D092E0BBA', '4627102710079', '         50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43FEA1D1-8054-41CD-BF0A-5A591DDE6E6F', '45DAB150-0AE7-42E7-9D83-8D45F950FD6E', '4627102710086', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1C55E5B-AE33-41FD-8BF1-2ED2D9C60198', 'ADA7D1C2-BFC8-422B-B95F-4B9DB8B73BEB', '4627104460019', ' 180  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF4D4FB9-1448-4FAD-8834-0D14807ED69F', '9A48C3B1-4D27-4293-960A-9EC719E909F0', '4627104460057', '  200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94367762-BB33-4A3F-B938-8D3D6716F554', 'B56511C2-2C84-4EB8-A1E3-CA7F2062C3DC', '4627104460071', '  200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D110C8C6-F729-4D3F-93CA-E3D8D60D0E1C', '1B865A60-64A8-469E-B198-93C9CFCA950A', '4627104460194', '  //  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7AE0985-F82C-436E-9EF3-0A572D98175A', 'F8A493DD-6B61-42ED-9723-211133CE7ADC', '4627110040861', ' ergoforma   2/ 3/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B5A60BF-3C9C-4D62-8868-0D1FEECB1C63', '018030E8-5228-4124-B8B1-D24F9E2D107F', '4627110041448', ' ergoforma    2/ 2/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C12B1928-994B-46DD-8C96-27A8BE1CAB58', '5ADD49EA-E023-4D0C-AD9C-40FF2B683004', '4627110041455', ' ergoforma   2/ 3/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAE5B02A-B178-4558-93C0-38CE2C2E6C67', '5EF25B5C-EAA7-4EB2-B388-1B955C6485A8', '4627110041462', ' ergoforma    2/ 4/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB6C393F-1F51-4A78-A60C-28CB2A7CA41A', 'E41C25A5-502C-4704-8743-9401EC196D03', '4627110041479', ' ergoforma   2/ 5/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AF7167E-B521-4743-8774-60D0F1B0E081', 'FFF3B380-5816-4E25-B86C-48AF64A895BC', '4627110041509', ' ergoforma    2/ 2/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E417B403-B5D5-4E97-A0CE-587E33A8F2D3', 'A6072114-4BA6-4431-8B96-195209FF714F', '4627110041516', ' ergoforma    2/ 3/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9F19FAC-67F3-475D-AC1F-955AF02BD87F', '6834AE06-0D03-494E-B5CB-B462D45FD00E', '4627110041523', ' ergoforma   2/ 4/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35131A61-E79C-4456-A159-29C460C44F19', 'DAF991BA-4335-4C12-91CC-07B46EC9DC68', '4627110045705', ' -  fosta /l/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9A8AE54-7EB0-463C-9B01-3FB244DED3C1', '5DBC2512-2B51-437B-A4C7-6A2CFF9AA537', '4627110264342', '   - 4/-608', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA5AD051-9524-4BE1-AC3D-E23DF1C89AD1', 'E11204F5-B26E-4471-A062-6419B2F1ADC3', '4627110264359', '   - 5/-608', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6C321A4-FC81-4611-AA63-8716C343CBBB', 'C14EB2E8-6FDE-4567-9B4D-5B3FAC95F7EF', '4627110264434', ' // /  /611/  3 /90-100/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C2B27EB-BE33-4BE6-B24D-3B4E5C35C17B', 'FD2EB548-5850-43FC-85B9-499178C687D1', '4627110264779', ' -  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A199A224-811A-49A4-987E-CD8DBF6375AD', 'F2D37DA9-FFD2-42D5-85E8-8FD966012501', '4627115160038', ' 3  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20759316-0393-4E5E-A1C5-686349A32F22', '50FA55C0-5623-4CF1-8208-D09F2A545399', '4627115160052', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEEC3DFA-D814-4330-9CB4-10A28894994D', '6E7DDFA6-4E8C-4417-A30D-FB7754C4B191', '4627115160076', ' 6 d3  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6A3BDF0-82BE-436F-90B5-80EDA6D9AFC7', '886ADFEB-7B2E-4DFF-8557-78AF452DAD2B', '4627116055180', ' orthoforma /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDDB5EE8-BC18-432E-8916-1D82C4CAC923', '59219C9A-98A8-447C-BC97-EDF83AA3AC40', '4627117390020', ' / 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A9952CA-0AB7-4DB2-9AA7-E67A1623467C', 'F71F83F0-596B-449B-83CE-5112C81C18CF', '4627117390037', ' // /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B70069A0-13FF-4709-80AA-9E7B4A1EE491', 'AF74B9B4-7BF2-4340-B8B0-883807C93481', '4627117390044', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3ED7908-77CB-4071-8328-3853D5A8CD86', 'AF74B9B4-7BF2-4340-B8B0-883807C93481', '4627117391515', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('450128F4-10B3-4EAD-940F-FCFE86B1D155', 'E0A05A56-256D-4FC0-8E0C-ADF42D9750AB', '4627118560019', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2466B73A-D3C5-4209-AB64-83A38323E93A', '754DE3E5-6EC0-464C-9B37-15F37F11D4CB', '4627126380128', '-  tore 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC84C823-95C6-4B39-B863-6653DF24BA50', 'C6094A80-CCED-4633-B8DC-608E00D93720', '4627126380135', '-   tore 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58207EB3-18CC-4535-9DB0-0B0E71AD8E3D', 'C6FAC03D-382A-400B-8953-8B6EA2AA015F', '4627126380159', '-   tore 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01B5346E-9F10-48DD-8EB2-3459CAF2A62E', '799FB56E-C9A0-4073-ACE7-7B9081E590ED', '4627126380449', ' /   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E3C1381-159F-440E-BD24-EFD1D9796706', '89CD2C61-29A6-4B90-9EA1-40D2B0712D98', '4627129210545', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A20DD25-B1C3-47EC-9A8F-34F79BC915F5', '994874F8-B6C4-4E2D-89AD-5FAE2291854A', '4627129210552', '     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35296E18-C434-47B5-88D3-BC0A68F58BF2', '380129EA-E10E-4C44-BD78-5C739D8FD903', '4627129210569', ' 1,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5DC2197-F210-4DBA-8A6D-FCAFA5F5470B', 'E900A142-3E99-453E-8E0B-BC9E0D8AD254', '4627129210576', '   3,6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C78C582-43CD-4EBB-9932-0BF3471EF3CD', '8B5A4161-3989-4C3B-AA7D-8D4098DCE3BC', '4627129210583', '    350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32C8F754-4105-4213-A3B8-6A4F3A2E75C0', '327B0487-0E0A-4D28-9017-84CC8CB8C28B', '4627129210606', '     110', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3227296F-41D3-4790-9698-BB9EEEBCBC92', '784E752C-5B2D-4170-820C-925D8F8D614A', '4627129210620', '   .     125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0414A5A-34DD-412A-95CA-037259C15632', 'DB790FCE-5738-4B50-8840-0E3243E83D23', '4627129210651', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E7CD708-66EA-4903-98E6-6564CEA9CFEA', '6440E550-844A-47BB-AF81-A539F8755B90', '4627129210675', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD6C1FAE-523F-4B4E-95BC-C11CC3866376', '703657C9-A0A4-4EE2-93DD-6675AB5CB7AD', '4627129210699', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A829BA0-DB5F-4418-9F15-960B5684DAB6', 'BDD20D99-7DF3-4448-838E-B848BFBB1D90', '4627129210705', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96823892-0A96-4AF3-8090-5E3B3168A1EC', '9FB5C094-B428-4CE0-AC95-88A2CAB17588', '4627129210750', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CF905B1-471D-4B69-9243-E5E826354E6A', '45FCA6D5-DF2A-4A12-98E0-13E1B9EFF2AF', '4627129210781', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C27E08C-A93F-4C48-AE07-9FBCED629616', 'D67D7BC1-30CE-4070-9CD6-E8C27BEDE7F1', '4627129210835', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85C848BB-2138-4AA3-9D09-6492EC13BB65', '33C62440-CBBC-4106-B598-11ADED5045C0', '4627129210910', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAF70E7D-7DAC-4909-9658-4216B48A0080', '1CFA1E77-4326-4A4A-99B2-AF7C685EE895', '4627129210927', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2EB11F4-3389-468C-B086-F3424120EE58', 'C41CDA4A-FDB8-4A2A-88DE-3402DB9DDF84', '4627129210941', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC02CD00-DE98-4927-AD46-DA925645A6F9', '51F3ED93-05C9-43A7-85B1-CD55650B9BCF', '4627129210958', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C71B7236-F6FD-44FE-80C3-073E4A0085C8', 'EB434897-3500-4A04-8FB0-2F269A573FCD', '4627129211009', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F24FE48B-1444-4244-9EE6-3144CF3C2FB7', '3165162A-9997-4762-AC32-F36B3AB61034', '4627129211061', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CC444F7-4295-4E82-BD2A-2AC421AE17B0', 'CACF1395-694F-4C35-8C3F-CA634BA44E22', '4627129211115', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DEC69A9-F2A7-4376-B93C-325EBCDA1969', '426AEEC2-EACA-4467-8430-A3D765312140', '4627129211146', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBD38FF4-4FEC-4B50-9E2B-5552D337C6A5', 'C3DB612A-A4B7-442B-8CFF-12B9809D86F4', '4627129211177', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('548A4955-BF0C-4A29-B394-492BD0C8AA10', '8ACFA895-39E3-4AB2-AC6C-48FCF99B25EA', '4627129211221', '    10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD1FD514-EEC5-4AA0-B0A0-D86F0B1305B9', '507B5D05-B795-4B3C-BB1D-32288C86A7CF', '4627129211238', '   -   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19691EAD-22C7-4496-A5AF-B8244E7894AE', '9674AF11-8CCC-4806-A3E8-A4A12EFCC99B', '4627129211245', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C65BF96-8883-4527-BC53-41C5AB8D2AA3', '5C139709-3F8A-4988-9C7A-250AFFA59E0A', '4627129211252', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01A842EF-108A-4842-891C-6A874B24AB3A', 'E5DD7918-55DF-4364-B593-9471A16D4272', '4627129211269', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2400A841-C9BB-450D-AC07-25C21D735A2D', '203EB7A3-D2E6-4B66-A37B-CF2911B1A82C', '4627129211276', ' .  -  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25292979-0BBD-429B-BC6F-294DA2E3AE49', '9D9F90A4-91A4-4EAB-8E52-2FEB14565E4B', '4627129211306', '   -  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EA894A5-5BF7-4F9B-B6CC-DAF6A0464028', 'A1394973-9678-445D-BD18-1694D989B31E', '4627129211313', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('319EEFAA-9CFF-48E4-8C9F-D6B338A5D525', 'DB8CF031-F49E-4CCC-A677-D6682E87A9D8', '4627129211320', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5B94B9E-C74C-4409-9B6A-09F522C93D08', 'A5F2168E-6CCB-4AA7-ACD8-7C282E59A8C1', '4627129211337', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8B1C82C-34DC-4572-AE5D-20CF72FA9C50', 'FE4C283B-5ED3-4528-B757-730B17842D44', '4627129211344', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80ADE333-039F-4549-B3EA-23C935F15CE0', 'AD60603C-9611-4609-990D-E1833938531C', '4627129211382', '       30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('391BC42A-93D7-48A5-B594-8F3019E06129', 'BEEE22A2-79E9-4A1B-8AB0-00FE268110D4', '4627129212242', '    -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3730938-D7FB-4695-937D-121ACFECFA28', 'D10A0A7E-F0E4-4BAA-B7C8-9D740B903FD7', '4627129212259', ' .  -  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E270F81-802B-43B2-835B-6463C39F4B5E', 'ACF2B08D-C534-4952-940C-669282E92E48', '4627129212266', '   -  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE00A6ED-D7C2-4678-A307-18BFB54B3439', '15A5BAF3-05A3-4943-98D8-E5B822461D1D', '4627129212273', '  -. 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1A57253-20A4-4EDF-BC83-BE250F78F392', '01C2CD62-AA8F-4FD7-9BBA-5EB68D8C3E71', '4627129212648', '  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84DEC246-6448-4AC2-B3D9-0A76AC605876', '6466505E-D6D6-4170-8134-552DFD31A252', '4627129212655', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73F83885-BABB-4427-A4E9-71312E29C4AE', 'CE730B7E-A762-448B-9220-F8467F2B2300', '4627129212686', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90FA7B27-031B-4630-9C6B-717BF036F85E', '79A2495C-644B-4E0F-BD91-42AE8E0F19B4', '4627129212693', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03EC00D5-C58F-4029-B49D-D7A04C783438', '8B5A4161-3989-4C3B-AA7D-8D4098DCE3BC', '4627129212761', '    350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFB73104-B0EE-47BC-A363-68B3740CD658', 'A588AA81-DA07-411F-B062-F6318B219D3F', '4627129212778', '  450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91F42523-9532-4320-AD94-8C4E27A62EA7', 'DDDB4588-9D3D-4719-A3B7-63247C9FAD37', '4627129212839', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('238BFEDA-59E3-4BE9-8942-D6325E82B1A0', '16325D55-6FD1-4A56-85AA-5FF6C75AD33E', '4627129212907', '  /     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC664403-D1CE-4FA0-96CA-690CB57FDDB3', 'DD568942-78D8-4CF4-ABB2-A9C67BB98AE6', '4627129213027', '    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31E9A537-1734-4DA3-871F-FB3DF85A7B14', 'F52C8727-4CAE-4409-9D0E-D6EC48174E5C', '4627129213058', '  /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D11B6494-B5AF-4858-BCAA-B7E36C92BF94', '92807780-15D8-41EB-978C-D09B6BE8CCDE', '4627129213065', '    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60D5D6AA-841D-42DC-868B-2283E80B8E8C', 'DC7B1B7F-30A8-4729-BEFE-A84944D14B2F', '4627129213256', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07047B92-7B23-48E3-B6B3-9C37478B9530', 'AC8F2B9E-1944-43CB-A104-C3A07CC28AAE', '4627129213263', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6832109F-C0EA-429E-AB23-365738E1E063', '91AD81AC-7461-420D-A172-998ED22887AD', '4627129213270', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86C12189-22DF-4642-825A-D5645D7F9AF1', '86905E56-2506-4FB9-B14E-D3820FF9784C', '4627129213287', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B4F411F-5040-49E9-8C5E-8A2BC3A33529', '1E806216-49F9-41A8-B540-DB5AA816A4B8', '4627129213447', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81253262-70E2-4B78-9C6C-EA0C5D1CD18A', 'E52F9B9E-FF3B-4D0A-845C-4A24D3475306', '4627132420016', '   / 3 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55208780-58ED-4DA2-8A58-EE44129FB33E', '4CF64332-F3EE-4FB3-8161-4EAC31B0922E', '4627135780018', '     /.  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AD77E2E-B45F-445A-9158-68F0ECEC95F5', '0C66A2E7-10F9-4BF2-9FBE-612CC6BF0898', '4627135780056', '    /    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA69CA82-AD88-4AEF-AECD-53E6E63F0B83', '988C3F9C-089F-43D2-916A-824F66D8B15A', '4627135780186', '  / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('108FA1E6-12C8-4FD9-BF50-9741C5666933', 'BD8F02D8-9886-4420-91F0-A5EE17E2331B', '4627135780193', '- 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E40BA795-EA81-4B09-8C18-6CBB1C9449FA', 'E7C5FB7B-C9FF-4793-A5EF-90D9F41A0F6F', '4627135835664', '     12/205', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B02F418D-2119-4346-B0C8-CA04332B2BBA', 'FD6A0D9E-D4C3-4A0F-B0AD-9B3AA92A6A06', '4630000190454', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55E48B0C-1413-4B45-AC14-F4EAC35BFFEC', 'D4E41017-5434-4BB0-992F-FF9E047814AD', '4630000190720', '     2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E344236C-8B9E-408E-81FC-EF9C58C6C863', '1204507B-0ED7-4FEC-9822-9149085A05C5', '4630000190744', '    . 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('486CC3DD-3BF0-4E6B-83A8-89900EA6F144', 'D22E94C1-3BE2-4792-9D51-1AE9715B41D2', '4630000190829', '  21 .3-4 70den ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADD64685-8438-4E54-8CCF-06F3E25D785F', '1D4C4C22-0061-4B08-90D1-73BB75F7CFE0', '4630000890040', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E4455F8-6D1D-47AA-90FB-6D8612A2DF8C', '2E9233FD-5625-4E70-85C7-1EB25DCD950B', '4630000890187', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7611D7F9-2B6B-4099-9EDB-081E6ACBD8CA', 'AA2E326D-27EB-4F2D-8B37-AABC818B1294', '4630000890262', '  //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E60BEFA-D136-448B-800D-CEFF77C3EB7F', '949842DF-4C56-4F79-86AD-30D54BED3678', '4630000891436', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C1E8FCB-6797-4F37-99D8-B5083472F4BB', '44A00F9A-C0C6-46F7-9E16-A77C419E16E1', '4630000892693', '    // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F04F2ED-82F9-464E-90DF-A2D6DD2E00A2', '39198686-3921-435C-AF69-F4AD95DFC4B6', '4630000892709', '  // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24456286-C41E-46C9-9644-41781C512DF0', 'CCDEE90A-15E2-451E-89DD-1D7F3F0932EB', '4630000892716', '  /-/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A0C8690-97EE-4088-8623-F08974FE2032', '4EA5D32C-34C3-40C2-826E-32EF1A4BBD79', '4630000892723', ' /-/  / 1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F7A8B6F-EB84-4228-A510-F42DCF8804DB', '9FBAE832-C568-4A96-8A55-B2E6DF14D253', '4630000892730', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7418BE61-B599-4D6D-8060-9E72334CCB28', '4F1EC2A0-40AB-4C13-8160-829A369ABDBC', '4630000892747', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E060F95C-D05A-4DFB-AB2E-A93D5B2EEF34', 'AB2D5564-B2F7-4BE5-9B73-FA1786CF448E', '4630000892754', '    /  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C20CABF-5BC8-4126-9C19-98D02343A83C', '9DECBA6D-F12F-435C-B0FB-8F2FE4570F14', '4630000892815', '  // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('387140B8-2409-4E8F-846D-020F96B36911', '572953B1-AE05-4E13-BF56-E55BFEFC20B0', '4630000892877', '  // / 1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CC45693-724A-4A43-B85A-C94E9CA61101', 'F032FEE1-C619-449F-BA06-C98381288415', '4630000893225', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('187EB74F-BA44-4DDC-B323-7A94EFF69AB5', 'FC0B514F-2865-4BA4-8C7F-C54D4100D011', '4630000893249', ' / 1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30E567EA-E4AD-479F-AE08-89189B0EF44F', '584707EC-4171-44AD-B102-5D7A19455870', '4630000893256', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C986642-FDEF-4C58-80FA-C558F7A84954', 'BEFBA7B4-CE4E-4A34-BC69-DE2F4E959E71', '4630000893287', '   1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B8AEDF9-C29D-4736-A4D1-D8E695302D96', 'CA3D7845-88E0-4D43-8C9C-7FAE83D31D23', '4630000893324', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFAF279F-89A2-479F-B2BC-F4EABEA9DF20', '03283E22-45D2-40BB-9DED-F3E7DBDD3799', '4630000893331', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AC8A64A-512F-4A7C-BA4C-9C1043E974CD', 'ACD00418-DA15-4AE0-9069-520F9339E4BA', '4630000893355', ' //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A8FDE4A-F940-406D-8C5A-F7B181896B00', '90FA8F68-C3EA-42B3-AB73-D37CA7F54733', '4630000893379', ' 1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E9FF9C2-107E-4F5D-B212-6F7034D7D81B', 'ECC1EAB4-BF04-4A3C-918F-E4A1AF4175F4', '4630000893768', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C5EC1B6-1120-4898-AD80-A3C8B7434EFE', '82052DB8-CA5E-494B-950A-F99E31A5BAD2', '4630000893805', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55C24D60-7553-44C6-9962-D143C5250D39', 'FA7E2980-E857-453C-A108-704B861A5A53', '4630000910069', ' 10   3  10 0,838 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6139EE26-73FA-42A3-842E-B74DD7791A78', '537F349E-D363-4969-99F8-1AF7A4DF7864', '4630000910090', ' 1  3 u-100  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C29847A-29D7-40CC-AD8F-4F82B7244A85', '1E7C66D9-564C-460E-9892-D4B2595BF1CD', '4630000910113', ' 5   3  5 0,738 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2E07025-0BE2-4B5E-8003-150A7B18A306', 'A9B1A159-DB2E-49DB-A635-0392593F06FC', '4630000910458', ' 1   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8304CD0E-4C18-4483-B234-3F3C1A9F0A6F', '62F69323-FD62-48B0-BA57-1ADFF72321A1', '4630001120528', '- 500+100   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16822738-7397-4216-8B52-DC134387E3F0', 'EF22D94C-CEF9-4195-AD3C-7BA324363835', '4630001120535', '-  750+200   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B649BBDC-F1F2-486E-AE98-CE457559D725', '457F4FDF-4081-4DF1-8B2B-F6B6DEE6C18E', '4630001120542', '-     7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9672769-2BC8-4EAD-9835-8F73C5FEDDBC', '73BC5E04-86CF-4040-A5BA-3666E8606154', '4630001700096', ' - 0,6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FFBA7FF-5562-48D1-99B9-32EC6CA98D0A', '8F1C292E-49D8-4DE9-9890-BC648529FECF', '4630001700102', '  - 0,6 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42AE46F0-0AF5-444A-974A-D4BC6F6F0039', '19C72E5F-3B9F-48A7-9ADD-2A99C3F8FD7C', '4630001700133', ' - 1,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D8C9782-78FC-48C3-8550-0A8E12A60A66', 'CA3C01D6-7926-48B7-A51B-BA9809A55173', '4630001700140', '  - 1,5 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1659CE1B-8D19-4A2D-9546-3544FFF45830', 'C8A237B8-917A-4A2B-A931-914A4536400A', '4630001700188', '   / 0,6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFE0DA9C-C24E-411E-A41D-9E78E5567CB8', '9E5A87E6-A937-4F57-9695-F78A9DA4D33F', '4630001700515', ' 0,33 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('082FA794-8B7B-4DB4-8A17-F5D610744FB6', 'BCFB97F2-D862-4102-9105-3106E8ECC1F4', '4630001700539', '   / 0,33', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21C1E7A5-3751-456F-B41C-DDE52B224127', 'CA7BD1E9-8E1E-4C1A-B970-48797F461C3F', '4630001700546', ' 0,6 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8540CBB6-E377-4459-BFD3-CF9882193064', '9EF1F860-AF5B-4893-9870-6AFF3DC98421', '4630001700584', '   1,25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A128B4A-FBCE-42D6-B0A6-D1D81EB3D67E', '10CC2D82-7310-4831-A0F9-A16CBB482CA3', '4630001700607', ' 0,33   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16041F53-1AE7-4013-8CBD-7362003A1723', '8A66213A-6B49-44CE-8554-A7AD0C62793E', '4630001700614', '  0,33 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0CAF25C-122F-4370-824B-F986723A9D5B', '41A0410D-C8C3-40F2-92CC-1EEE6FED255C', '4630001700621', ' 0,6   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FA14259-B146-4177-8E8F-CF76E3B9981C', '7BCEEF5F-3B47-453D-AC19-5E88F629ACE5', '4630005643863', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0687A96C-7CA7-4F6A-9925-108A6ACFD147', '2AFC5E2A-A89A-46C3-8DB6-CF4854C5FF70', '4630006135367', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD37B93A-D4BA-48F4-A4C7-0B5B3F025BE5', 'B0DBCC95-F2FA-4405-AAE2-33D190C0B743', '4630007831701', '  /  // 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77A92F93-C515-492D-A395-1E33F1FEA262', '64F01476-92F9-4905-87FE-645F13FFF656', '4630007836904', ' /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19FD5C32-80B9-41E0-B02D-C80836CF443D', '8748B2F5-E711-4A25-8180-BC0D8C52153D', '4630007837963', '1000   / // 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F96868F8-F4BF-492A-A249-D564DC253CB9', 'CF353289-4ADB-4A7F-8B51-7EBF00BBC6B4', '4630007837970', '1000   / // 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('549F6534-41C8-4661-967A-74A41D36F0B3', 'C5EE7731-A259-48D6-AEF5-240B857341FE', '4630007837994', '1000  - / // 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0EA84D6-6440-4221-81CD-6144319E8BE4', 'D555A6D4-2F69-410F-A5B2-DA6FB19CC726', '4630007838007', '1928  - 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7715CEF4-91C4-40C6-B3CC-89A4CD039A0D', 'CABC003A-F87A-4B0A-BE3A-6E977BC34CCD', '4630008130223', ' 0,25 2 - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('778BD14C-E551-4A1B-84C5-038C9B0F74BE', 'C6543A9C-9992-4148-A897-1C1C4EAE70F2', '4630008130230', ' 0,5 2 - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D91B0A5-19A0-463A-96A9-F1A77E51BF67', '2A3BEEAE-6728-41A9-838E-E6DA9ED713D1', '4630008130612', '- 1/ 20 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD6A8E33-B72D-4798-A1AC-CFD31875DC13', '7F814B7E-4D28-4ACB-8B1C-407F0C43D514', '4630008130889', '- 0,001 2,5 - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3820218A-CE8C-4670-BE60-9A5C30606FF7', 'D3A4CBBE-E914-4116-9A52-D66AABCBA0B9', '4630008130933', '- 4,5+160/ 60  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0510EB14-F974-44A5-9353-9E16DCE2A361', '6DC839CA-1A84-47D1-B415-03BDEC56BEAA', '4630008131114', ' 150/ 17,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C13C28A7-C823-49AE-BCFD-0DEE57A3C2E5', '6ABAEAF8-329F-4B58-86A6-3FFC5BA700C6', '4630008131268', '- 80+4,5 +-  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6971203B-1CB7-4023-83F7-AB0146C428B3', 'F7431E3A-39CE-4E39-B8F7-1207B50075E4', '4630008940167', ' 0,01% 500 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D42B301D-641A-4BF0-A406-A759421B37ED', 'BB0379EA-A875-4C1F-8032-047EB61E3FBB', '4630008940174', ' 0,01% 50 -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC7408BF-44B7-41B1-9711-F2C5DF2B50A5', 'CAC6E16E-0329-46F4-AD09-028AABBC46E4', '4630009180913', '  0,33 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EBA604E-BE3D-4F44-BDCF-3D86EBC203B8', '749E5451-4309-48E0-8B34-040DBECD5390', '4630009181149', '      4  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F96B81AD-CE6B-477D-A198-108314946F09', '8EF748C1-F0F1-4C16-A4F9-2C6C1EF22CC3', '4630009181330', '   1,0 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34FB8F75-208D-46FE-B9FB-6C8002E9F758', 'C6231B6B-7634-4064-9C6F-F4456194AF96', '4630009186397', '    4  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9740F6AE-763A-46C0-ABCF-EC94A0377CD4', 'FEA324ED-DCAA-4336-A9BE-A952188EE320', '4630009186885', '   0,3    . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4563EF4B-C0E4-4388-BF74-A6F80079D805', '0C7584D6-5919-4711-9FB6-ED14BD9067E6', '4630009186908', '      330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61321517-C926-474D-9CE3-EB867387D007', '1EFF6078-7497-4758-B9F9-41ADFC012DB2', '4630009186922', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38FF478F-DDF7-4C8E-B0D3-EF75C03C000C', 'BC9D3EBC-5587-4EB0-9C6A-9F5071DB5C03', '4630009187882', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C99DAAA-B648-4536-BBA9-B26794E1957D', 'D07D3665-6F87-4C0E-AEEE-4FB264FC8484', '4630009189251', '   0,2  .  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('216B0AEF-3A19-4372-9EE7-F73F0CE282C5', '9466F1C5-16B2-4998-B0A8-41AC6EF8428E', '4630009189282', '   0,2    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4859EB3-370A-405C-9794-B095DFA52FE0', 'A405CA96-1A29-4CC8-993E-487556FF13B7', '4630009189374', '   0,2    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D742692C-08DD-491E-87A9-98A12F08A4FD', '7113ABD9-1251-47D5-9E45-1BA53544D85E', '4630009620020', '-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F866AC1F-E400-43CE-9F1E-D5A8C51C4A87', '0D8BAA30-2F9D-471F-92B8-25DE132D86FE', '4630009620037', '    5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AC6801A-8637-4580-8F1E-426F48EEC15D', 'C23CB68E-F27F-4A1C-96FB-8E91A2571FEA', '4630009620044', '    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2D69011-6EDF-4F29-A5FD-9F4BC8CF9573', '295A7590-CFFE-40A5-A57F-AD2AFB847785', '4630009620051', '     5 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C39CEBF9-6FC9-4201-830C-CF51091D756E', 'CE34112B-858D-4AD3-AEE0-8C2AB81D31B6', '4630009620082', '  //  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74199BE6-92AE-43D3-88E7-3EC7CF7717AD', '648F3D24-27C5-44A6-8911-C91218C4B2B1', '4630009620099', '      12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BE2AD46-17AA-4063-ABC0-48B854A32BBA', '6742B418-26C7-464C-A5D3-DDE207136E90', '4630009620105', '-   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C94FADA-809D-408E-9084-ABEDBD3E5A51', '830080B2-F639-498E-B742-2C15B6584455', '4630009620129', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A4EE864-B0FF-4F85-A1FE-02A7D225F05D', 'D78A34A2-29A5-47D9-975A-DD3EA8B62CFE', '4630009620136', '      24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CEFFC0B-DA61-468C-9D25-CF678D0C18A9', '2C3A39A3-D779-4E07-B0D9-1DEAF097E372', '4630009620488', '     5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79B548CB-A62E-4BDF-B140-D7E0F00DFC7D', '5F40C581-BDAC-4F43-82B8-6DFBAF2AF94B', '4630009620495', '    5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('086FC7C5-4200-41CE-A9A1-659AE7067DCF', 'F06DB0BC-9780-478A-B9DF-27F4645AEDB9', '4630009620549', '  // /. - /. 6  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5644585-A531-4A4B-BBB7-7DF49C86D2B0', '9B5F67AC-1669-4D2B-B9E4-47D370564C20', '4630009620617', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77C394A6-0D79-469C-94CB-9AFB1D2C9E94', 'CE3A5889-2659-4A91-9D21-7BE4499EE437', '4630009621096', ' 50  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB494E84-C420-45AE-A5B4-57CB1BEC55FE', 'BA86DE74-144B-443E-B80A-8AF62C7F94EE', '4630009621171', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80177A3F-91B3-4422-B68F-41D2C3C89F4C', 'AE8869EA-762E-4524-936A-D93128EE03EE', '4630009622253', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A0E0E92-8496-4097-B393-7472D10BE0E0', '3BDCA996-C520-4431-AB0D-33A6AF5C4A97', '4630009622475', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('536853F9-BA83-4A87-A23B-03C311C30D72', 'E21FC8AC-CA10-4E8E-9F0F-4EE0D04B024C', '4630009622536', '  //  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB1533BE-3771-429E-B5F6-7EC02AE85FB0', '80B15581-2A56-4724-A204-18693D39B5F5', '4630009622543', ' //   5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3330BA13-E449-43AF-A82B-C0250A3EC142', 'D3BACFA2-99B7-40C0-B3F4-23BA2B643803', '4630009622550', ' / /  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('013EA904-1E5E-4ABC-9D96-B44181A2DC8D', '08111F7A-C946-4DB6-BC61-1EC49FA703F0', '4630009622741', ' / -      5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65BB6F2D-ADCF-4C90-B71C-A0A2A3E1FEE0', '7E8A7F57-3ACC-48E4-B352-527D44C66567', '4630009622758', '  //  5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF57E3F8-EFC0-43F1-90C6-7DBD26CFD5F7', '97204BE8-E9F1-4B66-A3C2-C1A11C13FBBE', '4630009622765', ' / - /.   //  5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B35F014F-7DD8-4E12-9E7F-51D3A310DFF1', '6AA40E01-83A0-4CEA-B3C2-6000EAB1B4AD', '4630009900450', '   10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF34B543-1BCC-4A76-A149-E8DFD7FC7764', 'FB1C851F-59A8-4C47-9018-3F42B72DEC02', '4630010490018', ' 1% /     10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8C3981C-3C3E-4E55-A910-A95E700CA7D3', '7C3AB33B-BDE0-4428-BA02-029A18DB3754', '4630010490070', ' 10%  - 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E4C8C58-C3B1-425C-906B-12132DEC2439', 'E05D7E88-8DD0-4DC8-8BCF-F136081F153D', '4630010960016', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FE12E1A-F55F-4C8A-B9D4-CA9176441A4C', 'ACFAE0D3-B556-4193-B68B-E7664E670A74', '4630010960023', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF2855C4-C279-4B40-8402-6E71ACB5A334', '83D165E3-A537-4107-B891-1A54B4DD539A', '4630010960030', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F5D014F-25D6-4AAC-845D-3C811E2E8D1A', 'FE3394BC-EF81-4032-9973-30E62170F4E3', '4630010960047', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29AC5686-5872-4BF4-BE41-82ED768D4C50', 'F3D18F04-35ED-4E4D-8EDE-497FCE37CCD6', '4630010960054', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D20868D-5659-4134-BDEF-CEB71DDF3DA5', 'BDD20D99-7DF3-4448-838E-B848BFBB1D90', '4630010960078', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95B81E4C-C8E1-4EFA-86DD-F93CBE991F3E', 'CB2E957B-79A0-444A-9581-6F546DFEA5C8', '4630010960085', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5479D10C-7689-412B-846E-3006D054840C', '9FB5C094-B428-4CE0-AC95-88A2CAB17588', '4630010960092', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55F77D3A-1054-4DFE-848C-DA8B92E51B5A', '8C484D8F-39D2-4D60-A6A7-049798D1BFC0', '4630010960108', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9035A47-4B28-4DD7-9DB7-7FE299FA7827', 'F9471987-916E-4378-87C0-C1F119D6EB39', '4630010960115', '-   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15F8C08A-9EA5-4F0F-890D-EAC638BC5F8C', 'D20EAAF1-91B5-4814-867F-5B897BA7FF3A', '4630010960153', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC495B9B-05ED-4870-BEFB-F2602258DA6F', '952976EE-6B3B-40CA-8F17-0C3DC538B7D0', '4630010960160', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8032D3ED-49E6-40DC-81B8-6AB16E89F93F', 'B8136726-DD39-479F-AD0A-AC60C8B2BEFC', '4630010960177', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52358235-89FD-45D8-BCD1-82BEDFC0BA98', 'CF2E2CC0-2E70-441D-9847-D37E425C3784', '4630010960184', '  // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F116EE9-1D94-40B4-9D20-3EFD11ECED6F', 'DBAA9FDF-1AF2-44E0-8E96-F5C14076AC06', '4630010960191', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('899C7747-D510-4DEA-8A71-88462625D56B', '24BFE81D-8F66-4AA8-8E0D-73C06A1D2D5E', '4630010960221', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('128F0EEC-B5E2-49A1-8854-F3F261DC1063', '4C9C1B3B-8E25-4F21-9B4F-C7979CD7DE1D', '4630010960290', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CC43C49-EEF6-4FC0-8963-AC77A731D4E2', 'D89004A1-33CF-4D05-BE71-35B88812CB20', '4630010960313', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F7CA881-6AAB-47F5-A916-DA29ECD3E6BB', '34831609-B72E-496D-B9A6-BFE8A67A05CB', '4630010960320', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('051E94F6-636B-46A5-A159-4420FE5DEB7E', '5F4BD133-E84F-4BE8-921B-6812771D33EC', '4630010960344', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83DC69A4-720D-4894-9802-0B1E73FEC4E1', 'D434F50A-FE90-4FEF-8C74-BCD39BB79740', '4630010960368', '   15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BFC4B6B-6120-4925-A980-DF50AD06E3B8', 'B5E2EDDE-E270-4CAB-80E0-335C65B6ADC7', '4630010960375', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77D48D02-F3A4-455B-8E89-FACD26A1027E', 'A11EFDA7-9BCD-4AAB-AEA2-32B30CF2BA47', '4630010960399', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E042277-0DAB-4EAE-A5D2-7EC66581CD02', 'ABA87615-07A2-4C15-B6E1-7462890C0457', '4630010960405', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0D4567C-B4F9-46A7-BEBB-EC5FEA7B434C', 'CEFDE10B-5F66-4CD3-AE0E-ACF9D5BCEC1B', '4630010960429', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A18F328A-60E0-49BB-B63F-8E0908F6F4D8', 'F2AD423D-368D-4AFC-A977-4DCA5FF1171A', '4630010960436', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F795F6E-1102-4227-B435-A05BA4F37556', 'BFA776E1-E4AF-4789-883A-A0D614415118', '4630011120051', '  3 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('429689B4-1FC7-49B6-9D70-6C187CE64D7D', '49790B98-328C-42EB-944C-2C0B0B8E0437', '4630011120075', '  + // 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA658707-A73D-4473-9548-C3F1CA527076', '83F07588-8ADE-4AAF-AC47-E34DAFECECB6', '4630011120211', '  3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F6EEB03-E26A-4421-8235-0CF4A3C5DEAC', '83F07588-8ADE-4AAF-AC47-E34DAFECECB6', '4630011120242', '  3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF399C3C-F982-43B1-8F2A-9D93E8B9EB17', 'A5F824E6-502F-484C-BE59-0491684D434E', '4630011650039', ' 25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3D9E0C4-2C7C-48FA-AEA5-B3F935905DD2', '94D4C373-D780-4CCE-A1B7-EDB6C68E5BEE', '4630011650084', '  0,32  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFD1FDD2-5E7E-4E20-9AAB-2A25E0F6941C', 'BF89EEE2-289B-4320-BD21-D0CBA3242A46', '4630011650091', '  320  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7F54A45-856A-4B56-9292-A08040AD052A', '24E5AE47-C73D-406E-B713-60F19EE69F99', '4630011650114', ' 25  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5326D38-AA1B-4102-BE50-FB21EACC420C', '8B840FB5-F2C2-41E0-A35A-02C2BF343CAB', '4630011650121', ' 75  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C54DC405-4399-4803-8518-2D41F44F671C', '66C9A8C2-FCCF-4E6E-8C32-2420E84DA21D', '4630011650145', '  10000   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15C8B291-BBEF-4AC3-9C4F-157B8863F9C5', '50011260-942C-4DC8-ABAD-1FC7A576826C', '4630011650176', '  320  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE79B9D0-D6AA-4FC2-9D41-F3415B6F842B', '286B414E-72A3-417A-BF80-13454F90EEB2', '4630012030038', '   /    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('766634F5-54DE-4BA1-91B7-2E7AFC8BF755', 'B61A74FF-DC3C-4ADA-8CF0-0FC8649289ED', '4630012030045', '   /    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E25C2F7C-67E8-4125-A5FB-D8771837D007', '031D3FAE-3ECC-48D4-97DE-B4EB87A9C0E6', '4630012460798', '  100//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFAB375B-3B1D-4C8C-B230-46B39A84EFEE', '6635CA90-EADC-4604-96F6-BBD968BA72F3', '4630012460842', '   600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C38B6141-0FA4-4B3B-9E95-25EC1867119C', '8C3F5DA8-AAAE-4823-B0F9-236F55E39CC4', '4630012460873', '  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4F569C2-38E2-4B03-B94A-AAA823E01435', '1742BF5C-D05E-44D8-ACEB-37CE02D742D2', '4630012463461', '    . /.  .6 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9222451-360C-45C7-85BA-158C905BA8BB', 'D97218FA-61E4-4271-8DD3-473B6CF4E350', '4630012463492', '    . /.  .7,5 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FDF52D8-C117-4785-8785-90A7A43E2F82', 'ED7BD27B-BB20-4756-A273-57A9E55D7619', '4630012463508', '    / - 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBB01855-7F7E-4C22-9A65-1DCBCF8DB4AB', '7031B602-4649-4456-AA56-600AE8500862', '4630012463515', '    . /.  .8,5 /', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A73D4A1F-51DA-4616-8E2C-5C1DAD6CAEBE', 'C8335160-84DD-4AF2-A19B-ACFAB0041CA5', '4630015110041', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C943C9FE-2B9D-4C94-97A4-9C62C0661695', 'FBCD1B38-6F47-4F68-AD5E-EE276BD7FFAA', '4630015110058', ' 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51B9FB0F-8596-48E1-9360-E1B3C8C16ACB', 'C75645A4-CEBF-4B43-BB67-D93652D05D88', '4630015110126', ' 50  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F5CF233-A3E3-4288-976E-35B3D0AD3521', 'F7B33774-9759-4851-B09E-43B78732F1AE', '4630015110133', ' 150  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D74495CC-C308-4F9D-AB43-34C63719249C', 'F1E42041-25FA-4432-A81D-178FE2A3E12C', '4630015110164', ' 2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('586F367F-C33F-443A-9ABB-DD7129E22F27', '529E9562-535D-4C9F-BA45-59B5558F08F0', '4630015110171', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92A0D48A-73AE-4E73-81FA-E6D7F03246FE', 'DDBA14DD-4B68-4726-9E19-9656CBD01F17', '4630015110188', ' 5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93A152DF-4A54-4D6A-9E85-5C8B87895226', '969674FA-50B3-4E4A-BF70-A742501A1A42', '4630015110195', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E84B4AE-5C47-4BF9-B67A-4E14DFA37B1B', 'F9151039-29A5-4252-9019-77A00C41A8F4', '4630015180099', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33C87982-17A4-427D-AC8E-A9FFD9822F8D', '162E67DA-7D72-4138-A16F-6CF883DECC6F', '4630015180112', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FECB636-0B5C-4581-84C0-4D3E0573CA79', '68F08C31-60FD-484B-8CE7-BFB8D740D9A0', '4630016120025', ' 500  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCEE968B-0BCA-468F-9A0F-92DB1F81269C', 'DDC57E8D-6214-4276-A525-E12C0E9DC724', '4630016120049', ' 0,25  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6933088D-F3CA-49DA-9516-507938095EC8', '513E93F2-B3B0-41B8-B2A1-5199338A56A3', '4630016120070', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E80D7202-C715-4C68-B90B-04B6439A4F9F', 'AB402AFB-E076-4601-A26B-313E187700A9', '4630016120117', ' 500  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FD1DC62-4320-410A-AAD1-3CD5689BB7B8', '231AEB85-FE6B-455E-B485-9C0A8C7D638D', '4630016120124', ' 0,25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA858FAF-B255-4891-A56F-EFA9B2EEA60B', '353D21A8-D3AC-4BF6-9AF8-988745D28C3C', '4630016120162', '  300  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F036950-F855-4135-9607-4C4B5A04119B', '58B9CBEB-A264-48CF-AD44-F99A6A220695', '4630016120179', ' 0,02  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F791A55-D308-4C2E-908C-CF8F36509FF3', 'C5F80A1C-256E-4BDF-9454-E9EB7CF9D775', '4630016120186', ' 300  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9A9961A-DE22-4230-84DE-7A1DF66CFDBB', 'F94CA742-6EDF-491A-9A79-7EB0143FE318', '4630016120216', ' 295  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50E5C935-231A-4E78-9452-D8E395F418EB', '270E0456-93A6-4920-AE9A-84771E944A71', '4630016120230', ' 500  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AA9D2C5-12CB-403F-B01C-FA20D4CB899D', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '4630017130603', ' 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F33903D7-3ADB-4A33-BC07-638FA3956A88', '65847902-E9E4-4980-9CF4-4DF56C2D9D33', '4630017310029', '   - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('515FE50D-46FE-4C26-98DB-19CF1EF95CB9', '82F6F05E-D613-4C21-B4E6-4479AD558A19', '4630017310067', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDC1921F-C429-47C4-BBE6-156AA0752EBA', 'F4C7D4A3-9F05-47E2-9645-F855BE358E23', '4630017310111', '  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CF8E796-53D2-43B2-B51E-DEF12BAB2F7D', 'E26D8207-4C25-463C-B6B7-7CB3D009D673', '4630017310159', '     6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F78671E-E8DC-49D4-B910-B73DE0BD24CF', '40D570DC-1EF9-468A-89A8-43314E4392A3', '4630017310241', ' +   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B968D5E4-F401-4F02-B6C4-F47C945A8AC7', 'ADF857D3-1EFE-4E7F-B7D8-C27242FA2327', '4630017310319', ' 0,5  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44644794-1B69-4F1C-95E8-27F4D3B5D418', '9CFBD287-1905-419F-A89B-53132F6B8A1B', '4630017310364', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4577D4A-9BBF-4200-912F-158260D7E5E0', '9CFBD287-1905-419F-A89B-53132F6B8A1B', '4630017310371', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86D98A82-799C-4785-B353-2008DE3C6B75', 'E8473A2C-8458-4CDE-9A4C-0BF8D6DF6596', '4630030920175', ' ()  500  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3AB0806-3972-4750-B077-FF39AD1C3634', '2AAED9B2-5751-44FD-BC70-5F686A688264', '4631111106143', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F575FEE-A2B0-4EC6-853A-00D9AF8AD212', '6DD479E8-E159-410B-954E-8CC5A30652C6', '4631136004219', ' - / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F9C3772-ABBD-4131-B0E9-4927D08069B7', 'D92E5BB6-7584-4A32-9861-EA0DB6C5744A', '4631136222613', '    /     4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F1E8638-C3C4-4657-ADDB-BC3ABF2C09A1', '40DE0660-7302-4BE3-96C0-58A8C4C00EEE', '4631136372851', '  /    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AECCFD5D-9C32-49DF-883A-CE37349F09EA', '3431CF21-FEFB-4740-872F-9D3D984054A2', '4631136460930', '    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A4BEC08-CABB-49D1-ABE4-CC091A77D4A3', 'F18DCF5F-17A0-43E7-A2F1-BCD8CB213962', '4631136460954', '    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A587E79E-78E3-43B3-9DCE-3FE9E4955E66', '31CA7EDE-CBE7-4FE1-86CA-C2A0935AE0A8', '4631136460985', '     2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9D612A5-B600-4B73-90D4-4D7CFD5EEEDA', '90CFC6A7-5404-4D30-A7A5-9C73D535F3A6', '4631136742760', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('556625AD-10B7-4831-B391-0BF30C41E5A8', '22AC5BF6-D2A2-40BE-8136-A041F8121DB4', '4631136742777', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62A546B7-9619-43EE-A548-E3A070B80803', 'F920F13E-E9E2-4DB5-99B9-07E2EBD7B5D2', '4631136742784', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7704023-E4BA-4B21-BAEC-D82512EA1ED6', '833B4E5A-2B77-45F5-B859-D942668E278C', '4631136742791', '- Lubrima   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B57CCE3F-9C75-4C88-8034-76C627B694B8', '5B0DD564-822E-46FE-A653-FC2B3B38F90E', '4631136742814', ' stimulate  - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E121E6EF-E90A-42E0-A5B6-474DE13F5795', '75E0F1F9-98F8-468C-8324-F936A2235B74', '4631136742838', ' protect  - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2765C9B-18F1-40C4-8409-27D890158E43', '0D341650-1426-41FC-AA77-FBB4E5578CC3', '4631136742852', '- Lubrima  long love 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9774E892-159F-421D-848A-62CB49D7F00C', '52312D0E-3E88-4A20-A33F-E8B4D9910BE9', '4631139708275', ' /    /   5 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A832F627-2853-4DE2-9FC9-B6B19838E467', '95F643DC-5125-42CC-A3FA-47BE51CEA162', '4631140314823', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F618BA99-503C-49DE-AD42-F11AF4C3913D', 'F3BC84E9-6A8F-4916-9DFF-7D743587985E', '4634444036163', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED715071-B5E0-4B3D-A0C6-4278515DCBE0', 'B73441F1-DDED-43CC-8F37-B7EC448D7CDE', '4634444070822', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CADFF749-F34A-4096-867B-545805BBB63F', '247CF6BE-5B04-422A-B636-79F0AE0C3652', '4640000900403', ' 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('852086D4-219D-401D-8F2C-0A4BA60A1A36', 'C9FD621A-0A8A-4BF9-B655-87163A8F3A38', '4640000900434', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9E11496-26CC-46AD-B2B5-A9123E049F4A', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4640000900465', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01983FE9-F0EB-4169-90B1-D41BEE8A87E7', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4640000900854', ' 510 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A9EAD9A-AA72-4083-8A21-718F3659EECB', '1AF09E02-4A11-4981-8E07-41E726FEF2CD', '4640000900861', '  714  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1D26580-2508-4641-907C-1BAD056F129F', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4640000900892', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BCD5ED7-A1C8-49D1-A45B-26F14DA94C66', 'C9FD621A-0A8A-4BF9-B655-87163A8F3A38', '4640000900908', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04CCCA6D-4BEA-47EB-AA2A-664D6CC5BD85', 'CB06A0F7-EC68-49D2-BA4B-29F8AA329F7A', '4640000900915', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('520CD5A2-9797-4D8A-AECA-ED5DC4A6ECB9', 'F47E8F3C-117C-41C9-A4D4-A653CF68E83A', '4640000900922', ' 1614  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C09F771-02B4-4AD3-ADA3-E9273AADA1E5', 'CBF17615-B09D-46DC-9AB8-35AEF9B9D8DC', '4640000900939', '    help 4529 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BED3825-EDDE-47CA-AAC5-613EF4C34A38', '7FF5C5A4-0702-4523-A630-B66CB1CE9364', '4640000900960', ' 50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10916F41-9C1B-4AFC-92FA-E7EB482185AE', '239C6F47-EC52-45B9-8A6F-B2C714D1AC5D', '4640000900977', ' help   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C325346F-6957-4FD8-9B60-FE22AF3F872B', 'B3241352-5C12-47FA-8F8E-359187E8554C', '4640000902476', ' 710 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A6D168B-5EFF-48CA-92D0-766CA2E4F044', 'C7358577-D03F-4AA4-A319-BA3C9159FEEB', '4640000902483', ' 714  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D1A244F-B199-4896-8127-F583A0DF0C16', '1159736E-E7AE-4A69-84E5-EA38F2D92F73', '4640000902544', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09A7EEB8-53EC-4ADB-99D9-5D42C06D1102', '624CD9B7-DA51-4BA0-9EB7-A456FA877605', '4640000902551', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4F28C9B-2EC2-45DB-A9BD-F773763F75F3', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4640000902568', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B032F54-A352-4463-8B34-3BCAFAECBF5C', 'C9FD621A-0A8A-4BF9-B655-87163A8F3A38', '4640000902575', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D91283A0-9049-45BD-8D33-8700BD7CB234', 'CB06A0F7-EC68-49D2-BA4B-29F8AA329F7A', '4640000902582', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6109F96B-C04A-473A-A028-9686189FDA21', 'F47E8F3C-117C-41C9-A4D4-A653CF68E83A', '4640000902599', ' 1614  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('802D3C78-4711-453B-AF41-940D2B9DD30A', 'F03D0789-4783-4AA9-A4E5-46B4BFB06FDA', '4640000902605', '  1614  2-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('352B7D1B-7768-4DEC-984E-76E17698125A', 'D95B56EC-59D8-4B20-87E5-7F2A3E47B53F', '4640000902629', 'Evers life  /   44  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43D8191C-FABE-4F2F-90BC-9E4536D0BB3A', '927831E8-F07F-4689-B555-97E05A88D102', '4640000903350', '  // 915   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41A12BE3-D3EF-4B23-AEBB-6A693AB5BA5F', '071CF47E-E0E6-48B5-81A7-0606F7BBE0F7', '4640000903411', '   55 .  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD48B9A0-AB80-4871-BCE0-74BA44B68322', 'C7453CE4-DAA9-4EF2-9162-E0F8CD11B09E', '4640000903459', '   86 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17BA661C-E949-48A3-B286-794B674FF726', '3FD45AAD-5E68-41EA-BCC8-EE1932C90FD2', '4640000903480', '   109 10//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10B6D50D-EE8B-47F2-BC01-D78A61200727', 'C7453CE4-DAA9-4EF2-9162-E0F8CD11B09E', '4640000903596', '   86 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03A4329C-66B7-41AE-ABD3-ACF009B0BA70', 'D254606D-B238-4835-9639-8F7C0691A998', '4640000903602', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3143FB6F-9752-4F3E-8259-3DEB94471C90', '46A16F21-D9F4-402A-B7A2-C4107920A6BB', '4640000904203', '   5  5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B1E3F04-6429-4409-A8F6-2ED68325A597', '997A8A53-448F-4EAC-9556-0390A44C4002', '4640000904210', '     12  55 / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('372C565B-FFB2-4573-846F-5C4FFA06095C', '9B357661-BDD3-472C-BD42-8C1F1C491D3F', '4640000904227', '   7,5 7,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B59BE668-BE87-4BAF-A34B-939B0BA63CE1', 'E5418B2F-2B55-4252-83BA-63BAF9A51136', '4640000904234', '  7,5*7,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75A3CD5D-3B86-43B7-BC42-25872ABBF069', 'D68A5E2B-B228-4E6E-BE26-1BE4EE92293B', '4640000904241', '     8  1010 / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C78FCE70-8699-45A5-A2D7-053263DB5CFA', '8EC496F8-8B17-4DEC-A92B-283584E62ABA', '4640000904258', '   10  10   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7B5CCAB-4A84-44BA-B494-4C9CC25E4032', 'C915E337-0789-4055-8702-BFE1D439E4BA', '4640000904418', ' 1,5 8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71921D67-50B6-4C69-8401-63B64F3C98ED', 'C868ABCC-5B43-49FA-98C2-04A54CF0D9FF', '4640000904449', ' 85   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('807318AD-F249-4157-B047-535C3E968051', '35635850-7F74-4971-BB30-BE60F02BE731', '4640000904562', '  38 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0391D33E-FC59-43CB-9680-11273F2813AC', '628327F7-7DBA-4CEB-9D4D-35F91C1EA689', '4640000904692', '   1,7/6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('579B4789-907E-4654-8B5C-1F89BB63B12E', 'B04D1BD6-4520-4AE5-84AC-6C11727A0390', '4640000904708', '   1,7/4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E040DEA7-2FFF-4F86-A052-7CF927EC86CC', '0E5DE4E8-B55E-4F93-8777-7E5BE7E08B37', '4640000904791', ' 3-    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A71CC0DF-66F8-4A25-8B2C-58EB7532506F', '99FB231F-7E57-40A9-BE3C-1AF81695E980', '4640000905316', ' / 10,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49167CA2-CDED-4FDB-A3C4-C1100DD772DE', 'D0085F69-CA7A-4E52-B84C-AE5330C47F3E', '4640001380020', '  0,1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42AE08F4-CA12-40F0-B3D4-E9841F7E2957', '2E7A1531-1A6D-4FAB-AF69-CDAF17FEA602', '4640001380099', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E325DBF0-3CA4-426B-8BA5-B944007456E2', 'CF5AC6CE-CE77-4481-9101-D85A68FB9EAB', '4640001380822', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2CD3E77-2AC9-4D87-A744-D5B399EF4C49', '6BEBAF0A-3CBB-477D-B34A-A1169CBC41B1', '4640001380839', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0124EDEB-9DE2-4769-8E70-8BAA8BF5BC25', '2FCA5F74-3D01-44BF-BAB6-82C580133309', '4640001380846', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84B2E1BA-195A-4B65-979F-B5735F24BE1A', 'F929A27F-04EB-4310-84A0-346D77C371EC', '4640001380877', '    / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CB2A2A8-4808-4E89-9375-B178C86D208B', '2595DE79-961B-4B3F-977F-05F4BF57C1F6', '4640001380884', '  50   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('503EA6BB-276C-4945-83A0-76683AD99481', 'EF00CC56-5289-497B-B616-EE5F4E9279F9', '4640001380907', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF7BE0EF-64E0-49CD-AF86-5B73E5E09615', '22CA0CB1-229D-473C-B7F0-14901F4C6E65', '4640001380914', '  25  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ECEA214-FD59-4FC7-9B75-5494F74BBA3F', '7D0C86D3-027E-421A-B85B-A6B0D036D555', '4640001380969', ' 0,2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('610DA7BB-34ED-4AD2-B33B-0C6C1B5DF04B', '4199A4B2-4597-4A4F-ADD7-B1DAF4C6FE46', '4640001380976', ' 0,2  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6500E2FB-1DDB-47E3-BB8D-D0E1FC8942FB', 'D1E429A8-95ED-4DEA-AA6C-A1C670368A59', '4640001381003', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64E48341-417E-4D71-B82D-C56EFDCB7B9F', 'E77D9044-DACD-4349-B2A9-D9AD44F5D360', '4640001381065', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE800C7E-C318-4644-9A7D-6D2BE161F7D5', 'F9F4EEEC-463D-447C-BADF-CF84ABAE7311', '4640001381164', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AF829FE-D11B-4A9C-B225-356063EC78A0', '95286DBF-421D-422B-8B42-315AA34BAEE1', '4640001381225', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91A4628B-BD3C-4F8F-A90F-CC14779CD767', 'F9BD7430-31E2-4F1C-ACE6-A319D067C10C', '4640001381232', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1562647C-FDE8-4538-BAF3-A954444D6D0F', '1F3798ED-5707-4119-B19F-475C3EF4D999', '4640001381263', ' 1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6E55D02-99D6-441F-AE12-7C9D1FF28001', '1EF4F0B4-FBA3-4E8D-B5B1-22F21B2029B8', '4640001381270', '   100,0/-/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBFA7928-6B98-42DD-B7D2-685349871DBD', '8E820F25-2AC3-4898-8DC1-B21049D99037', '4640001381409', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCC31C09-1483-40EE-8DC6-EA091F1F25BF', '50900AFC-E41D-4C59-8C5F-915D7B3DA55E', '4640001381423', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CB0C6E1-BBEC-4C1F-8CFE-1A6FAF2110B5', 'BC4522E2-AE70-40D8-AE20-F09A7882D039', '4640001381454', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E94162FA-B595-4267-AD00-0690C77AD0A1', 'A4F67EF9-DEB1-477F-A131-B6600E4D66CD', '4640001381478', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C42F03D-8D76-4550-A1F2-4B25EFDEAACC', '02B17AAC-6951-4A07-8DF3-6C465E656C9C', '4640001381485', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9073C9A0-9C2B-4A8C-93D0-BE4A8128FCC0', '9228CCF2-416C-42B8-B92A-834A3DEFCCE3', '4640001381515', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BC25AD1-C5AC-45CF-A32C-18B5177A2F34', 'DB6689FB-8DEC-46A9-8D81-7C8B422B7255', '4640001381522', ' 1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('322D5483-3E6E-45B0-829B-CBE04AD3422C', 'FE63EE55-3239-42F9-B0B8-5F8334D54713', '4640001381539', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A6520D6-D970-47DF-A08F-07B1585439F2', '4FFB5E70-3BA2-4EF6-BE65-B4C83DA05B57', '4640001381577', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E79978A6-460E-4683-AB55-41C35397BDDA', '74FB08D8-5440-40EF-98CE-FF03BFA6E55C', '4640001381584', '     3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FA6A8A1-4ACE-41CC-BF2E-A50A16AC1F97', 'F1EFBC52-FAA8-4799-A5F2-2E53EE64E836', '4640001381607', '     3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4C9F025-370E-4EE9-A5D6-31C0A7BBCFBA', '8C9E5444-FC2C-4E52-ABC2-5DA883D103AE', '4640001381614', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB080DCC-DE8D-42E8-AE88-6E17DC07F432', 'DBC66F76-C50C-41F4-A8BA-8C7123AB96EF', '4640001381621', '     3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98B494D2-8649-4683-8F83-416654ACBD7A', '1D18A5E9-36BE-4C6C-99DB-DF86245ECB84', '4640001381638', '  3    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DCF00D6-EFE6-45BB-AACF-D838F58C3065', '90687693-B782-4706-B42C-C555A52602E1', '4640001381652', '    3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EDE5DC1-A898-4671-86F4-0B90BAB4AD8B', 'CDA61143-7051-4E21-8B44-2AA9BC1CB494', '4640001381676', '   3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1250331F-1637-46B4-980C-93F7EBC8472A', '1C549674-6BEE-493B-916C-79E2B3F9C1BC', '4640001381775', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C19EED73-1157-44CD-A775-D231ABD367C7', '4980F54F-1852-413B-ACBF-FE0601EADBA9', '4640001381874', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F945091-0B85-4E7F-B2ED-59B3D7562C0B', 'DB2FC475-34C1-4270-A042-09191304A8D1', '4640001381911', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A27B2EF-14E5-43ED-A4C4-966CB5C63EF6', 'F570D7E7-70F0-4E99-886E-0C6BEE971E91', '4640001381980', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('149FEDE4-CEA9-4C57-944D-F991B831A951', '09829650-DC82-44C8-8600-19C1EB07A17D', '4640001382185', '   250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA0D77D7-E6D3-48DF-99EC-A5C542DDCC46', 'C660A897-38D1-4548-B370-28DA41096FB7', '4640001382192', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BDB3C91-8414-49E6-8172-803BD50DDB34', 'F283BC1A-BEAA-4A50-846C-DA98B6BE7B36', '4640001382208', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B16908A0-8F4C-463B-A881-5E46CA63C69C', '428FDDF6-8D35-4156-B769-630C5A1EB141', '4640001382253', '  0,2  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F7C0FE8-85F9-485C-B047-13B483C9952D', '5ECDABC4-7D8E-4413-A825-B7339B19B1DF', '4640001382314', ' 6   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F695E51F-94DB-451A-8D6D-C117BB82015B', '82A59A4A-0357-4B44-AC8F-E4B1C94EF0A8', '4640001382499', '- 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('746B60B3-CAD5-4822-AFCE-5391EEB49D28', '447D101B-AEED-42E6-8957-01ED1ABBD257', '4640001382635', '  500  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B776B35-6DF6-4837-8C6A-98EEA8EA8B53', '46A1CD9A-2E0C-4FFF-9FFA-D02229AC2D04', '4640001382703', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A0040AA-4385-4574-9B0A-8CC2F0C46E0B', '087F260C-7E52-4A43-AEF9-9B3E164A0F70', '4640001382710', '  50   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C608DF0F-B732-46E5-B0CF-AE8013D652BB', 'B08C7BB9-BFBA-4A24-9082-84EBF1C38FED', '4640001382727', '  3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7F08B6B-7311-40B1-BCCE-8176063A0A0E', '89D2CF4E-7B8B-4A1D-97A6-11134441803F', '4640001382734', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('834AFF12-FD73-4E27-B63E-0C488ECC8562', '8E8851B0-18B5-41EB-AAB5-74B2230BE39B', '4640001382741', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('908AF4E1-9D55-48AD-919D-99A569012440', 'C9831C21-0D7F-43FF-9E92-5322D124EEA6', '4640001382758', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FF08DC8-2627-42E3-A65C-0A6CF1EFB7B4', 'E6E94C7E-32E6-4A3D-8B96-907EB5D85B23', '4640001382789', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('495A09D1-4266-4FC4-96EF-2422A386787A', 'FEFDA53A-C680-4B56-9C0D-E4AD59F1E745', '4640001382819', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46960899-B846-400F-AA85-E8B663DA89FB', 'CDA61143-7051-4E21-8B44-2AA9BC1CB494', '4640001382826', '   3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7584EA1-5533-45E3-9635-9078FE360408', 'FDE5F618-69DA-4E12-9E13-54C683594E4E', '4640001382833', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7940B918-4353-4582-8321-91E81552656B', 'FE60B9C4-3EAE-4D76-8900-BE9E3C281D50', '4640001382871', '     / 16/ 3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79BCE8AD-E934-4C6E-A556-D0A7C43D73B5', '4AF7840D-BF7C-4EF1-BFF3-2DB7D4970A73', '4640001382888', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AA6F2EE-BC49-41A3-B8CC-81EE68431A42', '8F14F430-9804-4335-9379-BEC55E31634C', '4640001382963', ' - 500  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0749ECAA-29CD-4C0C-BBB7-ED88C925EFD1', '419AD2A7-6B3A-40A4-B2F9-0DF70359052D', '4640001811647', '    30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E87A307E-209B-4BA6-8AFC-F1D29573F4AC', '7B006A4D-8D1E-4032-AB0C-0EDF78077DA5', '4640001811852', '   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC41C11E-C353-4164-9013-06AB3ED92971', '17649B81-E4FD-4C50-B015-EC1DA93E5EFB', '4640001812040', '    / // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0BBC9D2-E2C9-4338-83D0-31C8E23A5E99', '0459D4FE-70FA-48EB-A95F-34F0579E459E', '4640001812798', ' botavikos   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EEF68E2-F3A4-410A-8F7F-093B8E4E86DB', 'D7464EF0-6F4D-44E4-B878-5D9B31B6A649', '4640001812828', ' botavikos   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5438393-9DA8-4580-B450-4A04BB1DB0F1', '1B8A3DE7-1D6E-4226-ABF2-38F9A21962F5', '4640003260337', '     30/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88F15CFB-2440-411A-A1A1-B96F62E6B610', '0BC587C5-615E-418D-A6C5-DE27E3225FE4', '4640003260511', ' 1 20/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D975333D-31FB-4169-9B0F-9E611BA81F3F', '5B1715FE-BBB5-440A-AFAF-8A9BC525A676', '4640003260559', '   /./ 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B07A886-8C22-41CF-966E-BEC89533B8B5', 'B6F22399-B226-4A61-803A-32D88521B5BF', '4640003260573', '   1  /./ 1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81203F00-E4A6-4ACB-973C-B94815D649E4', '114680C2-30F3-4883-BB27-B212E73561CA', '4640003260634', '    /// 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11B7347E-C825-4495-97AC-D0AD007EF239', 'BE1EE691-B666-4265-8C26-DC055A768A1E', '4640003260658', '  /./ 20/ 1,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36C20D86-5B52-4EC3-A870-94792574185C', 'F184220D-1106-4A4A-81D2-243177EBD715', '4640003260719', '   7  //./ 1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB99EF93-EAE8-4541-8143-2CF9E954BD3E', 'C0570254-41B0-41FF-922E-AA98C67B36DC', '4640003260733', '   8  /./ 1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA4014EF-1F08-4529-BC07-EE6CF6C57CDA', 'C7E167DF-34F7-43F8-9A35-4E93CF3E7446', '4640003260757', '   9  / / 1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0CBBD26-20DF-495E-856F-2451F8BC8924', 'BCC336D1-4B08-4250-AA9A-65C5D3C9E1C2', '4640003260771', '   10  /// 2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B33C2227-5D71-4714-934D-6AB3CD9C4CD4', '60BC0478-E12B-416C-8140-366079958883', '4640003260795', '   // 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E0EE3D8-DCD6-4068-8FB4-013478BCE57A', 'BA8CBEA6-8A0D-4EE2-9C6A-C5BAFAA400AF', '4640003261211', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62551604-349D-4BA4-A285-D91B77B3C4CF', '80E423B6-0FA0-4CFC-9B8B-34FE60A7018F', '4640003261235', '        20/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FCDCA56-886A-4C92-9C13-1F8D896E7E3D', '9E275384-EE57-433A-A606-30D071FB9FEB', '4640003261259', '      20/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D5F19FE-7D46-4AC5-9F1B-CE1879DA768C', 'DB0CCCF8-3C7E-4B56-862D-955AE6AD02CD', '4640003261273', '      / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F092534-1101-4CA6-8117-F77C5FD9A60E', 'DB0CCCF8-3C7E-4B56-862D-955AE6AD02CD', '4640003261280', '      / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('563BEACA-0765-4FA8-9CA3-00D5BA86C219', 'A4C59588-5A63-401F-8073-99B06CCD30DB', '4640003261297', '    / 2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97101577-C4F5-4DEE-BBA3-27D3CCB2498C', 'A2775CC9-B4CB-43B0-AF7C-4C87AB5D8C0F', '4640003261310', '     2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3109541-A3CF-433A-A1A6-7E28BE31CC38', '80BDCE31-2919-438D-B021-99369841944D', '4640003261327', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BE2A45F-B385-4782-A257-7E89555AC03E', '29FA58DE-5199-4657-8953-27846BEB6A8F', '4640003261334', '     / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0A30697-B5D7-4A6A-8F9A-F52BA30C2A33', 'E54763D7-6A63-4C37-9F40-3029D2C2FCC8', '4640003261358', '     30 / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AAA1D41-34AA-4105-B636-E8FDCBF5C55F', '423A672D-617E-4C56-8ED8-E4766A6D1107', '4640005760026', '   1  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6B4487C-38A3-4C77-9852-E969E282F00F', '92062739-E0E9-4161-849E-3498C429E180', '4640005760088', ' 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A08E968-BB91-42DC-BC20-03D5BAC3D776', 'F1CE0542-1A45-49EC-8A14-CAD0E28F1153', '4640005760149', ' 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A08DBB2-2267-4A03-B118-49E1C39C3719', '495BC5DD-BD6C-4E95-BCF1-5168FAE23C93', '4640006090382', '   // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E619899-AF03-43A3-8739-0B3663CF4039', 'B76402B1-96B7-4012-BE29-F1F9B6A4A73B', '4640006090399', '   // 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17BC490D-3D3B-473D-A15C-C59F658AA70F', '02683F97-42EA-4682-BCD0-EF074EAFF78D', '4640006300252', '   44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B84913A-902B-4350-92F6-A8FEC3AD1A35', 'A61C9BD2-FF10-4525-B894-5C9F45D52003', '4640006300320', '    / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63C44284-0CF2-4514-9FEE-B91AB04F4E0C', '32467903-B3B4-4810-9940-1358E91355FA', '4640006300467', '  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB98FB60-C9F9-41D0-9192-3D1AACF4C30E', '5FB2FC41-4AE2-45E1-8B12-890D9E47EEDC', '4640006300498', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B77C439A-01E6-426B-B67D-81384D4C6241', 'E311E9A5-130E-4D97-AA52-6E84D4C0F728', '4640006300559', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D43EE5FC-B33C-4638-9D90-287BB84DFA13', 'F51BA706-F5CA-45B3-A8DA-27E217594322', '4640006300627', '   -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07891C84-F0F0-4753-81A5-DEE941E1EC3B', 'F2B8AC20-937D-448A-B420-530EE1880FD8', '4640006300733', '  44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3DA556F-9A5F-4954-AAA5-5C695F444F21', 'CA938BAD-6996-4B7C-B4DA-86D1A6DA2C39', '4640006300863', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCC3852E-F8F7-4A40-B5E5-55ED972A4C0E', '15454852-FD45-47DA-A8E6-E241AC16E1CA', '4640006300931', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8FEB2AF-7BC4-47EB-8CD6-AC504EEDF5F1', '18C9DF3C-74AC-463F-8801-EBBFBC55FAA6', '4640006301358', '   . /  / 20  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A233C4C-C014-45E7-BFC8-BBF2626F0613', 'B6F1A5EA-E5FA-4455-8291-8DEAC31D7973', '4640006301389', '   / -.. 20 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38B4914A-E5BD-4B91-A17E-34019D407655', '44E4FFD7-9AFB-41C8-B1D1-6D9A08AA0738', '4640006301396', '  - / /. // 20 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72D08C05-A034-4CBD-8887-80F5DF908B55', '3CBC8656-FBDF-459E-9D48-4C5F3866634C', '4640006301402', '  - /.. /// 20 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF813CF6-B3CB-43F1-9DEC-632E54E026F0', 'FD3C329A-D90C-4555-9812-2DC0A68A4CE8', '4640006301525', '  - - 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0325975E-38D7-4884-A6B0-8F6A5F019BD6', '68CC2C30-CBA7-4F6D-BEA6-17197ACAE98E', '4640006301587', '  - / 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C1BED4A-632F-4AAB-A096-575902E980E0', '9745C9EF-FD61-4151-80DF-EC39FF6FC853', '4640006301679', '   / .. /// 20 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82677C1F-2CA9-4835-B6C9-D880E2783083', 'D99E914E-15BD-41E3-A923-73BA3BF3D861', '4640006301716', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('076A7238-52DC-4F2E-97CD-2F79E9E9DA1F', 'B1EE9B5A-36E1-4002-B77C-4E0DBBDDEC20', '4640006302539', '     44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33476FBE-2E8D-4B03-B33E-85E9638DFC63', '9249C7F3-EA73-4A14-BB93-48DEDEDD877E', '4640006302546', '  44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D3ABF0C-22C8-4E39-9892-85B71E0FD26A', '88FAB1F3-60E5-460B-A52D-479DB9DADB8D', '4640006302553', '   - /,, / 44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B5E791D-3100-4CC8-86A9-07C5C14AB67F', '0A77DF46-15E8-4C67-A9EA-D2A2A48AC698', '4640006302577', ' ovisolio   /     70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C245F74F-E3A4-425B-BF8E-67524F7B88D3', '595948E0-08CC-4247-9090-B08A9E2B4818', '4640006302584', '   /  .  70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2872889A-449C-4EA1-B082-4F28FA7D3E84', 'C059BB4C-06CE-4DE5-BB53-A4EB2E297B78', '4640006302591', ' ovisolio   /   70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9732B31-32F3-481E-98D5-17405FB87373', 'FE5839A0-CAC5-4E5A-8636-2D84155DF818', '4640006302607', '   - / 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E73A4D0F-FDC1-486C-B927-565233E3ACAD', '5B235FEC-314C-41B5-9F18-DF4445592856', '4640006302614', '  - / 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48391D6A-FB15-4BB4-970C-C412E4895F25', '7871FF59-50DD-453D-A75E-CDBB23480CE0', '4640006302836', '- /    /  70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06CE141E-7AA0-4C2E-8AE9-9F8BB1DC4EBA', 'DBF35AC2-9EE9-46A8-8969-1F92F1C18C15', '4640006302843', '  - /    70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA5BD28B-B417-4BCB-951C-B404F27E0B89', '97C4A001-EEBF-4C82-9E42-1D76474705E1', '4640006302867', ' - / 44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBD1725F-B405-4C87-9FBF-231B97C33654', 'AFA2D914-104D-4263-ABBD-3429EFFAEBB4', '4640006302928', '    - /   // 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A24DA5D-5B8F-49A8-9FEE-FB44B6F9B3F4', '12571893-A6AE-4752-B7AF-8A0ABEC19A3C', '4640006303413', ' - . 44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E38E597-CD27-4531-895D-24A41F70BE56', '0C770F20-DD27-4781-8E55-CFFED8CE3809', '4640006304373', '        44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10254168-5F04-4B81-BA64-8E7FEB2776A9', '26DC9149-8044-4E1B-AA4E-3C707C56A9F3', '4640006304687', '     44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C64976F-129A-4D6E-8CE1-EAA2EAA207D7', '767884BD-986E-4CB9-8BDC-9B6DE8A92A83', '4640006304793', '   /  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77AF3019-769F-458A-A6E8-F7893D2DEB44', '212E2452-3B2A-407C-8DD5-E7EC61C88D19', '4640008530442', '  20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('201684F8-54FE-4E58-9559-648BFF261F9E', '34778FD9-2D79-4292-ABE7-9FEBE2B7749B', '4640008530541', ' 100  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5B32BD6-0EEB-4EBD-BEA0-10DE1F48CD59', '937EAED8-783E-4D49-A76D-680590AADE36', '4640009680023', '    -+ 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F94A5C9A-69F8-4FEE-9394-77AA1F4FF87C', '9E552681-7729-4B33-9B73-5ECDCC1B3816', '4640009710089', '   /       500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68211972-F6AE-409D-8CA8-86A6D897DDDB', '2DB94C9A-5B87-4E37-8B40-97D2CFF778A2', '4640011896641', 'Armed     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF9BDF1C-BFAE-44FE-B8ED-4ACF75C80911', 'C8E7A9C0-A873-4510-BB85-B423D432E0A0', '4640011898805', '     fs929l', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD69582A-1561-46FE-B578-CD353A97F60E', '57C2BC3B-3BB5-4687-8D58-4312C0FA896B', '4640013300177', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('527C192D-8B8E-4239-A3F6-9173C40971C3', '5F2B52D8-48BD-4C30-A836-F9CB15B43E50', '4640013350011', '   / 1 // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D88736F8-7941-4826-BFAB-047EEF66F312', '1E75C453-EBDB-406C-83EE-75291ECE32F4', '4640013350165', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73A56084-9A80-4604-BBA8-503F87F8A378', 'E0726248-195E-44B0-A38E-D4820FE684CC', '4640013350172', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('089D63E5-27C2-45EF-BBF5-5BC3EF40C6B3', '04956E78-9F7B-4456-965E-A2DD932BDD8E', '4640013550121', '13958/144/12 - "".  6 .,,  , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD83BA86-2790-4C5E-8232-D34DB350EF03', 'E8B63002-FB5F-4A5E-B4B4-F87C5A00B96A', '4640013550145', ' "".  6 .,,  , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('333DE007-8C83-4FAD-B97A-9926D562EFDF', '80B4610E-F2A6-4BF9-A13F-4F28AC58F3CC', '4640013550190', '    0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6FA36FB-8233-441A-AD2D-6C50E800738F', 'B74F6DE5-D591-4A49-A918-D41B424B0A09', '4640013550220', '  ., / 2 4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B2CF5CA-B2F7-4E2D-B1BC-DAE6A06F95D1', '2335D2B3-15FD-4916-9D0E-6376CAAD8604', '4640013550237', '- lubby just  . .    3./13967', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9D2A711-28B2-4F1A-AC28-A709E74C6E36', '948925B9-9478-40B6-BFF8-AA985D883474', '4640013550251', '      4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66584B7E-B7CD-4909-9490-3893CD65845B', '85EFD8D2-8759-452B-8EA9-69DF515506F9', '4640013550282', ' .  Just LUBBY "" 6+./13966/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AB55065-16D2-4D04-8F84-BE57AF6FEFBE', '8C20F957-75CD-434B-91E9-64766F25AF7D', '4640013550299', ' just     6./13972', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F09C3A7-D142-4F43-BC4E-FD80C1B978E1', '06E126AB-2BF5-48C4-9DCB-7603A6EAC70B', '4640013550435', '          6./14075', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAE98FCA-321D-4D79-809E-001A7C3C956B', '06FFE6AA-4D70-4F32-BC34-0B03C9510A28', '4640013550480', '14080/144/12  "-"., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('398385A1-BFA5-4EB7-BC3F-630D27B0B010', '23E0545D-1E84-460F-BE09-E589E0CD3D3B', '4640013551944', '   3+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EF099EA-05B8-44BE-8BC5-EB8D81139F4E', '7C022B20-159B-4A00-A3EE-E767F4E366F6', '4640013555454', '   ,  6+ 13652', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD5B0A78-7A66-48B4-BABE-AB0532E1BBB9', 'A3D28BCF-C5A1-4BF3-9D1B-999C242B4E5A', '4640013556833', '   "".  0 ., ,  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EADBFEB2-FA22-431F-B2FD-9287EB08F85D', 'B0DD05C5-2DC2-4698-9ECB-78BC04DA08B8', '4640013556840', '   "".  0 ., ,  , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('180F9730-C096-4C1E-BAC1-070D3DE2F617', '933910CE-F17F-4935-B317-683F778211C3', '4640013556901', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED1EAD57-AB6A-43A4-B388-080DDF1A525D', '0542491C-CF7F-4609-A333-BF9187EFD7A3', '4640013557045', '     14380', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53806D6B-1FD2-4BA4-9138-A1366E8AFB9F', '5BD34D3A-A9D1-4B2A-AB94-F0FFD4DC843D', '4640013557076', '   / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45E18B4A-45C4-4619-94FA-0900A30894B7', '7C2A4854-537E-4DC9-8D4D-22070C17CC6D', '4640013557083', ' " " .  6 ., 240 .   /15759/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99624194-077E-45CE-A432-4FF7FE46ED57', '6B056A34-2721-4062-92B0-9CD333A932A4', '4640013557090', '15760/144/12  "Mini Twist"  .  6 .,250 ., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE1F4A2C-6398-451B-B2C3-07AE4D6D11C6', 'E500F923-6FC0-4F07-BF1B-96781D16A4F9', '4640013557106', '15761/144/12    "  ".  4 .,', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0D2BFB2-BADF-4619-B2AF-421F2FC74D10', '439AE949-1F4C-4790-83C3-F5D7172234A4', '4640013557120', '   12+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E49E3BC-D6D0-41F6-9731-4A7951F0B64F', '7F0CC000-CA74-46F0-8782-861D4F1889B7', '4640013557236', ' /  4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE394AA4-321E-44E4-8829-A7075E7306C2', 'A6C6D548-A998-47AB-ACF5-3436BC6981F7', '4640013557298', '   "".  0 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('067B9471-0B91-46A5-9852-15807FC7B42A', 'E1C84DAD-4A37-4A8D-A8E1-811ABC56AF6B', '4640013557465', '     6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4ECD05D4-26D8-4D36-B853-8ADC8CD59967', 'B428B4E9-48D3-417F-A442-9AAF714A59EA', '4640013557588', ' 250 0+/ /16401/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('878C7D15-1495-48E0-8383-4DE957892E4C', 'DB1793F5-1145-442E-B1C3-8631BC66C83A', '4640013557687', '16429/144/12     ." .". 0 .,250.,PP,.,  .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46242AB7-EBEC-4125-B83C-5760CE2CDE99', '0F418610-D526-4DD3-8528-666AE4592E0B', '4640013557694', '      5./16430 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('060C78E3-B550-4446-A255-FF5C036A46A5', '93963C0B-0814-4AF0-99E7-C4377168F91C', '4640013557700', ' LUBBY 250      6./16431', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B6E7B96-EBA5-4C1F-AB85-DC795DBDBFD7', '6B99EE67-A076-4025-972D-DABEF71B6860', '4640013557991', '     0+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7167B050-7E8D-4F3C-9EF4-6A840A36621B', '067F8750-274C-4EC7-AB38-435C120F4020', '4640013558059', '16588/144/12    "  ".  0 ., 60 ., ,', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0767C598-D814-492B-B5A5-08245929530C', '35B0D0A4-FA50-4B87-AACB-F50C1045A786', '4640013558080', '16591/144/12   "".  6 .,  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6105B813-6DB7-4F99-9736-4F8F000F8149', '59DC9D00-5ED5-4849-BD65-CA94417F0EC1', '4640013558622', '  ??  4 ., eva16892/144/12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('279058FF-F57A-447A-A087-0D7AF9B82F85', '4945B86A-C4DC-4AF0-9043-B8467EA01157', '4640014200360', '  kids  6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF6A28AA-36A0-448F-AF09-E92A2212A216', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4640015938644', ' 510 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99D0DF46-FF0A-436A-82AD-755538324276', 'F35C3260-2ECD-4D49-ACCA-90C07698DAA9', '4640016740093', '       1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('939601C0-AE85-43FF-B740-321A50EC45C5', 'AD8DCE45-C8C3-4908-AB14-781FC7F95AD0', '4640016740765', './ 21 /.   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AEBC210-2BA0-4CA6-923F-FC6DFC156BD6', 'CAC61DBC-D3B7-4769-8853-0CB6D414A6E7', '4640016741052', '   / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17D5175C-B27D-4ADE-A9A2-A9BFA1374EE7', '442E9852-ACE1-4BC0-97E3-4814455D2778', '4640016741069', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54C619D3-512E-4734-9E9A-9E2575E74E65', 'CB2E4DAB-76AC-45D9-8086-BD27F0647A28', '4640016741083', ' //   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CD0CD57-F49C-43C7-BDBF-783C880E4656', '6F5C8970-3784-4D30-9DCF-8BCDC2D6380F', '4640016742257', '        1  80 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C563E79D-A8BA-4FEB-A1F2-D499616B19C2', '08120D2F-A238-4152-BF3E-86B9BB558652', '4640016742271', '  -     /  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A88F1CF3-1D32-433D-9907-E3555552F305', '1B18B8D9-4BF5-4E87-B1C8-6E4C95D74327', '4640016742561', '       60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6621A182-F9E0-424A-BE4D-5EB3A3349FD6', 'F04D0B2B-0EE3-4523-8A0F-9FCA10729871', '4640017330316', ' all inclusive    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('505F97A8-C429-40E5-A008-0E667C2460B1', 'BDCBC570-5A5C-476C-9AE0-F9641E939234', '4640017590178', '  500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36B41E68-54ED-4746-B22F-020F12688179', '1E8EDC71-92AE-4611-A884-941225B19F82', '4640017590185', '  750  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CE59BD3-4B78-470F-9DAC-4AE692975BE6', '96065772-6B65-452D-98E4-CB1C4C3E38DF', '4640017590192', '  750  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14D27A3C-0B1D-4D1B-9748-29203B848A8E', '472A955C-321B-4C47-B36F-CE67E62AE1E4', '4640017590246', ' 0,5 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6CF4760-70FA-46EE-B043-3A68DFC05F22', '287D379E-9F31-445F-A413-0C9DEAD8C39C', '4640017590260', ' 500 //.  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF60803F-DB6C-4910-A1D9-BBFE48D870B8', 'CA21280A-241D-45C3-ACF1-EA431A8098B2', '4640017590277', ' 850  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB952747-1283-4F6A-93DF-FC270829009C', '22060E6C-5DA1-41F4-9749-DCD9F5AF94FD', '4640017590291', ' 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA2BF3F3-06A7-42ED-86E4-182700484DB1', 'D9F6F81C-E612-4D27-9A64-57F0F56D913B', '4640017590307', ' 1 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E66ABEA2-6561-4789-B390-F808F91DC667', 'B845973D-D1F3-4B03-A77B-77767FBF2DA5', '4640017590321', ' 5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7E90C0B-9A8B-45B4-AFB3-868376D2DEDF', 'E6C7499F-FC56-43D9-AEB4-B4ED59793B59', '4640017590338', ' 10  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34029099-A1AB-4C10-AF63-03F38F00582C', 'B0267239-ED3E-419C-823A-DC40698FA8AD', '4640017590345', ' 2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C811AD58-1457-4AE6-8D4B-FBE0C5B76D31', '1D9A4CDF-80AE-4110-945A-2B1319CF1B01', '4640017590376', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0A10762-80EB-4ECB-80E3-3A88E93CDEF4', '8B3EF4B1-3181-4B98-8577-72546C356BF1', '4640017590383', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D55349C4-C7DE-49C0-9AC2-CF9DED091B94', '3F5A3851-F610-4D15-A89E-C54A30258B66', '4640017591113', ' 6    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDF0D4D7-7E20-46CC-A500-21FCBBD9E0D2', 'ED15141E-E78A-4988-ABE4-606C5C596B77', '4640018640476', ' 400  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('747E4562-C22C-4D98-9FB1-A4D49BEF2CE0', '4B030AAE-A562-4373-AE2E-D182061AA5D5', '4640018640865', '  200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('664CE5B0-FB78-407E-AC54-4B6F831B581E', 'BF2C0017-AC70-47CA-B87C-42B1081F1D40', '4640018640889', ' 15/5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25D2A6B2-5930-4528-AE06-48BAD1C9CBFA', 'EB9F0C51-2DA2-44AD-BD6A-0D75F4F2A4D2', '4640018640940', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6EF5646-EBDE-477E-96D0-F593F7368619', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4640018640964', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9AF0C2A-AC15-4E3A-A7B1-197989355C9C', 'FA179DEF-95BC-4633-B70E-F8B28CF13E49', '4640018641138', '- 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('652C1861-F8B4-4837-9287-BE3B17643347', '93209699-C224-4238-8433-187D135E49A8', '4640018641183', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6966D71B-8278-49E9-BE06-C98FE1A1A406', 'E8D227BE-A6A5-4DFA-90C6-EDB7B6A3AFBA', '4640018990014', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC21C3FE-F9CA-4B35-A8C3-607CD311B857', 'D0FDFCDE-F93C-4351-85AA-EF97EC90DA14', '4640018990021', ' Gel  work /  / scholl', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89534513-D51B-4487-BABB-8D11F5AD724E', '8E5B73E9-6DEE-4714-BCB1-2F53607BDA00', '4640018990038', 'Gel  work  /  / scholl', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07915131-65CA-4B63-8D56-B982F37A4899', '4F55CC1F-2635-4B97-8836-457834DD654E', '4640018990045', 'Gel    /    / scholl', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DD23B54-2CFF-41F2-998B-3FCB4CF45A52', '4E308A9A-ED1F-4528-94B1-C593323012BF', '4640018990052', ' Gel  scholl    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34B53119-3E86-4E31-BCF4-00EEEAC395E0', 'FD2EA5D3-1C56-4AE0-9D3C-2FB898D7BE1E', '4640018990069', '    sport /  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('083727C3-7F62-4FBF-BF73-50ADA0A8E1D2', 'B8EBAE33-FA19-4F64-864B-FDC2EFC497FA', '4640018990076', ' Gel  scholl sport / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF2C97E0-3CE4-4B88-9D4A-9D7E2924819A', 'A5D0F59A-2E58-4833-951C-817CE657C48C', '4640018990113', '   /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9112A9B-660F-460F-8990-184EC967CEE8', '1598A3CC-D6E8-4129-AD77-8498969F84E3', '4640018990298', 'Gel   /    scholl', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('961DAC6D-D577-4F6E-B483-8FB5CB0E7F3E', 'AFDF40FC-3914-490A-958E-2AFBFEB8B25B', '4640018990311', ' Gel  scholl   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70D907FA-75D6-4946-A974-F20A1F07C998', '40391848-13EB-44FF-9398-8DFC72DEABE4', '4640018990328', 'Gel   /    scholl', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5196F685-FEEA-46AD-B918-E3D60942B1A3', '4DED8866-3718-4779-998A-39A7870AC542', '4640018990410', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CA1691D-EB98-48E5-9B9B-65C3FDE23B5C', '7A24B8B4-C9BB-45DC-98CD-04DAF291D0EE', '4640018990762', '  elite emoji 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3C30078-A42B-4F51-95A1-EB60BFB4E2DC', 'CB686930-1125-4AB7-8C21-6C9C1D4CB39F', '4640018990786', '  elite 12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('674CD59A-1DA3-4CD7-9A90-E6416ED40356', '29C8960A-0E77-4D1E-A0AF-BEBC5518637B', '4640018990809', '  pleasurema emoji 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFB4DAA0-6D38-4A52-B54C-AF2EBDF5C571', 'D730523E-BFE4-457D-9AEA-DD5454A961A9', '4640018990823', '  12 pleasurema  .   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6593B7EC-0C37-4117-9657-4E90E8E14DEE', '78428D19-4C12-4A37-8D8A-1188444AF5E7', '4640018990847', '  invisible  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A72DD12-9309-460B-B803-BBD0941BEDEF', '49F430D7-1E99-483F-A0AD-71C35E99B4C2', '4640018990861', '  invisible  emoji 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DA7B66A-11CA-41D2-A9E5-7A03DBB2211B', '2D626FAF-1AC5-4CAA-A4E6-71131957BE50', '4640018990939', '  Standard 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40A43CF2-7AB9-4213-BF4A-C9CD65216162', '4C7D7B80-7E04-4E80-A956-0FC75DD292EB', '4640018990984', '  invisible  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6827EDC5-79F6-4E12-B8B4-8CD7F09E2DE5', '618DBCE2-841C-417E-AEB8-AB7CC970A0B1', '4640018991004', '  extra sensation 18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D454E1AE-3C7D-4EE3-8F8E-722CF2AA6A47', '584CC2C0-5223-4E44-B21D-2BE4AB8FB50A', '4640018991288', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64799364-9A25-479B-B8C2-E8D7E79E9D0B', 'F3BC84E9-6A8F-4916-9DFF-7D743587985E', '4640019020062', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C7531E4-0E53-4311-9804-63C315EE9169', 'BF4422D8-E436-440D-B9E0-5AA3CBAF0C28', '4640020870304', '9   /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC06D017-43BD-4517-BF6D-F37FBF08D1A0', '101AE37C-2A6A-4BFB-833E-ED8DE846D0E1', '4650001680273', '  aura    72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('275AC2C2-5F19-4B1D-8CA1-098055A9A457', '26FD9C22-6D57-413B-98CB-6A157EAF2115', '4650001680280', '      15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51B8339B-9208-4E3A-97EC-38C2AB8752D9', 'F9FADE3D-4E7F-4268-BE0B-39F212384216', '4650001680839', '         0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABC335F6-90DF-4C0A-8DCE-527DC23EEB10', '71962D66-FC95-4128-B9E6-0130DF4CC465', '4650001681058', '     / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C07C6946-527E-42E5-8529-FD50253344C8', 'AE8E7850-1177-4FCB-94A3-102329258DD4', '4650001681096', '    63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D653C77F-C6BE-459C-894D-5709AF8D0A21', '9F3CB923-F284-4E75-A26D-576ED141BAB9', '4650001681379', '      60  90  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F751A56D-1AAC-48F3-A925-BF4FC350F38A', 'C7756E9B-395A-4E92-B092-AC3CAA02A118', '4650001681614', '        bio-   63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4512A829-A9F9-439F-BCDF-A7C228A12BBF', 'A7993CC2-E056-4217-86B8-277CCB7A21BC', '4650001681621', '      60  90  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BE3D1F7-F43A-4AAC-8C3C-70952133B9BA', 'ADE40A64-1A7E-4202-A49C-4A1F67E2A8FE', '4650001682666', '    /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72C755EF-AEF5-4D7C-98BC-4D79C0DFA008', 'ABCC1C73-106E-4941-B56F-AF05E84CD4E4', '4650001683557', ' maditol  / /   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B9F60CC-7F6A-4A5A-915E-020D21E180D6', '858C8485-9DBB-464C-8CCB-CCFC93B01047', '4650001684813', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FB3AE8E-D6BE-4117-B706-B89AA6EC8A70', '4A725842-57BE-4446-93B8-4057AA67FA2F', '4650001684820', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD70B479-9125-4474-8B0A-107E28C41B3F', 'B0C6C89F-4F37-4974-BAED-4E6DA27A27F5', '4650001684837', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC1087D4-05C3-4343-B940-E57BC09803D6', 'DB99CA73-4614-43FE-931D-6E12BED73C97', '4650001684950', ' .    72 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F4EE9A0-EA63-4FC2-878F-66211E9318D2', '9248C002-C40B-4894-85F1-A6AD37EB6776', '4650001687340', '   / 31 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A33DFEF9-D7E2-48C7-90B5-989DFB883125', '874BE637-09E4-4139-A1DE-5856B70C902F', '4650001689023', '  /  /5664', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61538248-0C18-46FC-BDB3-4E9035F5195E', '01D65A29-FAC0-46AE-9FF1-4A7B9822C160', '4650001689061', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CEF0399-A079-4978-98E1-7517543D8CAD', 'FBCEE5EF-36F7-474C-A7EE-83DE25D39D8E', '4650001689146', ' /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17B17F9D-5AA4-401C-8AC8-A60B5A102E6B', '9AC70678-E822-4881-BB6C-B5EB7D417A7C', '4650001790019', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFF6AA12-5041-47C4-95A1-5071F04D46FE', '3060C205-18B9-4C6B-9839-E71B4394AF56', '4650001790026', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BD92A7E-F7A1-46B3-AF38-3AD8D601616A', 'DBAA9FDF-1AF2-44E0-8E96-F5C14076AC06', '4650001790033', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58208DCC-A417-4E05-9996-EFC2B3504E1C', '8A1BB1DA-72E9-476F-BD50-FD6F4E05B8A7', '4650001790040', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D65A875B-9822-47EB-A191-3B615078F074', '344C5A99-F3AC-4E78-A5DC-C6042A38E1E0', '4650001790057', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('468F6517-A5A8-46ED-AABD-7802F771136D', 'CF2E2CC0-2E70-441D-9847-D37E425C3784', '4650001790064', '  // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D50E962E-EE7F-4428-A688-4A9F3585DFF7', '7BA6736F-5C54-4F69-AB49-19B9D2315F1E', '4650001790071', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAA850A2-49E4-4458-9E90-2296A8FCF66D', 'D20EAAF1-91B5-4814-867F-5B897BA7FF3A', '4650001790088', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4496541D-CA1F-40A8-AFE1-F7E84DBA1FAF', 'F9471987-916E-4378-87C0-C1F119D6EB39', '4650001790095', '-   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55D17C6E-16DC-4972-AE52-88485BF52443', 'E46DA87F-3837-4BAC-A814-E6F7467C187B', '4650001790118', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A75B5715-6787-4F08-B4B8-54C206521147', 'DB790FCE-5738-4B50-8840-0E3243E83D23', '4650001790132', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA0D14CB-2BD5-42E5-B72A-AE7DD0A39729', '8C484D8F-39D2-4D60-A6A7-049798D1BFC0', '4650001790149', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('806694FA-6A56-4AC8-AABD-6D5217DADD27', 'BDD20D99-7DF3-4448-838E-B848BFBB1D90', '4650001790156', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C133402-EC11-4910-87BE-D02674F4FCF3', '0CC01517-5361-4A79-A561-6C262FB126DF', '4650001790170', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E88A1047-A092-4922-9243-196019F8B653', 'CACF1395-694F-4C35-8C3F-CA634BA44E22', '4650001790194', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B81BAA60-AE65-4655-B661-22A1DE3DBC35', '9D35F458-1CBB-4FDA-84DE-C97BF607B665', '4650001790200', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4496B0AB-5820-48BA-8763-4098041E9893', 'C41CDA4A-FDB8-4A2A-88DE-3402DB9DDF84', '4650001790231', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01292F91-C772-4E7F-99C2-4F39DBBC1750', 'AE9F0B90-C047-4609-AF56-8A63D7685702', '4650001790248', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B17EC7F-3D0B-4923-BE5B-91E1D17DF51B', 'B8136726-DD39-479F-AD0A-AC60C8B2BEFC', '4650001790255', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8F5D262-6318-4DEB-9662-C8AF399B38C7', '49D5C431-B2EF-41FF-B573-E5002702CB76', '4650001790286', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E294E616-792D-4C37-9D7D-46B1A5522289', '55A56005-95EE-4E48-9942-745FE073E8CC', '4650001790293', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FBDF972-F581-47E0-957D-DBC39D4ADB98', '1C3AF068-B26C-4969-9A91-6E00EC9E8CA2', '4650001790316', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08B79BE2-8A8F-42D8-A24B-949AF49804F8', '1753550D-427C-438B-8B4E-59496F662CE1', '4650001790330', '   /  // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70CC8AF5-C683-4878-9E1E-7F402CAF8677', 'DDB9F1A4-685F-4310-980D-0E59D1035260', '4650001790347', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8444B72-1D78-4128-B579-7D431C808B03', 'FCB38991-D64F-4EC4-BA67-12646FF22315', '4650001790354', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2C6D12B-4222-49F0-9539-D9561E8F49D8', '90D96401-0C91-4C0B-8AC3-572F06510D8C', '4650001790361', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('085EB72F-ED87-4C02-B9C5-61E71488FE9F', '79017E3E-187A-49F5-94C8-7C6702B605DA', '4650001790385', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBE35821-815C-4477-A3F3-CF706698A85E', '7666880B-CFD5-4835-89AB-B2258D313F19', '4650001790392', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F8CB6B3-72ED-4060-90CC-31D17E19452B', 'CA7ED2B5-3689-40D8-BCDF-291BFABA713E', '4650001790408', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C37E182-4202-4CF7-9104-DBE138788E77', '0FB3ED49-0D5A-4A8C-8F7B-D856DB842119', '4650001790415', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6724672E-E895-450F-882B-D64F22A2BBCD', '5E12BC55-3816-423A-8DEA-B2EBF9D471A4', '4650001790422', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D8380D1-2446-4650-AFAA-DE92321EBFC0', '2922B123-5D6A-43A6-B55E-40ED14E3164A', '4650001790491', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E32597F-A5EB-44FA-A9D6-C7AAB5E09F5F', 'E835B197-CC82-4897-AC3D-500C4E277DEB', '4650001790538', '   1% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95561816-B582-4B6B-9A80-1FA4EEA8765F', 'CD5DE716-D697-41C1-B7C9-55296C4FF698', '4650001790545', '   1% 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8DC7A55-8735-4BF2-9BD6-B90DB6BD8097', 'E5D9E0D6-732A-4104-B91E-C120857CACA5', '4650001790552', '   2% 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F5B5A24-88C6-476C-80FA-35BCED37E238', '6E17FF84-2F3C-4884-BBB9-710C15566145', '4650001790613', '   1% 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71005AA6-8198-449E-9B44-ABAE5D1B8264', '62964EA1-B818-49DE-BE5B-3CD2F10C3342', '4650001790620', '   /1%250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27F99ACC-94B3-4300-9E39-C555CC24CA0D', 'B627896E-D6D8-43E3-AF92-865EA58B92FA', '4650001790637', '   2% 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2282975-7B15-477A-90DE-2FD45F82CB05', 'B996238C-AFEA-49BE-A1B7-7CFFAB80B870', '4650001790644', '   /2%250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1D776DF-CE4D-48C0-9C17-5219FEFF2FAE', '0CBBB2F8-881F-442E-A918-456C3D72C259', '4650001790699', '        150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('600EE364-6F49-4237-822A-78A5FCBD1B34', '1B8A8EDC-077A-4634-BF63-2B245FFBE8A6', '4650001790705', '        150*', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70483259-9C4B-40A8-B150-D4E8C46366E7', 'C373949A-24F1-43E6-A7C5-25F5666ACE18', '4650001790736', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78D65BE2-70C5-40BE-B91D-BB566C788F16', '83D165E3-A537-4107-B891-1A54B4DD539A', '4650001790743', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D05FA0F9-8CF3-40E7-84D1-ACE415312A3C', 'CEFDE10B-5F66-4CD3-AE0E-ACF9D5BCEC1B', '4650001790750', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F379344-0DD0-43BD-B0AA-9B00694E5AC6', '2856949B-33A4-4864-907C-45FF19B5FAC3', '4650001790767', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A15D8311-527C-4A3B-A1C8-E00D82A43493', 'F2AD423D-368D-4AFC-A977-4DCA5FF1171A', '4650001790774', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('279EAAE9-C8C6-45CF-9F60-7E45AFDF6AA5', '37100C7D-A124-4C37-8706-0F89720B0A31', '4650001790835', '   // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C1B5F5A-CCEC-4C9F-B63C-529F274EBB16', 'B8E713E3-BD49-45DE-A73B-25E00B15BA3B', '4650001790941', ' /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFFC094A-A855-40F2-B4E2-484EBCFF50B1', '3EB8FFC1-7033-4C70-895B-DA70765C4420', '4650001790989', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEA642C7-535C-49B7-9FAA-6B7C27A1E7E4', '7CAAAA30-8889-4247-BA0E-0F79C78EE5F5', '4650001791009', '  50 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0125F562-C7A9-48C9-900E-841A50488020', '5BF52E49-6654-4E1E-828F-D9706C852A81', '4650001791078', '   // 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4281BC94-F9C8-4D16-8F23-8F84E23E5358', '3EF06161-D30A-4A5D-BC78-D0E7E0CDF53C', '4650001791092', '   100 0,37', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90CBB976-3159-4A07-A306-E528C685C59C', '79478D5D-B1D8-4AD2-A048-524DA5859083', '4650001791108', '    0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CCDCDEF-A1DC-489C-97B5-C618F789B30E', 'C0FB0F11-E2DF-4916-8C5B-83F520EED252', '4650001791122', '   // 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B9E624E-F25F-43FE-AE9A-BFFE49F2474F', 'A22C184C-C1BD-4C6A-84E5-4A630773EE8F', '4650001791139', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58588B93-77F9-4290-9FE3-78096A35A37C', 'E05D7E88-8DD0-4DC8-8BCF-F136081F153D', '4650001791146', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07741ECC-3786-46D2-AC76-A7D5A24407AB', 'A10D16FC-780A-4DB9-8DC2-2BB562A1F5CE', '4650001791153', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B657A59-46CC-4E0E-A612-1B34D31C036C', 'B03EF6F4-B883-4139-AE8E-B5E505D9F2A1', '4650001791160', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57FA3087-8452-4C6F-8DDC-7C042EF22762', 'F7A678AE-9BEB-44CC-A7BB-1898051F3A04', '4650001791177', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0C9E98A-7210-4F53-BDA7-924300246781', 'BD8B6646-6B36-4BE5-900E-4AA24E248DEC', '4650001791191', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E021DFF1-85D5-4C10-91F7-158F74AD373B', '512341FA-0800-43EF-904D-7A89C2ED4D72', '4650001791207', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9068FF33-E01C-4F7F-9668-68A9A53E535B', 'DA4D0E4E-3FB2-45E4-A47E-8EBB6E105316', '4650001791214', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9619AC4F-48F3-4E1A-B299-C5D98F027A3F', '01064AE3-796F-49F3-A3E0-88C6ECA6CB2B', '4650001791412', '     /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45C89D6C-37B9-44B7-AE3E-BC2CF635966F', 'B31DFA3D-464F-4366-8954-87EFCF2D6B2C', '4650001791443', '   // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC556830-E93A-412A-92E3-F5479CE8B7CA', 'D9DFE08F-96A5-4E8F-9113-1B877869FFA8', '4650001791450', '   // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6F2FA7D-FC26-4529-A8DA-16425764E803', '0022252A-FBA1-41AD-BDEC-727F32BB3761', '4650001791467', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E617F8E-33AB-463C-BDA5-1F346E51C919', '522D9D97-ECBD-4866-8A05-93671AC8682E', '4650001791474', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6222570B-49C2-441E-A176-0D732F838AB0', '5D72D0F8-C3E0-4668-A84C-90F0A6F5BD90', '4650001791481', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D3A3660-219B-490D-BD92-1E3834A127A7', '86B95A21-BAA9-4A7E-95ED-4A3E495B02D7', '4650001791498', '  30  .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C43A8FFF-66C3-4EAE-AF0E-4E7B205BDDBB', '4D7E78D2-30E5-4BED-A1D5-8B8B68A55A49', '4650001791504', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82CBBCF8-05A5-4FBA-992A-F867955AE90E', '2F9F3DBC-5911-4A18-8A11-275C1F487833', '4650001791528', '  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB3A5026-4AC4-4973-AD8D-10A22417521C', 'F6C7219D-3A5F-4BB2-A0C8-9230A4C375DC', '4650001791542', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4F8607D-8101-4A03-89AD-45E09237C540', 'CCAC09D6-3C04-42D2-AD44-70254CFB8D74', '4650001791573', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9936AAF3-F9BF-4140-B120-FEA7529F3BC1', '28598AAE-BF9C-455A-9993-7802D2164F32', '4650001792075', '      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8579B02-259C-4A24-8A18-0BC098BBCE86', '4B6D6CAE-DB5B-4A8B-978E-9E59071E1377', '4650001792099', '  /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1A4D384-6750-4CC7-ACEB-77AFA818E37D', '72FD8796-E29A-4DE8-BA9C-1A49818D709E', '4650001792105', '      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E84D4D2F-C5EA-4D55-9D8E-57923328E52D', '7E53014C-DFDD-42E8-8CDC-7207C03D56ED', '4650001792112', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DDBBA9B-325A-4F7E-A153-8D0BFCC658B6', 'B2D58DE3-12E0-43D6-9C83-6F2DEBB059DD', '4650001792143', '    / 1% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79B1A153-F02F-4BA3-9B95-ED6C4F51F0DD', '359557AF-2A2D-4D2F-8029-FBFE63700EC0', '4650001792150', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEBEB0F6-A1FA-4AAC-8B90-505DB2026E1E', 'ACAD194B-500E-41E8-B42A-5FD07EB8FD0F', '4650001792167', '      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41B5E131-DE02-41A5-B7DB-3B4446ACCCE7', 'D4B05DE3-EB67-4370-9388-EA78DA8098C2', '4650001792242', '      /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ACA8955-1F2B-4307-903A-AFAC8FF2FAD6', 'EB17AB67-FEF1-4BF4-B660-0785D4769CDA', '4650001792464', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E279F30-0A7D-423C-B4E9-E5B46790B5AA', '816A6336-3113-47C2-B2D5-61F443C9B275', '4650001792471', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('071A3483-C92C-4A85-8913-9F6D716D0D44', '68924F0F-489A-4775-B2F0-C0B2E3215459', '4650001792495', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ABA9F84-588A-43C1-A346-31EA515B6FF3', '78FEF9B5-6EB8-4710-8F74-EDEB7F41EA2D', '4650001792501', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44BDE514-E5DF-4363-B216-A58AB6475CF7', '45B4571C-F5E5-41DC-815F-914FF207E7CE', '4650001792518', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70B003C5-ABBE-4E36-A806-1EECBF252680', 'EC22D0B0-E23E-4117-8005-08BA60180776', '4650001792525', '   /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B711334-09B2-4EB6-9DE9-9F2A83BE5278', '493F884F-384E-4051-A2A7-614691D4BAA9', '4650001792532', ' -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ABB7F90-B11F-45C6-A767-305446EEEE76', '32F17874-BF58-4D7D-B651-5923812D196F', '4650001792563', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7EA7E2D-AC4B-4CA0-8093-938D5E68ED1F', '5F38E112-68F8-4DE7-8F5F-A608F2B675B2', '4650001792587', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1C3A0D8-A73E-41D0-BBB3-DEF9BFB247C3', 'D67D7BC1-30CE-4070-9CD6-E8C27BEDE7F1', '4650001792594', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75F5E2FB-EA31-47B7-98AB-CF0162EAEAF7', '59436AEB-ADF9-448B-BF57-95B6B02864A1', '4650001792679', ' -   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62342E1F-D02F-4BA2-9729-BC6BEE0B7FE7', 'BDF88661-F06F-4FF3-8810-616CB202D49F', '4650001792945', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ADB9937-FD83-4A8F-8EAB-240FE7A099ED', 'E676A80C-C0B9-4DB2-81B3-B47F6D255C75', '4650001793010', '  / // 250//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84269C10-9085-4714-BD4E-8299F6AF8023', '3CB5E5BB-9490-4F8C-B74A-51C8F3C14AB5', '4650001793034', '  300  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('015B9F7B-0FC8-4210-844F-70DFFF72561A', 'F5641919-19C0-4CBE-89FA-52927B8FED26', '4650001793058', '  0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFD40107-A144-4C55-A7C2-6634F79DEA0E', 'C39A9AF1-99E4-4391-8225-BF1D3D5B3912', '4650001793492', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E0E03E1-CB0B-4DBA-B554-7ACBA2F94D41', '59DD2C10-386F-444A-ADF7-F85A02ED8FDF', '4650001793591', '     03 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6A99631-3A91-4D78-B833-6AA79C62523E', '5AFC1A95-105C-42EF-95C0-718A37FF3BBE', '4650001793683', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A1B00B6-2C95-496B-A38C-AE88E3BFE2DD', '02A5E191-4537-4C22-BFCA-AE66E57BDE1F', '4650001793690', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5E65D58-5A36-47D2-A5FC-3BCF37524059', '5780993B-17B2-49C5-89CA-C3700ED5AC28', '4650001793713', '   0,2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEB54432-B9F7-4EBB-BC9F-B1E19FCBB105', '818515EE-5668-465C-AA8D-3D46D08DBCD2', '4650001793720', ' 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81CB39AA-2534-48D7-907D-A05A131BC06A', 'C0423A3E-0FAB-4414-A281-4DB20D5A8519', '4650001793737', ' 200  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95C09C91-FFDA-4DE4-A095-CD9385FDFD41', 'FF1A3394-DF32-4C48-AF28-85891E05CF26', '4650001793829', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F199A86F-CA44-4104-BB0C-2B24765E1D99', '52BD1201-100D-415F-AE32-A88389489C8B', '4650001793881', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCADAAAF-3B0A-4BBE-9722-E913296B0BD5', 'D79CEB74-2EEA-4E0D-B6A9-534FD6D3B4C1', '4650001793942', ' - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB55EE53-6BAE-4E52-A155-4E00453FA9D6', 'A9083BB0-AC95-4A99-B234-C2AD7462EC41', '4650001793973', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAD7CCBB-A229-4314-AD01-343DCB5AF053', 'AF9CBC47-F014-4DB4-A66C-39923F49FF6E', '4650001793980', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD99480E-9BDE-4639-8061-D93BF534AF5B', '7D2E5170-E90A-4059-A48C-0E0A0E419100', '4650001794048', '     // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ED03DE3-F32C-4BBC-B564-47AC1B4D0797', '267C0017-FF46-414A-9CC2-04D5FEFF18D8', '4650001794062', '   // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('971296A3-2C09-422A-9E69-2E4283805D52', '6B144AFE-2342-4784-9995-717D746F273E', '4650001794079', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A61AF660-6BF4-4163-A26E-7D6DD97B7C3B', '1B041823-892F-47AC-9FA5-DDA2D39DD97E', '4650001794253', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8959D22D-1AE1-48E0-AADD-48625333127D', '056D97D1-1B5C-47C4-AADA-AF2926808C37', '4650001794451', ' /   / 75/ 03/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7945EF1A-9024-496C-9A47-DF9855168D16', '097481DF-5E96-4373-8DB1-0B5FB7B4B5C2', '4650001794475', '      0,37  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E7B58F1-4DB6-4880-BEDC-4573D4E108C8', 'AD864988-C8B0-49F0-A2F4-95682AD6C8F6', '4650001794512', '   /  ,,/ 0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77308E66-A2CA-470C-BB57-4C24D04260E6', 'FF0E28AB-5790-4ABB-94D1-D9C2B5932158', '4650001794734', '  0,3  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7652B9A8-00D5-4315-A365-8AA5EA129834', '4DB2EB6B-0D00-4C56-BF8D-50E2652D40C7', '4650001794840', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89A91ECE-8C7E-4282-A355-21731BB7CFF8', '1958C534-8257-4EA4-86FC-ED77BD6D1E03', '4650001794901', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F946684-A508-4C65-894F-F63DC28F375A', '470B3388-B616-4F76-9189-814F7C45800C', '4650001795182', ' /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B3548B3-FB06-4BED-8F36-FFECF333F92F', '20F00A27-FC3E-48A1-9B5E-E7DEC50C28D2', '4650001795328', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('587E6129-13EC-4388-8362-14BC5E894298', '471E957D-047E-42AF-A9BB-FCB0B58100F5', '4650001795335', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19A9245C-BBA6-48B4-A914-C1229CCEC6D9', '75413DB9-BA4C-457E-8DE3-733C753D0BC4', '4650001795342', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15F04ABD-4EB4-4211-A7BA-F2E8AB3D2C01', '9790A1E6-1915-404E-93F6-3B5968555898', '4650001795441', '03  /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7B1814E-ACC0-4686-8C27-B05FFDDA6579', '8D7E7102-A7F2-4CEA-8A97-19690DBC1E74', '4650001795557', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C08A6E2-052D-41E5-AEBA-2E61BA74F7AB', 'E464253D-ED3E-44EB-A7C1-F2EA59ABDE0B', '4650001795687', '  99', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D59405DB-5141-4B59-A5C0-DC817E6D7DDE', '149C6846-BBD2-4242-8EE5-0BFFA2EEE1FD', '4650001795700', '     99', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2931D8A6-1C67-48C7-8B12-9EE3C8E3FA74', '09DD1591-90B4-41BD-80A6-A7E14AED39AA', '4650001796035', '   10% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6E5CE53-7C95-4059-9BA1-E9973286BF7B', '6EF9E7A4-18AB-43C7-B9A7-4B470285E2A9', '4650001796646', '  / /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1712BB0-218B-46B1-BE7D-FCF4BC6C50C0', 'A5CAFA03-576F-45BE-B3D3-4AF94353E3C2', '4650001796707', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB63298F-43EA-4455-8DFD-B16B0211AE4E', 'EDB84732-78E4-4998-9232-AAF764E8E9AA', '4650001796714', ' 3-6-9  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67F6D39A-0FA8-4D70-9793-4033DC47292A', '135CA113-6083-4261-950C-F090AA8E9B65', '4650001797094', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9882DB4D-94A3-4B9A-82E5-F28A87545F48', '59C55B22-987A-4D83-8F7C-C1ED56EB3F70', '4650001797124', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3353F0A-C2B6-4B13-83C5-000CD24CD12A', '85CB1C21-DDC1-4C26-9B08-5C88CE5350C4', '4650001797841', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8B1A716-D743-4F52-9E8A-34A5AE64ED69', 'D07475F8-9B61-4DAE-8570-67528DC19B58', '4650001798046', '  0,3 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A986B444-0EF9-4F18-B0A7-8311732621B1', 'D76297B1-525A-4EA7-B8E6-07C315F954BB', '4650002420052', 'Bugstop      3-  170  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35F9FCA5-DAC9-491A-92B3-574B24823F3F', '3F9CBEF3-2B34-4907-88EE-CE01C7FDFC8A', '4650002420120', '   bugstop  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26B7CAFB-DF9A-4930-A4B9-B4FBBB8E9186', 'F4D38A2E-8263-4230-B024-B7AD8DFFC94D', '4650002449039', ' /   105', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6B4B1A7-A1B7-4187-9BA3-BF36A163E53B', '26F704FD-6EE3-411A-AA06-20F3C9A68383', '4650002449220', ' / /+/ 105', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57A4244B-BBBF-4054-9655-1081622940FA', 'F44DD162-A240-48A1-B249-ED33E6CA7636', '4650054310202', ' 0,4  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4263C773-60B3-43FD-95E7-011A21376F07', '43489854-4BBA-4A9E-A29F-A10D14F539C8', '4650054770136', '  2- 4529 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FF65D4E-FFA0-4047-8F0B-57FB0010E2DA', '058F9559-BAF3-44E6-A27C-17F5879A82EA', '4650054770150', '   1614 / 10/ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64732EDF-8F95-486F-9F51-1DD15DFEEAB5', '97FA56C7-45FD-4BFD-A298-61F8434E1A3A', '4650054770297', '  1614 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43C3E374-0705-4DF5-A7CF-F41D3D324116', '608DBBEA-3F36-4AEC-9430-09B43956D4B7', '4650054770518', ' .   1- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30A9DD4B-C938-4048-92B4-8A885B6C33C5', 'F34E1DE2-2425-465A-92CF-E95746B0672C', '4650054826963', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7218A649-07BF-4209-A1D5-9262685DD425', '4FB7A343-8FEF-4FAB-BFF5-2E39594067C3', '4650055920011', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D14CB131-E200-4757-AB83-D44C15847835', '32C25A83-D57A-4196-A903-C6E088016A01', '4650055920196', '  / 5    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C48D953A-9D99-4233-8126-44878B33F031', 'C198105E-C27B-453D-8852-05A66E8A3B69', '4650055920233', '-   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEBCFCE6-1EBD-4A48-9CC5-EB3CA456D9E9', '6C6083A3-C662-4991-A1E7-3630A2AF08A0', '4650055920271', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF019CD5-2BB5-406D-A595-2C5870D9AD12', 'AD69FC8F-4D42-4564-8362-F919AAEA41C7', '4650055920387', ' /.    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8746735-1800-4FA9-8F54-101017473CE5', '052BF0EE-605C-419B-A3D1-56080896609F', '4650055920417', '-  -1/2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7AF4AC0-90DA-487E-AE6D-2DA55D05FCEC', 'EEB855AC-7FE4-4181-8CC2-624C7983BCEB', '4650057490123', '  300/ . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('526CAC25-7C2B-4164-A56E-91FAE31F8A7F', 'AB402AFB-E076-4601-A26B-313E187700A9', '4650057490208', ' 500  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD624D3A-0C97-4ED7-8967-2EFDA6155912', 'C32895CE-CF27-48C5-9D0C-6CEB750FBF86', '4650057490215', ' 500 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16029DD9-A39B-4FC5-8898-BBFFBCCC979F', 'FFC4EB26-2427-4E2C-A80E-E222FAE1D26C', '4650057490239', ' 10%  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEE7BCA2-6C9F-48A8-86B2-C45368C69152', 'F94CA742-6EDF-491A-9A79-7EB0143FE318', '4650057490307', ' 295  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('149E5679-8DD9-4979-8C0F-9182C6FD9DDB', '353D21A8-D3AC-4BF6-9AF8-988745D28C3C', '4650057490338', '  300  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABFCAF1C-1F32-422C-9BE0-1C52648B9474', 'E3E5293B-DA7C-4D2F-A800-619CBA392F27', '4650057930476', '   0,71 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBA1B16B-7B1C-4E18-A47E-E55522507EDE', 'E3E5293B-DA7C-4D2F-A800-619CBA392F27', '4650057930520', '   0,71 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('564EC0DA-E4AF-45CC-9594-3DF1A11E47B3', '85FD1CA2-6A42-44E1-B35E-41B276F5C4DF', '4650057930537', '  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('595FD63F-458B-4E42-A895-F7611D7AEF9A', '59661479-9151-4F0D-BF21-CF63AF06AFBB', '4650057930650', '     1,41', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52691ECC-90EC-4CF7-97C7-DB50D65FAF40', '88DF96B6-0A29-4136-B980-C840000ABA45', '4650057930667', ' .   . 2,01,4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90F7F0AD-0178-42D7-A272-8A0C0685EAD9', '25FB2C36-C580-4BA0-814E-BA96DE3E2AB4', '4650057930759', '       -   0,71 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C07BE78E-4AD6-4F59-8405-A924A36E89DA', 'EB19879E-4795-4AE4-AB82-33753B3C88B7', '4650062750359', ' 100  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC6D7841-952F-43B1-966F-6D573F462728', 'A497CC1C-B75B-47B2-8A8D-430501DCDE13', '4650062750366', ' 200  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AECA3F5E-9C57-44E2-B68B-39398C79A365', '5D65476D-A4DD-4BA1-9D23-F9B02F627EAC', '4650062880049', '   /  30/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('787788DA-8335-43BD-B2E6-5B9ECA4ABC5B', 'A8C18428-BCF4-4715-8722-A7FAEC9A39D9', '4650062880056', '   6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B8F7EE4-FE77-4F79-8311-476D11BEFD5D', 'EE411F15-921D-4410-A6FC-2203BB36D643', '4650062880100', '    6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5FFA8D0-E0AF-4C13-AAAE-C2E2C4C74F17', 'CDBF25D3-37D6-442A-88BD-2DEB0894F74E', '4650062880155', '    6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBE0FB33-42CE-4548-9F15-FB6D9CD1C1D2', 'DD4B080C-1E65-4650-894F-47B7FB4143E6', '4650062880209', '    6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7583F1D-89F0-4A3E-9AFF-6DB4B3DEAE82', '50F9EF64-2336-4ADF-9378-03F1FDC64B6B', '4650062880230', '    6090 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('428ED4E2-3AFC-4AE3-90B7-10072EF8AE73', '68C0007A-D76B-4C19-9988-177987688559', '4650062880452', '   6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8676CBCB-DB5C-4263-A790-B6AED000F532', 'DD4B080C-1E65-4650-894F-47B7FB4143E6', '4650062880506', '    6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B9AA3AF-F6AD-47F2-B2FE-4DEFA2A5C61F', 'CDBF25D3-37D6-442A-88BD-2DEB0894F74E', '4650062880551', '    6090 5', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('095BEFA5-9D0E-4D56-B17E-1914F36E4C76', '36CAD9D3-08D8-4FEA-8AF3-227E49872A14', '4650062883538', '   /  30 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F779B56-9304-49E5-B8BB-F21E06E0136A', '2DC5AEC9-F8D1-4E88-AE92-22E6796C36BB', '4650065230032', '  /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7E85E09-59D0-4A74-8742-59ED12DE2A31', 'C2C34D3C-5C00-467F-AB53-0C74F45A451B', '4650065230070', ' 800/40   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22D1F0D7-4A26-4BDE-ACA8-84F0EF1DD05E', 'F40D4861-C99A-4D8E-B92F-DE5CF905A0D7', '4650065230087', ' 800/40   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DEAF720-F2E9-40D7-937E-3440517338D1', 'D2E6863B-CF41-4D86-8944-96EE647C8E9F', '4650065230100', ' 1500  . . / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DA428E3-8F50-404C-B277-FDDFAD557B0D', '864A1654-2EC4-4C06-87E3-9748DE70CC98', '4650065880077', 'Bugstop    strong 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DA16EDC-1875-4577-BBA4-0FD8CD4284D9', '96CDBA80-41A0-4B43-90C3-EEB918A68077', '4650065880114', 'Depend   / m/l 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74654CF0-2462-476A-95EC-3114DEC00B14', '7F0659A9-D0C3-4E6E-92D1-5EA4A22F1F17', '4650065880251', 'Bugstop    -  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A93D13E9-F56C-4A30-9D3A-67BC0B2ABB7F', '2005B25F-095A-404E-9329-326A80AC52FB', '4650065960021', ' 100 10  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBD63407-DCD7-42C9-97BC-F9B5FCE5EA35', '6F04EA0B-2CEF-419B-826A-F817AB12FA31', '4650065960038', ' 50 10  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9E20B43-9844-46DE-B7A8-68D911B58B71', '7384EC32-DC5B-4859-9C6A-16185FD2A772', '4650065960045', ' 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D3BD16C-3F73-497D-830F-977514A04B5B', '9089BC42-154A-4F54-AE5E-E2F2BA83903B', '4650065960052', ' 25   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96670F42-D8AD-4B0A-858E-43917F84ADA7', '17FE5419-1CB2-4AC2-AF44-AEF98D5D2B65', '4650065960090', ' 25   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7EC24FC-19BA-4E16-A676-C3D0851A0944', '2801D166-F583-4809-A99A-4876500826B5', '4650067760018', ' -  /.   240 + - 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ACF2607-DC5E-425B-9175-F3EFA4761C01', 'DD5D1A76-9973-4DA8-B5A8-8383733BBA97', '4650067760056', ' -  240+  2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8019DE7F-00C7-4B40-B06D-CF6CF449125F', '35D5C3CF-1E51-41B5-B287-7A89F4D6D575', '4650067760070', ' - . 240+- /. 30 /.2/ /  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A863E55-FBD9-4441-9550-148B59425D6E', '9AE54A2C-2D78-48EA-ADE6-2AE499C2586A', '4650067760094', '  /    1 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4415C280-6909-4A83-9854-0329D11FB3B8', '5E493A16-FCBD-43A7-A132-E0B31CBE84E3', '4650067760131', ' /  2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D660646-1A39-451F-99C7-47A6795AD39D', '92BA64D1-5714-410E-A87A-FA50E66B881F', '4650067760155', ' /  1 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C508E9CF-6634-48BE-B6EB-B75C91B86FB0', '9B59CF89-0F1B-49CD-8324-6B1C081D7144', '4650067760223', '  /    2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC2CB862-7C35-4C3A-8A65-E5B23BEF22F4', 'BB0379EA-A875-4C1F-8032-047EB61E3FBB', '4650068810040', ' 0,01% 50 -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5C7047A-C335-4C70-B241-CBDDCDA6536D', '4FCD4D14-4B75-4BDC-8715-689F03F31179', '4650068810057', ' 0,01% 50 - .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80316DD6-F79D-4603-868E-F81DF89C39BB', 'F7431E3A-39CE-4E39-B8F7-1207B50075E4', '4650068810064', ' 0,01% 500 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65A597DF-DE40-4220-B00F-2DB99A28DDD6', '819D8236-0265-46CB-8184-3A5CBC027E18', '4650069650010', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E83EECEA-0A0F-46BF-9299-C673C7645E05', '2422941E-738B-469A-8EB7-0058E56137F7', '4650069650027', ' 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54DD7D33-0B70-49CC-BF90-1C049D0BACA6', '4D8E41A7-229F-44A8-8507-76236FB1F06E', '4650069650034', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37DA6536-6C48-46F3-8164-1396D4F2C12C', '0303F946-57E2-428E-974E-F8605AAACDA1', '4650069650041', ' 0,0125   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADA8F2AC-973A-4CA7-901D-359BD030D4BD', '1B92F244-8A9F-48E0-B99D-72DE0E851322', '4650069650058', '  50+12,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA2F612F-EC10-42D6-90FD-8906A1E38717', '92EA917D-2272-48E6-9D78-92F8FB513DDC', '4650069650065', '  100+25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97EEEC37-69B6-47B9-95F8-B945FF30EDB9', 'CCD34312-04CA-41F4-94AB-537E341D6CD5', '4650069650195', '  2,5+12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69B1F229-B5C0-4D38-BCD9-6DB096D424B7', '00609E90-C3C0-4117-BCAC-F0F47807E41B', '4650069650201', '  5+25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86089402-D00E-4465-A4A7-99E61805BD55', 'CCA3BF91-2ADD-4D6C-BC54-3EBC813A8D70', '4650069650409', '  100+25  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C3857A6-1F8F-4D92-AB9A-292398774FBD', '40CB90B0-6571-4AA6-9229-ED57288F3A4A', '4650069650423', '  2,5+12,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE637C70-9E63-4F86-BD07-7868630060D3', '93A6BA82-CC0E-4315-BECD-EE10C7468221', '4650069650447', '  5+25  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('147EEC2D-17B0-4320-BD77-A60F31C38A51', 'FB56D46A-1B29-4286-934A-A7D482187A18', '4650069650461', ' 0,1% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1525679-B8B8-4853-AFE3-1D0FEA5C41CC', '5BE73A9C-C6CE-4077-AD51-7639C2FB627D', '4650069650478', ' // 0,1% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CB20123-C97A-410E-A2CC-AD34D7228469', 'F5572A08-D563-4BD4-BFA7-7A64029749AE', '4650069650485', ' 0,1% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02FD3AE8-0D49-4327-80D3-289E2093B438', '1C4977D8-436B-4691-A90C-79FB5AF551E1', '4650069650508', '-  0,05% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8464773A-D917-4579-85F7-156C34477109', '3B3CA5FB-2CBC-44A4-A0D9-F41B5A8415BB', '4650069650515', '  0,1% 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56B9340D-B81D-4093-B382-F6D76C159199', '6B91D50E-C2D6-491E-A275-2D840DB1149E', '4650069650553', '   /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F570A7E8-CCF8-4231-BA06-12E1E79B85DA', '91DC3966-F830-4B0C-AB4B-C0E6C2A5B323', '4650069650621', ' 40  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BFD6F6D-C5A7-4ECF-BA68-90F63DFE2BAF', 'EBD8ADD2-1396-48E7-BF39-731C7A9D8BC2', '4650069650669', '  0,0125+0,04  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B5B29FE-FCD9-4F54-8260-A4C49BD3EF23', '1001F374-529B-47B0-868E-E69674607990', '4650069650683', '  0,0125+0,08  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('240E969D-F506-4C17-9DF9-884F2454DEBA', 'AD0A72D1-E497-4FC7-AF49-02481125CD67', '4650069780441', '         250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B17051F0-AE3F-4299-8904-A31542EDD6F2', 'A9719340-44CC-46EF-95D9-3D6C20AC28F9', '4650069781424', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('898A8FAE-0D81-4AE8-B1A7-35530D9200C6', '119EB4D9-B8BF-436F-8743-72E6BA3A7F63', '4650069782667', '         6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DE4347E-C0A2-462A-8C88-99663DC04CE2', '11E8B3C6-DEF5-4BFD-8F1B-3C3DECCB1465', '4650069840053', ' /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F764787E-5685-43ED-9D8C-AAD547939865', '7BD61EE3-92C4-4F8F-8D13-BD12B9DF27E2', '4650069840138', '   /        75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C607A3F-8D15-472D-9416-6E2FAB426F77', '0BC59F87-B0EB-4968-8C95-7F4A31868A7F', '4650069840381', '  - / /106 / / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7471725-F354-4A41-ADA6-462F34D75499', 'A162622C-3B83-4DDE-B0E4-12ECF7BFBC3A', '4650069840442', '  . / / 11 07', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCEE2860-573E-4403-A7A6-4B7297C845B0', '3B175C6C-0D70-4810-A8EB-A13C5971A351', '4650069840602', '  - / /23/ / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C31D755D-B5AA-4197-B54F-C5B36910ECCF', 'F6045553-7BF2-4B8B-A885-696377B40D18', '4650069840763', '  - / / 11 39', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C237B2B-9667-4135-8A76-0C26CFDE34F2', '102B2913-EDB2-4704-B66B-A8B5EB3FC9B6', '4650069840770', '  . / / 11 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06985581-3B1B-472E-A838-441A61A3D8A7', '52DDD1D8-03D9-46C3-98F9-3CEE1F087B57', '4650069840800', '  . / / 11 43', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98D8B569-5209-48B2-979A-572D0026FA3A', '88382D5F-ED49-408E-83A2-06EEC46F1721', '4650069840985', '  . / / 11 61', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48ABEF45-AFE5-42A6-ADB1-C31F104EC753', '64AAD6DA-EEF0-4F07-8E46-6B93E514F868', '4650069841401', '  . // 11 303', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2391E7D7-27FE-439C-8647-44C80A9626AF', '1B68F11F-FA02-47E3-8EF1-498C4664FB37', '4650069841531', '  . / / 11 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF307A42-FB48-4F32-872C-BFEDFE340A71', '9D4104A5-8006-410C-912D-0ADFFA4722B0', '4650069842958', '- 105/ 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C7B9E78-BEF3-41F6-8FDC-0BDA25AC66BF', 'B480F703-152F-4E0A-81F2-9B10EA71AFEB', '4650069842965', '- 106/ 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B772C69E-3E33-4D56-A198-42928FBAA016', 'E1750605-1399-4F5F-9CC3-727B31551CC8', '4650069842972', '   - / /108 / / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A4F96B8-496E-432C-A276-0CBEE11EAFC1', '9AAB1647-F581-4EBC-A399-3DA871A94A55', '4650069842989', '- 109/ 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAF1ABDB-04EB-4796-86B9-2824F864B463', '6344649D-2182-4314-B996-1FB0C76D296A', '4650069842996', '- 111/15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAAA3491-22D8-49F8-8254-3AC01774FF27', 'B5C1EE8C-D71C-4513-945C-147E4C72B4F8', '4650069843009', '- 115/ 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('897955A3-DB3A-4AC0-96DB-CB4674E6287B', '0DA32A7A-3CC8-46DD-B193-4D9C9F848CFD', '4650069843016', '  - / /117/ / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36F187EB-0671-4DA9-A807-45A24453CF22', '7B537462-CFDD-4B3C-91DA-7C4069F3635A', '4650069843023', '- 118 /15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3538CC69-F76D-46BA-BC4B-D9F4DE5C50ED', '7A10A6E0-33BE-4AFB-A2DF-8F20322764D2', '4650069843030', '- 120/ 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9373C9A-C646-48C1-8136-07F6E146B8CB', 'F2FFB2FA-B373-43E8-99B5-B73CE655F254', '4650069843054', '  -    11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCB52D45-D71E-4FFE-BD53-1A7C464AB462', 'A7F297FB-6AF8-40FF-AAF2-1656E9159B83', '4650069843078', '   - / /125 / / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C721FD1A-36DC-4DAE-A028-41E572EFF282', '58B811B3-3F3B-4D42-B5BF-8F69956797F1', '4650069843092', '   - 128/ / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93360BE4-D8D9-46CE-A46F-605F9F955BFC', '0F91A8FC-0D30-4049-BB56-B32C4A8619D3', '4650069843108', '   - / /131/ / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4380D5A1-E59A-4D33-90B1-A7700CCFEBBA', '7290CCF5-4AF3-45E8-AD60-5346291BFFD3', '4650069843115', '- 132/ 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7432B5A4-49A8-4A29-9626-78213144BD7B', 'E3C86D2F-ECE2-42AF-BC1F-D52C6DC49D37', '4650069843122', '  - / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('071C6BB0-23E3-4549-8BEA-7F4C6CB28DF0', '2A35741F-04E2-47C6-99A1-B807FC0FD98C', '4650069843139', '  -   11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4318DB27-F17D-4245-BF46-E8830702A8C2', 'FF995387-5DA9-4379-97A6-B2DEA235E92F', '4650069843146', '- 143/ 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4C404F6-187C-4824-B951-92CCE94CC20C', '87ED2284-4BB6-47F1-9002-A348E04A342C', '4650069843153', '  - / /144 / / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D616DF0-3AE3-45A1-BC54-20A7ADAE8658', 'D5FCD596-9E9B-4F93-9F00-C7CCA10B2C79', '4650069843160', '- 145/ 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ED0B505-491B-48E3-9F8C-BFB69FB03197', '6175FF6E-78C8-4316-9B81-551A06F63886', '4650069843177', '- 148/ 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('819F4309-75D1-45BD-A1F5-B90FCE38FBAE', 'D6A5A083-9FC6-4578-8EE9-F1455262865C', '4650069843214', '  -   11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB4935E0-E621-4A7F-9E20-52ABB482C567', '27176807-1334-4531-A9E4-ECC94594632F', '4650069843290', '  - / /165// 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CAD14F8-3A4A-4BE3-B2F0-B49BAE4E92BA', '62D0CB44-AEBC-415A-ABC8-E20E28FE3D36', '4650069843351', '    11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8226464-13BD-4269-AEA2-016FDFFC2A14', '69F66FA1-B60B-442C-B1C1-060E0D507C6E', '4650069843368', '    11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA7EB186-C41B-401A-B680-002628A25842', '81DB2A87-62CC-4231-A26C-6B48B485A8E0', '4650069843375', '  31 /++/ 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8612E701-433A-4273-A11B-6C252C03D846', '473CB254-2331-457D-926F-C3A64770959A', '4650069843382', '   /  11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E5ACCCE-E72A-4F82-9190-8C7AE1EC1E91', '5E7EABAA-2042-4478-B884-614DF54A226E', '4650069843399', '   /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46A9B1CE-E4CE-4FA5-BBF9-97CB1E573CD6', 'FD3139E7-E7C7-4694-8B1B-409578049F6C', '4650069843405', '   /  11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74C8BE25-57DC-46E1-B186-F8010A0B9133', '8498B764-D702-4EF1-A92A-4012C897D783', '4650069843412', '   /    11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1A68067-FF68-4146-A0E4-851FE609A8A6', 'A385113F-6B48-4CF0-B722-28AD8879E82B', '4650069843429', '    11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A897704-FE2A-412F-8915-D3AF75AA139C', '945648F0-83EF-4F32-9F25-C94778015C2C', '4650069843436', '   /   11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C25D6AE8-8F96-459D-A88F-4420299F4219', '773A517B-F7C2-49FD-BCF2-45E1BBD34583', '4650069843443', '    11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57CAC99C-F91E-45DF-A0DE-3854D1B336D2', 'D5BB2E4C-2CFD-4AC1-BE5F-A884EBC0BA6B', '4650069843450', '     11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('803E5CE4-A78B-47FF-A886-350990321DF2', '1A04BBBA-A2DB-4D43-B388-052E90D7AAA7', '4650069843467', '     / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0D743C1-F246-4BB3-8C82-EFC79FBB9E01', 'E6EFF17D-C9DA-4C6B-B8DD-F2819F9A5B36', '4650069843504', '  - 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85EB5A9A-1012-468E-B7AE-D76D44C7DB4F', 'D7502F2D-8AAB-4E6C-8DC4-950112C09DA5', '4650069843511', '    11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('345202EC-C08C-4202-98D8-69D5CF4230FF', '16F00C70-97AA-43B9-AA21-C0473C1FE0C1', '4650069843528', '  -  11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA9DC6DC-4290-471F-BD80-D2F2332B512F', '7702DC14-D500-44E3-BE28-911908EAA292', '4650069843535', '      11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88C46C8D-13CF-4DED-9560-4EC0155C418C', 'C411D54C-DE84-4140-B96A-C4DBFC519523', '4650069843542', '     11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0156E953-1EB3-43FD-8AA8-6FA86C9C1221', '3CBDF72A-4C8B-4A0D-92F9-DEDD6C9FE53F', '4650069843566', '    / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E7F6F87-9DB4-46BA-8D8B-43C592B5B3AF', 'C88ED8E3-3936-4BF4-9A5E-C2B92235D8E6', '4650069844129', '    11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5D5D354-2A74-420C-8662-78FEC99FA6B5', '40FCDB41-5C56-41CC-8348-BF30FD14711B', '4650069844136', '     11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B26D5FE3-9BA8-452D-985A-92557A6FD88C', 'EB4F6700-BF52-48C5-8349-D2261411BB3A', '4650069870104', '  150  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7197E16-C714-443B-BBC4-BC8EBB42946B', 'E4B0A8CF-8E68-4859-BC54-8EBB61E5A30F', '4650070110039', '   20 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20B16D1D-C88F-44FD-A1AB-4F5BF2080E6B', '3EF907E5-61F1-4800-8363-DA78E695AA13', '4650070110053', '    20 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DA0CD5F-D67C-4370-94CC-B9C1CE5E8CA2', '3F0B7F66-44E7-4A50-957F-839F4D01C92B', '4650070110060', '   20 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F79A5D1-030A-45FB-95FD-FEFBB62CC0AA', 'DD924E49-FDA4-4368-A886-6BDC88F8FC6A', '4650070110077', '    20 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7025397D-366D-4F3B-AC04-CC289A69E522', '365920AE-46D3-472C-9B83-E92CF93C1F96', '4650070110091', '    20 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68BF6720-70D8-42AC-B9F5-2D4E7CC2F91B', '9169E452-05A5-4860-8372-7166CC3B7443', '4650070110114', '    20 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37B7965A-D5CA-49B9-930B-60EA90BB012E', '08EA01B6-DAA7-4054-8623-981C4984A66B', '4650070110381', '  //    1-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2F500A5-9D51-4AEE-BB45-657F4E5E3374', 'C72E87BF-75C5-4201-8A95-C54A35B600B0', '4650070110398', '   /    1-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66A1A6D2-99F7-4B4C-BB68-BCA75FD0D152', '7115BC92-09A5-4040-A7CD-DA030030C72E', '4650070110404', ' //    1-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F34092F3-F41C-4D6C-8CC5-923AEB5406E1', 'AA4DC576-99F7-4AAE-99EF-13320E2D93FB', '4650070110435', '     2,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CD26C1B-9FCB-42C3-BDCC-DA23E161764D', '82B7CA1C-8C3F-48BD-9E41-9D7C84AA7491', '4650070240019', '   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB6C57B4-5B63-4287-9322-7F1189B2C92A', 'ECF6694C-F866-4877-A9FF-7F7CF8A50D06', '4650070240026', ' // - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5991AEB9-77D9-49CE-85F7-70F48E01BFBE', 'ACB029FF-D046-4612-95DE-4C7748678887', '4650070240033', ' //    - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCD54F34-2EEE-447E-A841-187C3CF3FEA2', 'E179999C-C38E-4866-A379-74CB5DA10EB5', '4650070240057', '  /    5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AD8A1A7-E236-471B-8EE8-FA30DEDDD771', '27F5EAFF-45DE-46F0-A7FB-3C58774CEEE5', '4650070240071', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E8D6A3C-78B6-4CC5-A936-E7F8F058E32A', '9BEA4B8E-E29B-4ECD-96E1-B9C4C9FFEF99', '4650070240088', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D43BC2C3-EA9F-4B82-8B7D-24BC6EFC054E', 'FFB3BC73-2A44-4553-B7DB-9AF7C291215B', '4650070240118', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A74AAA0D-90AD-4870-BE7D-AFB577039FA8', '4AAF216F-7034-4F34-B2B5-2F814C60CBD1', '4650070240125', '  5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('671EF8E9-25DC-4AA0-A587-78629B5BBABA', 'A553024D-3F1F-4874-8CE0-F3639625AAFE', '4650070510235', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB924A70-2F96-47FF-9EB1-7852CA05D32F', 'FC2167A8-79E9-49D6-AEFD-EC0C8795E36F', '4650070510273', ' /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('843178B5-A37D-4FB9-B1CA-CED7D2AC4CF0', 'EC79B83F-6DD2-4114-B155-84285724A921', '4650070510327', '   / /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B50B5A4B-7936-4AA6-A0E7-26ECBB21359E', '8CBA8196-A632-4918-831B-77DF819EBBEB', '4650070510341', '    - /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21201487-4A5C-475D-A0A0-96A6943B34E1', '5A5CA376-A85A-4D37-857A-AA552123908C', '4650070610010', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B686B7E0-B036-4536-BA89-894547D99083', 'FF93B6A1-757E-4617-9295-CBDF1703D389', '4650070610027', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E76784AE-810E-4F5A-8FD7-42C00ED87695', '5F2DC197-9C79-40EB-84E2-F8DD4743E2A6', '4650070610034', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A0642DA-8972-4780-BCC7-B0A6C0B6E2C1', '2878D8D0-6DC8-47C9-8004-D3352DDB7422', '4650070610041', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('650BECB1-5398-4890-9635-82E44D4F9D10', '6CE539E5-1EBC-4770-9ED7-AA8714A87023', '4650070610058', '     125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACF2CDF8-FE8B-46BB-B51E-48B679F6576F', 'A5626A76-D0EB-49B8-89C4-9B1B373C205F', '4650070610065', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B7E4B60-2A94-41C7-A6CE-83F998E15DC7', 'D02B4738-E1D4-4CAE-B7C2-70EB8B3B11C4', '4650070610072', '    4,5 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53A04D27-C1F2-42DF-A46C-A31622DCFBD3', 'FEF5590F-DD98-4E6D-A8E1-9871F51FB169', '4650070610126', '    -   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('965FDE5C-A409-42A5-B0FD-4CA7CA4FD274', 'AD18CEC9-D9C7-41B1-B6E9-C1DE18D34391', '4650070610164', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3B11F6F-1C1F-4CE2-B21E-5B199BACE47E', 'E53D372E-E223-4E01-8082-70D10E03AA00', '4650070610171', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C92FEDF5-0E6C-4CFC-B400-8B892D419FDB', '77A8585B-6F04-4CE0-87F8-B25B8A8D811E', '4650070610232', '   0,2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B248E86D-1C48-41DF-A73B-89D763EA947C', '99B2157C-9692-438F-BC51-BD164EBD159B', '4650070610249', '   0,2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3E694BE-C1E2-4AF8-9965-501762E02445', '236F9152-DCEA-43D0-ABA0-6776543FCB51', '4650070610263', '    10   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90B13D3A-4945-4337-B678-1C5A897FEE90', '75031F5A-85DB-4CA4-904A-FD28F48B09AB', '4650070610270', '  / 4,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67C49A67-552C-41DD-9DBD-49F6E96D9B67', 'E2B7647A-DD46-485E-B745-FE71FDA6AFA6', '4650071435643', ' 320 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D64435FC-8C71-463C-91D1-BCA017303E3B', '7FA501E2-B3EE-465C-810B-FA40C533408B', '4650099780138', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21097DF6-434E-49D2-9E47-1F89DC3DE495', '66B85911-75E3-45C5-A641-71765A7D2447', '4650099780145', ' 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60682AE4-029E-471A-BC11-629584914C7A', 'E4CA84AB-C264-49A6-9739-C947C52E0A01', '4650099780190', ' 2% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A478F7D-6EDA-451E-8941-F159A8F2AA69', 'FA15C994-21A1-4F25-8940-BEF9A39F2B9D', '4650099780213', ' 2% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBCB50C5-5121-4F12-BF32-6A4D9BC1857D', '631BFF65-2443-4E81-9D8C-518296293B72', '4660000410122', '    0,15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FB37ED0-6F79-4106-99E0-98B615E50DB0', 'D645F3E7-6B13-439D-92FD-F8EE9802D263', '4660000410351', '  . / / /..89-98/ 5 // -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('287DB9C6-895F-4659-8115-0AC36096517A', '43D789D6-180C-4050-8C16-ECE733B90470', '4660000410528', '  . / / /..99-109/ 6 // -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59361BC6-EA6C-4419-BF33-7E669F411BCD', 'F5CE284C-BBA4-489D-866E-52F32B094EE3', '4660000412201', ' 1,58  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6366E264-98DC-494D-BBB8-D3A2C7F48A4A', 'AA301A84-EE56-4CDA-96E0-1561C4261DDF', '4660000412232', ' 3,58  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C9FE9DF-6C26-4538-84C2-0A62066253EE', '16F49086-1ACE-4287-9B37-84E73B67227E', '4660003080049', '   0,05%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A60812A7-3FAB-423A-AB7B-31C4E7141AA6', '7213B4D9-D8D1-4C49-8126-2DF7AB2630FE', '4660003080056', '   0,1%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C2877BD-AFB3-4E58-B71C-1111614FE667', 'BFC2EF58-6DD1-48F4-9DCE-864674D8F350', '4660003400014', ' - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54B86E89-CE67-4708-BC20-CB5C2A4E2B47', '8904949C-DC0C-4B0B-81DB-2E8162629922', '4660003400090', '-  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6379E1E-903B-4618-AA10-027AD69D34D7', '1BD0C5C1-DE16-4144-BF06-2E6C974A3B73', '4660003400106', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FA990B7-E442-4E5D-837F-6F6DE788FC0B', '11F3D421-D6B9-4D0C-AFE2-D50FA3B669D3', '4660003400113', '-   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37482D7F-862B-4C65-B0A9-3DFA2110253D', 'BB204A62-A76D-4B79-8A1C-C98657783EFB', '4660003400137', '- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A43734DB-33DE-436C-958E-651FEA85C012', '0773E156-8630-4C19-ACC0-32207083AB7F', '4660003400168', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ABDF77E-9EDE-4A09-AD62-27B2F471012C', 'BB204A62-A76D-4B79-8A1C-C98657783EFB', '4660003400250', '- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77BE9814-0DF9-42CB-9D9C-34FECEE17E3E', '8CED3A3E-AE53-440F-AFB2-2057FC8B5570', '4660003400687', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8613E3AD-2BE9-4F4B-92E4-59278DE510A8', '7ADDF052-CCFD-4CA1-9C2B-D1755C83AE27', '4660003400908', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7ADA52E-9AE6-40DF-9A85-FDBDED28B958', '39198686-3921-435C-AF69-F4AD95DFC4B6', '4660005620069', '  // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8281EC6D-5120-43D7-9AC0-C3C27C2E2CD1', 'F51AD99A-1961-4019-8FFC-032745088B4D', '4660005620076', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EDD6FA7-E588-4564-A039-79EBFDD431A7', 'DCAADCE6-73D5-4777-9AD0-01DB843DCED9', '4660005620083', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('255EFB27-3D6D-4C2F-964B-6C0650626199', '63069A07-49A0-42AD-9425-6F1D659C0B33', '4660005620533', '  /     4 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74301DCC-E146-40E3-88EB-1403A9A04B4A', '1FAF031D-AB36-45FA-9946-2C46EC51EF87', '4660005990018', '     2   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('621139C2-3453-470A-B690-761102746E5B', 'C2A22931-E163-497A-B12C-8DCDB609DF41', '4660005990025', '    2   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29AC28D0-E160-4592-A5A8-94C8A116831D', '40C06863-6B1E-4B5E-8D74-08EB27EE6E69', '4660005990032', '    2   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64A8CB5C-6E16-4615-AAD7-1582FD65BE22', 'F41FB9D0-13AE-44A6-8596-F17D8B7F87BE', '4660005990049', '  .   2.. 4 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA8EC6F5-DF2C-442D-B4DA-E7586BDA3F5F', '6D9D452A-CB5A-4F41-8A5D-7CF37EDD8804', '4660005990063', '  .   3.. 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF91D56C-BA3E-48B4-A6F9-AC02FA328660', 'C008D598-3A8D-4F58-A178-65CC1A43E09A', '4660005990070', '  .   3.. 2 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A651B89-CA59-4437-A269-81B83AE293EE', 'A05582B8-97BD-44F2-94C5-4CE31A45B217', '4660005990087', '  .   3.. 3 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E804B959-2C32-451F-867E-0ADB4E1AB5D5', '3FF7710A-DBE3-423B-A9C9-9F2AFA12D203', '4660005990117', '     2/ 1//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97E868F1-1A34-40E2-981D-07ECF641D19A', '26B2176B-B467-4ADA-BD65-979D98786E62', '4660005990124', '     2/ 2//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BC31F8C-B624-40BB-BFC0-6503A3D741EB', 'D5703AA2-57D1-43E7-B928-1CC82F86277B', '4660005990131', '     3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D30AEC1-8B24-4145-ABFD-9FC560B6703F', '8AB92367-2813-48A3-A230-B2318521682C', '4660005990148', '     2/ 4//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAEC219A-1978-46D7-9849-67471B6C9785', 'E0B7131C-DB11-4C64-A897-8F95E06EBF26', '4660005990155', '  .   2.. 5 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BAA48FA-D284-4456-AD8A-6AD476D48530', '4A45E0E1-C1B9-41CC-9DA7-D9CC09F3CD48', '4660005990179', '  .   3.. 2 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E9A1D9D-D94E-4A52-9E7F-2E0472BD7D32', 'DC79D708-4601-47D9-8990-B5B3A5E4355C', '4660005990186', '  .   3.. 3 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36549672-8669-4A46-BFB0-2099589500D1', '50465825-013B-48ED-8829-926A2D155281', '4660005990810', '       3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF03A4A3-1631-4106-9E89-D89FDB9EC10F', 'E9FD9D50-9F38-4795-BB4D-C7DB7446AC17', '4660007090068', '      -3   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('193695E3-0AE0-48D3-9EE6-4E793CC088EF', '73ABEFB2-3ED7-4316-A5BC-05B83B8FE433', '4660007090075', '   -3  4 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92301B51-6040-4EE5-A65D-7D7A86199CA0', '4A2D6A83-E0CE-4A94-B0B8-F3493A1172B1', '4660007090082', '    4 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9235A181-2356-4041-A932-F8D7678F47B2', 'D76EAFC9-A135-4DA1-92B9-11D631E43130', '4660007090099', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('377884AC-1F19-4C41-8896-B3D5EDD7A8DB', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '4660007700080', ' 5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88A35CF9-59A1-4999-8654-3241357880F6', 'D2B950A9-A8CA-4908-9C50-F74BA91FB53D', '4660007700097', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B441EBED-804D-4F98-BC96-C5D1CE643AEF', 'DDBA14DD-4B68-4726-9E19-9656CBD01F17', '4660007700233', ' 5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C981B516-0D62-4829-811A-4F79AE716C8D', '7A521097-95D4-46FC-970A-68331A417D68', '4660007700363', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54056D55-223A-4A32-850E-790518F44A97', 'DB9AE522-7513-4053-A3BF-3416B706FD3F', '4660007700387', ' 20  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('092C110C-FD9F-4FEF-927D-9139F0FA46EA', 'AC8BE330-D4B7-4F09-9AE0-37A3CD286722', '4660007701025', ' 10  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15677BEF-E499-48E9-A02F-D5211FCA4252', 'C18562AF-7764-4147-9782-A23076B7237B', '4660007701186', ' 15  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C0F8890-AE6E-412F-96AC-9AD634BF1F59', '8838EB78-84EC-465E-9F82-3B2321E67EE8', '4660007701209', ' 15  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AA5FEAF-67BC-411F-8F4E-D9CA0FE78793', 'ACEC81ED-8880-42A9-AC21-E4BA67C65048', '4660007701575', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE0EA77B-3FEC-41CB-BB42-66CB4C7D0C48', 'DD38BCDE-4D74-4F40-8282-C6AE7E61DDDC', '4660007701780', '  1,25+4  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('401D8949-7770-464B-B817-323678753E2C', '4A3A66C6-2720-4657-856E-84BC34C66BE5', '4660007701827', '  2,5+8  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBAA7D46-B563-4FF6-AD40-F15C72549236', 'C0C15ADB-10CA-44FE-ACDA-4FDFA61538AB', '4660007701858', ' 0,12  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8802A690-8EB9-4AB0-AE30-4626AB6B6895', '81B0CFA4-4224-45F4-BE16-673FC4C92F3E', '4660007701872', ' 120  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEA35D83-5903-47D2-A070-43B336685DA1', 'FBE9A8D5-3120-462C-A12A-D942003431CE', '4660007702176', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAC36EC0-EC7F-40FE-A2C7-DF99869650C8', '596FEF04-40CC-4205-8AFD-2A897A2AF2F6', '4660007702541', ' 5  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E38708D-1E7D-4AC5-AE5D-BB3A708A3C2E', '18922815-2D8C-4DDC-9649-24935364C480', '4660007702664', ' 0,075  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADD1EDAD-BD53-46A0-A5A3-D76A6FEC16E4', '0117346F-15DD-4532-A137-36683127DA40', '4660007702930', ' 500  // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2A6BC0A-874D-4DBD-AA5E-FC332C90E27F', '8451248D-FDED-41B1-B2CE-12193ED85199', '4660007703142', '  10+158,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CF0269B-50EE-4291-A5D6-268175FACD4A', 'DE7F99CA-6963-4130-B710-7B89127E0C9D', '4660007703173', '  15+153,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('043C0049-E3A8-43F8-98FD-E9593D581526', '6C2497E7-D951-426A-967F-02C4A85BD0D0', '4660007703913', '    . 850  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0BD46A6-0EB8-46BC-83DD-62D91314A76E', 'C8335160-84DD-4AF2-A19B-ACFAB0041CA5', '4660007704026', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B307942D-4490-4D48-A7B8-134D7B3E12EA', 'FBCD1B38-6F47-4F68-AD5E-EE276BD7FFAA', '4660007704033', ' 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDA4DE54-6F19-41B8-A2D8-275657C007C5', 'FF2A6465-C1B1-4DE1-AC5D-B96BC6DDD816', '4660007704040', ' 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D583E7F-FB85-477C-8448-02FE86FEF74D', 'F7EA6D1F-8751-4C10-8C8A-EB82A3731D22', '4660007810154', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F46A42E-EA74-4642-9A6E-C45D548680B6', 'FCF9463B-1E69-4C57-83BD-A5351D0A7386', '4660007810222', ' 24 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2086A69E-EEC7-40E9-BB4B-EE4A1FB69FB8', 'D936DE22-75D1-4759-8173-DAF9186E538F', '4660007810246', ' 24  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('314F40B6-D1D1-4BC6-AE37-C89231852B92', 'F1E42041-25FA-4432-A81D-178FE2A3E12C', '4660007810390', ' 2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE5D346C-0798-482E-9208-B49F8337E23C', 'DDBA14DD-4B68-4726-9E19-9656CBD01F17', '4660007810444', ' 5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F9B4456-781B-4785-9A96-9DBEED64AE0F', '969674FA-50B3-4E4A-BF70-A742501A1A42', '4660007810475', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80D659B5-0C2D-4D8E-B186-9D1C3F84AF52', 'FFFD72F1-8BAA-47FC-8EAC-725A0A8419CD', '4660007810482', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC3BFD0D-A203-4C46-B9D4-4184A8DFC823', '6B735EAD-4531-4A87-898B-6F061A94B4A7', '4660007810543', ' 250  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('570B4A8B-07E5-4F60-AA7B-CCDF07466F8C', 'A7286499-1A98-40A3-885E-91030F323439', '4660007810598', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70666746-FB6A-473A-9DB4-9AFD48E58DA6', '9C9BB25A-3B79-4312-9C84-5426E69AAE24', '4660007810611', ' 500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C96FDCD-E943-4512-A745-BDEBDB77EC83', 'C8335160-84DD-4AF2-A19B-ACFAB0041CA5', '4660007810895', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B534F5D-E23B-4638-99DC-8A321CC3ECFA', '91EA663F-1A66-437F-AABA-583D46C5DD05', '4660007810956', '  // 0,85 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('964DA63E-512D-4605-9BE2-E20A8693AB9C', '4179E891-BD56-4EB3-80A3-B62C3E5E6E05', '4660007811014', ' 1  // 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6F9B929-BFCC-41E7-ADD3-FC5B9B65848F', '93209699-C224-4238-8433-187D135E49A8', '4660007811076', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE2C4560-976F-411C-9A62-019F105E5827', 'F2E43CB2-4445-486C-9476-C16F292316EA', '4660007811175', ' 0,5  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4492F87E-20CA-416C-8ED5-0E5A98E046A3', 'EC17DA47-3F3E-4A69-99A2-4A90D9884228', '4660007811236', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5939A43-1D0A-4537-A57C-49966D592730', '28672181-6238-4FFB-8BB8-581D41977394', '4660007840830', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11A56C3D-96DE-42CD-B256-26667DCBE094', 'AA7F7750-ABB6-45A7-952A-B0E242B96EDB', '4660007840939', ' 250   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9BD983E-CD1E-45B8-955C-3A468F64D1D3', 'CD633F1A-A603-411C-ABD6-DA5B9920FD50', '4660007843022', ' 0,002 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD5B4CFA-0D02-49AB-AB5F-259E239715AA', 'A8F3976D-6DE4-4308-8DB5-9BBF2C291AAF', '4660007848522', ' 0,035   /// /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6905FEA-7807-4163-80FE-13ABA06902AB', '088FB410-EA48-450B-827D-E98FC29726E9', '4660007848539', ' 35  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3911074-0200-4765-A1E1-729E639AC734', 'EBC38D4C-5618-4261-BFA9-4F56381FC9B8', '4660009150098', ' 510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16396A16-2FCF-44CF-812C-72A295A59861', 'D27D9D27-FB4D-47BD-8FB0-5F8657FF8F4D', '4660009150166', ' 38 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF29DFAB-5C94-4294-B9B3-BE2335BBAB4C', '11C0EA4D-57B5-42B8-926E-1DFEA280D023', '4660009150173', ' 3,58 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E42DA38-D3E9-4316-A30C-265F2C5A84B3', 'DE1B3FCC-8DF7-4CD7-9532-1CA03B02F11A', '4660009150333', ' 310 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBF28572-4FB9-4E50-A319-FF8CC0FF1510', 'F77EE8D4-A249-4070-AB1D-2A14AFA134AE', '4660009150340', ' 315 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED973B80-E65D-44B7-8364-ACC7FDA7F78F', '99136443-7467-4723-9101-F62F8A599A28', '4660009150357', '  320', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1EFBCCB-3A54-4700-B761-3A5DB4D443E1', '7AD54117-F385-49F7-B091-37BFD058B04E', '4660010100433', '   /     .  . . 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('284C6479-7A72-4159-8162-B9B9D3364ACC', '008E3CF0-F2EA-4760-9583-3E9B210F2314', '4660011211657', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ED6CF9A-0119-4304-9261-C91A7F12477B', '954A7695-785F-40E3-844A-9F03BCF1E831', '4660011213170', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBFBEDEB-0E60-433C-BBE4-FF60B692DA68', '17724091-7B32-48F6-8C31-BED0D5A821E3', '4660011213194', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76CC51AA-3B63-4517-9503-C466EC62AD00', '6F5C3AD3-4D86-4914-8358-915B3111F23F', '4660011213217', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8970A1A-4FE3-4256-831A-A3EAFC947235', '2599D832-1E4E-4670-81A3-C84DD99A7D02', '4660011213545', '  100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('706ADE27-2D0E-415B-9497-FD881269EFFE', 'FDEB511C-43F6-4EBE-A2D8-D6B4E791DF14', '4660011213569', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D5A71B0-340B-46E2-9B9B-15A7285C65DE', '90213CEF-70DF-48BD-B976-349D15DD9E3C', '4660011213613', '   250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC8CAC44-C0DF-48B9-83A2-84946004FD3E', 'BE5EC503-1D81-43D4-9ACF-59DE3CB86E4B', '4660011213644', '  20+6  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20550931-8F7A-41D3-B00C-3A21058546C0', '246620C1-B657-4289-89CA-7598BC1C2FEB', '4660011213651', '  //   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A6B28D4-E494-45E9-B0C3-EBAC616F77AA', '1349D76E-AA65-4910-BE75-3A68023CBE86', '4660011213675', ' - 0,1  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D59AD32C-8951-47D2-9B2A-1DB1C4912363', 'CAFF4535-F70C-43FB-B6E1-80D44F1EB2AE', '4660011213682', '  14+6  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F47CCC20-0EC2-4509-9F37-42EA0B7941B9', '02DF891A-0665-4C99-B939-8BEDEE424814', '4660011213705', '  30  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD0C9521-56A3-4A94-BD7A-EA2F62637E44', '92293E7F-97B6-41EB-92D9-C7FAA6FF1047', '4660011213750', '  /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23E3A1E5-8CF3-4749-AE0B-7EBBE7335306', 'BF30F515-D474-4F41-A5FB-2C423106FBAE', '4660011214207', 'L-   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D43D9BB-4893-44F2-9CB8-13E6D9F3F73A', '33D88FD6-E5C6-42D7-B01C-05AA35FD6786', '4660011214269', ' 3     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA66C980-4316-490F-9634-6CD88334433F', '2F7BF587-C4A0-446C-9B4C-BB889855A5DD', '4660011214276', ' 3     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC93D66F-7607-4FE6-B205-76806B573A27', 'CB61FA1F-A150-41D3-AAA5-554142757359', '4660011214283', ' 3     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89EE4E83-E017-4A9C-9710-5C15578F2B58', '9EC498EC-55A2-4E61-B92D-F17B88FA349B', '4660011214443', ' 6  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0EF0D70-BA7E-47E1-B3AD-C277AE5ADDE6', 'C709D8F0-FCB0-45F1-ABDF-82077F3A30DF', '4660011214504', ' 6    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA222F65-2552-45EE-AB67-1ABEFA52BFEE', '6D6973BD-AA69-4082-940F-1DFB05F754D6', '4660011214573', ' 100   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('094ACCEE-D9FF-4792-9813-B5E299D32FC9', '2668391C-E7E7-4C9A-A139-439B40A081F5', '4660011214597', '  150   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A28C1F7-49BC-42BE-B248-0425D15CF484', '67AC56BC-5674-4A57-8337-443027042089', '4660011214627', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C0B779A-A1B1-45DB-8322-061C3CEED2AC', 'DC984068-7D94-4145-9430-9E2A7A5BEAE9', '4660013570219', '     /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DA8A7CF-2711-4769-8DC4-748A0EA04F66', 'D3332FBD-3C27-4B04-9DA0-C85152BA7409', '4660013570226', '  -   /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAB0807C-9A0B-433B-978F-08DA43EAA450', '689BECCC-CA67-4920-82BF-5F9AEF7B6EDD', '4660013570257', '  -   /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('458B4400-FB61-47A6-967C-B54AB7CE4FF9', '415DC71E-02C3-4EE8-A87D-7F7D41CCC858', '4660013570271', '  /   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EA60B0C-EC1C-45B3-8522-C9FD48979B4F', '50966081-D5B1-4E68-82B3-92882891C1D1', '4660013570288', '  /    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F741F64B-3C86-439F-802B-F032E8519D49', 'B29AA091-11C1-4F8A-AE35-7679DACD5CBB', '4660013570295', ' /    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEECCDEA-91CD-404C-A942-54DB436E3F6D', '5960B132-F984-47CD-9DDC-81A4AD740026', '4660013570301', ' / -  . spf10 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D94E121A-252D-45D0-A211-770ED39F98A5', '33661326-CB0F-47D3-848B-5BEA016FC5CF', '4660013570325', ' / double juice     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69C34A37-D35B-46D9-BCF8-53A92F3BE38A', 'CC74E1EE-9F8B-48EC-BF2A-EA5F20AD05EC', '4660013570332', ' / double juice     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('622B86B8-E1D5-498F-8AD1-0023DB42DDDB', '68972BF4-064B-4365-BBC0-ECA649AE833C', '4660013570387', '   6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF6F6B29-3764-4BDB-8685-114973E7D44E', 'BF29DDE6-F629-4906-99D3-5242F0DE91C8', '4660013570400', '    //-. 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9AC0FE0-A331-44BF-BC49-914DBD11C91A', 'BC9793FD-3902-4B08-A4A8-79E8066181FF', '4660013570417', '  / , - 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBE1A382-F978-47AA-8E79-288AE8B0F0B9', '874B0D29-08DE-4094-B248-D9669FA52A26', '4660013570431', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7D3E589-8A05-4D1C-B6EF-C7D54C6FC5DC', '1B4C8D47-AF63-4141-AEF6-2E6EF420C2F9', '4660013570448', '       . . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('982E9CF3-0E69-4B3E-BA7A-F0EC3AD418B4', '42A9F19D-21FC-4CFC-8564-FC3C2310ED8A', '4660013570455', '         . 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('322BB689-7113-4BCC-A2D4-F0ACD89E6992', 'E467583B-BBD2-443B-B51B-0413ADE8C493', '4660013570462', '       /  -./ 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85734428-620D-43F8-8ABE-5C960A8EE990', '69955A40-7017-4187-B279-96F1D7C8086F', '4660013570479', '      45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C46CF770-EBB1-412F-B2F0-1A9B6BAFB67F', 'C3785675-4670-4B4E-8D7B-E7262790C577', '4660013570493', '    /// 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01C08C32-FCFF-42C2-9D48-C9AFC118649A', '9981234D-C025-4D35-B41C-3CB1F7A8577E', '4660013570509', '   /    /// 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A31F716B-7838-4E2A-B46C-37411CF2B705', 'E1F7DCDB-19EF-43E9-99D0-24665CA8971D', '4660013570523', '  /  //.250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('311AAC63-628B-4B44-B872-235C15CB13F7', '77A07FEE-1229-4DAD-A386-0E3541578021', '4660013570530', '   /  //  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F9A732A-2FAB-4935-AB1B-4695135739BB', 'D286F7CE-32DF-4DE2-B550-F02637633D4E', '4660013570547', ' - /  // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03FCEC05-C69C-4732-B7BE-62DA1FCF96FC', 'DD727214-232C-4AF4-AA33-2C4EBC10D652', '4660013570554', ' - /  // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51C69814-AC62-4FC6-97D5-2F8941BAD6A9', '89DBC66C-2816-44BC-B062-D56D3259E669', '4660013570561', '  /   .150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16DEAF57-328B-4A7D-8380-241746430A3E', '015261C0-A10A-4115-8359-3455D5EB2C0E', '4660013570745', '  -    130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9691EE94-13EB-4F65-B51B-C7F11B2F8CFF', 'AE6362D8-FCB5-4799-87B1-7B06579A0FC1', '4660013570752', ' --  .   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB59D310-785E-464F-B02B-EF44BBB42A8B', 'FDF8CFE3-45DB-4C53-8BDC-AE8C867243AE', '4660013570769', ' -- /  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6566FEC9-DFA6-4467-9A99-364D82C863AE', 'D654F407-79FD-42F2-AF02-0F57D539457B', '4660013570936', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6D1698A-006E-43F2-82F9-A1CD200D644B', '22BFEE62-B06D-44B0-91F7-B4683132E706', '4660013571001', '    60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56A08CC6-FBD0-4EB5-9F5B-146D27B2726F', '57C68515-427D-4F9F-85F3-58DAE420EC7B', '4660014120024', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76FBD8A5-2309-4A02-8A37-68FD802E4CDA', 'EF8291CB-9AC4-4D2F-97F4-D066172C767A', '4660014120093', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5415CA2E-79A1-4AE5-8A9D-22E77F2287CB', '779285BE-4ADA-48A5-B9E5-814E1473912F', '4660014120109', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABC94804-3EEC-4556-96D7-B46E7FA76785', '0ED14C3A-3DFE-4C6E-B8AE-AEB2B5036241', '4660014120116', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('095E05E6-37FE-41A9-8C72-E49C2D5C70E2', '5DF92EE0-5EF8-4C4A-95A5-C7A58C2F8361', '4660014120123', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('224B3221-7FAB-4F61-939E-47646595B0E2', 'E0CA45D6-2964-422B-84A5-93997C892EFA', '4660014120130', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDD150B8-1ABC-43AB-B380-34592FCFA4F8', 'BF032C42-8023-44DF-B2E4-89BEBFB8B11D', '4660014120215', '  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B66062E3-C456-4812-B664-094C1FE3031D', '7AAFE2EF-5273-4169-A808-22297A539F2B', '4660014120246', '  /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AF25B43-9719-4FFA-9342-322ABDC2586A', 'E59F0EC4-E2AF-453C-9208-BE1A690655E0', '4660014120253', '    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B9F79F5-8584-45BA-A6AA-E3EC6B12B8CB', '776C4EE0-0F96-4B7D-A287-666F2D113188', '4660014120260', '    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C06275B-2942-4CE3-BB94-C12078E85398', '2E2FDD79-DF1B-4BA5-A853-F3A2ABFAF89B', '4660014120314', '      / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9610E980-B8AA-423E-A507-3A6227AFBCD9', '10043446-5A12-46E5-B83B-22853FBEF570', '4660014120338', '   . /50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5D25CCA-E160-435C-8152-72F59A8D7337', '90A7F2BF-C9F6-4C57-8C82-3F2B475118A1', '4660014120345', '     / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCBAA165-6A45-4D4E-BBBB-05859FA60004', '395D47FA-CD3C-4462-9589-4F3B9CF27F65', '4660014120352', '  /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5445C31B-9C4A-45DF-92A5-34485317D35D', 'C8B546C3-5A7E-45C6-A049-22B07D751EF7', '4660014120376', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EA4B033-B17C-407F-9687-E310B93698CE', 'FBE8FCB7-A43E-4431-8A4A-08C5BF112254', '4660014120383', '-      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('917155B7-ED29-4DF2-8D31-BC47EDA3536C', 'A6126A79-951C-4E83-94D6-021FAACDB2CB', '4660014120406', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F22C086-99BC-4AC2-9B03-3DA1B394EFBC', '2CA0F749-0CB9-41C4-90A0-AB9370F2B0D3', '4660014120413', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B65254C9-5DC8-41A4-B93D-EEE650C7F91D', 'B0AF3CA4-576D-47C0-A607-9DF1F158E794', '4660014120420', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA6A5F60-0FED-4642-99C9-FD713289578B', '108B80DA-E01C-4BC5-BB5D-BA344D237693', '4660014120437', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22BB7787-1098-415B-B579-39CBD9BD3559', 'A5A32C55-E74B-4041-8A30-DB92DB0307F7', '4660014120444', ' -  30 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26183726-D17E-49B5-9DEE-65E5138C3A88', '75372828-561A-4653-B898-31CA39C9BBFF', '4660014120451', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2380F0C3-94F2-4F66-9558-3554D9DCE712', 'D0B6DBE1-4F1D-43AD-A39D-4A59E65155CA', '4660014120468', '   /      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F50727E6-6994-4B05-85DD-2FCFC6F32DA3', '0850E613-83FF-4A79-BA3C-7662BDC3B9E9', '4660014120475', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E34D638F-EE79-4DC3-A4F7-6E8D6A265B61', 'EC35DAA8-FF47-4BBF-BC5B-F313E6283CD8', '4660014120482', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49BD4F5F-C022-4B32-A749-C660DDE5C81F', 'EE5F124D-BD5F-4889-B12B-EBA780BD73CF', '4660014120499', ' - 2// 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEF86AC7-F8B3-49E3-8B49-CE500C89C9FF', '49F99F30-399E-4BEE-AC91-93243D081B07', '4660014180011', ' 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E6BE810-3D1C-4EEF-B62E-EFC0303BFD7E', '4FBEC8DA-7267-44B7-A00B-7D4E21E5C27C', '4660014180240', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76A5A9FD-6112-447E-BE47-C755BF8FBD96', 'D3338741-31A3-4FB8-9C01-1B879CB9661F', '4660014180363', ' 1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49434DA5-C800-4DF1-B7F4-5DF4F189A49D', 'D0A13016-20A5-445A-9770-54EF32E65708', '4660014180547', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('092261B7-6F34-485E-9523-3E7C77BC92D8', '02DDF7DF-FA6A-49CB-BEC3-B78BA31A6E40', '4660014180561', '  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9FA1E09-1B2E-4739-955B-9CCE125D6DF2', '5B7969E8-5600-4ED6-BFBF-83443BE90764', '4660014180615', ' /, / 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E0F3202-105D-4E47-8CF8-9ED6AE20365F', 'A83E288D-19C5-4DEB-A1C7-7C9071683270', '4660014180639', ' /  3- / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E302ECA9-4282-488C-A6C7-2F7CCE21DB3F', '0D591A3B-A3DA-40D7-BC7C-EA00C1D877D6', '4660014180653', '  2% 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D72BC44-E562-4FD8-878A-884BD7E5BAE4', 'FCF3DDE1-06AE-480B-8A3C-C064861460E5', '4660014180677', '  - 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E833EA0A-66BF-422C-8779-B3CA29B41633', '5E467ED4-284B-4CE9-BA2B-B6FD004972FB', '4660014181032', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('586873CF-FB09-4F98-8FEB-95174D0AA7EA', 'A5B3C477-D916-402B-A874-E4D3FC56FECF', '4660014181056', ' 1  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('525885B9-FAE1-4D1A-9392-13A04C522FD6', '7565AD9C-E225-4A79-B762-3BC0AE58FF11', '4660014181070', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9713A4C3-309A-4F59-B9E8-DFA6F6EF6EE5', 'D0A13016-20A5-445A-9770-54EF32E65708', '4660014181087', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A2FDCC3-8914-49F7-BDE0-A2CA8A875896', '701CBAD4-F826-442C-A3EE-CD0A0895D477', '4660014181094', '  0,45  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF54FBD4-9B27-4B4E-B792-A4DBE179D0B9', '554B5ED4-2D54-4155-A467-3E1BE88D0311', '4660014181100', '    3 45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B75D7511-52FF-4C31-8977-222D7D2A29C1', '90084A92-805F-437C-A1AF-9A5407223202', '4660014181117', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3357D097-0B54-4042-9047-986A5371D1F3', 'BD4B7973-9AAE-42BA-ACCA-5FB39AE117EF', '4660014181148', '  0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('896219CE-5A36-4A93-A350-ABC4CBEB7981', '4FBEC8DA-7267-44B7-A00B-7D4E21E5C27C', '4660014181179', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78670941-F39A-48BB-81DB-0A37231405F3', 'C7536757-08D0-49E1-9134-E6325EB26F0B', '4660014181209', '   1  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF610F64-32DA-4949-918B-82DEAA877140', 'A5B3C477-D916-402B-A874-E4D3FC56FECF', '4660014181223', ' 1  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('656B437F-2632-45B5-8123-6AEBF360E632', '9AC43BAA-454B-47A8-BA63-E0594852F3DD', '4660014181230', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC004FB9-018C-4B71-AEA0-B92A42804600', '71D32D23-65C2-4ECF-8E08-96A443E02D84', '4660014181247', '      3-14   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DB14282-6B7A-4209-8596-50AB9AFBA1B7', '824F971D-FD8D-4C5E-B2B2-26590B153F6F', '4660014181254', ' / 510  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A897695-FFBB-4EEF-9F0C-2F78392CB810', 'AD672412-2186-4580-964E-BB8EB64BA53F', '4660014181261', ' 50   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F684429-5985-42E2-92D1-BB90EB5B9E22', '75CF1551-AD27-4333-8044-C4BB745E362A', '4660014181315', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09C1FA33-A127-4FC2-9191-828D3E7BC3F2', 'E9CBEC1E-B3D8-4B05-95E1-032BBE88A4F2', '4660014181322', '      . 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CF941BA-0746-410B-91FD-5AFC3221D74B', '74BEC4E2-7CCB-4720-AB96-0B644542B7AF', '4660014181377', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6B44129-88B3-4607-80CD-3FE2B365E577', '5722528D-95DE-4D36-BB79-CA380EBA24E2', '4660014181384', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AA49ADC-CB26-4C18-8C12-52E6890ADCD9', 'FCF3DDE1-06AE-480B-8A3C-C064861460E5', '4660014181438', '  - 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C5F1B57-561C-4E01-99D2-97760AA473A7', 'DFB27ABC-4028-4A5B-8816-10599A469437', '4660014181445', '  525  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82B0B9F8-07A8-4BF8-BCE8-A5F4485A09FC', '28AD56AE-6DA8-420F-BA0D-499397DB8D9F', '4660014181452', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('450C42B1-1020-4A89-83C0-1E542C808190', '7565AD9C-E225-4A79-B762-3BC0AE58FF11', '4660014181476', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DBB140F-9E13-43FF-971A-634842FEA958', '66E22943-189E-4F58-A83A-6B363A52EAB5', '4660014181483', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6A32E6A-3904-47D5-B15D-3BFCB1CFD1E8', 'DFB27ABC-4028-4A5B-8816-10599A469437', '4660014181490', '  525  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('887F21CF-F3A9-4DC6-BDCF-2E1AD00D5DB7', '75CF1551-AD27-4333-8044-C4BB745E362A', '4660014181506', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29599DE9-6471-4A80-92CE-6408D4100E1E', '701CBAD4-F826-442C-A3EE-CD0A0895D477', '4660014181513', '  0,45  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47B826D4-1D90-4118-A052-CE71F3FB97B7', '90084A92-805F-437C-A1AF-9A5407223202', '4660014181537', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('200D597D-A200-4397-99E2-02708334C9A9', '4E3C5F84-1982-4749-AA1A-A503793A9512', '4660014181544', '       60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CE97579-7489-434F-ACE1-C9F9E4148FAE', '74BEC4E2-7CCB-4720-AB96-0B644542B7AF', '4660014181551', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82AA1940-2B84-4C88-823F-297860347656', '5722528D-95DE-4D36-BB79-CA380EBA24E2', '4660014181568', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18BCF656-7B5D-4C56-B28E-66EF424ECDCD', 'AD672412-2186-4580-964E-BB8EB64BA53F', '4660014181575', ' 50   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDE09D64-E30D-40B3-B80D-EB99C463DC75', '9AC43BAA-454B-47A8-BA63-E0594852F3DD', '4660014181582', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96A3CEA7-AB47-4E20-8CE0-551D6F93B2C3', 'E05D7E88-8DD0-4DC8-8BCF-F136081F153D', '4660014190010', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75BA9913-4295-4675-9E08-A9DC99D7ABF0', '64CD1835-18A7-4367-A8AB-CE677F27EE4E', '4660018600010', '  /  spf15 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C6B0A31-CB0E-49F7-A4F2-31C8FC7C5F7F', 'F93F3B14-D8D6-4816-A002-96B30464DDEE', '4660018600034', '   /  spf 25 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AA1CAB8-CB54-45F6-A1AA-0143209DF94F', '58D38F0A-F541-4F86-9DE9-CA0E5E88387B', '4660018600096', '     160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50C3C1E5-0D13-439A-9196-07938562F972', '13BFED30-5A00-47C8-9854-B1B11450E5AC', '4660018600119', '   /    spf 30 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('167EA470-3652-4586-97B6-0A3CAAC0D4CB', 'B6759085-95D3-42B1-A1F1-2FC7D528921D', '4660018600157', '   / spf 30 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('024FD254-E967-4848-B7DF-BFC388A43AD6', 'D911337B-73B5-427A-97FA-5D59391181F4', '4660018600232', '  time /   spf20 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5EE9BC7-0640-493C-8595-E010F490BC00', '684C9611-6614-4BE3-B399-C087A1233458', '4660018600317', '  time /  spf40 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E4256B8-7F3B-427F-9EB9-BB99431443F8', '8B60E4C8-33E2-4B5B-9A6B-5CD0BDF8F75E', '4660018600331', 'Sun time sey bronze -  spf 3 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1C58F94-692B-4338-BDAB-858F2D880889', '64C454C7-8AFC-45B2-8780-D9CB96F6541A', '4660018600355', '  time sey bronze   spf6 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C57151EE-9175-4181-A747-5C74596ADF36', '6AC0B53A-A184-4026-834C-CAA1E11E5484', '4660018600393', '  Sun marina   spf 30 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('062AE97A-0CD8-496D-A8EF-DAD95760551B', '60DBFCE8-36BD-41F6-9FA6-5E41A8122104', '4660018600416', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6EE49B0-0A23-4D89-BF0E-ECA4E4B3315D', '69C2BB41-4EE7-467C-993D-99177BAC54A6', '4660018600430', '  /  spf25 95', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('689D0544-23BB-44D2-9D5C-7E701A6FDE10', 'FD6312C2-10F6-48FA-8B91-2E038585058D', '4660018600454', '  /  spf35 95', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66EF99C7-6C4B-404C-928B-863D06FAA0D9', 'B6491E95-9DF8-4089-AAFD-28F0E08B2CC1', '4660018600478', '  /  spf45 95', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE3594FD-A4DF-4F52-A5E6-DF3DCB421496', '12F3E6EC-34D8-47DC-A137-5F3C1B671016', '4660018601284', ' / 2  1 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4D01674-BB33-4EE9-87BB-BFA1198D7127', '54932F88-C0E0-404B-B270-06E9C46411F9', '4660018601420', '  Sun marina   spf 50+150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9187F54A-AD24-4CA1-94CA-3BE81977A1A3', 'E9E0D26F-0C4D-483A-8DAF-FAE3E49343EE', '4660018601444', '   /  spf50 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('281B417D-3D79-48ED-9F00-1EE2F132A906', 'F6EE543C-0E66-4C1B-8830-7EF5382ED668', '4660018601536', '  //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F4DD979-D565-407C-8487-A4CBB12BBB27', 'A24B17FE-6F0B-4EB6-BDE6-61C72F89C6C6', '4660018601543', '    /  . spf 70 /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FECD4A28-3A64-4F95-9DF6-4CB746A1255B', 'FD2D0242-A365-4F77-BC00-A81EACAE91E7', '4660018601550', '   /   spf 50 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECA29D81-D8A4-4874-A7EE-9B19EB5B4D2B', 'C856F907-DF6E-44F1-A769-157E617944DA', '4660018601574', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E524150-94FE-4236-8B30-805771D3BA37', '5D1DCD32-4313-4817-8950-C1FDC63AB84F', '4660018601611', '  /  spf15 95', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B35C2240-6592-475A-A98A-6B44A38DD017', '9E3077C7-6BF6-475B-85A7-783F76EDBE3E', '4660018601642', '    /  290', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D1CF761-1C9D-4395-B18F-B00A0A3D28B7', 'BD5D72E0-F2AD-4247-924E-38BE7B7F0707', '4660018820098', ' 1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B661813A-E3A5-47A3-8FB9-360E277A7BAB', '882221FC-EA98-4C82-B0A7-C33C9E61F1A4', '4660019931359', ' high risk  - L 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95D1C48B-E1FC-491B-B75B-DD844C9FC944', '0E80645F-CFF4-4DCD-B348-858774BA0917', '4660019931588', '    . 7,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C37AEE9-6526-44AE-89D3-A4609B262EE4', '5B0BB41F-9227-4DB6-8A88-CD4A51E05F3A', '4660019931595', '     - 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7F4A191-C9CC-477B-8259-72959051B74F', 'B67267EB-DF63-4C96-9E62-4A04852F32B3', '4660019931700', ' 210*90*20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EA15486-F905-4593-8357-1C32E2D5D5B0', '9A1C0675-47A9-4F0D-9795-0FB12DD9C197', '4660019932400', ' /   /1 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F145AC45-4F63-476C-A2E8-E0B090B881A0', 'D508EF74-8B98-4ED7-8E5A-6FA0D7AE3BE6', '4660028030067', '  7,5  7,5 8 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B44C09CE-29B0-4966-92AB-E97A29985796', '6349453D-527B-4ADF-9278-8D49872367C2', '4660041990454', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA6A5B80-9FAE-47C1-8502-5B37BD7316CB', 'F67C88E0-3CBE-4C9D-A312-81941E6C2398', '4663111034430', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D399BBD5-9C39-460C-BA15-0CDA5114B403', '925ECF9E-A2F3-4440-9BC4-0E3C6438E218', '4663111034447', '    / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2445E307-B874-46BF-ACCA-E1082A4ED8B6', '0924F343-08EA-447C-BED2-9E2C35C5576D', '4663111036830', 'Herbes     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BF8EFFB-3869-4029-B7CF-38C077A310EE', 'D325DAB3-D387-4E75-98E5-3498E113E431', '4665273050037', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7F29817-637D-4875-9AA3-163D5527AAE8', 'CDE61842-15B8-4BE3-AD51-2875E4714A47', '4665273150010', ' 0,2  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CD7675D-AC94-462A-810B-316FE9482AD9', '6A2FBD04-DA50-4D5B-A95B-07E8C57CEE13', '4665273150027', ' 500  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E334B1F-69DF-46EE-A556-4BB0B88ACCE0', '3514EB43-ABF6-4AE9-8E6F-1128CB7D6622', '4665273150034', ' 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('510E509E-782A-43A5-AF2C-F6CBF8E18958', 'E6DFA23D-9D93-4BE1-969F-DBD6DBE01997', '4665299447415', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('571859A7-AA27-4F26-B419-FE727F45BDC1', 'FA7CFA1E-D82F-4062-9CFD-08A1D51351DB', '4665299686760', '  3-   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBE25A61-F6CC-41CC-A8DA-05C0773BBF61', '0E3E8703-7712-4077-941E-F41AD211DA98', '4665300271077', ' ././ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FF1998F-E548-47B0-A7EC-DFCF3FC1D2A7', 'E7791523-51E4-4D0E-80B1-324E0D138C66', '4670000470019', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2B11A5A-4613-45E7-AC1B-6F827CF08BB0', 'AD6FF72D-AC5F-4B2C-B161-00DCBDB5A25D', '4670000470071', ' - / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1AFC87F-E958-424E-8505-9FD3208E5522', 'EBF9253E-081D-4FEE-B7A8-3BF54C2D0A60', '4670000470132', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB20C1B8-1440-4960-96A8-1D145E3115B0', '8499E7B0-1567-47D9-9138-2502BFB62285', '4670000470255', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11C3CCB2-1A43-4749-B08F-79CEC4B42475', '81F65C6A-EC05-449E-99C6-7F290FD3F055', '4670000470712', ' - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9BF435C-5826-4BBA-962E-0D102FE2318B', 'A4EDBFDF-43CA-4C7B-BA01-02AE7E96FABE', '4670000471832', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92F94E0A-945F-4140-A885-D4EA77783C7B', 'D607EF28-A168-4B8F-B0F7-F6C73E853978', '4670000472013', ' -   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5816C226-D837-4D7F-B2B8-BF09E1F5790C', 'B84C7DE9-5833-42F5-AFC5-6762370C5A25', '4670000472044', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA7727D1-6804-4A6C-98A6-317E2AD78679', 'D4CE508B-6BE6-4CCD-833C-A52AD3D07D06', '4670000472068', '    - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3AB673E-505C-4FCF-8E96-7458E8237249', '8864E779-F434-4115-B8F8-5A26C00D13E2', '4670000472167', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('263DC5A9-AB46-41EF-BA27-051A7F47D55F', 'DA10E5E6-07B6-4B5B-B8E7-FBCAAE2144D3', '4670000472211', '  /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8936D4C6-3428-462E-855A-35AE6CE5BF6B', '38291C4B-1B53-4852-9282-8248A23E8D7C', '4670000472235', '   /      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCFC06BA-3922-44D5-A8B8-5E63DF7E890D', '5928B717-6A76-48D1-A689-57F24FB7CF88', '4670000472259', '  / spa- 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F7329E5-5FD2-46DD-8E33-19482BAFDEAE', 'F5978E42-1DE2-41D4-88F3-1270BC88C93C', '4670000472297', '  /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9150162E-451F-4661-9671-72E9072AA9CE', '73EF6CAA-E46D-4278-875C-21A645656029', '4670000473522', ' -   15 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D29C216-64A9-4029-B37F-7EB910355A6D', 'C734DF4F-6C8C-43D1-BE99-39EFD5285401', '4670000790094', '   1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4D1510B-4FDA-4B96-B601-659F3AEBDE16', '3501ED20-4718-474F-A2C2-4541CA63E4D2', '4670000790100', ' /  7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E159600D-DB23-469B-9E2D-2D453BCA4943', '7B0F801A-4E3F-4314-87FA-7B145C3B465E', '4670001381741', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('084F642E-A6C4-46F1-B8CB-6728D27EF2E5', '58A30C44-CE5F-4EAA-96DD-0D705351A8D0', '4670001381758', '   (, , ) 500 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56AE1ED9-8800-495E-A10A-B6EB6FDDDCE0', '31EC0574-0D69-4816-9F9F-86620F6097BB', '4670001381765', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('626EF467-A998-4476-A453-9E10D9CBB849', '78DA60ED-ADD1-4882-886A-466073FA54B6', '4670001381772', ' 3   // 0,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA64E6FD-AB8F-4B57-A4AE-0A61F378F1B4', 'BE3FC8A6-B2BD-4B31-85C8-520B683F6446', '4670001381796', '-5   0,5     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD625812-7A16-4ED0-9ED1-41DCD92F83BE', '73805F8C-2C5A-4802-BBB5-87406B3979FF', '4670001382243', ' /renewal/ 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5ADC61EC-3258-4830-8805-F981E7967984', 'C4D70E26-D019-444F-9D50-5AE56BBFA9C4', '4670001382250', '  0,6  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3A3CAF1-56DC-425C-B36D-E8F9A896BBA5', 'F7BA9B2F-47AF-4C78-934D-3C6E43E99142', '4670001382724', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45477780-8C1E-47AB-91F0-0C0AB57A2326', '169C6BE0-0A45-46DA-ADC2-0C8DAD775AD6', '4670001382731', '  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0EEDBC4-0386-4BAA-9BCA-69F77FD71143', 'E239965A-E479-4301-8AAE-074797DF7EB7', '4670002260106', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7179367-B929-438E-B818-A47F5C3D9F76', 'BCA47E75-3E56-4553-A625-F3310EDE0834', '4670002260113', ' 0,63  30/ /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B464C99B-B279-42AE-9638-A837F3EF804A', '6CE87948-FF1F-4FFC-915C-FE49C7205EFD', '4670002260427', '    /  0,40  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1180CA18-C170-4114-9EE8-8B6337DDEB99', '6B4C20FC-DCFD-467C-809E-75815921D8DE', '4670002260458', '  /  0,40  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('007EA0B8-F9EB-4332-9C71-698EBDB668BE', 'FEAF0DF6-1F30-420F-9744-A6777AA19A99', '4670002260465', '  20 // /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CA314BE-839D-4BE2-B66D-B6C9BD5E1C07', 'B1EC60D3-75D7-416B-821A-94245B9171C6', '4670002260519', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74CB2D3D-8D0B-49C0-A738-1F6472685D3E', 'D30C90AD-A16F-48E0-A406-AB35C20D7A4B', '4670002260540', '   20   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('929317BA-F9B9-4478-82C9-8E1F30E6C193', '8C132F44-E542-411E-AE12-EAB2F44DDFCD', '4670002260724', ' 30  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC455F23-909A-41D4-A7ED-417B3C2C9A98', '71BB3506-F7E8-4957-ACD4-1B2404212BCC', '4670002260755', '  40 . 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC5CB880-EC7D-45AA-BF94-FA5F1248FDC3', '46BB754E-A8A8-4B05-84D6-3040D635FC2B', '4670002260830', '   / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29EAE2EA-36DA-4CF7-AEC6-162118BB19CF', 'DAA9149B-3338-4F61-A19E-481520AEA425', '4670002260847', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9CF804B-EBB0-4C44-A08B-C5347303CD55', '1238F306-6A5B-417E-B2DE-2711C7759A6D', '4670002260885', '  0,35  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80B76E5B-3C65-4682-B454-A7B22716437F', '2CAD4E62-D1BA-4C4F-A686-4DB862DF4D17', '4670002260922', '    1,5 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D99BDF6B-EC7D-4876-B193-DCBF8ED918A4', '2B339192-E2F1-4957-839D-2F888A9D4187', '4670002260977', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F74F525-D457-4705-8E95-952FA50BE7D4', '6D413CA5-878B-434B-B20E-BE60BD86270E', '4670002261042', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('040016CA-8027-448F-81DF-BFD6EDA1361B', '9A1F64B0-A3CD-4BA5-92A3-9387B3E51A03', '4670002261059', '  20   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('509BBBA7-4AE8-4249-9218-19BA36A1B3C9', '4352AF80-89E5-4953-8756-E92BAEB62B9D', '4670002261066', '  20   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39951796-8F17-4F0A-B93B-5D93D90E1D88', '0C97C522-ABAA-4E42-B242-6124F94F0E90', '4670002261073', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4918FDD1-9705-464E-987B-822CCA824A4F', '67B206E5-C8F6-4AFB-A97F-9605C3B1D9ED', '4670002261080', '  20   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('577B89E3-682F-4096-AA71-F69F099EF8A6', '1763D2DE-64EB-452E-80E2-956258B05D84', '4670002261097', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00D46B11-4CC1-41DC-9B00-2E3C0209237B', '33F37E48-F4CE-4A68-ADB5-5BFCB90FA579', '4670002261127', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6920D7EA-A7B8-4C51-83A9-9C9561D65B7B', '731950DA-723C-4580-9746-F58016EAC516', '4670002261134', '  0,51  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1118D409-CF9C-451A-8572-853DBE2B8335', 'E2E81E3B-DF8B-4084-A4A0-2D58C943C1D2', '4670002261240', '  / 1,5 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38760915-D15B-4DBF-9119-DFD3C6D6ADAE', '43582B3B-42F1-4C06-935B-33C3F305E58C', '4670003600802', ' 10 16  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8D730C5-F698-4A25-8794-464189806D0B', '3007A8E7-2117-407E-9506-320503422829', '4670003600819', ' 510 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A84F8877-999E-402F-8BA3-980909030632', 'FAB00712-2A6F-472A-8931-E75EBA79B77E', '4670003600895', '  1614 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E3320AF-5746-4EC9-A33C-6743410F04C2', '97FA56C7-45FD-4BFD-A298-61F8434E1A3A', '4670003600918', '  1614 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60D3ADA8-EC47-4F58-8200-D8306148F826', 'F1B51764-529A-4E37-AAF2-8FDEF49B374C', '4670003600932', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D6F5976-530F-4813-AFF3-3C2487AA12A4', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4670003600949', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EC5FAB3-ABDD-44EC-B239-88DB7F9B7606', 'E667C2E7-BE56-4C99-AA6C-C370B070D6C8', '4670003606224', '  300  90 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59A29728-9CBC-44FA-A0F1-AD0BF1EDDFA4', '82C89BA2-F57D-449B-BBC1-48AF68734DE4', '4670003830940', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34E0BCF6-A898-45FD-9566-58F814821AFE', 'F93FAC18-EB29-4C51-99FB-D2A687FAC9B2', '4670005860044', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7CF7649-1DD5-4ACC-B307-78CD39F0EDD2', 'F93FAC18-EB29-4C51-99FB-D2A687FAC9B2', '4670005860051', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4012D435-D153-42CB-A98B-0BDF67B37D3E', '60CB7EE6-D053-4F88-BBF9-262E5E61EA58', '4670005860075', '  /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('896BD19A-59DF-4B24-9703-0D9E8B133544', '131CCCF0-61E6-4C8B-B399-4F920D7F538B', '4670005860082', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F714258-6009-4129-80A7-C2D48584FD6B', 'FBA1B3E2-78FC-4816-8040-8ABF9FCD4345', '4670005860150', ' Q-10 0,5  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21A88186-83ED-4B17-AC54-5E26A343E20B', 'EA71487D-1AF8-48D9-86C8-6D1F5ABE1C4F', '4670005860457', '   naturlivit 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AED2604C-EA05-424D-A4FF-D22FEB27CEF8', '408DD910-CE49-42B1-B5AD-C7D6BF7348C1', '4670005860488', '         /  250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD13DEBF-2074-44AA-90D0-22A4B8D323FA', 'A7D2C004-189D-49E7-A096-3D67638EB362', '4670005860518', '  /     250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F49614FA-7F2B-4500-8738-4FD86D8EBDDC', 'EBE9E13B-877B-4904-9FD2-309EFE2E0DF4', '4670005860549', '     .  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85A48407-FC1F-446C-A426-D31C36FF06E6', '77927C43-AFB6-47BB-9A63-D3C6B9E22F01', '4670005860556', ' hair therapy - /200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D70D3CC8-400A-4EAA-9E36-0C7744551107', '7A414EEC-DEC4-4281-A53C-3B5BBEBEB394', '4670005860570', ' hair therapy - / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75037634-6D9C-4772-86FA-004BC22318B9', '108C810A-51E8-40BA-9EE2-D347D7E60B6E', '4670005860600', '        150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEF352F0-6C39-4C43-91DE-14429C5E6DB3', '1DF10421-9C10-42FF-82B6-FCA412EEB01C', '4670005860662', '     250  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBCF4DA1-33D5-4FCB-AFA1-D1668B29D35E', '3D1EAF18-E6B4-4F10-A854-5806567C45CD', '4670005860860', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('209E7D71-0B2C-4219-93DF-E33CE19C80DF', '1832781A-058F-470B-B63E-76393C73C522', '4670005861003', '   /   5  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E761432D-1FAA-43A3-BF21-3C8C3847FA0C', 'A529D17D-DC83-4296-A4B4-03887EF4721B', '4670008160080', '  0,1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E823647-894D-41C6-B10E-5C9B72D60427', '04BB93D9-218A-4D76-9716-6734CDF8C361', '4670008160226', ' 1% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F48EDC7-8F8F-4611-8CB9-CECFD9A32D34', '78B24F1E-A7F4-488E-8975-A1B44AD1CDFB', '4670008160370', ' 3% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6D61B15-D24F-424A-9331-CF33BAB7E034', 'FEFD7BEE-4E15-46E4-AEA6-6E1511A20F4E', '4670008160608', ' 5 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CC2A3A4-F221-4FF7-A553-03AD8F320FCC', '9D1BCA4B-C9AC-4779-A40C-105195D84619', '4670008160639', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB0D6D4A-BAE2-40E5-B5BB-7A3BD3754A48', 'FCECDB71-DDBA-4033-817A-B20E748941CB', '4670008160677', ' 20% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAA2B8B2-0E97-4DC5-8BAE-6B8531A2DF87', '35B8A95F-B546-4839-A8E9-DD0A363FCC45', '4670008161346', ' 0,05  -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8D8E13D-992A-428B-A641-4F91872AF019', '30317B99-9C59-42C2-9601-6FC245ED9A9F', '4670008161476', ' 5% 5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('781710E4-AE5F-4934-BB89-2ABF3F7ABBD5', 'A23FF6A4-1A19-4D44-A7FA-CB780857EDCE', '4670008161544', ' 50/2  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('634BDD9E-749C-4F8F-A724-735ED69991DE', 'BB02085C-61E9-4D6D-8901-7EE678C708F9', '4670008161568', ' 0,05 / 5 -  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97EA35F2-2A12-4FC8-BB28-72863CBDC64E', 'CD4F275A-68F3-4EBF-AD8E-EB72C511FD3C', '4670008161742', ' / 10% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24EFABB0-8C7F-40DC-86BD-30493B3056E8', '70DAE204-239D-442A-980E-66C08DF2A461', '4670008161919', ' 0,004% 5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68154ED7-3253-49F5-BDD1-B08E6F441162', 'F016EBBE-8BE6-450C-AE46-FC382A4E3D0E', '4670008162343', ' 100 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C13B2063-E5F4-4DFE-AF0E-73F40B362242', 'D25BD6F6-EF38-4E8B-9A35-342BC349CFEA', '4670008162350', ' / 2% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20D96228-00BF-4BD3-9F90-47153F76C6C2', 'B402ECD4-AF1E-41F4-83B4-B4CFE0BA4492', '4670008162473', ' // 5 1  -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66FE65F3-6E9E-4220-880E-EF3694337D84', '1D7F95C7-F7D8-44F8-946D-43FE05AF1FFE', '4670008162480', ' 15  1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7C28457-1642-4505-83D7-EC0496D63918', '2D083D63-6027-43EA-B41E-0ADA350305B1', '4670008162510', '  -5 10% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6660FD2D-56A5-427A-97F7-29064DFD932C', 'D51C9BF4-DC21-4038-9786-BA83FCD73FF8', '4670008162534', ' 25% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7F17295-3A40-4B29-8708-B435E8C7EE18', '914CD43B-AE9C-4357-878C-13EE9C0C7B87', '4670008162596', ' 0,004 / 1 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5838CC1D-3694-4E34-AAFA-50D60AB7C83A', 'A509250D-0D37-471C-B29B-CCA9015A5D67', '4670008162640', ' 4/ 1  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('796F9E89-77A0-4F95-AC06-6176CB57242D', 'D3B095AF-D74D-486A-AC8E-381BFF0A75D5', '4670008162657', ' 5/1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EECBF634-EFED-49B7-804C-F96DCBF7F703', '85776EA9-063C-4EAE-82BB-44211D960D7E', '4670008162664', ' 3 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('280521A4-710B-4B77-88DB-E753A2977C49', '0650DF49-AA5A-4B52-B1B6-28759B19BC0A', '4670008163012', ' / 20/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('673EF573-6F4D-4894-81F8-5FFB0BB691FF', 'D72D9EEC-C7A2-493D-AA48-CCDEC38CBC91', '4670008163050', ' 30/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('886CE9B9-B35E-42C1-8F03-60E44F24BBF7', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4670008163296', ' 50% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96B008FD-68E2-413C-B26A-52F49222D2FA', '2F798566-4D09-4E5A-8299-4FE71AA508E3', '4670010370071', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('981DED49-39EB-499C-AC05-2A07D710D9F2', 'F4BE64E0-C42C-40AD-AAA9-A45C0564CCF2', '4670010370132', ' /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2988394-ED10-490F-B2DF-4E81A75755D5', '721B2A40-C1A1-452E-9775-CD7A88CB59EB', '4670010370330', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB10DB4A-9275-4736-83DC-B8F9D3DB7F13', '9760A017-C318-4231-8106-69A421B919A1', '4670010370361', '  .m 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35EDE470-9DF6-4AC4-8FFD-63414529AE2D', '152669B5-E0F0-4AAA-B95A-8F63985B97D7', '4670010370729', '      .m  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABFAD8AC-89FB-4A19-8895-012749F452F5', '9144344D-1175-49DE-83EF-D8223A0B29CB', '4670010370866', ' - 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD118019-C1FC-4B37-870D-1E49DED80A0C', 'CCB2A05C-746F-43CE-9F92-C8AC50819744', '4670010370941', '  / 45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF091659-9F60-4853-AC61-BF86161EBFF8', 'C6258E5B-98C9-46D2-8E40-87E6B31C5593', '4670010370958', '  45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('219FBE03-17D1-435D-8992-3E3C4962652C', '63BE9DBE-1272-4B7A-9689-F9E9EBD96E6F', '4670010370965', '   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('528A1E39-CD49-41DA-A222-849A938D5446', '059833FB-93FB-4DEA-9254-B5922187A0AA', '4670010370989', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFBEFCAE-6F43-4C2B-A148-6CDEA8ACA8D0', 'B1C0DA1C-0804-40AF-84B1-BA0D54FCC7BE', '4670010371306', '   /  45', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC689AEC-FEAF-44FD-86FA-7D650B3B3059', '4797885F-C433-49F1-BB60-F2A8E4802B9E', '4670010371313', '   -    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94CC3170-86DF-4ABC-B50B-F116E3567960', '7692BB50-60C1-4640-9CC5-C56ECFE6A3AF', '4670010371320', ' 0,02% 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F07AF06E-1287-4C1E-9321-9A6398E9E80F', 'EBFB4407-691A-482B-AADE-160E078AD4E1', '4670012150015', '   / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25F608FB-0005-419B-89B1-93AFA73D07AB', '2B3CAF95-0A35-4779-9480-5E5666E3D30F', '4670012460541', '- 0,12 //  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62D1F6D6-E651-40EE-AC63-F0CD2FB91BD9', '0B690E07-FF31-4CFB-A4B5-EFD36829432F', '4670012600244', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58BD1723-CA9B-4B6E-A6C1-ED312B4A9304', '0E96159C-D04D-42AB-BA5C-AAA85A0024CC', '4670012600480', '      //     6 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC3ACEF4-D83A-4D51-A9CC-C25BE29FE9A5', 'A3266C93-3DEE-49F0-A740-D9DF2BF56B51', '4670012610113', ' 16  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F4414D0-27B0-49DE-BF59-217FA5423DE7', 'BA8D1CEF-B934-459A-AB12-DCF86FD8F685', '4670012610151', ' 90  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA192758-D3BE-4C46-8B4B-5F0AD71BCE4E', 'C9277339-9265-49B7-B215-8DE832AF74DB', '4670012610168', ' 90  / 168', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A9DF830-16D2-4302-97B3-0CA36B8CBF83', '0FD8A849-53EC-4571-B73A-0DAAE4DDEDAC', '4670012610175', '  25    14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D55D1C0-793C-48CF-9379-2BDC93F47F46', '4C083356-882D-4158-AAD9-BF6E8481EF43', '4670012610182', '  50    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('828F9F12-EF0B-45DB-A499-27D5072A89F8', 'B73F581E-2A73-4C48-80E4-1E02280560D8', '4670012610199', '  100   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E07B8D7C-197A-4C44-87F9-70897E43E79F', 'A520559E-B7FA-4EE6-96F2-3A8F15809619', '4670012610205', ' 20  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C7F1112-A285-4262-97BE-EC0D633165A5', '973782DC-2098-410A-8E97-B12546ADB609', '4670012610267', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94DF9511-EFCE-4D7A-80D1-62FD8EBB780F', 'B037E828-49E9-4060-A1EE-82B7DE218D99', '4670012610274', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC388623-EDAD-464A-B8FB-C173C90C2541', 'FF91E898-CB95-424B-A751-9F918ABC95EE', '4670012610298', ' 10  // 98', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E91E97CC-DE50-4FFF-94A9-CA4E32509F60', 'E8318468-2944-4DED-9166-B2392CDBA321', '4670012610380', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7B82368-08B6-4AD1-81BE-0E66D648CD89', 'E3EB18AE-3E9B-4F7B-929A-8805AFA2BEE7', '4670012610526', '  160+4,5/ 60  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33DB4659-6AC0-45DA-965D-4A11C77A9AD5', '64D47A27-6050-492C-8950-0A8509D07F25', '4670012610533', '  160/4,5/ 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89508520-83B0-4179-A471-760FEAD42752', '86ECEEA9-A3DD-4A2C-A20D-683521922E42', '4670012860051', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48FA5ED4-ABC4-4CFD-8077-102EAA4347F7', '912F3763-D9BD-4C53-A6A7-5B0A408DBC17', '4670012860075', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF2E68E9-6283-440B-B69F-1C251116B6AB', '63D308DD-7012-49F3-8B62-D503F13E3F4C', '4670013490233', '  lenco  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('578B855A-410E-4D44-8857-555A887DB683', '58A307BF-31B8-49F0-A513-72848E1112AE', '4670013490974', '    -/ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F196B747-082B-4F00-91DE-6EE75DD5284F', '63D308DD-7012-49F3-8B62-D503F13E3F4C', '4670013499199', '  lenco  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AA01B6D-EF33-4D7D-97BF-9B67A9D0E626', '2E548030-C847-4F8A-9FB2-EC90F4219C0D', '4670014500016', ' 1  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('489BCCD7-384A-40DB-8464-7802A1BA8861', 'B7B37813-D9A5-4B0B-B043-00F993F3E6E4', '4670014500306', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A74C9A7-1689-4783-AAAE-DC266A2CC8D2', 'EB72BD95-6B27-4A97-A1AC-57DB49D0D68F', '4670014501952', ' 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D1F2F70-419A-4983-9B1A-BD2E20093AA6', '14DB7E41-5EDA-4B4F-8E5A-F4A06C769108', '4670016720047', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FD1F298-6026-46CD-8B32-0C9DFD3FB666', '33CD5FB7-B6E9-4855-B076-B328DDCB1E38', '4670016720054', '   /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E013484-658A-4754-AA88-761327086874', 'A33743E2-A6D1-4CA7-BB97-9CA2B00D797A', '4670016720061', '   /    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C474585-1B6C-4F37-A551-86CB0087F2D9', '1009BA4A-7205-4486-BAE0-90CA722AC562', '4670016720078', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('800EF6B7-B4E5-4398-BCF4-1E9090A5279C', '7AB8F3F2-6C98-434C-899B-7E39F66C9780', '4670016720085', '    10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8992BC3A-F7E2-42F1-A69B-CA17DC4D42B4', 'BA601588-EEE5-465D-9962-274ED0FEC507', '4670016720092', '  waterflow  10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('801E4B60-5744-4AE6-8F36-444D7D073175', '8F4BEC64-0973-4D72-A1CB-931EEFC3AF3B', '4670016720108', '  waterflow 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('333232E5-4BF4-41C4-A072-FB0A60DEB181', 'A104AD16-9BA4-4A11-9AEC-2DABA47AD4F7', '4670016720115', '  waterflow  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F038527-EB6D-4809-89F2-EFA20C762536', 'F2051132-E670-453B-A09F-FA591CB04D1B', '4670016720122', '  waterflow   10*10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44CE1045-27FB-4761-9DBF-D2DA1334C829', '7DF1B854-3D24-456A-B817-F936E3110DF8', '4670016720177', '       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2664A8A2-1231-4DFB-B71F-09776EEE07D0', '6997F79F-DEE9-45F1-BD31-81F4F8A023F9', '4670016720245', '   /    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C5270E0-787D-40BB-8F2D-718C7F5BC10D', 'CD895091-1EDD-4737-B357-A25ABF32B28B', '4670016720290', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B792501A-93F3-4EAA-BD68-0ACEEA59440F', '063555EE-5F21-4800-A9C2-FB58B6FD4DFF', '4670016720306', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('420635F5-4BC3-44A4-982B-390ED8FC4758', 'D06069F1-E314-4428-88CD-75B1C43B9244', '4670016720313', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5314EEE6-1B7F-4F33-8982-928DC5C33E56', '8FDA7DEE-4788-464B-8BD6-530596F7A7CE', '4670016720320', '  ola silk sense 120+12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('301E90B8-61A9-4888-8802-DE9307483CC8', '80BF52D0-D4D9-4CDE-BE28-7F180CB72996', '4670016720344', '  ola silk sense 100//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DA5BE07-1205-47B9-9305-086DE9C8CC9B', '188548FA-593F-470B-BEA5-71749E6DCDB0', '4670016720351', '  ola silk sense // 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19807C63-20C1-4E39-A394-150FDFFA709A', '6EA23511-8C4B-4788-ADBD-C99EA68E84DE', '4670016720368', '   silk sense  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9A1F968-EEDE-4DAE-909E-17F0DB9F2CFB', '47B34A48-8CFF-4D8F-808C-46B08D5465D5', '4670016720375', '  ola silk sense // / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9754954F-B999-492A-88B5-E596072A5C5A', '54929198-4DAC-4107-BFA8-8A9E9D09AE17', '4670016770035', ' 25  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F1488B5-E9DA-4BF3-9798-E53C99A3527B', '0B80EAEA-26A3-4D86-95B6-97F4C80F55B4', '4670016770059', ' 50  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4BE032A-96FC-4D11-8176-DAA0BBC7A553', 'BF4301A0-A5E5-44EB-8BC8-E9A926264B2E', '4670016770066', ' 100  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D039ACC-3F13-46F6-ABC5-E312286D9009', '89A4F9F7-766F-4031-8538-E7B70E46AAB0', '4670016770073', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FAB779F-4494-48E2-8C8D-0E1DC2AEBDF8', '85FBC9A7-A29F-4E1C-9AF7-92ECC5B3C337', '4670016770080', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B05651C7-A9B4-4303-8EB8-94D94B8D497B', 'BD73DF5F-5F36-4322-B34D-6113A73F3DBF', '4670016770097', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1492AC98-9823-4D7C-95F5-DE2467D36C90', 'A15D9597-1339-412A-88F4-54B5FBA9686A', '4670016770103', ' 5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE729732-8274-449D-B094-8D552F9A0567', '066D4DDB-67FE-4BD6-A337-FCC910F42E99', '4670016770127', '- 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F808D67-F018-49E9-A004-BEEA4EA6C0F5', 'D34C82F0-EF19-4055-9D91-2510D0748D54', '4670016770141', ' - 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7F37A81-EBEE-481A-9B2D-4D999B38F197', '2469067D-DAF1-4DAD-899C-D5CA95847ED4', '4670016770158', '- 1000  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ADF8B3F-6D48-42CB-88E5-CBCD72D3F9DE', 'FF2A6465-C1B1-4DE1-AC5D-B96BC6DDD816', '4670016770165', ' 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('313D4C79-1A8D-4D53-8787-AAB4C5523EC4', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '4670016770172', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78F01CD9-57B8-4007-AC13-CB924A295DD4', '0BE9CFCA-A3AB-4097-9F9E-74A3E132E9D4', '4670016770189', ' - 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6FD509D-FF2F-4EBF-80C5-D80691791FAD', '7B04AA8A-3951-41B7-9465-1226A3EF9BEA', '4670016770196', '- 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFA4F923-A492-42D9-863F-35C79398EF78', 'E234426A-6472-42A4-8E03-A5C8C374AB49', '4670016770202', '- 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6143A77B-3FEF-475A-9A9B-10465BFB73C4', 'AFFF4CC0-3B6A-4EFD-B709-F53872B855CA', '4670016770219', '- 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1083E89-336B-4F4D-B46C-8B983ACF18A3', '10313B7B-ED89-4E33-A69F-0A1F8875F22F', '4670016770226', ' 5 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AB2DEF4-22E8-4F14-86C3-85D67D4D97EC', 'E1F6F4BF-CB11-4AAF-ABA5-D7916E6D1600', '4670016770240', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAE393F2-842E-4BCF-A18D-08390BF19968', '23C30FAD-778C-4FD4-8C68-211295A9E0AB', '4670016770257', '- 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23245B2E-DE06-4E0B-A664-1F4A0D7DE1EF', 'C040541A-53AE-45C6-85E4-93B98C013EF6', '4670016770264', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99C184AB-1FA4-414E-A745-73C633D67A2C', 'DEEF506B-DE83-4CBB-8DAB-FDA810401698', '4670016770271', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D08BA1A-CBE3-4D88-8228-7867FAB7176C', '826F90B8-F960-4982-96EA-511120E0395F', '4670016770288', '- 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE64E020-9369-41E6-A4AC-23D5811E219D', 'DAFF09AA-D4A4-42E0-A713-954556DEB8F4', '4670016770295', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B665B20-6845-4FFF-9C23-22ACEE2298DA', 'A80D0EE5-BFDD-4F9A-B5DE-0BEDB5E805BC', '4670016770301', '- 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47DFCBB4-E106-49D7-8C49-AC827E5A5B19', 'E114BB70-925E-484E-8DC9-9C99048CF82C', '4670017090231', ' 1     0-6 800', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05618EF1-2D1D-4121-9E99-C21D00376BA0', 'A1828F4E-4CE4-4A64-BF72-77844DD51E65', '4670017920217', '-     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C63EB30D-8A62-4FEC-82C6-C92B465B15AC', '8B6B7D0E-08E5-4492-A5A7-ADDD454C837B', '4670017921962', ' /   -   2/2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('746C3E2B-BA27-460E-802E-B25CFAB6890D', '421E4803-2BDD-489E-AE78-F8A361B9309C', '4670017921979', ' /   -   2/2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFB2F4CE-2264-47E3-8665-16DBB55FAE9A', '7B008797-C531-4B61-8D29-1B59C562EF17', '4670017921986', ' /   -    2/2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C883915-5704-4CD1-95B9-AAD00A8CF6C8', 'CF0C10D0-2AD9-4691-992B-D3CBE6F7BA50', '4670017921993', ' /   -   2/2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF709AAC-CBE2-41B9-A699-041EF8DE3B90', 'DADA5061-B520-4C5B-AB15-C459337E4A9F', '4670017923010', '       45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E80AE9B5-CD7A-46CA-9447-80B751E98721', '09C2A915-144C-42C4-BBCD-F3CBE9B34BD5', '4670017923027', '    /.   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('505E8513-1D42-4AFA-A22C-56EA0E43928A', '0B447E7A-EC30-4DA8-94B5-D1DA3EA8FB28', '4670017923089', '  /   155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBEB708C-82BE-44CF-A23F-F09ED3815D21', 'B4249636-FA87-4F12-B664-C128B7661D8B', '4680002310022', '    180 7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD478194-F889-42B4-AA79-E88B81E67757', '82F94D7A-8807-4065-B247-FEC1204A50E1', '4680002310046', '    32 60 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52A80B83-FCE4-4D1F-9947-C86FB97D92CC', '21DF7A5D-57D1-4446-B065-9533419F9F54', '4680002310800', '    200 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4250BD8A-318A-4BE7-BADB-EE4485324E5C', 'A1E75258-8644-4498-A47A-7B48AE227314', '4680002310831', '    200 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('187266A3-6267-4902-8101-36F0303F2C6E', '82518A4E-D274-4CCB-9020-EEF42B5BFBE8', '4680002311067', '    32 60 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7DAB08B-F532-425A-B346-72F00185E0F7', '3D3AD3FD-7B44-4749-9A24-842486CDB554', '4680002475646', '          5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CE24F57-E18E-44EB-B020-1CED460D1179', 'E4564875-9F2B-429E-B57B-8D38F2D78934', '4680002475653', '     " "     5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F134B363-3C83-4DBB-BF6B-45E0753C1D1B', '836338B8-E0F9-4CDF-A0D8-54012B624EEA', '4680002475660', '          5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FBAF8BC-2801-4ADA-8AB3-C025AAC1749C', '0CB4B0E9-C764-4C54-A83B-55ED8AA0B36C', '4680002475738', '          6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC85BAD6-A84F-490B-92EF-E27A7E20CC15', '332B9847-9DBF-4602-95C8-EB98CC92D8F2', '4680002475745', '          6.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68C2E7DF-6497-4E89-A41A-15D00AAFAB03', '4B7C9B90-29A5-4C7E-B97E-DE32CFF0E1C4', '4680002475752', '     - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CE4E41F-074A-486D-989D-2F610453DABF', 'BD16AF6D-810F-4425-9E47-CFEBE3140F31', '4680002475776', '    100     6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0811E1D-F01D-460B-98ED-DD964A2A40E4', '8C87FE6F-0B26-4160-9484-ACBD58F30F21', '4680002475783', '    100      6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99DE0586-F1E0-4182-A3F0-3086FF002610', '14B90808-8EE7-40FD-85E9-D540E959E7D0', '4680002475981', '           6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8DBEED3-F628-4DC8-940B-5024AAF03E61', 'DF5A3AA2-9725-4085-9D86-F6B511B00D11', '4680002476001', '    80     6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B50979AA-8B91-402A-B3E7-3B88D7A425AB', 'DE2FC651-C42B-4A47-B8B8-454065D2186B', '4680002476162', '     4  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2B30E9E-7371-4874-B605-29285CD54C68', '00E76E23-7AED-4E3F-9D1F-41A2C84F5B70', '4680002476179', '         4  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A67DF991-CF65-43FD-86DC-34E40ADAA7A2', '4DDD493F-D9EF-4364-8E4D-CC4D91F6519C', '4680002476193', '     5  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE5E41A2-E748-4A35-971E-D6D6ED2B2953', '56719D91-3405-44FE-B70A-C352ABE33774', '4680002476230', '         5  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D474859-49D9-44B5-9870-08A636930EED', '8B2E2C0F-4681-445C-836B-F18C6CD1F266', '4680002476247', '         6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9FB48FD-9051-4E31-8497-E68BC1226D5A', 'D52E6B26-AF35-4430-B88C-384112A8AF25', '4680002476254', '      3    6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96B3689C-6872-406C-A636-F7E608161EB3', '07EB69A9-088C-4F13-95C1-293487B2CC9D', '4680002476261', '         c 6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0FF6CC8-8F82-403B-8473-585BAC89911B', 'C2800B63-B793-4B3A-83F2-D633932EA733', '4680002477190', '  /  / c 4  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('784122A7-9531-400C-8217-8ABF881EAB79', 'B614C879-11B1-4264-A4D4-D21000B4F3E6', '4680002550480', ' /-/  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E6A4105-DCA7-4816-9922-BB5A5372E20D', '67437998-BD25-4CBB-B597-959617956CA7', '4680002551968', ' // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED6A5E65-8C4D-4E93-A5B3-EB167E8E6BEC', '333BA5FF-8319-4B4F-B380-70D7413ADA09', '4680002552293', '  // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA0EC1A7-E913-4373-87E0-1BB214F936D7', 'E907224D-1FAA-489F-8A67-09D4B8145B32', '4680002553245', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB2D7A16-493D-40AC-A720-C2C0386B195B', '8BFB1C8A-22B0-490D-B2C7-AAA6611EEF2E', '4680002553283', '  20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB82B987-7947-4BA0-95A6-6D504569F8B1', '8EFDD397-B1B8-4A52-AB04-C26B8E68828C', '4680002554198', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1510BDB-AE89-4E71-8967-D1911B475CB5', 'FFBEC055-EA28-403F-8DE6-130CE34E7C15', '4680002554846', '   / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('253720C7-80B2-474E-B0A8-4873C5F5CB0D', '934AF27D-C2C0-4C1D-9C2E-B5387935C7DF', '4680002555003', '  // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2781F479-1DD0-4937-AE3D-7A5402ED97BA', '872736B1-DBD6-4761-B4EF-EAEEB98FC518', '4680002555843', ' // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60E91999-65A1-42F8-9708-68C18453600D', '34757A34-BCA5-4C7F-8501-BAF68FBB6E58', '4680002555874', '  2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B52818C-87F5-49D7-A3A9-E65C2637C2A4', '8E264AD3-53F6-430A-9E30-E64494DFD632', '4680002950181', '   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE041D02-3946-48BA-8C94-9B5978D95C0D', '9ACBB23D-AA8B-4118-8064-030202FD4B0A', '4680003370384', '  3 //   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2188A24-A783-4858-9AB0-35DFB57FB6DE', 'C26C00D9-A834-4EE6-AA63-F73A2A7DEC88', '4680003692479', '    /   S - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA4E2844-4509-420A-B723-18A57D3E0C2D', '3D4C999A-CF4B-4C31-A716-342217A75904', '4680003692752', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6A77B35-DB9B-4D02-9C7B-9139E0274102', '694A5962-92F2-420B-B58A-25C2B790BE13', '4680003693063', ' 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8782EB6-BB04-45C7-A8AC-DC475C64F298', 'C8DFD474-18C1-44BD-8D4A-F5771B7BF9E9', '4680003693780', '  3-   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F1200D6-44C4-4AB6-AA47-A800557C4842', '8F90953E-82CD-4EFD-A99A-8426490FF66A', '4680004852797', '      / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E9B8487-EB70-4989-8D0A-03705027C2D5', '177978BD-BCD1-4AFF-82AA-73822E46DA31', '4680004852872', '      / / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74875621-4201-4A9B-B1CC-F83EB67F1BAC', '2B160BBF-6D81-49FA-857F-BB8322E6DBD8', '4680004854258', '    . 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('072C46D0-7F3A-4AB6-A22D-1FCED81D9F9A', 'D6D637C7-F060-41EC-8A6A-F58672215F5E', '4680004854302', '    //  .  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA863DD9-FBCB-45BD-ADDD-5D2B2C7AF0AA', 'AC879FEA-ACA6-4887-BD9D-4DD864A6133C', '4680004854319', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('667AFD02-4680-4FCE-BFE4-24F4C28A76E7', 'AFD3E648-1D2E-46CB-9591-0631CF35D0F1', '4680004854890', '   / /  . 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00567866-4529-4365-82EB-07E29AD249F4', '8BB14181-776E-456D-ACDD-3FFBD1439C23', '4680004854913', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A082B2D-03CB-4676-ADD6-96833986F543', 'EAF9378E-61A0-4C57-B9B3-08E45338FB3D', '4680004855248', '   / /  . 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A1C278F-C206-47B7-A02E-AD2CD73517D5', '4023F51C-8D52-4EEB-850F-C0ACA80952A5', '4680005640010', ' 250 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E666D2F-1354-4B8B-8173-041981335044', '7BBB95FB-1465-4DC6-9190-C9696EE14BB6', '4680005640027', '  / 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AFDD671-9916-4ABC-ABB7-FC78FB981FAB', 'A035BAF3-F3E7-4A0C-9E1C-C9E8C91792A2', '4680005640041', ' 25  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9ED2431D-15D5-4524-8B64-5E88C87F3E3C', '4023F51C-8D52-4EEB-850F-C0ACA80952A5', '4680005640058', ' 250 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA22F435-A61A-4D3E-98C0-2FA25090F691', 'C71FD1A6-175B-4F65-852E-E7A2D9A6C633', '4680005640065', ' 100 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83F740B9-C3AF-4E6D-8441-059F713FD0C1', 'B16946AE-480B-4CD6-9765-D68442ABA7B8', '4680005640072', ' 50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C9E5058-4242-4CBE-9C76-6F1D33669241', 'D18DC729-1D42-455B-BE3E-6E187CB4C669', '4680005640096', '  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD60C2B5-DC7C-4E77-818D-8AB3A762A8DB', 'E3966C1A-5731-416A-A07F-BF0061B74113', '4680005640102', '    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BDF65C0-D857-4241-9A28-B4725C66A2D8', '48BE3950-FC89-4D46-9784-52EC03AD6804', '4680005640126', ' / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B303BF07-8903-4A68-89B7-EBFBBE8C5899', '4023F51C-8D52-4EEB-850F-C0ACA80952A5', '4680005640133', ' 250 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A003DAD-1358-45B4-9DE8-F249A4397975', '516FA3DD-81BB-4DC1-8A58-8A4036C9A5D3', '4680005640140', ' / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDC7C2C9-B259-41BB-B045-2F4B57C5E477', '01F7CB19-4CBD-4BC5-B1B2-0F771863BF31', '4680005640157', ' / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4C75D50-9F66-4233-9567-16595C735A66', '23123A60-B054-4F88-A4AF-9F1BFCACE224', '4680005640164', '  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('275EAC8C-4206-4421-9D69-20FF17140A1E', 'E7F9F3B0-A3DB-4208-A17A-A41F8B640B5F', '4680005640171', ' 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('261A3E26-7ECD-4664-AFC8-483A43AA6083', 'E97EFE6B-6E4D-4441-8A72-37265BCBDC16', '4680005640201', ' 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9043FB57-7E31-4B56-8564-056D72D866F0', 'C7358577-D03F-4AA4-A319-BA3C9159FEEB', '4680005640522', ' 714  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CD4FBB0-B89E-48E6-9B85-89654FD7D7C0', 'DB3FB652-9F0F-4FE6-8584-CCC2B0239206', '4680005640584', ' 50 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F2CC5A8-8C05-4FD9-9ED0-51A2171E5F32', 'F5B19561-2AD2-4CA9-88EE-7B1458346FCE', '4680005640591', 'Cotto    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8E9FE42-176C-4567-993D-A7BC34B17965', 'DF61EFF6-7BD9-4B20-834F-005A18913684', '4680005640607', 'Cotto   / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F5A1CC7-EB2E-4464-8C1F-933A240D08A5', '4365A019-DAB8-4C0D-8631-1E8EF1124822', '4680005640614', 'Cotto     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBF80D21-3A96-4076-8D73-A84CD4888581', '8AE9204A-14E6-4197-84CC-3723F872F711', '4680005640621', 'Cotto     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A504EFF4-7145-4718-9B59-674176CE4BC1', '7221472D-08FE-41C3-9FA2-6C595471B168', '4680005640638', 'Cotto     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6948E922-F601-41FB-BDD6-0E35CE2B2280', 'C4386110-64BB-4928-B539-A49B2FD8FD69', '4680005640645', ' 510 /. /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6B97D2F-B375-4F1A-B9B4-34FC9B419F7A', 'CB16F60F-3578-4298-8784-006BCB091A12', '4680005640652', 'Cotto   510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A9012C5-FA4B-40B0-A6AF-2F1B63C5AB73', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '4680005640669', ' 714 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07AAC3BC-0453-4672-8670-89F42C1C8AE3', 'A5D163FD-F7D3-4EF1-9558-F213E457AEDE', '4680005640676', 'Cotto  714 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99CE2314-26C7-4060-9E84-F18B8D2E460C', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4680005640683', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87E4BE95-B4F5-4BDB-8F8C-1996FD7AAF67', 'C9FD621A-0A8A-4BF9-B655-87163A8F3A38', '4680005640690', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8564C3D-94E2-4E6C-B93E-CD1A6505D98A', 'CB06A0F7-EC68-49D2-BA4B-29F8AA329F7A', '4680005640706', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F85149EE-1841-4DE0-AB5C-6F328F9C14B1', '9E54D138-0238-4A34-A81D-2E54584DBFC6', '4680005640713', 'Cotto  - / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AE34660-7A80-4DFD-8714-9FBE4713EDB0', 'DB2DCDB6-B614-42E2-9F9B-9B38CD5CECD3', '4680005640720', 'Cotto  - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE7DB365-1220-4E20-A189-B34E5607E9DD', 'E6295BC8-B4E3-4378-BEBB-1C8077909094', '4680005640850', '  /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1FF410F-06FF-4262-BFB3-C4641A976B1F', '0F499830-75CF-465D-A435-C3672C03B281', '4680007210136', '   /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FC562A3-A6C2-4F41-BFDE-04A69364199A', 'C1E429A4-0B15-4B10-9D93-D2ED8441D3CF', '4680007214141', ' organic shop     / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F9C07FC-5D25-4DA0-BEED-772F377E70C7', '06244B69-FCD4-45FE-B92C-E1292B6A170F', '4680007630255', ' 0255     4 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86F54A5E-CC82-416B-8294-41EFC253E4C2', 'CCC29E98-E8A7-4BAE-9688-1C571515D748', '4680007630262', ' 0262    . 4   10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B419EA3-8A2B-43E6-A28C-3BF773B4777A', '5CA6A66F-971D-4DFD-B4A3-7F8F64D66DE9', '4680007630279', ' 0279    . 6  8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('715441E5-9F1B-418E-B790-10159C579F46', 'C822F2D7-686A-497E-A126-3F2B7748C7D1', '4680007630286', ' 0286    .   6   . 8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05E162FA-1890-4FC5-9D4E-AC3DFDA5AA43', '7702B676-958E-4F82-A682-594E594B2E88', '4680007630309', ' 0309    . 8   8   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6E545F1-DD24-4321-889C-F8574DC33AD5', '6E16A860-50E2-46D9-AEA4-861167AFA9ED', '4680007630392', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82E8E56C-FE66-4873-8C83-B18C318385AC', 'F39FD595-7014-4D3B-AF03-41CD478B05B8', '4680007630408', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A94BFD36-9C30-46BB-8748-E39636C3D3F5', 'A2458389-56C6-41C5-B52A-5A90351FE65F', '4680007630415', '     7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE4C9D51-B523-4C1A-BA5B-2F553CBFF6E9', '641D3489-B667-4FC3-83EC-0053C4726024', '4680007630422', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F4C4D75-B5D6-4B65-8E7D-541FC9949A6A', 'FFD055AF-6DFB-4975-8CA2-864282CB5E8F', '4680007630439', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D671956-F31C-4638-A258-A67360776224', '914F303D-EDB2-4E1C-871F-692C5581D29D', '4680007630446', '      7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('941D44C6-E10C-4E46-BF0B-0D0770C4C04B', '6E16A860-50E2-46D9-AEA4-861167AFA9ED', '4680007631252', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55C6A9BF-35B5-4DA8-B0AD-DEE45DF9298E', '17FE44B1-564C-415D-9206-1C4D23281C58', '4680007631412', ' 1412     4 lue   10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('914000D8-87B4-4FB4-A030-18AD683C0D2F', '421374C4-2A0B-4F1D-B185-47D0BE680CBD', '4680007631504', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16F06ED4-6FA8-4783-B9ED-41522FB4E063', '2A12355E-ED2A-40CA-8019-DD4A503FCDD8', '4680007631771', ' Terezamed   6090  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40FAF93E-952A-41D9-BE7C-B4A52BE27306', '1F8A7FC6-584A-4783-BF8B-B39FA20DB55C', '4680007631788', ' Terezamed   6090  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AC55C71-174F-4D8D-AA8F-BDD4AAA2FCDD', '07F7DA28-DEF0-4D4E-9E69-1D6ECD766CDF', '4680007631795', ' Terezamed   6060  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('932A010D-6758-4013-BE44-76ABCD36D261', '5FAA36D3-6020-4552-83DB-EF286D78058B', '4680007631801', ' Terezamed  6060  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF6B6C65-C9A6-40BC-9BF9-A78CFF540201', 'C33A41D1-19C1-403C-A42F-5255AABCAB99', '4680007631832', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEF7A8B1-5839-405A-A56C-C0C8D989F78E', 'E9AB1E28-C8EF-4347-8FAA-71F270AE4394', '4680007631849', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CF2825A-A860-4D05-8DB0-60D873CB7B4D', 'FD832782-4D27-4E7B-BE42-8EF3E986E1AC', '4680007631856', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F148AD6E-3433-470B-87F8-86172CC90258', '9B9C7BDB-C49F-4896-9508-3C83E7FB0232', '4680007631887', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB7B2E4F-DE0F-4648-8332-FD550E5F64A4', '960DB30E-6EDD-4603-B1F7-B811C11434A8', '4680007631924', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BF0D093-1436-49D8-BE2E-F5D739A9FD23', 'E9AB1E28-C8EF-4347-8FAA-71F270AE4394', '4680007631931', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78CA0176-242F-4230-94EA-E7CE6C4FDB7B', 'E6D435B9-534C-4970-9886-EA6E0EB0F54A', '4680007631955', ' Ola .  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44D18774-8D5C-4F5B-93F9-F8CD5D5B8E34', '0291160A-8744-4C1A-BDCD-370952A4A5B4', '4680007631962', '      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C14D85BB-FBAE-4B97-9F6B-551FDD292DB9', 'F57AB90D-58A1-47C2-94C3-F645A6D9D6DF', '4680007631979', ' Ola .  20 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5401CE7C-C1E5-49C9-8A33-740FDCE56400', 'D27B5B8E-B61F-410B-865A-84F54B3CC07D', '4680007631993', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D24FD5F-368A-4415-9D9A-725B0DBEBCB3', '7B966A72-FFDA-49C1-8882-CF72C5C8FE54', '4680007632006', ' Ola wings normal 10 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F0D7765-9F7C-4EE6-9C52-A833D8AFE10A', 'DFC1CA03-9734-4FE3-BC06-D7B07AB6718E', '4680007632013', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACFDF317-3F77-455C-BE10-033E2C21FFCA', '54F4681D-1271-44FB-B081-5278BC3D4727', '4680007632020', '    - 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CFAB7AB-4D23-4443-8959-C7D6B192DE09', '292935D3-6CA0-4DAC-89B5-463A637BC5F8', '4680007632037', '     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7981C285-6AB4-42C4-A67C-F77F8B573DF8', '1EE0E91A-70F0-42EF-B7FF-C820AB8CF11E', '4680007632044', '    - 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('950A85A3-BA62-48E8-B963-04FBE9EE431C', 'A27BD5AA-06DA-4BFC-B8C1-C1136DD64DFF', '4680007632051', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14340CAB-4E3F-4CC5-9D21-F3E3E80C8AB1', '2A7923A7-4F51-4896-B2C9-A5AC45938F25', '4680007632068', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAA8FD7A-6371-4A89-89BB-FB5B5E38635F', '7739F76C-E818-444A-8AEB-11A83C2748B5', '4680007632075', '     16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF537716-72BB-4464-9957-F12379F00DEF', '5C2A7771-AA2D-4439-8AA2-6FEB5D6110DA', '4680007632082', '  +  - 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E88AAAC-8998-4829-8D13-13992912FFE7', '45643530-3A2B-45AF-9E96-F2B6BFEE7BB6', '4680007632174', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F145D692-DECF-4834-B455-5483C28B790A', 'BA2B1433-16D2-47E3-9F56-286F1FEAAB8B', '4680007632181', ' .     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10304CE8-CAE0-46CB-9E5E-4AF9606C2102', '06853677-0EC9-4537-8A3A-ED1CC866694D', '4680007632198', ' 2198     4 , 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E28CF9D-49EF-4F48-A9CF-8D38F5290FB0', '2B28ED3B-DF0C-40CB-8106-CDAF4369BB6B', '4680007632204', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('436E7B0B-88E9-445C-81E6-6AD2EA4549A0', 'F447A678-C231-49C1-8B47-EC91F2DE8066', '4680007632211', ' 2211    .6   , 10 2 +', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EDA704F-4C55-4945-AE44-A142D6A09A92', 'B9399C41-9876-4DD5-9702-9D91682FEC96', '4680007632266', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92F0AA67-4102-4BB2-813C-4C1E7AA0486B', '6DAA286F-D0FA-4767-B2A4-BB1F72E2ED54', '4680007632273', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10F89CF5-586F-4EE3-8721-FCC1A20B887C', '7192BBA3-B890-4408-BF9E-4D40313CA346', '4680007632280', ' 2280    6   .   7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA90074F-F9AB-4D83-8990-15A444785933', '6C7065ED-89F6-4E8A-894E-AE9F28B9A128', '4680007632389', '   6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D2577CF-88CC-43D9-AF1E-11A26105CEBA', 'DA56085D-5131-4C86-B544-371E58FEFD91', '4680007632402', '  6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('913D7375-02D0-4540-AAAF-42B8E48F5781', 'F5DB3DB5-5D49-4500-AD27-961812BE82F1', '4680007632617', '   - 20/    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DCE08A6-DD26-41EB-94B9-5D3D186C2E7F', '49324B83-8394-4E0A-A745-6F6AF734B460', '4680007632648', '   - 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96E78C57-9281-48E2-993C-C6884B40A78B', '3D971A1C-FDD0-4216-B76F-DE4328DDF949', '4680007632655', '   - 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17048669-597F-4192-A1FE-36A431B2D2F8', '97F170D8-4375-4474-85A0-422E74945511', '4680007632679', ' Ola . - 20 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0453DDA5-8A73-42D8-9F80-16D880765E65', 'DFD13D5C-C4E3-47E3-B980-45B042937C25', '4680007750076', '  lusan  60 60 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98DAC13B-11CD-40F6-B922-E46C997DB9B7', '39A56C53-77A0-41AA-8764-61697DE523B5', '4680007750168', '  lusan   6090  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E361EFE-7B44-4999-B4E0-5C04F411DC61', '990EE0A3-3E3F-4715-89B4-3D2D2C12A5FE', '4680007750229', ' flufsan   6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('449B3549-7ACB-4E25-B902-FD5CB3619D7B', 'DFD13D5C-C4E3-47E3-B980-45B042937C25', '4680007750236', '  lusan  60 60 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D4C7809-86EB-4D42-A5CB-4C10E982B86A', '17810CA4-DFD4-44D9-B411-60AF25CA89B4', '4680007750250', '   Lusan 60-90 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C53B8446-5614-4EEE-B71B-3BCC2301E36F', '2DA4546C-BF5C-4559-B2D8-EAAF0EE106C3', '4680007750267', '  lusan  6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEF90311-8845-43C7-BDD2-3FA0F643608A', '43AA3756-55B3-4630-BEF9-9821F1C69736', '4680007750342', '  lusan   60 60 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2A9BF6D-D0B4-4309-89C5-4F3BBA80A10B', 'A10199D9-EE06-49DC-8230-E2D20CEB70E8', '4680007750366', ' lusan  /  6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87A40774-9A59-41F7-A8AC-EE0036D038D0', 'EC557122-7E49-4209-9AF3-54FE690CD8C6', '4680007751424', '  lusan  60 60 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F1FD8E1-455F-4A12-B760-17F59D0C3E7C', '33EF6768-D181-4412-9D73-6DD9D5D30C77', '4680008980304', '   /  /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26097FE8-32D3-4BB3-A278-9C93F81F8D86', 'CC505238-4E02-4328-8B56-5DCCFD112A1B', '4680008981592', 'Magic herbs    spf-15 140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D224130-FF74-401C-BC4C-95CF4614F3D2', 'DD426F5E-98BB-4A30-806F-EBF42DD0530B', '4680010640012', ' 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('849DF6E2-AA00-4A68-94C0-C64734DE5260', '5CE98FBC-9AB2-4E79-BE2D-19EE36D28AFB', '4680010790014', ' 120  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CFC7573-08AC-40D0-99B2-F7CC33DFD7C3', '1260C032-9C78-4E36-8E6B-BD71A80CDBB5', '4680010790021', ' 120  42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C78C3B6C-144E-4EC8-B9F2-999002330B02', '6AA34C58-4531-463E-863A-A3240FBE442F', '4680010790038', ' 120  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EB1F2E9-8166-4A87-BFB8-F00880ED57AE', 'ADA59562-9529-44C7-BBAB-EEEF3F0EF508', '4680010790069', ' 150  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B9D45DE-910C-4760-9186-B75649509336', 'D0858672-0D2A-4657-9744-224B95903C0D', '4680010790076', ' 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05DAEA45-1B1C-4F7B-ABFA-D6DF3743A08D', 'BD62B0E7-8519-4B5B-91B6-E942CD89CC54', '4680010790083', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ABC667E-381F-4F96-A4A8-CE53580503B8', 'D9D761A6-9E15-4AA1-98FF-975A27B689F0', '4680010790090', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('043D1661-D714-4362-A447-8BA839F9691E', '48598E93-C602-4333-AB42-BB5B062E16F1', '4680010790106', ' 40  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E509A91-B329-46C2-9B60-85B4F63BA863', 'BA276935-FF32-4182-8409-1CC71F7F1F23', '4680010790113', ' 400  / 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00CAFC98-E66F-4D71-97AA-5BB887FDCF55', 'F7EA6D1F-8751-4C10-8C8A-EB82A3731D22', '4680010790335', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8B0E2DF-65B4-4EC4-9DC2-6E6052261C5C', 'D8CC2938-3DFC-4AEB-8584-B522FB67B9D9', '4680010790465', '  10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('137E69FC-1A12-41EB-A1A8-97B0C10BEC6F', 'B26E2812-0EBC-4881-8FFD-E6671C5B9205', '4680013240011', '  0,9% 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2649604-D8FD-4F28-A517-E9D7AE7DC1BD', 'FACE51ED-4354-49C6-B1FA-051B11C30726', '4680013240028', '  0,9% 250 - / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86B38E54-DA9B-42E4-BC08-757CC354345C', '99ACBF73-5912-448E-8FFD-7416DB6FB6AC', '4680013240059', '  0,9% 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DD69742-50B3-4220-87E7-ED56619E0B71', '37E51DF0-B616-46DD-B093-21C4B37DFF82', '4680013240097', '   / 0,9% 200 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('210652C4-73B3-47F1-B730-5FE6280DAA99', 'A3CF2513-260A-465D-9B88-46CD20C20EC2', '4680013240103', '  0,9% 200 - / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E4E02CB-CEB3-4436-B4D6-32E6644E910E', '37E51DF0-B616-46DD-B093-21C4B37DFF82', '4680013240110', '   / 0,9% 200 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6257680A-EE8C-486C-BDED-A017F33299CF', 'EBD897DF-1242-415D-B0C7-A95415E6A89D', '4680013240134', '  0,9% 400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28A18348-EA68-49C8-8029-E875C0AC9142', '315E593E-CC70-4788-8F47-31135F44D3EF', '4680013240141', '  0,9% 400 - / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF755AA8-12E5-46C3-B47C-F8F237769E16', '2BB6F381-4FD7-4CB0-86F8-E9AF0D32D2F8', '4680013240158', '  0,9% 400 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('923DF1F1-D89E-4050-8FFD-E7FEB6BFA501', 'DBA9B569-CDA5-43C9-839C-1A185BB7D19B', '4680013240196', '  0,9% 500 - 1 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0142C5E-D300-418F-8D5A-8570D6BC9AE6', 'ABA61038-0446-4963-86BF-936353B39743', '4680013240295', '  5% 200 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7AFDFB7-564B-4897-B316-AAC2057A0CDE', 'DF2BC770-11CE-4C58-8D11-CBD983B43813', '4680013240318', ' 5% - / 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8476EF9-D930-4F08-A003-1A976A542762', '6487295F-617A-47D2-B884-3876B3E42E2D', '4680013240332', '  5% 250 - /  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC2B9C7A-7C84-4745-BBA0-E636C17CB49D', 'A6E851C9-FF9C-4650-ADDD-D5A75568B117', '4680013240370', ' 5% - / 400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A2BD094-04AE-4A09-BCCF-154315C2E281', 'B7594646-1CB0-4B33-9D04-B489541CB31C', '4680013240394', '  5% 400 -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E3F84ED-B724-4484-8C10-B204711F7BBF', '517CB052-FC27-49AE-8201-EC85D9E56DD3', '4680013240431', ' 5% 500 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E94C2F84-136A-461A-AE5F-B09ED1810253', 'F3E919D7-F601-42E1-B3ED-95C3B5ACA252', '4680013241049', ' /2 /  250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A89AE17B-F5B7-49EA-B21E-3DAF27B8D862', '55155EBE-17EF-42F7-A10A-D5152D35B2F7', '4680013241087', ' 400 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFA40381-5860-43E3-9C44-E3FD7E36882B', 'F6E6A854-4F94-4543-A663-E3A7CEDF6771', '4680013241124', '  500 - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE90E029-CB94-46AA-8D60-2607F6830F32', 'E9A4CDC7-31F0-407A-B9AD-B7D2B187044C', '4680013241834', '  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('599693F2-C37F-49EC-9385-09684C392EBF', 'CF1E101F-7B48-4D32-A746-FE66FCCFF85E', '4680013241858', ' 400 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAB0C8BE-D660-4E4E-9032-3D0E22B34B4F', '1FFFFD7A-AA93-4C0C-991E-2B4B6AA50B24', '4680013242183', '   0,9% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('506C772B-9767-489B-B709-83A09A55C5BD', '68332835-222E-4E2C-AD5E-A52D457E5EA2', '4680013242251', ' 10 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FABDC009-D844-41B3-9070-CD7A66C5603A', 'F81D7286-6BFB-45F6-937A-4314C8D14CC7', '4680013242473', '  25% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4967D85B-F376-447D-A0A3-F5C19F04C90C', 'E7296CD7-265C-46E4-BB92-C5AC33F73E44', '4680013242497', '  25% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B15E0418-97EC-4E4B-BAD2-94AD0881D80C', 'D40DE8F4-6E3A-44CE-9CF8-71989F033A69', '4680013242534', ' 40% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5B03AD6-6FDC-45F5-B43D-6C09E0B82D4B', 'FCECDB71-DDBA-4033-817A-B20E748941CB', '4680013242558', ' 20% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C10A896-1092-4FA4-9270-3741DC3A8D69', 'EA022BED-595C-48AC-8C77-9024DC02DAF0', '4680013242626', '   4%  10   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50962E08-F2AB-4EEE-9A9F-19ECDBD3B32F', 'FC342286-453E-4E4D-A088-FDFF404648CD', '4680013242664', ' 2% 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D42C66D-AF0A-4735-83C6-0576C349902A', 'F9649F8F-E801-4478-9D1E-5425A3133F04', '4680013242824', ' / 2% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14A14C6C-DE36-431D-BBEC-F1CCEBBA6CA6', 'CDCF25AB-84D5-49B7-B6E4-E3F6F7B46BA8', '4680013242848', ' 0,5% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE33F262-4E34-4F31-BC09-9610D00703E2', 'C23FE29E-5ED0-4D5D-957B-706DAAC8D1CA', '4680013242893', ' 4% 0,4   - 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80B16D2A-531D-4D4E-95E1-16E2649B44EA', '4C33927B-AD32-475D-BE44-1E8BF9CB29AE', '4680013242909', ' 4% 1   - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90C96F78-35DF-4720-86B7-61E1260FB67C', 'C23FE29E-5ED0-4D5D-957B-706DAAC8D1CA', '4680013242916', ' 4% 0,4   - 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58522F03-2A73-4F5C-A346-1342D41729C0', '2A4093CE-AF2A-4D41-BCAF-68E4A8946A16', '4680013242930', '  20% 1,5   2 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFD2B672-BB55-47D1-9871-064B817884D8', '4838AFF8-1FAD-4730-9E4B-0945B227325C', '4680013243258', ' 5 400 - /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('128A0354-A5DA-4A40-B7C8-39B8BF3895D7', '8C7344B0-8405-49EA-ADC4-D2B0E01C241D', '4680013243319', ' // 0,5% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3FEC8A6-B22A-497E-9994-D03E2BCD5158', '284E0DD9-B9D5-46A2-B5B0-489F65AF11E9', '4680013243357', ' 0,5% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C07423A3-CDC4-4F9F-9C4E-C3745881918D', '174DDB83-7CAF-4DAF-903B-B891249A9EE4', '4680013243364', ' 0,005 // 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01FF155B-1757-496D-B34D-04FF572A2793', 'D8857AE4-8A94-4355-B7ED-B2D9078E6231', '4680013243401', ' 0,05% 10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72C366FE-D111-45D3-82AA-DC052F5C4A27', 'CD7968E9-AB8F-4784-8B54-31B8BC8EF77D', '4680013243425', '- 0,1% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61871C7E-0ECF-476A-876E-1B13B0196192', '1CAF0A8C-FCF1-4CC6-BC87-9AF9F6534095', '4680013243487', '  0,18% 0,4    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A4ACAAE-3056-463B-BC16-0FDC5D6132CC', 'B8078C1D-EFDA-495D-8248-4941585105FF', '4680013243517', '  0,18% 0,4    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17153E0A-1D41-45B2-9260-651A3F10A1BB', 'DCB0F389-9CB7-4993-8B67-3A8257A91BF8', '4680013243548', '  0,18% 0,4   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93074706-28D5-4608-8A65-0D6910F9B8D5', 'D2079C69-078C-4D37-A4A7-AF507377B36C', '4680013243579', '   0,3% 0,4    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB76180-6B89-45EC-B07E-E3193A5CCAC6', '509E17ED-AF18-4E75-B0FF-1F1510F1F1DB', '4680013243593', '  2  30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('694C8625-E13E-4024-9819-2DB0784EE9F8', 'E72EA80F-495F-4FFA-8E84-E23757104099', '4680013243609', '  / / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF65D121-2F9E-4ED1-BB49-CF795E845C75', 'CC3BF98A-21F9-432A-BE9C-9CE71FBF5761', '4680013243630', '  0,9% 125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABD5C366-6922-4E7E-96B7-9E772522D358', '96EBD4FF-4154-4F80-A5BF-8D2E7381861D', '4680013243685', '  125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('678102C2-3324-4EBD-B583-7E641FDDF454', 'B94F3950-788A-4AF4-9645-E85736FACA4F', '4680013243708', '   /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12A270E5-9E55-480D-B9BA-0520822F6A5F', '6A48507F-8A11-4A26-827D-E1EC0C92C188', '4680013243739', '   /  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E93DF77-9833-47EA-AA11-D09A5E54F7FB', '2F5E7B1F-14A1-4997-A332-F0BA4D96C1B0', '4680013243753', '  - /  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F83B2A97-E8C9-4DAC-98BC-25FE50F4F9BA', 'D759DFF4-B01B-484A-8DDB-CB26C80D1256', '4680013243791', '  125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4F07CAC-1CF0-467C-ACF6-B5F095D86BCE', '1ABA3C2C-2C56-46D4-AC67-364EDA6C3448', '4680013243852', '  /   125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF897D5B-13AA-4958-B574-B46FCF1B91A1', '509E17ED-AF18-4E75-B0FF-1F1510F1F1DB', '4680013243975', '  2  30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CB59020-C353-4746-86FE-860E0522E04F', '1D4E9BA8-5C7E-46E4-B600-4B09FF03B3C4', '4680013244088', ' 0,01% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E1AA258-B7A7-4A77-B10D-1419C4FC0854', 'CAF6F9EE-0261-461A-81AC-DA9B94562E25', '4680013244156', '  11,25/ 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62A99B6C-243C-4BA2-A10D-0DD26ED51DEE', 'C504957E-CABB-41F4-9294-E0B44D4F3920', '4680013244163', ' 11,25/  15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('339B6E85-DB99-4E3F-B604-EF835AC36487', 'B497B08E-BDA0-4F68-8857-04B798D9DE31', '4680013244170', '  22,5/ 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E68DFAE1-1437-46BE-8476-3DDD3DAFAE4F', '84935945-DDE6-4A18-BAE1-0E97224F8302', '4680013244187', ' 0,05% 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86CA17F4-9BAC-42FA-83D9-27BBC6E27B00', '565E77B9-A542-4E12-BC89-ED560E0AFD39', '4680013244200', ' 35/  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14AB38E9-CD15-4E2B-A29B-83758F97F119', '51614F2A-8059-468E-B02E-BC6A009D04D0', '4680013244224', ' 140/  15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBBDEEFE-3A86-408A-9592-F0D47E3E40C2', '34A36ABF-F294-41D1-9B6A-B7AEF5A62694', '4680013244316', '   3% 5 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D4960B8-EC9F-4861-809C-FBA8298C2E4F', '79D04581-D029-434B-B8D1-B689C8A0BAE5', '4680013244323', '  3% 5 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77ED7423-0152-46DC-A5E3-EF2ADD7002E5', '1EF7CAD7-8F53-4BC1-B757-D5059EF45377', '4680013244347', '   3% 10 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E5AA772-032A-48F6-98FC-A718EE586957', 'E075309B-CCFE-4522-A71A-EAA345142CC3', '4680013244415', ' 2,4% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F01467B-BBE3-40C3-9452-21F8CF863167', '02684725-4CBD-4B5A-B2CC-B317261DD967', '4680013244453', ' 0,024 /// 10 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BA8D418-866F-4F4C-98DF-1D75522B097B', 'E4CA84AB-C264-49A6-9739-C947C52E0A01', '4680013244477', ' 2% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('376130E3-F7F8-4093-AE00-EC0860E6CC2C', 'FA15C994-21A1-4F25-8940-BEF9A39F2B9D', '4680013244507', ' 2% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82F4F6FD-532C-43C6-BCF3-8BA58C126325', '5C9A391E-ECC2-4487-A2B4-777C8C8140D1', '4680013244521', ' 2 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDA97970-599A-448D-88BE-CA8DBE08CA34', '1AB4002B-D797-4756-A139-91914231E9D3', '4680013244569', ' 2 4  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09CEF115-65F4-4990-815B-7C55A7DACCBE', '270C32F4-3B03-459A-AFC2-C05AB7649DAB', '4680013244668', '  0,05% 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B817E758-8CA5-42FC-9237-09058D515D63', 'B24869D7-3CB7-49D1-AFA6-B40115590426', '4680013244682', '  0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8832F892-FC17-491F-A78E-11EF9BEEAEEB', 'B24869D7-3CB7-49D1-AFA6-B40115590426', '4680013244699', '  0,1% 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2BA3631-51C7-474C-9FEE-EB9B67B2B259', 'E25FB881-7F44-4A8B-BD06-E8162DFB9A05', '4680013245412', ' 50% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8C312A5-0198-4B2C-88E2-C91107F57CAD', 'FD8312B8-52AF-4323-BBA4-F2C88946F0F4', '4680013245429', ' 0,3% 5 / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9717C35D-14FE-40EB-A0AF-0181F1D67153', '7B89895C-172C-425A-97F9-1B84723F6988', '4680013245535', '   0,1% 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1E67156-7E5F-4FF5-8EAF-EDA915560C23', '918F7D20-0E8A-4E13-891F-7A6E036C84FD', '4680013245641', ' 25/ 3  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C63C1408-A106-4968-A2DE-73C3A64FEECC', '6274908E-3207-4171-BB4C-C7BBA1202B3E', '4680013245689', '  1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC9E73E8-4F26-47D6-8756-59CF480CF830', '7D8B27F9-19E4-44A8-847F-3AF20A5F36CF', '4680013245771', ' 1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8408967B-FEB3-4662-A916-400872C11C62', 'D6F9976A-7E84-4137-8D08-9A7E5DDF83DB', '4680013245948', ' 1% 0,5    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DFBBDAD-9F6B-484A-84E0-86261E1D9DA7', 'C4B435AE-0C6E-40CD-A349-EF494D94FB85', '4680013246938', ' 0,005% 2,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EFD0939-BC1C-46F9-BDA0-586996298A83', 'E356E783-C9FA-406B-8062-D830AB934E7F', '4680013247218', ' 0,125% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1212649-B944-418A-90F8-2779AC9061EC', 'B94F3950-788A-4AF4-9645-E85736FACA4F', '4680013247546', '   /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E7589C0-5363-420E-BE52-0F8BDC8F16E1', 'C6AD11C6-84C0-4A26-8628-D74DFDD94F86', '4680013247560', '  / / 1 125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F9DC2D4-6F2D-49C3-B8F2-2BB7CD69C88E', 'CB40618D-E214-49F3-9BC2-22564A6501BE', '4680013247584', '- 50 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C58687FB-557D-4AC3-8BDC-D9726BA09480', '03650561-5FAC-4C96-821A-16864E582FDC', '4680013247607', '- //  100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0CFCF05-22DE-4CA6-8E28-C2EF8F9CFD80', '6FFC0EAF-27BE-428B-AAD9-1FC28B0EC672', '4680013247621', '- //     / 50 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2CDE63B-D96E-44D7-9D32-8E2EF5AED6C3', 'E1374040-0C51-4F83-9B95-48B18914DFF4', '4680013247669', '- //  150 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38D39F84-E5D4-40A9-BC0B-269D0D09D9E3', 'E1374040-0C51-4F83-9B95-48B18914DFF4', '4680013247683', '- //  150 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B50450E-75CC-43DE-9B15-D0A9D14B0540', '653CA139-8567-4664-86C5-6EB8E706E913', '4680013248208', '  10% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B10CF7E4-A85C-43FC-9672-AF88D051407C', '5E27E48F-571E-4695-B5FF-34B616C5DEB6', '4680013248222', ' - 100/ 10 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46C8B621-C5A1-4B65-8FFB-DC25AB53A6D8', '4E310828-5E65-40B4-83EB-B2334F4B73AD', '4680018090031', '  55 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B98D0FBA-4967-4D0D-B6CE-F50E4213CC61', '132EAC6C-9F87-431D-9E7D-CBC088C5203D', '4680018090055', '  99', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('129869A3-7E44-44EB-9DB0-00CE476E8992', 'F71B180C-389F-45F1-A2F3-2D93EAC881E2', '4680018260960', '  /aqa baby/   spf 50+75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC8D062B-032B-4742-9553-36460109A06C', 'ADE1E689-9A7C-4885-9249-31E0C44E7D3F', '4680018260984', 'Aqa    spf 30 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4CF9603-4214-448C-99EF-D6953DCDA042', 'DAC5B9AB-E61E-47EC-9640-C2B0C47E8019', '4680019290010', '  /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4213D061-D777-44AD-8472-580FA6971B6B', '53FC147B-9E23-4BD5-8E7A-074752E76568', '4680019290034', '    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55A9AF50-49FE-4306-9B64-6AD7FFC24429', '1933DFFA-8571-40E3-B36A-E2C9F473C553', '4680019290041', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82EF0F71-C622-4732-8BD4-23388E5DCB4B', 'BC1794E1-AAB0-40DC-B836-D21A54755C44', '4680019560397', '   1    . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E60582A3-3B27-4C77-ADE9-C62314EEABE6', 'FC6DD5DD-0229-439D-9A61-F869CD9014EC', '4680020180041', ' 0,6 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7913E8A5-DF8B-4CEF-9C35-1513D6AA0826', 'B08F344E-8D61-434A-9004-6B56256FF039', '4680020180089', '  1%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B8E2E56-BDA6-4236-93CB-B7676278D635', '01AD4498-A38A-460D-A9A1-FEA81BB1FBDC', '4680020180096', ' 1000  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6B16B4B-8311-4477-A19C-3FA844A8A5AD', 'DAC3368E-0E47-46F0-96E9-590233A46D27', '4680020180133', '  5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFF00F8D-0B92-41FD-8E05-0C019D3EC847', 'D7F123F5-7CB6-40E7-BF54-79A601BE7E6C', '4680020180232', ' 10 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84661652-3CCC-4C74-AC35-3E556A2F261B', 'EBCBD511-F7AC-4C22-A60C-2A93552A9FA1', '4680020180287', '  300  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A91281C-562C-41FE-9491-F17646AE841E', 'FA559073-C2D9-4261-8586-06642C957147', '4680020180317', ' 5%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F81CD35-9A1D-4193-9A33-E11779C7AB8F', 'E8411F94-EB73-4992-B22C-E087CE8493BF', '4680020180348', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CCB1F53-DC12-4FE6-8FF8-892A777C2631', '9CA1C0A7-FE64-4405-85F3-83B1A12D7078', '4680020180355', ' 10  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76FA2ED9-D0AF-44E6-BD82-CD8C3185A109', 'C45541CA-0071-4226-BC49-19E8E10147C4', '4680020180379', ' 0,125 /1+1/  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6451DA6E-470E-401B-9B39-353A4950FBA1', '9F8A8076-570F-4B1B-8BD0-2B576AF8F802', '4680020180478', '  /  / 0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EF57B00-1FA9-404E-AB5B-973669BB6566', '82C7123C-70B8-4790-9D71-7305753942FF', '4680020180485', '  0,2  /1+1/  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D335094E-D00E-4EF7-8341-278B8196175D', 'E672DC8A-0EE1-49B2-82DF-A32AE500A5C4', '4680020180515', '  50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('978C5F69-B65B-46A8-8C19-B9EAF3708A79', 'C3DF60C5-3D40-4873-8311-EFC3BC8EC7EC', '4680020180553', '  0,2 /1+1/  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EADC8660-AC7D-49B2-9CF0-D0FDCD31D0F7', 'A50DB288-D1BE-447D-88F6-A22690299AF9', '4680020180577', ' 0,075+0,0152 //  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9880A085-F7B0-40E7-A2D7-AC9CF5E6A140', '8E8CD75E-F1AF-495D-A5B8-128B422ADB99', '4680020180607', '  150+30,39  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DC642FD-CB8F-43A8-862B-DADA68738A91', '91852FC1-C89E-4348-8014-433091CF615D', '4680020180713', ' 1,5  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15D80E9B-103A-4E48-9315-4D3DB8F37804', 'BCA35A2D-5F4F-43E6-A3ED-A840E95560E8', '4680020180805', ' 0,001  30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71D7ACCF-3ECF-467B-B0FB-307527D96E8B', 'D5416C87-1AF1-4324-800C-7B3535322852', '4680020180812', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDFE9F65-27BF-4644-9F6F-E6E3EA010FDD', '8066739D-270D-4905-8A2B-1E72E9D3622B', '4680020180836', ' 40  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F8DE490-4F14-4B9D-82A4-A25C954ADF42', '1F997818-5322-4C07-AA87-912D88521BBD', '4680020180874', ' 200  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C79016CF-07E1-4EC1-867A-76084541B9CF', '3136C483-3A57-4997-A1AF-FF9A9961832F', '4680020230098', '  500+125 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1170BF86-5B62-4B97-BB46-B415915463F5', 'F6640000-3546-4ED2-801D-A73E88857A62', '4680020230142', ' // 100   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79CEEF30-6A24-4A86-A369-00AB7BBEB98D', '2EF7FF4C-EA0F-4B30-90FD-0B7A0E01631E', '4680020230159', ' 100   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14503B50-FF27-49AC-95D5-30FF753E61A6', 'ABB9962D-DE46-48C9-9C69-A8F2A8D498C1', '4680020230272', ' 100  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB32BE82-B657-4F68-8C33-889F480E9B54', 'DAC6618C-3C33-4592-BC7D-65DA1EB562EE', '4680020230333', '  500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B25D6ABA-D597-4B71-91E4-37E46124B067', '1F93397F-3EB1-4741-80F0-7D6F3BD48137', '4680020230531', '  0,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAF2676F-5225-4868-84B6-BF13FFC29944', 'DFEF9C69-0331-4F22-AD1D-3622B79A4927', '4680020230616', '  500  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D674E03-2252-45BB-9136-86C8FBC77361', 'ACDA913D-9506-4A14-AB05-78EB4EFB1ED3', '4680020230630', ' 200/5  / 22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32635932-D203-483A-87B9-A571DBCAE8B2', 'A7286499-1A98-40A3-885E-91030F323439', '4680020230722', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA847413-7AB8-4934-A5F8-9E3A11F38ACF', '774EB078-1B6D-4420-A287-839A0D198C48', '4680020230739', ' // 500  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13815E52-0885-40EB-AC14-C9F9A330AAAD', '448087F7-578A-4E86-8175-B9B966DBCE57', '4680020230982', ' 25000  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C067F20-306E-4B95-B759-7509B51F95D6', '76AD3BDD-ED6E-4F0F-8881-CB061363260E', '4680020230999', ' 25000  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD5EEC12-E967-4038-A1E7-45EDFAC83127', 'D6A31297-6B73-47A7-815C-495D9E35A2F6', '4680020231095', ' 400  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D70C7842-E38A-4DB5-B591-C258692B5EC3', '1453FCBC-254F-4F40-8236-F915AFAEB782', '4680020231101', ' 400  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90C0DD97-903B-4433-A7B2-925AA2F560D0', 'A7EF6480-AC58-4245-9623-2C33216D818F', '4680038247491', '   /    spf 30 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D16FD9F-4EA3-4D8E-908B-76287AB06456', '694DD8CE-4C4F-4F49-A3EE-D9AA1D8C4841', '4680038247507', '   /    spf 50 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67CC592B-20A8-41F3-9BE2-79392613088D', '0D7FFA66-7CA7-4CCA-B797-0147E622C5FC', '4680038900020', '  /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85558879-1064-4F10-8056-6252F65DA423', '5A14216A-5E4E-43CD-8852-15D34447FD58', '4680245001206', '  /  / / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76383620-A108-4743-A808-F05F29986B77', 'CE77E5B9-BA09-4EB8-BEB7-B2AEF4BA2AFE', '4680245018921', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3652B87-CF8B-4BC2-9072-B27F63A1348B', '29C8D258-802B-467A-B004-B60854F48092', '4680287506622', ' .   1,8 21g 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C908EAF-E458-409F-A410-1361554DB314', 'EB5238AB-8C98-4BAB-9A21-332CC63EA94B', '4680287525630', '  /   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F510A37-14D5-4592-9682-E6FAB9B4608C', '15EDE089-C47A-4F07-A9B7-B16752EB32A2', '4680287525647', '   /    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26FBF9DC-86AC-46A4-B317-5C94F8516D14', '6AA40E01-83A0-4CEA-B3C2-6000EAB1B4AD', '4680287563809', '   10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF695871-6FF9-4869-8D40-880383E4D7D2', 'B3241352-5C12-47FA-8F8E-359187E8554C', '4680381003362', ' 710 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5210C261-2845-47AD-9D3E-ABF6975B4AB7', 'EC09E8DD-8C9C-42B5-875F-602EBA5BBCAA', '4680381003379', ' 7 14 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBEA51CD-A4DA-4500-BEE6-77812F24DA27', '8987D6D7-46E4-44F5-951E-A02D06D088EC', '4680381003423', ' 7 14 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D30652C1-B9CB-490C-9E66-91DEBAD5EA84', '624CD9B7-DA51-4BA0-9EB7-A456FA877605', '4680381003430', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60E83C57-3ACD-457B-B1FB-FD65CB1EEC2F', 'C9FD621A-0A8A-4BF9-B655-87163A8F3A38', '4680381003454', ' 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A12658C-557D-46F1-B110-057DA25E1FCB', 'CB06A0F7-EC68-49D2-BA4B-29F8AA329F7A', '4680381003461', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42A01EE0-078F-48EE-8D3E-99C1B10A13DA', 'FAB00712-2A6F-472A-8931-E75EBA79B77E', '4680381003539', '  1614 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56A46D41-60E8-468C-86B5-E8401F471F00', '68F71CE6-5340-4C73-8E30-6F1EF9926CBA', '4680381003546', '  1614  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8511E4E6-8C44-43E4-ABD1-349761B9A22A', 'F30875E9-D35E-4E97-9ACB-8556D80815A3', '4680381004901', ' 1016  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F39D4F4-5447-4FCD-A5F2-FBD2EE61E5EF', 'BABF426F-CEA6-4050-8DCD-7EE77BAC76A4', '4680381004963', ' 510 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B653F53-B80E-4E68-A28D-FD9D0285B9B8', '0AFBA977-6650-4456-B2A5-B7CE9D37392B', '4680381005052', 'New life    714', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90BCFB7F-6683-4BD8-ADEE-DA1102E5658D', 'ED427B94-C3A4-42CC-BCE2-5CFAD59BABDC', '4680381006233', ' 1016 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B34569B-AE95-466E-A8CA-97523ACE361B', '0378E573-93BB-4A0C-8659-C728F9984CF7', '4680381006349', '  life   45  29  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8742EEB-AD58-4564-86A9-2D8A4AD49173', 'B8EED219-958F-432E-869E-292B78BA6962', '4680381006417', ' 1016 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5251B45E-83D9-4554-8B8F-A9DAC11547B3', '9B162350-A784-45DC-9E49-052A3F7C1E0B', '4680381006424', ' life 1016 / 10/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A4B0611-27F7-465E-9DF7-6F6A51126701', 'CB06A0F7-EC68-49D2-BA4B-29F8AA329F7A', '4680381006912', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63CE7440-229B-4EAA-BE42-06A5EB768C23', '0DFFD58C-6CA4-4AD6-A8B7-5A4019FBC814', '4680381006936', ' 500  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD4E2177-4CCB-4470-87F8-AA89B4BD32DB', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4680381006943', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54F25D37-289F-49C5-B590-82DD4E27EA9E', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4680381006950', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78C337B5-CDAC-425F-81B4-F1E11DBE8EA5', 'DC273A1C-20C6-4B7E-B5F8-B5D18414A103', '4680381007070', '    1010 / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('347B2FE7-57CF-42D7-9847-222239969940', '927BAEDE-20E8-47F1-B3FD-C2CEEC14D2CA', '4680381007087', '    55 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6F21395-F7BE-42AA-A368-3D0180684C41', 'A2DCFD88-5CB5-4935-9322-DA4571454672', '4680381007094', '    7,57,5 / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BBA9456-6C43-4390-9680-9C14C48C13D3', 'F03D0789-4783-4AA9-A4E5-46B4BFB06FDA', '4680381009173', '  1614  2-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('997319E6-070A-4AEB-94D5-F24B2A0B4590', '241163F0-D37A-4B88-A924-694529B458AE', '4680381010247', '  1614 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FF7271D-8058-4A86-A96B-31D111B0A9A8', 'DC273A1C-20C6-4B7E-B5F8-B5D18414A103', '4680381010285', '    1010 / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A03963A8-865D-47BC-B8C7-8119FBDF8712', 'A2DCFD88-5CB5-4935-9322-DA4571454672', '4680381010308', '    7,57,5 / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E8849BF-0B4B-47C0-876D-1D1AB5947644', 'AB83297E-0ADC-413D-AACA-165D381B0601', '4680381016928', ' 510 /./ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CD56850-9D85-489A-A138-908147D40444', '35661243-BBC3-4CFD-8693-EC87B8E47514', '4680381016935', ' 710 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80E91D5A-677C-4B11-B0E7-90DB4A2750AF', '08171F10-5C11-48B8-B8B1-6B687B3264E7', '4680381016942', ' 714 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('508A453D-42E8-4908-A95E-6AB1F05EF1D5', '12028A89-129F-4080-BABC-442C423C574D', '4680381016959', ' 510   /./ /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B49658C9-8ADA-42AB-A855-2E9D90091959', 'DCAE0B45-3D6D-4B9F-A779-1126CC4FBDCE', '4680381016966', ' 710  /./ /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08669710-9753-4CB4-A5A0-3434F99AEDC3', '1A513BB0-9926-4F0E-8616-F657FF8987F7', '4680381016973', ' 714   /./ /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEB70519-2C60-45F6-86C0-82E49B11D701', 'BFCCC833-A1A8-43CE-8400-720221DF41DD', '4680381022240', '  / .l  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5927F3D9-5E15-4157-AB18-2CF03BB35000', 'B3AC59EF-8CE5-415F-B298-2C20F17D9D52', '4680381025784', '     55 / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BB23D34-89B6-4B85-A552-EDD74615D3A8', 'D4B0AE6F-4C0D-4A7C-AA85-45772E38ED52', '4680381026996', '   1010  8   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52193C15-0DAA-4D1F-8D11-8001E3997373', '6E8CBD40-AB15-4836-924F-A42B50CA9181', '4680381027009', '     8  7,57,5 / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E23F59F-BD6B-44FE-A6DC-7A574517A429', 'B3AC59EF-8CE5-415F-B298-2C20F17D9D52', '4680381029959', '     55 / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('957DECBD-3091-490B-8E49-D4D30AB94592', '03D73A3F-08D5-4D94-B29E-7105920DB7B8', '4690329004559', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB4904FD-DFBD-4824-A0AE-5522D3BDADD7', 'CC4481EB-8B25-48E5-BF91-E602C96C6589', '4690329004566', '    70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63776B8E-94D3-40C3-9A85-B554251792FC', '69CCA198-D422-437C-8564-3E511F5CD809', '4690329004573', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('224041C3-6C56-4A30-A2FB-61426575A328', '81A8F644-E173-46B8-BBB5-683BCE5CE3AB', '4690419000614', 'Orange slim   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75BA5E39-ED46-49B7-B693-3D5747380DCC', 'AFE474D4-E5E7-4A3E-8BB8-81B54A4D3A98', '4690419002595', '  - /  /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13789A2E-37E6-41DF-9A5E-1D6D5149F7A1', '31789C6D-6815-4A83-BB48-E27CDA96BE57', '4690419007446', 'Stoppr.    / /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39049338-6DE3-49EA-93B1-E305340EDFE5', 'C2896257-E567-4D3D-A240-74928435DB47', '4690419010071', '  .   36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C76E3542-2FFA-41A9-AD31-461312766E4F', 'B8F6BAF2-3606-40B1-811F-4459F0E9E97A', '4690419010606', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D42B8A24-A776-4218-8D01-D4DE65F88016', '2C7DE7FF-14BE-4A54-90A7-5098BE5E06F5', '4690419011795', '    / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68FBECF7-8384-4B94-B83E-FCE9699FC9B2', '20C77BC0-02C0-4357-A3CB-6944DD8F5986', '4690419011818', '    / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2385ECB6-C04E-4AD3-B596-F51F1B4B5BF0', '23AA613F-2E8A-4E58-83BF-6F3FB9A8D2B1', '4690419011870', '    / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70BACBC2-13AB-4468-BE0D-C3D6E7BE8070', '33616DC8-2DEC-4040-851F-75BF6A6ACF38', '4690419011948', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('310AC496-677A-49AC-A6CE-2D313D79EBB1', 'E784EAEE-7069-4511-A478-B2F09AD6E3AF', '4690419012525', '   /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A3166B2-21CB-426D-8EF5-40C831A1C9BF', 'D3D33A63-7E85-4C04-A868-B226D48413E4', '4690419012532', '  stoppr. / / . 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65446079-6016-46A8-A8FF-9CC7DFA44BF6', '9859ED93-912D-484F-A6E0-F878C2009BE1', '4690419012549', '   /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFAA90E7-4F73-4C25-B8DB-1A8D2AD0AD93', 'D0BD2308-D503-4008-9AB0-CEDEDBCFCF93', '4690419012556', '  stoppr.     / . 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BBDD86F-35E5-4F62-B1A3-2F9191E49129', 'E832868A-4C75-409B-8CBA-28309F42D288', '4690419012587', '      /      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63FA7091-AC86-40E9-B1E0-6103CA458A6B', '7696575B-7295-4CF3-B5E2-C6F98D57CFBF', '4690419013003', ' -5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B749B22-6C0C-4521-B361-762A2D850E95', '7F93DCBD-E5A7-4229-8542-FD1B6A30FCFB', '4690447008996', '    1+ 240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F98EFE9-EFF0-4AB9-859C-B1BB563EDAA7', '61448CD1-9B28-4177-85F8-EC2E5628EE5F', '4690567000825', '  - .   + 1% 20 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('581B5E88-426C-41E0-A00D-E00D4F0FF3F9', 'C2E83692-1E75-4A5B-8286-9157D0EDB33A', '4690567008319', '  2,5500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('038F652E-FF49-4BCC-A8A1-D39DBEF90D96', '5D9B16AB-2363-4DCC-93A1-495167C62B48', '4690624006807', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('882378C1-86C8-4171-9BAE-71772F80D74D', '71465C57-2111-4D46-BD52-9FA0E88EDDD5', '4690655000683', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B42EF23B-3A17-4F39-8B08-C94AA6C2E0D0', '14672DEE-9A7E-44EB-95FE-D7ADA4FDDBFF', '4690655001161', '  2,5 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE790302-8657-475E-B1CF-813719242EB0', 'D890BB6D-6A48-4DF9-95FE-D6E1409EB285', '4690655001291', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47C7CE10-1849-40BD-8FE3-8F902E993460', 'BA47F61F-1FCD-4B37-B59D-D0A796916FC5', '4690655001338', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B0ED0F1-2800-48ED-BABE-F80930B71AC1', 'AE75AF0B-4021-4126-B5E3-889B517EA8B5', '4690655001420', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8A8ADFC-70A0-4990-A411-5F771A4888A2', '95F77F3C-7393-4B52-A1AB-A6718CA71A8C', '4690655001468', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19498F8F-6271-4444-9E9C-E598D7C0BDC4', 'CD62540C-A968-4A30-899A-EB418689695B', '4690655003332', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29C8CCE4-3FB6-4E82-990F-72B1EB512126', 'B3B40E3C-1C57-436E-8F56-A6A319E629AB', '4690655003462', ' 200  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA36799C-5F34-4B6A-A51D-A1D17DCEC471', 'CFD6146B-A57B-489B-85E2-A7752C8AA6BE', '4690655003639', '- 0,005   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2A9A6F6-B3D9-4D03-86A7-684C0E3731CE', '01474DC0-050E-4CF1-9C72-6D7000DDFB20', '4690655003745', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('878B559B-35FF-4BC2-8B93-21F972156AFE', '43ADBB30-9440-432A-98E7-F3AB7FA9052B', '4690655004766', '- 100 //.  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79D6B9E8-E80C-43E0-8A8A-098344272358', 'E1584E9C-91F8-43B6-ABA3-89B4721222EA', '4690655004902', '- 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05AE912B-E8E4-4D97-B482-E3B5C349D77E', 'C1554E93-F407-46EA-8C78-D77FC7000A24', '4690655005008', ' 24  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5027326B-BDAD-49C5-8B6E-720866B6AAB6', '90BE6146-C5F6-4B4B-96BF-0D3FBFD79E59', '4690655005138', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2EA6D56-F706-4D4D-ACE5-EE2C4E6EB878', 'DDBA14DD-4B68-4726-9E19-9656CBD01F17', '4690655005190', ' 5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9266BD2-67CB-47D9-8400-82EDDEEC895B', '82805289-B03A-4960-BBED-423A2B7D51FF', '4690655005244', '  10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2229E4EA-6814-42C7-96E7-42C473EE1DCF', '501670FB-258C-46BA-A220-44C73A836C12', '4690655005466', ' 75  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03EFA8D4-37C8-4E59-AF99-2180BC1F43BF', 'F992E8CF-D990-41F5-A6E8-4049B2D5D0CF', '4690655005473', ' 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62056756-729A-4F1F-AAD1-785C78F6E5EE', '89FF768C-2EA8-40ED-B4DE-BC25F019875E', '4690655005794', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2723A8D-41A5-4905-987E-5FB4E25B1DB5', '49F08208-E7DF-449C-8D01-66943C3DC561', '4690655005916', ' 20  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A1E0180-4D0A-463C-9EE4-2705E57B68BF', 'C9B3A29A-8BE7-40E8-A57A-EC28230EC3C7', '4690655006296', ' 75  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA4646C4-37A3-4F37-9E08-B142B4C86F12', 'E3E3E0CA-E7FB-4D3C-9789-2C0D2B405AFB', '4690655006302', '- 75  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04719DA8-3C57-4D10-8ACE-8CE5CBF99C57', 'A4CA3632-C5A9-497B-BA23-B5DBEF491192', '4690655006319', ' 75  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A30846D-DEA5-4DD0-9140-D84A63BE1471', 'BA378D1D-1B75-4E33-B502-70D027CFB921', '4690655006746', ' 2,5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04EA5183-F4B8-4C83-95DA-FBD1D162BBF9', '9A9599DE-9BE3-497A-90F4-28FF569EDF01', '4690655006944', ' 400  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5368293-A39C-4434-BAF0-495CA7FA377A', '874AE1FE-388D-47FD-9AD7-ABE195F8A174', '4690655008023', '  5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('907736D9-A694-40FF-A88E-D38D5C8F50CC', 'F5272511-5194-49FC-9A39-3AC85C7BD37C', '4690655008108', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18D4166D-20D2-4C63-BFAC-C89C29B21081', 'C7E491A7-0387-40B1-ACD4-FB61770C6D78', '4690655008184', ' 20   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7072E5AA-02DE-4499-B89A-8C8A0FC9F11A', 'BF9C46BF-2DB6-4761-9A4C-73B9207BAA49', '4690655008269', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29D7607E-E5F3-4813-9713-A666F6BECDEA', '8F70342A-4DDA-4D44-A423-CCE29B27DF6B', '4690655008528', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EC5C074-5C28-46EA-AF5F-0C7ED821DBE3', '7ADA58E4-1E8D-4E0E-9EF8-A9CA96966118', '4690655008535', ' 40  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('001705E8-1366-417F-A4D8-44A0F3CE026F', '72DD2325-372C-4EA9-809D-95D89C57868C', '4690655008849', '- 16  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('231D818D-3F12-486A-BE97-1FFD76B3D69B', '4A027881-3CB1-4AE3-9B2F-0D0A00BDBEA6', '4690655008955', ' 32  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1AB1CB2-F13C-4D58-BA67-234290A164D8', 'DAB4FC83-73B0-41AA-8677-C193D44194F1', '4690655009037', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20F7A123-2231-45C9-AFC4-534121476108', 'BF517297-B9DB-49D6-B964-29A07B49215E', '4690655009051', '  50 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EBAA62C-441A-46B5-A9ED-652C5A119270', '34BE19BB-4164-4665-81B1-C94AD3CEDC1D', '4690655009242', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B3BB105-C04E-44C0-BEBC-DFEE298B15AA', '735B797F-832E-4557-9F17-69F61B65F89F', '4690655009594', ' 0,0002  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9489636-95F2-48FB-878E-C995756E429D', 'A49F3659-25B7-44DB-B97F-344043A7E9A8', '4690655009600', ' 0,0002  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60415C84-DF62-49BC-A5A0-5ED3322F3AB1', '5E0AD4F3-8760-4DDC-A5AE-D4E00C468C8A', '4690655009624', '- 0,2  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E44BE8F4-F094-48A5-B652-F3A6725DB8B3', '6B31E7E4-7FB3-4613-A6DA-63B52BB1C64F', '4690655009679', '- 0,3  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05541E5E-3A63-44A6-BD09-A42B2C7107A6', 'C8EC5814-F592-4BE3-A434-2F9DD433AB84', '4690655009730', ' 0,0004  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1713D77-8B82-42AB-98E0-5EAF61F9C9C8', 'AAEEE313-811C-4EF0-8A42-FFFBE6149A7A', '4690655009747', ' 0,0004  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B51290D3-0EFD-469C-9CA9-C915F0F4FC40', '797E1594-B79A-43BD-86BF-13D7163180FD', '4690655009754', '- 0,4 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2D09B17-C10C-4704-9DCB-70756896D0C6', 'AAEEE313-811C-4EF0-8A42-FFFBE6149A7A', '4690655009969', ' 0,0004  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AE0D4BD-EECB-4B7D-975F-28583B535208', '57201100-E571-4354-BB5C-95717DB2A4A3', '4690655009976', '- 200  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E123634E-4DFA-4125-B1EC-44AB3959081F', 'CD62540C-A968-4A30-899A-EB418689695B', '4690655011030', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6020A32-4B04-4F95-BC71-8A611E22A26A', '4259848C-A70C-47D1-8917-3001C79B6A43', '4690655011108', '   5   56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48AE60C6-2D81-402F-9C31-2325448B254A', '8D984562-E21C-4C81-8FDE-CDCA90E2968E', '4690655011153', '- 100 . . .  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0D24426-56C8-4364-AFBB-8FA4BCEA7DB8', 'D2B950A9-A8CA-4908-9C50-F74BA91FB53D', '4690655011276', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDE762D5-69D2-4B0E-88D3-57ECC2CE48D5', '88983405-F0A1-4CFB-81A7-CB5879E33C99', '4690655011658', ' 50 //.  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EC4C8E7-347A-4ED8-B1A6-FE9C168769F8', '11CD91F1-36E7-4892-97CC-7AC20FFB5B5A', '4690655011665', ' 50  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A41EC24-1F57-4216-937E-7037B715690D', '4F582B47-87D6-4440-836C-5B693B73DF82', '4690655011719', ' 100 //.  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAA23072-33E8-4B47-9954-70DCEBCB6C17', '8B353AF1-929A-48DA-BABF-51B401992315', '4690655011726', ' 100  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F90A012B-0DDB-456A-8E5D-F647710ED279', '16CF733A-410E-495F-8650-2CC96CFD1FAF', '4690655012358', ' 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EB23FC2-EC4F-41CD-8081-92EE1CC4B4E7', 'FD68EFE9-914F-441A-A910-01951FF341B8', '4690655012419', ' 250  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C708A2F3-FC5A-4623-88EB-1D1836FCBCFC', 'F83903D3-A945-4677-BA69-7EE870D19254', '4690655012907', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7C3DFC6-72B1-4F5E-B70E-A9EF8AB7B15D', 'C71100D5-2435-4108-9447-1F1DF1970F81', '4690655012914', ' 5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFE68DD4-1C6D-4606-B8F0-7583F645D752', 'CBFE9AA6-4CE3-4399-A765-80A2D22B8EDA', '4690655012983', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B51236D-BCB7-4F7D-B0FE-8B9A56A10195', 'CF05C525-C6DE-4CB5-8D78-9A856E80C330', '4690655012990', '  10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44FF5DD5-74DD-4CEA-9CD7-98C23EDD2AF6', 'C2E3E5A5-54D8-4695-9179-6ACC8065A08C', '4690655013409', ' 10  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B633FBB-89A9-4EB5-8804-48E3F93F8CAD', 'AE1FA4C9-C01A-4B15-886B-F0D97AC040AA', '4690655013430', ' 20  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04FB4255-11B1-4E52-BEFC-A43DD21401F6', 'DE83102C-B710-41F7-A9CF-8E9E35988C4E', '4690655014710', ' 10  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CEB7F5B-FC26-4798-9313-B9FA97970CAB', 'FD135E0B-FC62-4895-84FC-CC4E97A7F053', '4690655014727', '- 10  / 90', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43F73B59-3B01-4684-A86B-D729836FEF56', 'AD9AF1C8-2503-444C-B8CE-63C63D77FD2C', '4690655014741', ' 20  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B8DD162-C554-4869-8A14-B931432B4C32', '352ECE02-0C42-4F3A-A8B8-AD6F41195F3D', '4690655014758', ' 20  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('418574C0-FB1D-45C1-8A3B-0DD26E02765B', 'F1428072-34AB-4AE7-AB67-6009163E888C', '4690655014840', ' 25  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CD24D06-6497-419D-B0C4-B9ACEB88DF2B', '16C60D48-1612-4603-AA12-22E0B890FF84', '4690655014864', '- 50  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E16589C-1EA9-42DC-AD37-FDB97E623C23', 'B35784D0-7468-47A7-A6F7-7BC648389B9B', '4690655014895', ' 50  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41AD64BA-AA77-401C-B37D-57F9226D04D2', 'B1B703FD-E5AE-432A-A871-31872C00803A', '4690655014918', '- 100  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F86A66E6-D97A-449B-B2DD-B41E1BEEFFD3', '127B6128-F30A-47A6-98BE-5F5B8BAD0344', '4690655014925', '- 100  / 8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A287E5EB-4FFC-4158-AFD5-90A6CB4324B4', '23EF7E29-8864-4D46-94B6-7AED7D971C90', '4690655014949', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20964C31-0019-494C-9687-29A3E92FADFD', '6F7FD7B0-5CA8-4E6D-A3F7-B0F99293C832', '4690655015038', ' 100  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('670BC59D-7871-47C9-A5E0-119F8A6F9C94', 'ECD1683F-8A8D-48DD-8B94-CDB68FAEA3DB', '4690655015229', '- 2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E17029A9-A097-4931-B6B2-2F7AAA6E2E92', '40001720-5830-445A-B990-D3EA334D3060', '4690655015434', '- 10  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2633F357-6EE1-4986-9990-35BA455963F3', '1A658AE1-87BC-4FE8-ADDF-44AEF1CB1C54', '4690655015441', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC121D17-C8D1-45E9-8EC6-F46C6D60A2E3', '6725DD43-2162-46F4-83E2-6ECFD5C1B9D6', '4690655015557', ' 20 14 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8ED81F0-1812-41D2-B30E-6CF328EE763E', '907ACE14-E30E-4DF9-82E4-D258DFD329D8', '4690655015564', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('323B0F35-C404-4016-AE9C-5F977CEA445C', '18A57DD6-D0D4-42AC-8C72-B299991A2D22', '4690655016448', ' 0,002  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B257C422-EEF7-4D49-A667-F4D2F1D813CA', '3DED59DF-8453-40F5-AA9B-BA9227E8A656', '4690655016844', '- 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3973EB60-CA7D-4604-87D3-7239986D6625', '46DC54F4-062F-44A4-A15F-AD70B84E2CCC', '4690655016943', '- 80  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14379214-A9EC-4021-A2BA-4406BDF3A9CF', '50E5DA1B-0C5F-4976-99A4-3B871E23386C', '4690655016950', '- 80  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E89292D9-FC31-485B-AEBC-5BEF2747C2CF', 'BE95A587-A2FC-4E3F-8803-8EA003E06B0A', '4690655017049', '- 160  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('324C74F9-037D-4E31-AEE9-377711698E64', 'FD7DEDAE-4415-4A71-8B08-6251F89E7F92', '4690655017056', '- 160  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85AAA737-A577-45ED-86BA-D33317F367A7', 'E8029E98-693A-4202-B497-A880BB81370C', '4690655017278', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F969DF9F-8862-41E0-8134-9AD348609047', 'BE95A587-A2FC-4E3F-8803-8EA003E06B0A', '4690655017964', '- 160  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF6AFF1D-35D6-4CA0-A36F-EBD5AE642B3F', 'E0A5089A-895D-4C6A-B1A3-6DEA9BC1B619', '4693007750076', '  lusan /  6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('304722F8-AAEF-446B-B990-B170F2A0CE03', 'D9724BD8-2806-4E63-917C-977FA9BBB536', '4699303355021', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2188D9FE-4290-4179-9603-410CA2BCE910', 'D35B8BED-921D-4A09-8D38-04C12D12911B', '4700000770076', '  2,5  /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94F069AA-6E17-41A8-B7F6-73D12CCDA914', '0A85F4E6-2836-44B4-8535-17A7A6DF0499', '4710425920376', '  11020', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA637900-4B4D-477D-B765-F16717A5358D', 'C19BBE6E-2535-4D67-9CBE-42DC28DD4FA9', '4710425920383', '  100*19', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B644FDE3-85E0-4934-BE42-8F815F057709', '77457191-AED5-4D3F-8D6F-D047348E7AF3', '4710425920390', '  etralong  /11020/ /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F368A3EA-EC84-466A-A867-912FF9BEDFDC', '76943522-3A13-463F-B0E3-A9FC1B7168B6', '4710425924411', '    70den', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F91EC704-F6A7-41BF-B871-4A5DD35AD03F', '2747E720-E060-46F5-99BA-1995D354B94B', '4710425924428', '  70den  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77EF6913-6BD1-4EC2-B40B-79C46F0297DF', '3A40C2A0-F3A0-4191-9452-BEA848935F04', '4710425924817', 'Hote  70den //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D73D20E-0721-46F5-AAE1-3EF34CE3C143', 'DE6241A7-F0F4-4DF7-B37A-3AB99E4E953A', '4710425924831', 'Hote  70den //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D770437E-300E-4F1A-A8BB-B1BBF00C6452', '172224F0-8A7E-4243-9843-D786EBEBF787', '4710425925319', ' / 100den c  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88C5E28A-B544-43B6-9140-3A9A9DBBEBC5', '0A2B7414-7475-4FBF-8EB1-6A33FF6F0932', '4710425925326', '  /  100den', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84AB3176-B730-4F13-B5F6-13D6BEC32DBB', '2963FABD-D160-4C07-8430-D41703164A7E', '4710425925333', 'Artemis 100  / / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E638A2F-9E8D-4DB7-93A0-84974E7BEC3F', 'AD403C65-FC6F-45F2-884B-1310CCB9BFBA', '4710425925340', '  100den / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8658009B-63AD-44E2-8E08-DD0697AFA745', 'A0AD4D60-FE28-4763-A187-A8F2C1C260B1', '4710425925913', '  70  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AED1ECB2-A243-46F7-9A5C-B453C9ADA441', '3FEF40DC-8B7F-4C44-9476-B3ED9318C5F7', '4711146100771', ' 2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('116835DB-9C70-4174-BEB8-1F7891E64C60', '8EAB67EA-C561-45E9-AE90-492AA5A30D3D', '4711146203120', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A237E17D-5AAB-4F14-B8AD-C3C450985103', 'A0B62516-5BD1-4B8F-AC79-C95A9BC20A5C', '4711146211309', '21130 camera    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('724B6AA7-C1C0-40BF-9454-175CA8DECE60', 'AD66467A-D5B4-4DD5-B7C3-24DA29B60DED', '4711146216519', '  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C298F3C0-1676-4D2E-9C92-66490A4358DC', '4F2B491D-D406-4D20-B328-28130735B010', '4711146220127', ' camera /+/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E879A24F-6613-480B-B716-3CE9384168AF', 'DFB70979-ED17-44B4-85D3-8D0856202D50', '4711146518699', 'Camera  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00795A21-AA1D-42A9-A923-E8BE5A359C6B', '6B820BDD-1463-45EC-9459-7F212EBDE28D', '4711146531186', 'amera -   240 /53118/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8972AA9B-D3C2-4D06-8D64-799E4B895C10', 'ABAF3C7B-F421-4A2E-8056-89AD42AA4E3A', '4712803560754', '- Diacont 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('321B3638-32E9-4B28-85A1-413094C388EB', 'EB5E044D-DF6A-4B54-8065-953791E1AE72', '4712803561805', '- diacont 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0F6D640-64A9-407A-836E-505C11B4882D', 'B217CD8B-50B1-42C4-8EB7-B5368AE37681', '4712803562598', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E4AE68A-7135-4556-8EF5-C346B6E5BB8D', 'F5793A36-05B0-41B8-B418-192A1FA8DE84', '4712803563588', ' diacont   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CA6F566-011F-4A98-81D6-DA44BD291D56', 'FEB876EC-3A4D-4575-BB4C-149C08584CEA', '4714204010319', '   -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BC861AA-BE6C-4818-952B-1A7C91D94C6B', 'BEB05804-98D0-4CF9-A295-4DFAC3B838D5', '4714204010333', '  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('247A2C54-30D8-4996-B0F7-835C8C124003', '8BC57B7D-20F2-41CD-852A-284B5AA77C3D', '4714204026211', '  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14302DAD-8D14-4518-8406-400628018F3A', 'E646A627-969D-4412-8CB3-6385530B6835', '4717535318079', '  /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8B3AC7F-6201-4775-AB87-DBA7BC104079', '4AB550CF-1C29-47E8-8560-CCF8693495CE', '4717535318086', '  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3E07C20-0F31-4633-BA3E-A4D4944B0F8D', 'BAA8FCB6-7FB9-4C4B-A7C6-940D3F36CA46', '4717535318093', '  /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EEFB5A4-A4BB-4034-9E45-C8C9BE0446B8', '3E6F1107-1DF9-469C-A065-EB4418409268', '4717535318338', 'Achromin  / egf     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF3D4F68-A727-4A9C-AA91-39DFAB57A3C6', '7661DE1A-7008-47B9-B0E8-E14C1582CCB1', '4719003060015', '  1931   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF689AA4-89AD-41C4-9AF6-4176156CE07D', '76766E3D-FFB3-4B88-81AA-10931F2CBE97', '4719003310820', ' wa-22h // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95888BAB-85D0-4A27-9D8C-5F18653F0ABE', '6D4448D4-7AB2-41A2-B6C8-32712AC7C8C1', '4719003310837', ' wa-33  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D230017B-AB90-4A11-8C29-421637E690BA', '8E0607D8-8223-4805-BA7B-DB51F1DF081A', '4719003330071', ' wa-88  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('648F81EB-06CB-46C7-BE59-58C2F73DC7C6', 'A441B185-9C82-41CA-963D-8664E1CB1A5B', '4740412002211', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D53B4F8-F72E-4655-8F61-884FB0E47D64', '704EC30E-2A21-4630-BA38-000FBD550542', '4740412002259', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D576559-CAD7-4245-AB55-5474FC098F74', '1B0C1FDA-83DE-4B68-AF05-6BD0610E8BF5', '4740505000049', ' 0,005% 2,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4035314-AD31-460D-83B7-FFA65DCD0BFC', 'A95BD90D-CE91-40B7-8487-AC6DCE486BB1', '4741273118950', ' 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99A7F26E-C44D-43CF-818D-A624C4C056F5', 'A808A2EB-FED4-42BC-9388-BA7F9C46231B', '4742041001627', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D915309-4073-4EA7-80D7-8155FA38CFB4', '77682900-5324-4DA8-8742-A31238CB8508', '4742041001634', '    / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBE592FD-C1D9-424C-A84B-0C3C013CD06D', '0EE4764F-2795-438A-B8D9-398FB1883F30', '4742077001547', '-   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB399EB8-9B6D-4051-A3C3-4CBCE2F2D459', '2C04A5CF-6659-40D5-A8AC-6EF6B10F7EA2', '4744183018747', ' dr konopkas /  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31976738-DDE8-4D35-8869-161020BBA927', '9C0181E3-AE29-4459-9D3E-BCEF5C233041', '4744183018839', ' dr konopkas /   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5461C00A-2856-4F69-8945-BF1BD2E16B63', '8FA14D78-C1FB-4F5A-9859-C6B4794E87ED', '4744183018877', 'Dr konopkas  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A7569E3-C6E0-4942-819C-6BA9D75618B5', '0CC340E0-DDDD-4850-BCA6-0603FE6B0DC6', '4744183019140', 'Dr konopkas  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D64E547-9D8B-4217-A6E9-62B786B7DCE3', 'CD879599-FE71-4635-9072-D4EBD78D1E27', '4744183019164', ' dr konopkas  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC59D749-99ED-4638-81EB-27D9336D47DA', 'DAF9DDC9-439B-4B87-8FC7-7EFAC42A2610', '4750232000342', ' 4  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8039DA8B-B92E-4784-821F-598F71124E28', '1A2AE651-E73B-4095-BDA4-0003F64AB874', '4750232001677', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95E4F56D-A86B-4DFA-B587-3FC56F5E4717', '3C722512-43C8-4398-BF45-D342E74D2A63', '4750232003428', ' 450  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26514EF8-CBE2-410E-A5FE-5BCA83E951D0', '852C9F8A-C1AA-4126-A38C-5B89A613B3A5', '4750232003640', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B10F1EF7-BD44-4834-AA2A-AB27ABC6635B', 'B013CB50-0835-4EF5-895A-2CB691E0FE2B', '4750232003763', ' 10  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF2547EE-38E6-473B-A35F-A0CB2DB109E9', 'CBFD4631-2FBC-4519-B050-42ACF52C71D9', '4750232004678', ' 20  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('734B9279-6E2B-4F89-ABED-22516372AACF', '31A60565-C55B-45CB-9F85-3AC8F7A1D8DE', '4750232005200', ' 250 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6CE9242-81B1-49EA-B3BC-0D4B9F9E2FA3', 'BDD7A46D-C1EF-4C0F-A00B-9F46115C037A', '4750232005392', '  /   1,1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36C02FE9-4CBE-40A2-A948-B1331986B85B', 'F75919DA-F6E2-4363-BACC-B45ED2DB1767', '4750232006214', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF7BCD74-0118-4C09-BF60-60C1D726A231', 'BA1FB1C3-A4B2-4CF4-86E5-3129E1332276', '4750232006603', ' 0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C4D200D-6C1A-48A9-8130-49BEA0FD9A11', 'AA828F3A-63F7-497C-BA72-44EF10F13CD3', '4750232006900', '  10  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56FD74FA-6694-4667-BE36-05FB1A17C140', 'A441B185-9C82-41CA-963D-8664E1CB1A5B', '4750232007846', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ECA626B-7FA8-46D9-BDF1-C28A26ADE9C0', '704EC30E-2A21-4630-BA38-000FBD550542', '4750232008614', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68880E2E-6D8B-4F63-964B-DF69CA94F9A6', 'DF49DB3C-2221-431E-B67B-7E671554F5BC', '4750232008621', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A203668-6751-47A0-AC38-7CE8D0EFCC08', '0A304F5F-A4B6-4490-9214-D5ACD7AFC434', '4750232008959', ' 1%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40A0AC8A-CDF0-4429-8DDF-2D33B5E61C0D', 'D370D1EA-DA00-4C70-AD36-937DC1A6ACC2', '4750232009185', ' 25/, 50 , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8423890C-A5EA-4E2A-919B-3387258CD13F', 'CC46CE6D-9A5A-4F2A-A3D9-47909F78CC79', '4750258002153', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9E19298-4125-4AEE-8B3F-7941E80BB830', 'A6AD31AE-C52E-48AE-B8B4-D7F48CFA56EF', '4750258002818', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EA0240C-B893-4BE1-8B3B-5B87F059C94E', 'DE8D88B0-CC7E-496E-B2C5-64064FF32458', '4750258010042', ' 5/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F537E0AA-BBD4-4CEE-98A7-1F27F79B7BDF', '1AEC02E9-C549-40F6-8757-F348B646B7D9', '4750258010059', ' 15/ 1 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B1B55EC-5188-46D4-BD04-1A30A6B0C917', '84201309-07E3-4E05-A4C9-3F23AB655425', '4750258022120', ' 0,05  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DB2945F-BCB4-4C2E-813A-B2BEB7EAF9A1', '43154475-2188-4292-95DA-0A91DCF8900D', '4750258110124', ' 0,025  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2FF553E-885B-4E0F-812C-51657BBC85C2', 'E7F8B6E1-5188-4F83-A4DB-CA86F76900E7', '4750258110162', ' 0,01  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8C3B3AC-7A9C-4914-9E91-AD86627714D4', '4C99CDAC-C0CC-4D9B-945D-67121D7FCF23', '4750258110414', ' 50  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22B5C89D-1246-40D1-BCA4-01BDF1F85F9C', 'B080FA8C-7F9A-43A5-AAAF-6694C42C8D50', '4750258313716', ' 0,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A31ECDAF-47C9-40FC-B67F-46E2E81BD967', 'A9B81FC7-A6CE-40AB-981A-FA11F64F19B0', '4750258314102', ' 100   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05003183-7187-498E-AA4B-BA1FB3B11223', 'C8A55CEE-81B4-44AF-852B-C3F51DA623A9', '4750258314157', ' 0,02  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A652FDF-0032-4242-B000-DA6E53B6D80A', '1D065927-DA50-41C1-9416-94205FAB2D4B', '4750258314164', ' // 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6662BF5E-4FDC-437E-B309-9870F38C263F', '5EE3C5BC-FA6B-4BF3-8E2A-EDB8E18092F3', '4750258314188', ' 0,01  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D68CB1C4-A5F2-45FD-ABAA-BE2BF7BA5014', 'DAB4FC83-73B0-41AA-8677-C193D44194F1', '4750258314683', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F58CBA4-8B41-47CE-84C4-C0393CFC74A7', '623550FA-3D1C-4B58-8992-8AFBA814980D', '4750258315369', ' 50  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75A652B7-4198-4861-8746-24CBFFD639E0', 'A6AD31AE-C52E-48AE-B8B4-D7F48CFA56EF', '4750258315376', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C345C901-92C2-409C-AD52-C268B86E549F', 'DC235C11-9F64-4AC5-BE99-2598F47F5637', '4750282901378', ' 1,58 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49D4FBF9-CE13-4D3D-83F1-4711B5431CE6', '9F34BFB4-E2D4-4CDF-AC11-8E32170BC628', '4750282901798', ' 0,610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7789D0E-DEC8-461B-9C63-287DBE08C403', 'EBC38D4C-5618-4261-BFA9-4F56381FC9B8', '4750282901866', ' 510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BEC81A1-8E55-47AD-AA69-A2769876BA16', '9CB608DF-8A9D-446D-AF1A-61B2BA0C20DA', '4750282901897', ' 1,512 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49B8E4DE-C5FA-43AC-B5C4-BEFB2CA9F971', 'E123D822-69DE-4F8F-BB7B-884F34A64533', '4750283000032', ' /9512/ . . 3,00,08  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2275A828-A570-4986-904F-FC5A4F691E53', '8EC45DA2-2C66-4AC9-BE81-2058E72F87F3', '4750283000148', ' 3,0 80 / / //  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98613F07-364E-4B97-B8E3-7F6E0FE505DD', 'F9530F35-DFA1-4ED8-B29A-385C27927000', '4750283000155', ' 0,68 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B46DAFB-E362-4B0E-98F5-20D506AB57FB', 'E2C616ED-FCEA-4164-9AD8-2D743689E559', '4750283000162', ' 18   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('571949A6-C5BD-4D96-887B-EC15B712B94B', 'E89E83EB-61BB-49E1-B499-2BBAC3840995', '4750283000179', ' /9512/ . . 1,50,08  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1817F302-76C7-4D1E-9C2A-FEE716653852', 'C3A564C4-198D-408C-95B8-DCDA5E0742EC', '4750283000186', ' 2,00,08  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78371C55-8F08-4BCE-AE2D-7946B3DA94FA', '7F9D161D-929B-4DD5-97FD-CFBE25F55AE2', '4750283000193', ' 2,58 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1701B75-115A-417B-BE2B-0935DFFCD842', 'E0EF39BA-1877-4DD7-A233-643BC8376CBF', '4750283000209', ' 3,580 /./  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8696ECBC-0F6B-436C-862A-AB6E73953486', 'ABD884AC-8490-4125-AFDB-84FB7190CCBC', '4750283000216', ' 5,0 80 / / //  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23C38E3C-58B4-4CDF-942B-9A2326459BA5', '118FE74F-6117-4B3B-B913-EE252E9E328D', '4750283000452', ' 1,50,06 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45B022DF-26C5-40B1-B9A0-EF64B38D22F8', '6767430B-030E-474D-B6E5-FB55B04B3D4A', '4750283000483', ' 3,060    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F0DF674-1D01-4903-AEBC-42E526A8775A', '9F34BFB4-E2D4-4CDF-AC11-8E32170BC628', '4750283000520', ' 0,610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74576493-9546-4350-BFC5-4C85A419C2EC', 'FD23FB9B-8DF6-47AF-8BBE-E88035F8A07C', '4750283000544', ' 1,510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EFCDC77-B2C6-4EAD-BC9B-E3B9F28B6563', 'A29B9253-D64D-4425-B3A6-2CF3BC93CFE4', '4750283000575', ' 103 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22708821-816B-40D1-8468-335F8D8EE7E8', 'B08DA406-EBC9-4C14-BA72-E045D2F5195A', '4750283000599', ' 3,0 100 / / //  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BF1CDE7-7402-4976-8FB4-52B94D62E94D', 'EBC38D4C-5618-4261-BFA9-4F56381FC9B8', '4750283000605', ' 510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E829DB9-39A1-4E3D-B2BC-B498B94E1832', 'B54ED9AE-0A7F-434F-B64F-0DFE7433DE18', '4750283006218', ' 312  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83C8B1C8-3B64-4F50-A443-3037E633B53F', '1DBAE10A-9620-42AF-9126-E5D2FD830CAC', '4750283006225', ' 5,0120 /./  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E84F6AC-2792-43AF-B47E-3331AB8CE489', '9D4BC1E9-440B-40F4-9FD5-4CF1F4C5F61C', '4750283006232', ' 5,080 /./  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA9C7750-40E2-47AA-84EC-565B6193E1CD', 'EBC38D4C-5618-4261-BFA9-4F56381FC9B8', '4750283006249', ' 510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B802497-7DBF-4247-B266-AB360AE21EDF', 'CD68AE2D-2C09-4BBB-A05F-58E81AA5C320', '4750283009271', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('519CF6BD-2BA8-4A57-8327-0FD57E407BD5', '3147B153-E9D3-45E3-B291-8EB08F830429', '4750283010055', ' //    4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39312803-073F-403C-B6D9-92806029B866', '330E7E2E-A34C-4357-A7D5-C36369A6E8D4', '4750283010062', '   94-98 /9509/ 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('178CECB0-C3D2-4ED0-AE20-B60DAD5DEB51', '61A7FD28-0062-4D6E-9A5C-A5153F1EE04D', '4750283028067', '   1  /18-21mm/   0402 4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('954F14CB-98A3-4368-81C4-0AE643235FA7', 'C25A1722-EB3F-49DA-882A-6C7BB4CDBA25', '4750283035096', ' /  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('509B4BA8-8783-493C-A487-0BBA0BC1D9F9', 'BC0E7A12-918D-4450-962F-4E61CE3E145D', '4750283035102', ' /  4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4F96099-034B-4E3F-AEBE-A7B0E8D10E1A', 'BDBDD43C-6C38-4D5D-9D39-D3AA5485CDF8', '4750283038431', '  /9901/ /  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBD943EE-85DA-47DA-8346-9A928411FEF3', '9724FED2-16B8-42D4-8EF5-3DA29E5664B1', '4750283039001', ' /  /100-120 / /9806/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23B98BE2-DEE9-4CC8-959E-D309ABBAEEBC', '7DCE864A-EB5B-423D-B61B-0A2C81E2835F', '4750283040526', ' 1,58  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA769F70-2681-40B3-9A3A-A141F2F15C03', '0D2FC47D-1FA9-4F2D-878D-CA0C289A5E4A', '4750283047006', '  28   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FD9E9D7-959C-46BB-86A1-8DE3B62682A6', 'EAF05799-2E34-488D-9337-94781425E9F6', '4750283047013', ' 210  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4CA026F-8A15-43B5-BE93-FA4C17BE638E', '5530F450-9ABD-4ABF-9DF9-EBFA06ED0B3A', '4750283048027', '  . 0402/lu // 2.. 1 / / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74EA3EA0-7A90-47B2-BB82-EA6C3E756A3E', 'CBFB23D2-7CEE-4C52-B45E-1160A9174C19', '4750283065093', ' /    3 /38-41/ /9605-02/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95D5F048-10DF-48C4-8C72-EDACFF58CBF4', '022F397C-9B9E-4152-8BDB-A3EE9A7DB458', '4750283065109', ' /     4 /42-45/ /9605-02/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B510A611-AD1B-4522-BA7E-D1DE58F1FD5B', '0A619332-F804-46ED-A1B2-B6733E53150A', '4751006750319', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DCA14DF-6C2A-4C90-A083-96A798CE9E3F', '2F870A42-C7A1-4651-86FB-628E3E2CC733', '4751006750326', ' /   .  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4F7B9C9-0F82-42DD-BF93-1833934804E2', '7A596219-8A63-4DAD-A921-B3B0D55DB1B8', '4751006750333', ' /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C855A876-E696-4457-AA3E-35855BE14399', '2C76A3A9-0872-4502-A689-E560248C5BCC', '4751006750340', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47B2CA1F-E4B3-41BA-BC8B-3B0181A4B572', 'D95EB66A-8FC3-41E3-AB9C-6BFA43D92B47', '4751006750623', ' /    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C5A465B-E03F-44F7-9B10-BBD885F4EF85', '4399427C-A339-4162-B689-79E99D20BEE8', '4751006751460', '    . /  170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB7A53BB-A391-4525-B98E-B2F9EA595DB5', 'AEF7444F-CEAC-4A19-89F9-5A892EE2B457', '4751006752627', '  /    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3DC9DD0-9A34-42BF-8265-1A5F3EA05549', '7893DBC9-AC35-4BC0-ABAA-3E75F521732D', '4751006755857', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C6C5495-E224-4A73-B1B5-D0C8F352AD5C', 'A2AD9E05-FC5A-45F8-9B40-548D1A6B462C', '4751006755963', '     (.) 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55F7B419-E3AB-47D5-B324-F983AA98853F', '34B0E343-8BCD-4C0D-8D41-3D8245EA06A6', '4751006756342', '  /.   12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B6FBA90-4F20-4EC9-B986-E78CDFF67924', '84B9DD5C-E5CE-4734-A239-EB95C638D058', '4751006756502', ' . / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C6F4EAA-06CB-41A2-8ECF-933B694A92FB', '120A9B96-528C-4F9A-9918-074C83F7C5BC', '4751006757189', ' /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F6941F5-401D-42B1-84F4-6DE5CAC9AD9D', '56A2E461-619B-43FA-9866-AE7377718BE7', '4751018120032', '  /     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B73A8A09-DCCE-4859-B7EA-F6A25298098B', 'FC5149AA-9F5B-43F8-BC2E-97ACB7B3254C', '4751018120056', '  /      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('659A406E-0C72-4C9B-A453-174E5954F7F1', '2FAB1664-2C13-4892-84E0-777909DD67B7', '4751018120063', '  /    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('781FD4A3-3D2F-43B4-B70A-B411D71768C4', '47D9B3BE-906B-46F6-A8DF-D8759046398E', '4751018120070', '  /      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C9959D2-1DBC-475E-8FA3-E81EFAD6BC2F', '89197D2C-2B7F-4D0E-95C7-120025D69307', '4751018120087', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3613869-258F-4BE0-B542-1457AEEBC0F8', 'DB412C41-CD3B-4A52-BC90-0AE536C8A402', '4751018120094', '  / /    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFE96EB1-E72C-4060-B81A-565B7D347089', 'DFB6C0FE-D3A1-42C1-9F55-EC0F73E1F987', '4751018120100', '  /     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DC0266A-3FA1-40E3-A854-D2B87C0CFD1C', '2946D08F-7680-48E2-8336-C76AC3EE55B2', '4751018120117', '  /   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D8B3B93-1CE6-419A-B13F-51D1654DF90B', '4113A2C2-02AA-47F4-B867-0B10FBFE2B65', '4751018120124', '  /  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B765F89-E3E9-445F-B6BA-9A5817432295', '7BC160DC-D4F7-4D03-AF7A-555F51648B74', '4751018120131', '  /    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF61508C-E209-4509-B1BF-ECC44EB54BDD', 'F7DAC4EE-1B75-4228-9154-84F45E700F5C', '4751018120193', '  -   , .    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9DFE2D0-D995-42C5-A107-E4E77CB201D4', '9E0D3D27-05D6-4162-8B59-23D5DCA3E352', '4751018120209', '  /    7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A44534A-236A-42E5-9E49-FCD59FF0B2FF', 'E8B95BBD-FB3C-46DE-88A6-938FC51507FC', '4751018120216', '  /  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E207A11-31EF-474A-A78F-6126EFF2E08C', '0D83F6A9-FAFC-4C11-99EE-8BC930A56032', '4751018120223', '  /   4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDA19D34-9655-4275-AB1B-6EC55B6DDE05', 'E5EC8B73-A10A-4FD5-944F-2CBDDEEC03AE', '4751018120230', '  /  () 4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68E799B1-4D0D-4CC7-87E3-500B73B8F9FD', '65FAB483-FD17-4387-A886-0B3DD4326A56', '4751018120360', '  /   spf 20 4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2109332-6380-4C53-8B84-E20C41517FC9', 'DE46286A-5E00-496A-9229-BFC2BCFEE19D', '4751018120377', '  /    4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FB7AC1B-6A51-45E4-A5AB-943C31E511A8', 'A34DA056-88E8-4205-902D-E0A94B7686A8', '4751018120421', '  / // 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5556AAAC-FA9F-4E7A-9DB0-CFD5A9B616B6', '57954CA1-2F70-4A69-94B5-468D3EA836CB', '4751018120483', '   /    7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65B55678-822F-47FF-86C7-97827437904C', '933B4213-E10E-420B-8F46-24DB440A1276', '4751018120490', '  / 31 8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5FB3F36-2061-4C6F-A3A6-5E317F787877', '6BE0B2AE-5F42-4AB8-B0E1-53534882A7C4', '4751018120568', '  /      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73ECB848-4C41-4B82-8EF1-2C4A6E4A5A05', '195C4BBA-B980-46C3-9634-D9CE0F46682B', '4751018120599', '  -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DA51821-D8E7-451D-ADEB-BF39F618FBA7', '7CC35220-9B8C-480E-99C4-C78E62AF9B1C', '4751018120803', '  /     4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8D584A3-EE78-467D-877B-605A380675D9', '6F2ADA60-A7D2-4EE7-9EE3-DDFD95B34DF8', '4751018120810', '  /     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2D93BBD-13A1-412F-8B4C-10FDDA4C0FDA', '83F02A94-B6C4-4631-892E-F0A1376CA336', '4751018120827', '  /     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('447A2F7D-99F8-48D0-8427-04FB6AC6C099', '11E799A5-8865-4FC8-8150-5E3A8CD5D64A', '4751019610082', ' - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D69A026C-1E29-4070-857F-AC55922CCECA', 'F850C29F-3469-49EC-9FF1-F07E0BD8D4A0', '4751023292052', '   /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F27FD23A-53A9-4A10-8E47-F0BBCEF43AA5', '0E643107-92CC-4BDC-82F3-3849E035A10E', '4751023292076', '   -  . 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8229B9F-22EF-46D2-992D-A23FF34975CE', '85C84C83-9986-4EE7-BDDF-316F438E391B', '4751023292151', '        6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('695CB98E-A3D3-4586-A71A-1F5C598F8CC5', '4E0ECF82-5771-40C8-B6FA-997CE23DA61C', '4751023292175', '        6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5B44693-5F55-4CAE-8833-5C4860825F07', '36B8EBE3-4AA3-4872-9373-D55EA8DDA551', '4751023293134', '  lure 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D857285C-A047-4DDC-AF64-4A0B020B3FD1', '4AF1289F-81D4-400A-879F-BFB83A97671C', '4751023293189', '  lure 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22F5C964-5356-4A62-B38C-11E9FF3919F1', '94481EB9-4D72-4536-AF94-676A5938A8AA', '4751023293196', '  lure / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A29EB6E-40B5-4B2D-BD43-42F6EBF3FB9B', '19D6F101-4FF3-4A8F-94AB-944BBB4C4F33', '4751023293202', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96AA8379-6AE7-4028-9959-E844BB16168F', '921FF9B4-A3EB-46FA-88D6-E8211273DA84', '4751023293240', '  lure 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E67EF12C-6CA9-4189-9BF8-AD3019DDAC02', '2755BCD2-2C2E-46B4-A3C6-3F7C68EC0C0A', '4751023293264', '  lure /. /05456/ 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD7ED908-A92F-4052-BD51-C20CD6900090', '3FE664C8-D81A-421F-B677-BE517D848327', '4751023293462', '        30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88BB1512-4296-4578-BB0D-F53FC94983DD', 'EED95717-426F-458E-862C-1656F1722314', '4751023293745', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94BBFB77-8C12-466C-81E0-9D125BC48CCF', 'AFA4249E-736E-481E-98E1-00300D64DC55', '4751023293967', '     cocktail  . 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9038FAEA-B0AC-4E7C-A30E-4F1B2F4464AF', '8C01DF03-FC84-449A-A176-208EDB14C2AA', '4751023293998', 'Lure vitamins   /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2DEEA2C-5834-4BAB-8E96-AD1A37623BAC', 'F5E51603-7E92-454D-BE70-9A9D7B53D9E1', '4751023294018', 'Lure vitamins   /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('634FCF6E-E645-45E2-981D-0907E581C324', 'EE058A0C-38C7-4D18-BB7E-5A680790B11E', '4751023295343', ' lure  /   260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('792B5E18-716D-4821-AD49-28289DC0FD12', '06060C9A-E1CA-472A-8D96-E11A561260D8', '4751023295787', '  - /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB332470-032D-4393-B57D-ECDADCB9558C', '9640E0C0-9FD6-4BF3-AD69-12DF54A2B86C', '4751023295824', ' lure  comple  /  .   - 450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D22AF56-FB94-4445-B2E0-0010F8B99B45', 'D7AFF438-0314-486A-AF27-B735F28010B9', '4751023296012', ' lure /    . afe 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09799A8E-7792-4A06-A3DB-B28495A07DF3', 'E63F24F8-4E6B-409E-8D15-AE08264A5EFB', '4751023296111', ' lure - / spa  .   258', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16CD3B9C-807E-44DB-9B6D-C9C00304115F', '9B979583-4045-438C-8865-09BD25AB3082', '4751023297026', '  aquella 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BF93954-2733-4338-9871-B13A51D1D75E', '709D9570-A051-4A34-9640-9EFA78AC1540', '4751023297040', '  aquella 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C92A93B-AF16-4440-A614-85B261758D0B', '06423802-DD4B-41BC-B917-240222B7FE90', '4751023297057', '  aquella 100/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F89392A1-7D51-4196-BF1E-500483628A67', '5AFACE84-0E1D-47DB-8BC5-0764C88F77C1', '4751023297064', '  aquella 200/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41E3631D-0AE4-4DE8-871E-2FE21EE3DF94', '5320A50C-D406-474A-8752-6D1C3807C0ED', '4751023297224', '     /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E77CD4C-380C-4A5B-9BB8-4826CD998A1B', 'E0655008-2E2E-4124-8AD7-16A7C4A181DA', '4751023298764', '    4/l 7-14 64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76FF457E-1EC1-4376-B3F5-83C6F13996DE', '5AE58B31-E2B6-40FB-8D72-6CDF881634A2', '4779017992535', ' 12,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0E64CEE-FF02-49C0-A014-98A95FB32EE2', '3481BD5A-1854-4418-BCBF-65BFEF5F24C9', '4779033720013', ' dr gelper aloeplast . 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFAB054B-3CCB-4476-95C8-383BFEF8B7B4', '7FB6E98C-EDEB-44D7-815D-6BE6EDA4C6D8', '4779033720129', ' dr gelper aloeplast  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('882FFED8-C87E-4767-8C76-68C5ACC09CE7', '88CFC927-EF7B-414F-9DB8-D62DAE6B0F0D', '4800361383981', '     350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5132736-BF55-4CD1-81D6-8FAFE6235E36', '598FDDE0-96D1-4EBD-A284-B41CE8A8E635', '4810046000454', ' 200  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1F63A45-435C-4A42-9700-DDEFAEBFC084', '66213F6C-C89D-4BB0-B8D3-2A3285F60D90', '4810046004124', '   400 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19AE58D2-07E0-4078-8568-186310288375', 'BCA707BC-9EC4-44D9-BC99-2E96DE4D6AD9', '4810046004155', '  / / 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAA9ED5E-1B70-4DBD-BCD7-C1804FAD7051', 'D4168718-AA05-49F7-B5BB-25300203BDCB', '4810133000749', ' 4% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2D04EB4-8125-48B8-9C37-CB7BC34B1CA1', 'D867208F-6656-4288-9275-501B44E20235', '4810133000770', ' 5000/ 5 - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAD9FCFB-5D81-4BDE-B4CE-2DEBCF97ED3A', '96B8DA5A-AD81-4F1D-988A-B52C861F3FE0', '4810133000978', ' / 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5FB07C1-E4E1-4010-84AF-F7EC986026AF', 'DCB3DE82-9215-4E54-96A6-BE4FD555DBDE', '4810133001180', ' 2% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07A01B78-52CE-4EED-9593-2F287B1ECBAD', '3A97A7E6-24CD-4148-B048-5D7B5CDF0AC3', '4810133001562', '- 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AC54E19-0573-4F36-88AC-202C8C3B9CBB', 'FAB51128-9A21-4395-B629-5AEB6E709AED', '4810133002538', '  100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2ECF10D-5013-4645-B3CF-D2BBFA92BBF2', 'C90220A2-2065-48AF-9CA6-13C39F2AC71C', '4810133002781', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29F87AE5-D30E-46A3-B652-F19A0001449F', 'A0909009-981F-4150-A99F-4426F730B03F', '4810133002804', ' 250  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('646BBF74-3B5F-4B20-AF21-BE7A6F866D56', 'E6E0FE4A-5190-4768-8B2A-967CF22AF814', '4810133002972', ' 0,1/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8C39E18-CF7B-4A8B-B554-4107EDC7F268', 'D96AAB80-6264-471F-A5A2-00CAFDFCB66E', '4810133003511', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1CB5F2E-4B20-40FB-9EDD-B4221BD70415', '8F35DDFC-1F4C-450D-9929-C44355F99DE8', '4810133003740', ' 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E6F4F32-A348-465B-AEB4-0A5CFCB6061A', 'C66E12B7-229E-46D4-BEBA-FEF2EE54D856', '4810133003788', ' 0,3  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A40CA6E2-386B-4B6D-BBCB-969435C36DDF', 'E1542E12-FB7C-46D4-A58B-505201D2E24C', '4810133004136', ' 200  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC42B944-3696-497A-AC9B-EB79AF721932', '9401F3AB-1115-4ED2-AB3D-D92764EFEDF0', '4810133004242', ' 0,1/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68FE476C-C084-438A-9431-C6EA26E1A127', 'FCECDB71-DDBA-4033-817A-B20E748941CB', '4810133005591', ' 20% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('284D558F-46E7-44D5-9861-FFBD0A33835F', 'D5316770-0703-40EA-A668-F31DB81A4C1A', '4810133005669', ' 10% 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FAA9906-4E65-4082-9175-0684BE138814', 'C90220A2-2065-48AF-9CA6-13C39F2AC71C', '4810133005812', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33033DF9-D131-4F82-922B-1173A42D4AFB', 'F2F31688-4299-4E2C-A84D-B67B8AD41B44', '4810133006109', ' / 30% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78A7A866-6F39-4D20-993B-B4418AA94286', '6A1D2E96-A22A-45D1-B5D1-6DD84E14DABE', '4810133006246', '  20% 1,5   2 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1171AF4-9F8E-438C-AA2B-EC03BDA92F13', '1B19ADF0-DDAC-43B9-97F7-55D8EED8719B', '4810133006321', ' 500000  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3985C4D9-16AF-483B-A331-D53E1E576111', '8D4A73E0-B53C-47FC-87AB-463EF42650A8', '4810133006338', '* 150  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1894FC1-4E53-4700-9109-B9BB27B02D98', 'F4A8413C-6C4B-4394-AAE9-18D006770AB6', '4810133007229', ' 1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27C394CB-B2E0-4492-A904-BBBC1BF00838', 'CDCF25AB-84D5-49B7-B6E4-E3F6F7B46BA8', '4810133007441', ' 0,5% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54B0741A-47EF-4025-9757-77750AC5B5A5', 'FD10A0DA-D8A7-43A5-82B2-C0A9619A7D54', '4810133007809', ' 0,1% 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('476425E7-1E49-42CD-96EF-3CF2757FA511', 'F36D28E8-4CF7-4CCD-926A-96D0E5FFBA2F', '4810133008073', ' 1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B6EED60-C169-4612-93AF-233B6A750FF6', '853F082A-137A-4606-BD6A-26AD1982B2FF', '4810133008080', ' 1 /- /// / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD82A80A-28E3-423E-8D07-6DAA7A55DE48', '5407E7E0-A8C6-47D4-811D-E5303A010661', '4810133008158', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E6DA27C-4650-48A3-83AE-BD5BBBD63833', '47E7C84A-257B-4C30-8F5D-7AE3E68C04FB', '4810133008271', ' 4  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('863A8F92-C486-46F5-AFD6-59607E360D11', '36F0A13E-1098-4B6A-BC72-8D58D1F92C8E', '4810133009377', ' 1  /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AE3924D-A478-4F6C-A94D-6BEB281C0F85', '840E92DE-89DA-471E-9D24-172F1F55230F', '4810153021601', ' . .  50+ / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2C27A96-8074-46BA-9CB8-4BB19B2DECC0', 'B33E590D-BC67-4A67-BDFF-30E1B13ADAF8', '4810153021618', ' -.  / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89ED5E2F-2E9B-446B-94DC-2FC4E1BDCA10', '3E66214D-CD9F-4226-9610-F57F053F321B', '4810153021649', '  . /.     50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0023E7DF-2E27-4B93-9E7B-45AD0EB0F5AA', '6B52292C-E736-4B1A-B313-65125D2F3D02', '4810153021670', '   /   /  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA1C1076-7664-46E5-85B4-BB983348EFDF', '2F195E61-346E-4584-8600-E792E557D87D', '4810153022653', ' clean - /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D64B1C8F-0437-4C1D-91BF-0B5055C58C87', '4EA68850-F481-42B5-97F6-04EB1C29DE82', '4810153022660', ' clean - /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C582D965-B290-4134-A5E7-2520148D0D06', 'AE4F8BD2-CEDF-4531-A84E-CCDABDB58F42', '4810155001854', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43D00E9B-CBF3-422D-BBD0-F7FA490DC789', '76BF7B72-7C60-455B-94DB-37E9B1923046', '4810155001984', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('518084AF-255A-4142-94E5-6779A17C6CBE', 'BE3C42AA-CCF3-4FA2-A7AC-047497598531', '4810155002509', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D50A721-9DEA-4DCA-B797-49EF56336FB9', 'FC342286-453E-4E4D-A088-FDFF404648CD', '4810201000039', ' 2% 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44DD6C8F-8784-46B6-AF58-A684751F72F0', '06100727-490D-482F-8397-B8A7584E54F7', '4810201000046', ' 0,3 /// / 1 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4D7A9BC-5C77-4A0A-8B32-0A7CE7C372DC', 'E4CA84AB-C264-49A6-9739-C947C52E0A01', '4810201000060', ' 2% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AAF3233-80E0-4680-8F99-8CAAAFBE87A4', 'B9DB7647-9681-45EC-B0B2-C731CC44EAE6', '4810201000107', ' 1% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C034194D-0E88-4BB9-87FE-5C415A33DA9F', 'E075309B-CCFE-4522-A71A-EAA345142CC3', '4810201000329', ' 2,4% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94A9925F-9C7E-4C8E-9527-6139B20CBE0E', 'F81D7286-6BFB-45F6-937A-4314C8D14CC7', '4810201001845', '  25% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00FDEE95-E55A-43A9-B4D9-74686AD5862A', 'B878EA8A-0D4E-4231-9DF3-802B9D82771B', '4810201002262', ' 25/ - / 3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35B73BC7-1924-4FDA-92F2-9664511CC01C', 'C46D34B3-5447-4604-A879-72790ED2AF95', '4810201002286', ' 2% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32AFA48A-5740-4BBB-A962-31C9F778504D', 'C8028F34-DAA0-49BB-8818-959F2BF3A3D1', '4810201002590', ' 8  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0809DA86-19C5-4823-890A-8DCDEFDAF4C5', '86E6BBC3-6222-40B8-AFCF-A390C413B27C', '4810201002712', ' 500000   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C065410-E89F-4777-81BF-FEFC209B236B', 'CD3BD7B1-757B-44D5-97C2-10952994F806', '4810201002880', '-  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A7EEB91-B978-490E-AF42-DBE2AE563E2E', 'CC6DC222-EE5A-4E23-8846-B8E22583897B', '4810201002927', ' 250  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94CE9B90-87BC-403D-BDEB-CB6C7CE4C2D9', '35A95797-C55E-4A21-A847-8F9E557E2206', '4810201002934', ' 250   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54B3F793-BB7C-4252-9E25-0DB059F53EB2', '5BD64DD9-4EC8-4A6B-9C25-45D7179EBC05', '4810201002958', ' 100  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41E186F4-C52B-4C27-BD5E-FC63E1DB6654', 'D3C3AC48-5F4F-4B1B-B34F-7F3094BD27DE', '4810201003252', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAD953B8-E49C-4EB7-9D25-13E3FE6C776C', 'FD012C79-DC6B-4E92-8420-9C30362F3452', '4810201003344', ' 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('952EDA07-2809-4D49-B37B-D877769FC85A', '1FBA6C20-570B-457F-9268-E7EC8CB1F968', '4810201003597', ' 0,25 /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C8AA0F5-0D17-4982-B9D9-58798B15C422', 'B0F4D662-87AD-44D3-A0F6-DC57EFFE1836', '4810201003870', ' 20%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45947E13-9C17-4BC8-AD31-BEB083F14048', '9B9AC868-3DA1-4AD2-A61B-3490C8E4CECF', '4810201003894', ' 10%  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D46F5E3-A728-48CC-98A5-7E91B19775E2', 'F759FB14-5962-4472-8B0B-46CF4B9FAC48', '4810201004099', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E05638EC-C408-4D2D-A410-B664A1809485', '20511D2E-997D-4C72-B6A1-BFD76090867C', '4810201004228', '     25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F7D6FB8-3D56-4F83-9A65-43FB90040632', 'F489B350-249B-4009-9C96-6034B1E63DD7', '4810201004686', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1B4F8BF-4FBE-4E97-996E-F1906AF97704', 'C0F3806D-D703-4C2F-83BC-AB4577CBC5CD', '4810201004945', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('067BE3E8-797B-4599-93C7-F3895BBA1E11', 'EDE107EB-0D43-4973-A181-3C001627B3CF', '4810201005119', '  2,5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EB437E2-873F-4CC1-9F9B-6AF607E43383', '62B45E09-5D7E-48A0-825A-0FA7DDCCFC83', '4810201005218', ' 0,01 / / 1 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64C6C3CB-E35C-481C-B56B-27BD7311B143', '8CEA05F4-C96C-4007-B9D0-86CEB65E4148', '4810201005447', ' 10  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A7244D6-8644-49CD-8022-B155EAD18B0E', '5407E7E0-A8C6-47D4-811D-E5303A010661', '4810201005638', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98F1B783-740B-4B9C-B94A-B27997B46325', 'F1CE0542-1A45-49EC-8A14-CAD0E28F1153', '4810201005812', ' 1  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9243A6C-3C36-45E6-BC1C-A469945FB9D6', 'EF3FC955-9E67-4956-B8DB-72E5A6D8C87C', '4810201006314', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A766029-3A19-4AA7-B392-896A0A3C7BFD', '097BD284-CCA5-49C5-81D1-E83E3953D7FC', '4810201009490', ' 5/ . / - / 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBEC56E2-AC78-4D9E-9FE4-5B424FA1EA23', 'C62F3054-24F6-4127-97F7-974F48CDDD2B', '4810201009995', ' 0,05  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86FB696B-37A2-4683-86E5-B81FEACED1B2', 'C040541A-53AE-45C6-85E4-93B98C013EF6', '4810201011561', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D36B7BA4-4276-4D29-8D8E-FC050399586B', 'FB6FF834-3CD1-4B24-8A60-5AB176DC3B94', '4810201011585', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F949D2B-5250-41C3-A601-A66418B70C89', '51C350EC-7335-44E6-8368-CA1E23F3EC23', '4810201011592', ' 0,01 / /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E4C3A77-D14E-47B9-A8C8-2E76CD6B7B6B', '9DF5D5C1-47A4-42D5-92AC-E9BF715750A9', '4810201012025', ' 0,02 / / 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4501B30-E0F5-4487-B883-CB53A5B44373', '98C6D0D8-467C-401F-AA3D-AF5AD53B9DD8', '4810201012377', ' 0,5% 5/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A889CBA2-1E51-432D-A143-AB975539D64F', '5420EF44-93EA-4C8C-8618-4FF034822BE8', '4810201012797', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('835F0FB0-4013-45BE-9C72-9431FE716668', '8703E6E0-8823-47C8-BFD3-96E283CE5CC0', '4810201014210', ' 30  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F5A5252-E6D8-4BA6-AC19-D4153A3B04F1', '88A5DBF7-58DE-4993-A60C-62275B98B864', '4810201014616', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0325F765-F0CE-4C47-B13E-23AFC02DFB7F', 'D1F6B56A-FB2F-4D6F-A488-C630780F6805', '4810201014630', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EE41720-E888-4945-8A90-30BBA08DED82', '0B3BB519-6EEF-440B-A348-C3593C102966', '4810201015026', ' 2,5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCBFF83C-D947-4D47-A7F9-C0205CC7D228', '529E9562-535D-4C9F-BA45-59B5558F08F0', '4810201015033', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7100B4B9-E0A1-4AEF-9A4B-B57DCAE14BAB', '969674FA-50B3-4E4A-BF70-A742501A1A42', '4810201015040', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB507202-C846-4E9A-B45E-907474E1A975', 'FCECDB71-DDBA-4033-817A-B20E748941CB', '4810201015316', ' 20% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7931C397-9E0E-4C67-869A-41CD197E7C3F', 'AF964462-014C-477F-96D9-B269DB1296DE', '4810201015552', ' 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3805378-96D7-400F-9D4E-603BB83899F5', '36ACE009-D75C-4549-BB0E-F89534DE7AE8', '4810201015835', ' 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86046037-A17C-47F8-BA82-F9F0FCAF8B64', '531E07DF-7490-46B6-A352-798AA1DA863D', '4810201015903', ' 100  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5E39504-87EF-423B-8DF9-48C2C814B8AF', '5BD64DD9-4EC8-4A6B-9C25-45D7179EBC05', '4810201015927', ' 100  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB91BF7B-1584-4782-B69A-1DF0ACBB2CFD', 'B454FC44-252C-4EC8-899B-2E589D6C7064', '4810201016719', ' 1000  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32F8EA99-B111-405C-88A0-E867A776143A', 'FFC5CAFC-16DB-44E8-A8DA-E1B734D7667D', '4810201017099', ' 0,2 //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB357790-C0AD-4995-976E-216B101344B5', 'BE840DF0-7DD1-4B32-9D1D-2986BE7F09B8', '4810201017471', '  2,5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0698E567-47C5-4BF2-8930-7631D632FFDC', '934EE7B4-C501-4B3B-8B8E-5402DD9B961F', '4810263026879', ' 0-6  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79F79F2D-CB0B-4C0B-90C4-64693D37384C', '0A05D202-F9A1-4A2E-AFB1-7A20FC27523E', '4810263027180', ' 6-12  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EA43F26-AE38-4176-9A65-B585F7031B50', '3A73EBCD-2722-4854-862F-4531F6F168E2', '4810263027197', ' 0-12  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('050A661F-3F75-4596-B835-0E6FFD86717F', '3C71983C-AC5A-4B6A-939C-F61465E17B6D', '4810263027203', '   0-12 .400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB98247D-CB3C-49E9-8B5B-FC037B7E98CE', '30FB3169-1976-4554-A59E-7D946EF7CFFC', '4810263027265', '  0-12  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17035164-D283-4810-BE7B-35DAA20A748B', '289BAE99-C579-4E41-B5AC-43488081566A', '4810304013400', ' - /      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F05F47FE-F91C-4C82-BEFC-013E0E19184E', '84BF42DC-E360-4365-9B29-F89FBC9FDBD3', '4810304014599', ' - /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA4BF5A5-B6B1-4DA4-8E21-B375D735CB6E', '6CA4BD9E-F2A1-4D7B-858C-17C1DBFAF79E', '4810598000056', '  1,2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('080E4335-A14F-4210-BFB2-E33A4C384B99', '084E457D-4BB7-4B54-B85E-E984E7E34D4D', '4810598000070', '  1,2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E6E6D8D-30B3-43C4-9A1E-D34A4978838F', 'C6D1719C-D282-45C4-9EFD-5002EE669837', '4810910001440', ' 4  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8EA7AD3-06B6-42A7-8E4E-ED1E76713038', '84320941-3649-4369-8EEA-26BC079B2171', '4810910001853', '  900    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46C71A2D-65BF-4CCF-BFCE-6EBADDD641BD', 'ACE94538-8BBB-4212-9126-B63FED3F59B9', '4810910001884', ' 4  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FB9F976-DDF2-483B-A368-431C22C7F12E', 'C6D1719C-D282-45C4-9EFD-5002EE669837', '4810910001914', ' 4  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10F621AE-D2AF-44BC-B165-402A9D1CAD79', 'A4002409-E72B-4641-ABEB-979989FF20B9', '4810910002317', ' 4  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('282DEC0B-6045-470E-8B37-5E146229D7CF', 'C259846A-09CE-4214-9390-5C8F9EF1FDCC', '4810910002331', '  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('467EA300-9513-4697-B742-442738E91EE8', 'ACAF15CC-6827-4DDF-8196-15788D4B2059', '4810910003178', ' 4,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2FED84D-8C23-457B-B355-8C227FDE5C5F', 'CC35DC91-4458-444A-95F3-C8E5857DF748', '4810910003215', ' 4,5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('903AB4C4-0DB3-44BE-9501-8F024B27D98A', 'F293C9B1-4BD2-418B-9E88-A85CCF17A45F', '4810910003789', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('419A0E7C-E49E-413C-A3AF-01D22A1847EE', 'F65B2C92-B78E-4677-8ED9-B1A0E8A263FB', '4811248005841', 'Liv delano   7,0+- 5 /    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8C970AD-232D-4B6A-9052-29EB6E4CE043', 'DCF451F6-1A38-49FC-B152-8959B1056D47', '4811248005971', ' liv delano   /    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCA98BEE-C78E-43E9-B702-CA90A140587F', '523B387C-C90C-4810-9BDC-C372A16E9A8C', '4811248005995', ' liv delano    /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD70C85F-EA78-46E5-8827-BE3A4BBBAD90', '6B9B27EB-9ECF-4F6E-8386-F133132F0A4E', '4811379000029', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A091E220-F1D5-4C4C-811E-0F9697423E8D', 'EC8092E1-5AFF-48FF-9062-356C814730E1', '4811379000043', '  - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CBE5CA8-BF4D-4CE7-AAAA-DFDE72F805F5', '021F403F-83B7-467F-AB0C-4089E4553598', '4811379000050', '    ag   .  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E27C560-47DB-470E-AE3E-67D2BE758C41', '43A349D2-1B66-4DD9-B02D-3ED98FD2AE83', '4811379000067', '  -  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('214F1D2D-B364-4336-8240-E2448509E007', 'AC9B9B84-8613-40AE-97C5-3161B428E3CF', '4811379000104', '  - ag  -2 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFF314A0-15DB-4FCC-B0FE-F2B628DD69DF', '755C50B3-B643-448B-8D39-F549BC47AF1B', '4811379000180', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D04A2FF-4F23-4210-9F3B-F6C118B42422', 'C7F90A01-516E-4BD8-A559-C96177AE0945', '4811379000197', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56E8BAA4-3994-4EF5-B078-A10FA9EB12A9', '93278EA0-F2D3-41AF-94B5-E5486B482E61', '4811379000241', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE146E1A-31BF-4369-9B22-A61E332AFE85', '7AFE34BF-5A5D-4884-A8DD-223B9209294F', '4811379000371', '    ag /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E19E5966-EAF6-434B-A7CD-1B7BAFEC7287', '878FF0DD-02E6-4648-A6C3-AA6BBEF781A3', '4811657000499', '- ozz    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D6DD031-7A34-48C2-820E-777CEB62EC70', 'A9A1334A-DBA0-4CBF-869E-8188488BB77B', '4812317000101', '  //   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D2024EC-3E28-483F-B254-95E38F656CC3', '0ABA0E16-9C0C-4C4A-936A-B4A8755D997A', '4812317000118', '  //         10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AF40879-DF9A-471D-A5EE-A43D1EB33ED9', '4A83ED7A-2EB3-4A9D-A7BD-80D0DA418255', '4812317000125', '  //         10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D7F0F9B-C830-482A-AA8E-A304195355AD', 'C6F54878-B20E-44F9-BB1E-7A17EE942F31', '4812317000132', '  //         10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7CDCBFD-47EF-4A20-8667-559B41583EA2', '47C77FA9-D2AE-47EE-963A-FEFE6AE66221', '4812317000163', '  //         10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D28A234-5009-449C-BC2B-1A1C50311F6E', '34483ED7-F169-479F-B353-9209BDEF4849', '4812317000224', '-       100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C337C58-81B8-447E-9121-D9728A3F458D', '70063BFD-253B-438A-82C7-CFD0A9B9DFCF', '4812317001917', '  //         10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2566680D-70E1-49ED-A7A1-38D6623E2348', '379A85EF-003A-4330-B177-3BD6CE0BCD5B', '4812317001924', '  //         10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CA4B756-FF91-4A97-BE37-700909408BF8', '038B1FCC-379A-48E2-95C7-E7D4B50F2D4D', '4812317001931', '  //         10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0558A87B-CD07-479C-80D1-E667B947C31A', 'FE857C28-EF71-4D9C-B9EE-A222765DE70D', '4812608000148', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3E0BCBF-1D1B-4420-B9FA-CB01870BA12A', 'CD81FBEE-55D3-4094-AC83-69DDF1CA9098', '4812608000667', ' 40  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00FC0117-CCD8-4981-823B-9933F01E3FE8', '9C3AB186-3B12-45B5-94A2-420E8DD869AB', '4812608002180', ' 0,05  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E1F810C-45A4-4234-AE7C-2C2B520B5F14', 'F67364EC-D9B9-4B9C-8ADA-02AA7A4C7F98', '4812608002197', ' 50  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB602683-E3E5-48B3-B652-B9CB8397FEAC', '924EAF93-5323-4673-A183-8F0AED5DAFE5', '4812608002210', ' 50   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D3866F8-2C00-41D6-9845-06CEFB26FD69', 'E063DE4A-094A-455A-B009-1CB80CB90A17', '4812608002227', ' 0,1n10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEDA52BF-0AEB-4352-B957-DA788C094C14', '40EB02F4-C03D-4788-A641-3F0D666A198C', '4812608002234', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42D073FC-B7EB-486D-BE1D-D40B63617BD4', 'F0342EA2-D86D-4F48-822C-E752B3E3D6AD', '4812608002241', ' 0,1n30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06FE9F6F-0D37-4DCF-AD41-AF82CB858C77', 'D0CA4D35-93F3-48F8-A5D4-ECF0770CB0CA', '4812608004245', ' 50   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20C20B59-762A-48BE-A7E0-4B6DD56BC6F5', '7ADF4EB5-CCFE-4CBF-A640-39826AE985B5', '4812635000104', ' 410 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('870A9525-D785-4567-9465-ADBD640EB3E4', '91271F6B-3AA8-469F-ADA1-67DD0192E0EF', '4812635000111', ' 610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92224ACA-3458-4DE4-A313-732989A4CC17', 'E8E090F0-D2E3-4150-8CFD-9EBF6E46146E', '4812635000197', ' 1250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82F9CE71-8C87-4126-957C-C9067391CC20', '6F657D5A-7426-4C2A-B4F5-A21B17C6EDC2', '4812635000210', ' 2500 . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6227466-C267-483F-8D93-E6FE1B720EB9', 'C1F1BE1F-DE90-434F-9B39-5AA63B589B81', '4812635000234', ' 3500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA4589D0-38C6-45B3-821E-7F353A522367', '539C69FB-4A2C-4153-BB03-E611DFD726CE', '4812635000258', '  4500 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE04A876-7318-413F-A4DD-4E9245EB5928', '4A14C151-14A7-4E57-88AB-AEB923503F5A', '4812635000265', '  .   5300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40E0668F-A0FF-44CA-AC78-F1E0084ADD17', 'A02BCAD0-8CCF-4BBE-9E0F-A6A709BE092C', '4812635000272', '  5500 . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2C9C64A-6DA6-4321-ADA1-BB67B7A957C9', 'F4C3FCD5-4E9C-47C3-8A62-DED649813CAA', '4812635000289', ' 1,25500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3EDFF56-B0E1-4316-AB6E-DA14EB1DEB3D', 'E461C2BB-ADAA-46BE-A963-85E3C6D42A22', '4812635000302', ' 4500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66D12E07-3221-45BF-8BC2-98F6D3DDFFE1', '31756861-364D-47DF-A1B2-3C2BF4C4F63A', '4812635000319', ' 5500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53B6E1E2-3942-4EDE-8488-10F6A2285C22', '02387FED-BAE5-45FE-9175-79D64951971C', '4812635000326', ' 1,25500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85A3323F-827F-455B-83AC-CE65A8F19867', '46FDA9E6-6727-4AA0-9460-0FCC6DBA546C', '4812635000333', ' 2,5500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EA65843-B142-46A5-A822-F8CD071DDBBD', 'DE85F1EF-8E28-4C56-8EF8-5D4465CB45EF', '4812635000340', '  .  .  4500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70DCE8F7-6715-4B9E-89BC-2F581B04CDC5', '06C899AE-91CE-4559-AB6D-72F431A2FC00', '4812635000357', '  .  .  5500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E33C8642-C33E-42F6-B71C-051634040E43', '1DCA48AD-BF3F-4592-BE18-4274BAC89D99', '4812635000517', ' 1500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4854E0E5-6885-4C91-AEB6-B90142453132', '86EC5F8E-EA4E-49BC-AF70-C8570E4F455A', '4812635001514', '  .   . 410 / 10/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68CE8F7D-E581-416D-A2CE-08250C69A8E8', 'DB12D152-CFAA-4433-81FB-51C32B82E178', '4812635001521', ' 610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86342A72-82D8-42F1-877B-ECEEA2BC8398', 'BA3312EB-ABA6-45F0-A43D-1E32DA84AA51', '4812635002108', ' . .   1,65,7 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9304E736-BA21-48C8-8503-9BF406A28C4E', '3D505EE4-1D17-4F45-ACCA-4D8602159F63', '4812635002115', ' 1,97,2   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47765E69-8833-4D20-8559-97BBD20F0798', 'B1500BC6-CFC2-47F5-8583-EA6CF4383740', '4812635002146', ' 1,97,2   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC569B65-F94A-43FA-9132-4D07B58F191E', '960E178A-1F29-4226-9563-7A2D48438D7D', '4812635002153', '  2,57,2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A34A1AD-1727-4B63-A8A7-2D9F97FBA2D6', '5F546175-890A-48AB-BC52-288D1101C7DB', '4812635002177', '  . .  . 1,97,2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B59D7CE-235F-4428-BF18-63BD655B6E65', '399B3B57-D299-42A5-9FB4-53297E866959', '4812635002184', ' . .  . 2,57,2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7245DFE0-3D3C-4E0F-A8A1-D969B843C4B8', '58936C0A-56C5-444D-B136-E8980580E65D', '4812635002191', '  . .  . 3,83,8 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7458481-1DC0-419A-9D60-655FB183CEDB', 'EFFEFFD8-AE2B-42D9-82E2-CE645F39FF86', '4812635003051', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B0795EF-74A8-4EDC-B223-53932E129DDA', '0EF827B6-FBD7-4C4F-BD1A-D870E992BBF4', '4812635003068', '  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADD3A226-E4EE-45AE-92FC-F3F45221FECF', 'ED5B3D57-970A-457F-B61E-569F94784EA8', '4812635003082', ' .  . . o vie plast, 1,9*7,2.  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('159C0FC9-EB52-4CE7-8B6B-DD2B2BEA8590', 'CF697F92-1A54-463F-8089-D096CF5FB147', '4812635003099', '  .  . . o vie plast, 2,5*7,2.  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02D3EE0E-EE23-439B-A800-C3C02CE20D33', '582B56BC-1F57-4124-BD4C-40CFC2331DBB', '4812635003105', '  .  . . . o vie plast, 1,6*5,7 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09C8D057-0BED-47A6-A65C-804213D1F12D', 'BF19A71B-910D-4425-B5A6-D91FD5A48EB7', '4812635003112', ' 1,97,2   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2266793D-BA94-4337-8193-742AFFC7FEFB', '4028F57A-1FFF-45C2-8192-32AEF84EC125', '4812635003129', '  .  . . o vie plast, 1,9*7,2    10.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10A1E37E-2E62-4216-ADB1-D5259C982485', '420301AF-2A70-4D43-A308-17C80AD938EB', '4812635003136', ' .  . . o vie plast, 2,5*7,2.   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7E67B76-8EC4-4349-8547-9A011ADE2360', 'B11ECED6-640D-49A1-B4BF-7EEB6B2A96E5', '4812845000215', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('712B9791-9D42-49CF-8953-846AAF59D59D', '81A01113-57CB-4E30-B975-538E925D401F', '4812845000291', '   0,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B12B9383-9B0A-4E0C-A296-1D0195467810', '51454D4E-472B-4F04-9949-AA509450F717', '4813870001017', 'Dentorol    65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CCEA34C-5681-4F6F-B421-6E0DFCB6DD53', '0026701E-B38C-4E2D-9399-7071DEB8485A', '4813870002168', ' /    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4081EC52-B1BD-4646-B7F3-F11000FFE6D1', 'FA6D7592-0370-4EC4-9B0E-D95F2D121724', '4813870002182', ' /   strong+25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6BCB99D-B648-4012-B872-21381F094FE2', '5D949185-4285-434E-9D81-ADC1F0DD21E6', '4813870002236', ' /   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2534CA05-25E2-4AC3-82B5-6DE4915379F5', '869401D4-E16E-4BE9-AB27-BEA5B053D800', '4813870002793', 'Dentorol   65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED11F9D2-8AFC-432F-B97A-7B61D5BD0495', '18632D8F-13D5-48B4-BBCE-F66AABC4EE4D', '4814052000118', '  / 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6F6D3D0-5E5A-4797-B21B-8E2B1087419F', '21C2CF1A-24E6-40BB-8218-9C426591F2F6', '4814052000156', 'Multiwave   /      350 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8338B37C-A7C2-4F3A-BEF5-F9EC57DAB245', '1284FD54-635C-419C-AB33-F0FF72794232', '4814488003370', '    120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D298951-BE98-4DF0-8FDD-B58AAA64D72E', '456698C9-5EAA-46AA-A5CB-B06477B78093', '4814488003400', '        60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('260A249E-18CC-468C-9191-0A276A6DD1BB', '0FFF85D8-C943-46A4-8388-1517A1A18FC6', '4814488003646', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DD70B5B-870E-4664-AA96-E228AC3C2D9F', '04908930-63DE-48E9-A751-821ED701D1C9', '4814488003653', ' /    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E10F23D4-45E7-4C3E-80F5-D841F3C891A4', '2379D503-0B99-423F-AB93-CC94E97A8ECC', '4814488004636', '   60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3E74E41-864F-43D2-B205-82EA7242586B', '10434E08-04DE-40FC-A7B1-5F3C1F064B9B', '4814488004643', ' /  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F217453A-5DD7-443E-9576-6763A4DDB6F0', '3B3EFABF-FA94-4BD8-B5E9-61B0F7681B34', '4814488004650', ' /    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DDEB603-5E80-43EB-90C7-EAE662990AE7', 'FE61649E-FE82-44E9-AC19-44E7E8B6B651', '4814488004797', ' /    / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BA4F76C-F5E1-41DF-9E43-6BE96C0E06D0', 'A08CD405-AC94-4A91-956C-9E8276356CCB', '4814809000033', ' /  120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24F8E886-5EED-4206-8A9F-DAE057F61EE3', 'EC908052-AFC6-4C4D-9EA7-D200F6F91D2D', '4814809000064', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C10BED4-2A02-4743-B253-EF09B603B518', 'C1C4D162-C0A2-4B25-A705-226956DFCD39', '4814809000095', ' /   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47104CCD-0FDA-4309-BE17-C71A847F6637', 'D8979835-11E3-4C4A-ABC2-C2CF875DB4DD', '4820000680714', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F69B8B59-9CD2-46F3-BE69-6B96534BAB3C', 'CE730B7E-A762-448B-9220-F8467F2B2300', '4820000680738', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF45D59B-2751-4863-B3BF-A7A7EE947F6E', 'E43C3B05-D438-40B0-8CE8-07024CF66701', '4820008310590', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EA41323-B5C6-47FB-88D0-E0312A0104C7', 'BFC26CF3-E962-4BD1-8CE5-BEBDA75E0975', '4820008310606', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68F2C4FD-1235-400D-B27D-99FF310FF937', 'F9ABF37F-D1CA-47F0-9801-BA48C0BFD26C', '4820008310620', ' -    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43D6C223-3DFA-426A-A598-2B532F683849', '0F68976D-2182-44D5-B183-AD8DDAFC6F4C', '4820008310736', ' -    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1459193-DEC6-454E-BBED-7C245136197D', '41966ECD-F418-4A2E-85FE-FDA46789DBFA', '4820008310842', '  / +', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4770DC15-30EC-4F7F-8A5F-ECFCF6BD7F7B', 'A1AB95A2-7764-4408-BDE4-B462D171B88D', '4820008318947', '      / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C03B678-3281-4257-A65F-0BBE681C7182', 'FBF9CE38-7256-4452-98A3-B58D74326065', '4820014860096', '  5% 58 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D169A809-B0D7-4857-A70B-9C0EBD78C05E', '32C967B1-6A0E-4140-B276-BD8AF855A54C', '4820014860126', '- 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21AA98F5-CD56-475F-9707-171311D3B9FA', 'BFC32EA3-3045-4048-B9B1-CA5EBCCC4C8F', '4820022930019', ' 0,5/ 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20938A10-9993-4D51-96F7-F59EFEEE178C', '8FA382B7-D731-40F1-A834-784BDC00B22E', '4820031540056', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DED5CC57-801B-48EB-86DC-B166957FD5E3', 'C6352804-2E86-44A1-90BD-48D1A56EC944', '4820044110840', ' / 0,005  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76052F47-46B8-4EC4-B9D5-72EE154B2AF9', '1445FBC5-A4A0-4310-AAA4-527CB7256B43', '4820044110932', '  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FD44495-B513-46EA-80C5-B53F8EBA3F80', 'B73CB19A-D0C7-4E69-B7AD-6C21A4735CE7', '4820044111106', ' 0,07  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('905E173D-2C70-4088-9A09-1B94C91F10C9', '9D0AE2E6-AB47-43A4-919A-5421541703E2', '4820044111113', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BE29A0B-2543-4546-B42E-CCA00F62C2D2', 'ACAB225D-A426-4588-86FF-8D05B0AB8B8B', '4820044111168', ' 30  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('766954F1-0138-4615-97CF-F4AB8F3838E0', 'C5F81D78-8439-4CFA-ABAA-FB22CD0AA9BA', '4820044111335', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66FF5FF8-DB26-4539-838E-2427170C2DD7', '83EE2101-472A-4664-A2C9-8FE7A1DFE261', '4820065530184', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38CF796F-5367-4DE9-937C-FC7DE4CB1BBD', '9053DC4D-C23E-4DC7-A66B-26BC12AF4A2F', '4820065530191', '      15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('338048FB-D690-468B-942A-6316522D6296', '37302421-F2D6-4173-8962-38F756DEBD1F', '4820077020819', '   105230    4,9 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C801678E-296A-4A26-9864-17163F2E7339', 'B9DB7647-9681-45EC-B0B2-C731CC44EAE6', '4820090051210', ' 1% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21C7A9A2-79A2-44F4-89C2-B8E0D68C1D86', '393B1DA4-7660-4B60-A733-EDA00B513FBF', '4820090052569', ' 0,0005  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA830B68-EAE9-4F3C-82E3-3D60878498EE', 'E8AE4BFB-35C9-4687-B763-4DB37E201C09', '4820090056543', ' 25   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D3B1BB3-8D66-40C9-A32E-AEBEDFB1FC8E', 'FBA740E5-E690-453A-B49F-0C1A31D43F9B', '4820090056697', '  0,02% 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C1E1B11-6F73-4E0B-86B4-4F11108095F8', '61FDAC0F-4B0D-4F43-AA18-27F418005DB0', '4820099170875', '  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CCCC896-ADE3-4E8F-B7C0-84FB7B9FD64B', 'B37C4C40-A0F3-4D5B-BD51-DED06A06F206', '4820121900029', '    250 112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9300CEF6-02B1-431B-9AED-F22E3813A1D4', 'F11E8571-5046-4584-8889-68AD696A7CED', '4820121900135', '   1014', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A14738DC-BFF9-4EDD-A8DD-029F62EB6BD8', 'ECE8B6FB-F703-4C2D-A1F4-3D2DA902E384', '4820121900326', '   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AC725C3-D4DC-4B66-9A48-20CD2691A71C', '8915A84F-8DF7-444C-9B34-EEE223FA6D9B', '4820121900425', '    1076', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E83EDAEB-D688-4F88-BBE6-3606BFEA0808', 'D138111C-D990-4272-9079-BE054758F0D1', '4820121900432', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('421962B8-7CA3-4B89-BBE3-4380730A07A0', '046AAEC3-D76B-4DC7-9CE2-AE0CFBBE2259', '4820121900494', '   125 /1101/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9174B313-0414-4715-861D-A0927A0AD1E6', 'ACD2BE44-A622-4C36-B3DC-E6AE4E35741C', '4820121900524', '   /.  125 1104', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDB4FA52-A11A-4907-8B04-4983B70B66F1', '6C444417-EE53-4DBE-8F42-A8C2560DE66B', '4820121900531', '-  210 /1201/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92D56E96-10D5-4005-8281-B7583D7831CC', 'F0526C1B-40EE-4EFC-989C-8DB8D2A27E3F', '4820121900661', '-   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('150CECF3-51A9-4C15-9437-D46D3C419911', 'E2B90438-A7C6-45A8-8BBA-6918955D1471', '4820121900746', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ABAB289-77D5-4012-B339-BF5D8C7345D2', '447C28A0-1F0E-4EC1-AE51-D70A13FF307B', '4820121900777', ',   147', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59E35C45-69D2-4E62-80F0-601F19F1C281', '0F93D151-1C22-47C5-9939-1D820F3C2F8C', '4820121900791', ',   (149)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('517E8ADA-6B37-4F55-8E65-DB075375F71D', 'FF93E65E-9DD6-4EAB-AFBF-58438398C660', '4820121900838', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70750B34-FFC7-4085-B946-6139CC484934', 'C44AEABD-C333-4FAB-997E-C2B16A7820BD', '4820121900845', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93B19032-4233-480F-9719-5A9040B2A2E8', 'D39CA685-83E7-46CD-95B7-18FDEE61C2D3', '4820121900869', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EF58A00-9AC3-44B7-B0DE-EA5C5B7E2F2D', '1ACE6B64-4F4B-4E53-9C02-C853BFAB2E90', '4820121900883', '  /.  120 1111', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23F0DC7D-5404-4454-8951-52EED46EC60E', '7DFABC01-BAC5-4A7F-B83D-9CF212AD4A39', '4820121900890', '  /.  250 1112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77A5B26A-C7B7-47AD-876F-BACC012AD6A4', '0FAA1FBE-E781-4127-9F38-0544DB24E764', '4820121901088', ' -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DE080B4-19E8-4AD9-9589-1BF04484BEFA', '2B791585-0CD8-4BC7-AC4C-87D157DA3220', '4820121901095', '  8006', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DA763FD-A4CB-4F72-B493-2065457C0212', '4B896BDE-08FC-4D64-BDD4-BCAB23D9F6AD', '4820121901101', '   8007', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C43F3140-39E9-4F30-8869-70F674C8BB84', '164F0D7C-66D0-44CA-8E5A-DB32B21EC8A3', '4820121901118', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB69D9CC-CA88-41C5-B3A2-4358A6AB9337', '57723335-D42A-42C1-8792-3DA6A446933C', '4820121901149', '  2 ,  (8821)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA745BEA-EA65-4354-AAAD-00C4C50AB326', '486E4D8B-351B-4B0E-B682-7DDE74E88344', '4820121901255', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08E9D1F5-EB75-4264-9F95-EFA3F8899D33', '3FEE56C9-7156-452A-81FA-0BC3EE4EDACD', '4820121901330', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17E856B8-086C-48F2-8E92-C85678514F4C', 'E2E81FF1-2F13-419F-9497-FA806AD00063', '4820121901583', '  /.  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FB28DE4-F6B3-4237-BB07-CA5398416EBD', '07B9B6FC-8F45-4DC5-866C-E7835FA86EC3', '4820121901606', '     125 /100/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('049B9A95-EC48-4A9C-A127-FB868A43064E', 'F069E4F4-8308-44A5-9E38-C589E681BFA5', '4820121901613', ' -   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF62EC66-6158-4D39-A262-E97A5B4C3A93', '49425457-9D45-4E16-AE28-947B754F9B25', '4820121901637', ' 6-18.  ,   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('925E674B-7C77-4CC4-868B-78F57D2A3EAC', '79446E5F-0521-4FBF-910E-8F7D18428F5C', '4820121901644', '  3-6     405', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE8BCEDD-A997-43D0-BB22-047BBE5CEEE6', 'E753D5C6-3801-45A6-997C-295DF66B8A07', '4820121901651', '406  6-18 .   ,  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EA2E28D-6BA0-48A2-A6C6-94C8EDFE5730', '0E6975AE-3FD3-4E98-A214-772AB7F093F8', '4820121901668', ' 3-6 .   /407/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8110ED9E-AE96-4551-8825-D901B1E8CA85', '11410EBD-1962-4369-949F-37881A21359E', '4820121901682', ' 0-3 .   /407/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A4CEDCE-69B4-4D23-8C47-28A3126E9672', '95C63CF7-F8EE-4EC7-B4AF-A257E3DD31A6', '4820121901699', '  ,    410', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('804FFFA8-0A56-40BC-A565-C850425885DD', 'B3D7E7EE-EE23-44CE-9245-5270883DFA6C', '4820121901705', '411  0-3 .   ,    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('537DA103-E272-4C89-8CC7-89A7DE5BABDC', '34C8482A-83FF-46B7-93E6-0BD4B931DDE2', '4820121901712', ' 6-18 .     /412/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CFC2F33-B146-4947-90CC-58033DA2FB37', '07D0DF6A-CF7C-4BD3-9D60-CC35BD5E87AE', '4820121901729', ' 6-18 . .    /413/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3E22C9E-C4CE-4B82-8D2B-18585969DC9B', 'AEC36274-9204-449D-8CA5-57E9C28862A8', '4820121901736', ' 0-6 .    /414/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03C758CD-BBDC-4B4D-8F84-C402DB9629A0', 'D25AE65D-9AEB-4DCC-ACFB-6AB713AFB9C0', '4820121901750', '   ,     416', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A7FFD46-D352-41F1-A650-7966D2F0DF00', '632D35E1-6256-4C31-A2F3-905099DAB4B2', '4820121901767', ' 0-3 .     /417/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF6DB429-AEF5-4CCF-A87E-039138F14BCA', '35C1820D-ABC4-4788-A84C-3400180FCBCA', '4820121901842', '   / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('534F5EDA-D591-479A-BCA2-D9854AF501C0', 'B8CE193C-8F28-4137-8662-D59C36E9C8E1', '4820121901910', '   /.  250 1114', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E6FE81A-3EA7-45ED-BDD4-AFE19C3F3714', '9DA1FF47-D0E5-4E24-B424-98ED6C1C7BA8', '4820121902092', ' .  . 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B99F16CC-6565-4430-B054-2C8E312A76F9', '8200BE87-E1F5-44E9-866B-06B4A5E10E4D', '4820135580095', ' 1  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76132A76-BC39-48EA-85B2-8A115A664905', '6BBB77F8-1F6F-441A-97FF-A9BA1F84665F', '4820135580101', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('251BA7E2-6A6B-4676-8EC2-4AABA49A40B6', '08179BA2-76AC-4E8D-83DD-E9B761BA0099', '4820135582570', ' 0,15 /  /  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5656D63E-C608-49D8-833E-7CF01F54BCB0', 'D6A70C5B-6E96-4DFC-9C67-81AAE0F90868', '4820135583799', '  1  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC1E7E97-D2FB-44E1-85D2-34AFBD778782', '2FCA6D9E-2D07-4740-AE4A-BF56D90157DE', '4820135583812', '  1  3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35C28096-FBE1-4309-9CB4-0487A6857908', '37CEEC5F-A54E-4749-B4B2-DF6F16D1BC3E', '4820135585526', ' 0,01  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('154CDB39-AD2B-485C-8A23-050C8FE9F6B3', '53B7CDEF-BA72-40D8-B219-4B244316BEA7', '4820135587018', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FE2027F-0C1C-4721-B31C-7C0587BB4E1D', 'CB9B20B5-1A70-4776-A587-FDB7F219EA5D', '4820142800148', '  Lili 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4B4CF1B-BE43-4BF1-ACC2-FC40BF0B8071', 'CB9B20B5-1A70-4776-A587-FDB7F219EA5D', '4820142800162', '  Lili 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CF0FAA6-8A33-424C-A20C-70F8DB3E535A', 'CB9B20B5-1A70-4776-A587-FDB7F219EA5D', '4820142800179', '  Lili 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C85D4333-87E7-4BBD-B103-5579E2E9FC74', 'F4684251-30A5-4930-B557-36E310BBA794', '4820142800186', '  Lili 15   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24A6BB18-EDCA-4DCB-A5DD-7321EF4353D5', 'C3F9FE28-15FA-4C9D-ABA9-73E401D65237', '4820142800193', '  Lili  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F2EA444-10B2-475F-84B7-CFEC1793B766', '5676D017-A40F-4FD2-81B6-10E88AE97641', '4820142800209', '   .15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DDE6428-377F-492E-BF71-EBEF77934452', '43E43355-C433-4541-96AA-31B6CE6FDFFA', '4820142800216', '  Lili 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C1C2EDC-998E-42B8-8205-D2BEC2E6745F', '770DCD0C-19A6-4954-B6D6-89EEEE6C8415', '4820147512572', '   0,88 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FD80D86-F4B0-462C-AD4E-5C78F53B8621', '68F30C0D-583E-4276-B3A7-4B9579D24D7D', '4820153893924', 'Ma health   - 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8759253E-E101-4D2B-A802-4D978333EDCD', 'BB19801D-A8DD-41D9-9301-912EB6950B7F', '4820153893931', ' health    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B5D7172-D99C-4FB5-96D5-9F76C6932D59', '28A2785D-7E45-4FA0-B8E6-EE13CD8CE6D2', '4820160030824', '  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC96F547-FE6D-4BA8-9163-EF77743CECB9', 'E024246C-8E88-4458-86E0-852C12B08208', '4820160030848', '  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FDAAED9-D1EC-4D37-A2BF-E7C6C98FF254', 'E30B9103-ADD2-4F6E-8E01-8B319F626242', '4820160032590', ' - /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('705FB8A5-391A-400D-BAFC-AA881F6AE3F4', '97B356A6-DFF5-455B-ACDF-80435E665C3C', '4820160034723', '- / 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9CD5C0B-75DE-439B-BF27-44449C778811', 'B660A99F-F561-41E2-8C82-F491A24FE541', '4820160035393', '     30+50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54D67904-B3E9-4601-ABEB-431E63496AC3', 'A8D21388-B831-4767-8FF4-C31C5E309971', '4823000803374', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21FA87CB-A3AD-42B6-A80F-6986BAA7D44F', '922741A4-9145-4A07-9602-1B9254173F2E', '4823002004021', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('650E278F-82C9-48B2-9A0F-CE9D1F5AF354', '97AC3C53-2D25-4265-81AB-2774DFA5510C', '4823002200454', ' 2,5% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D600D559-CF6C-40A7-BB48-1F7569EF16CF', 'B5499D2A-2FC5-49EE-A606-5D3FC595F297', '4823002200898', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B6328A1-D823-495C-942D-827D000D8813', '991422E3-83BD-44C0-971E-801C16A0A902', '4823002201154', ' 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4290127C-38DC-49AB-B21C-8A9BFDB4CE1C', 'EEF7BD5B-4627-49EE-92D6-5E21218A1A01', '4823002204872', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67BAF8B7-F17E-4EB4-B9EA-E273808FBDD1', '74E405C1-F10C-445B-951E-958347B4A9DF', '4823002205831', ' 25 ', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CABD8F4C-27A2-4FA7-BBF4-6B234A6F96CD', '9CA95236-A39A-4798-B69B-C314C7FDF2DF', '4823002207866', ' 0,1% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33CF75F5-5789-451A-8BC4-A3AC3C2F7285', '0C5423FA-489E-4704-A0A9-97CEDECBBB5E', '4823002217285', ' 0,0075   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B6E1446-4F62-4738-A55C-32036A694401', '47EBDFB3-A3FA-43FC-8DD0-43EC4929885E', '4823002217308', ' 0,0075   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08D00524-5C6A-4551-8B66-2951A9E8E361', '47F83ABA-6310-4F41-BCC7-6E7FF2F60DE3', '4823002217353', ' 0,3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('548B663B-EC3A-4F2C-8D7F-17043A994D89', 'C3AF613E-5396-4534-B0A8-13024240AAAB', '4823002217407', '  0,001/  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A7BB933-CE8E-4B13-8521-BA87B716AB2A', '5FB38193-DA02-4054-BEBF-2A718F7FC4F9', '4823002223125', ' 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D877861B-5ED2-4CC3-8DD1-AC882CA807EC', '41CCE335-8F85-4F1E-82E6-E51F1FF8EE47', '4823002228632', ' 0,0075  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AE1844F-18C6-4B8C-92B5-FDFE375ED3A0', '7CDA308D-D1F2-44B2-9646-6E73C3B7E96D', '4823002233766', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D73BB5A-2C0A-4488-81CA-80054127853C', '70098061-9331-4B9D-8444-AAE3E13E1BC7', '4823004003961', ' 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C1C0FCA-DAD1-4D61-86D7-FC4E352D6765', 'A8D21388-B831-4767-8FF4-C31C5E309971', '4823004006030', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAC23ADC-2ED3-4262-AC49-E7F49B8E4E45', '76F65C1D-0C9C-4E08-B59A-D086F3C3075C', '4823006301812', '  3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E64FF4C-4344-4570-A884-E64304B821B8', 'B0774C4E-DFD0-4B9A-91D8-BCD6B2421775', '4823006301829', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7DCB83B-3F57-4B81-9E0E-0A124C02203D', 'B9E9AC6D-90A8-4B4A-B042-2C8DF1ABD2BE', '4823006402861', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EF45748-1B65-4481-99AD-D2CFF5232B0D', '80F092EE-0A58-40F3-AC07-870D8AD357E3', '4823015905797', '    / //100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FC8C324-201F-43D5-9180-7E2CBBB23D4E', '67AF6091-AA29-4BD9-A5CB-C923D1308280', '4823015907005', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26BB2AD2-F46D-4C9F-BED8-06B21406CB09', '25F0B9D1-0DAB-4C23-BBAC-C0CDEFDDC3E8', '4823015907647', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('619EB244-ED66-4072-94CA-7A241626F753', '5A7F5A1B-9752-44C7-85CF-91780EA51A0D', '4823015907678', '     / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D607D828-AE72-4579-90E3-56389C3BF922', '39CC59D0-9226-4795-8D06-525D97B7BC7D', '4823015907685', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37957A60-3505-4921-9CAB-0B75353A510F', '3C20BCA3-2E12-4714-8161-DA869FE3A93B', '4823015907715', '    // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13C02B07-19C8-4011-9FCC-A9FB275258DB', 'EB879608-BDBE-433A-BEB5-DEB887C37277', '4823015907821', '  /     270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08F8F6E3-DB8A-4F9B-B117-DBA3C0990357', '4E4BEE90-6BF3-4E36-9F17-54113F01B85A', '4823015907838', '    / 270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16E007E3-8038-417E-92B4-81B0E9BB98BE', '50CAB34B-A15C-4556-8E12-BE0202BEAB13', '4823015908729', '   /  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EE015E1-5C5C-425E-B7AA-0E8512096F4C', '62BD6EBB-BD86-48F7-A7A1-25A14B67BC6F', '4823015910807', '   /  /150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F1E533D-A646-4BCF-8CB9-11361F927B0B', 'F1832525-BA51-4591-B945-79A05655902E', '4823015914713', '      / 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF1446F9-0DDE-4152-A1B4-0DE8BCF2B270', 'F6BE6997-1E33-4011-B6C1-084B8CB305D9', '4823015916717', '      /    270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04FB40AC-CFAC-489B-90C3-79D0BF3649AD', '43622694-9872-49D4-9498-E1AFCF42050A', '4823015917073', '   / /-/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA8AE36C-92F5-4997-9DB3-4C4E34953B61', 'A17457B6-0E03-4A21-BF52-C9B352909FCC', '4823015918568', '   /..  / / 42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BA1BEF6-0ACC-414B-A58C-8BFAD1B90FFC', '30C6025D-30A3-4E33-9535-4B2E7E63A1CE', '4823015922909', '   / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54AF6E60-F40C-461D-B67B-9A78516F383D', '78CDDFB0-43A2-4B80-8187-BBC606D950A7', '4823015927317', '   /  /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ACD9FB7-81DA-4EC7-9B01-3292E779FE6C', '18200DEA-D879-43E6-B25B-D187F8B0746D', '4823015927324', '    /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73DC9A63-FF2A-49BB-8439-ACC3CBEA8061', 'EE53572E-458D-4A99-AAA2-4AB2EF0C8B0C', '4823017800533', ' 1,97,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8927001F-FCA2-4D26-A322-6FF8F198A00B', 'BFC82E45-6B9B-4E9A-843A-AA6F45FFB226', '4823017800540', ' 2,37,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB289350-8276-41AD-856A-7606B35048A6', 'DB12D152-CFAA-4433-81FB-51C32B82E178', '4823017800571', ' 610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF86189A-53C6-4E9B-B234-3D90C5BE242B', '19CB7A93-9485-4BBA-A616-74D24C7DFE58', '4823017800632', '   610', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAD069D8-DB3A-4DEB-9059-7BA06F69355A', 'EFFEFFD8-AE2B-42D9-82E2-CE645F39FF86', '4823017800649', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEDE90C6-BA4A-4960-B8F1-876A455183E0', '6C5D668B-37A1-4C4D-A5A4-E704882B0137', '4823017800687', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11FA3893-855E-4BAC-BD97-5C64B62D0552', '065D19B6-FA2D-4725-A727-7992EA7BC137', '4823017802469', ' 3,83,8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7823F386-F9FA-419B-BBF8-BEC3AAA0C960', 'FF005F49-D069-428B-A859-AB98D66096D9', '4823017802575', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA2E491B-3E36-4CB6-81EB-DF23B49B3466', 'AE14FFB9-2554-4BC2-B63A-BAF5A5D2D123', '4823017802636', ' 2,57,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D547A1EC-7781-48C0-97D8-19438529C00B', '36CFAECC-2B94-4A3D-9912-29A74F85ED85', '4823017802872', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09FCD5E2-0B36-420C-B82B-85A248C349CA', '45F203AF-32E9-4B80-B7AF-43A74F7672B2', '4823017803244', ' 2,57,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('762682E9-B90F-4BDB-98E3-08D3CF35A579', 'D8520DEB-AECF-4FDB-87AB-FCD76FFA57F4', '4823017803473', '  610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EEEE7D9-2634-44D3-947E-3CC4ABFEBFB4', 'EFFEFFD8-AE2B-42D9-82E2-CE645F39FF86', '4823017804647', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE5FF483-67BE-4E2A-9F1C-144682D23724', '3062952C-E57C-49A5-AAAA-C39CEEFD5137', '4823017804661', '    22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9A32B69-7BDD-4D6A-8E73-E9122E9DAFCD', 'FF005F49-D069-428B-A859-AB98D66096D9', '4823017804753', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('617AB10D-1D99-4246-8790-7164A9F3F646', 'E30C0785-0196-4F0E-BA07-1F03CFE59303', '4823017805231', '  . . 2,57,2 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3407408-5DE9-4F03-8CA8-9A640E3C0660', '91271F6B-3AA8-469F-ADA1-67DD0192E0EF', '4823017805323', ' 610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FBC00CB-A196-438E-9EAB-5AC89A553673', 'A5AE88BE-4808-4010-965A-C0DB28C9D98A', '4823052200329', '   / 2% 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78087469-5B71-4EFB-BBC4-726E9EFB7131', '5A8DDB17-8F22-4AD9-B0F2-1D6C8C7A1EC8', '4823052200855', ' -   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62D94FE8-79C7-482C-8CA1-73585C14C3F4', 'A37A7D4C-B56B-45DF-B009-7AEF422FCE00', '4823060800184', '   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBE4F926-0CBC-46C2-9340-8F84A2C42C0C', '139CE56A-0261-416D-953D-3F52BDAF917B', '4823060800191', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E003EDC2-D9B5-4DE7-929D-F47CEC8CF6BC', 'B5422C3B-5289-40D4-A69A-570749983F21', '4823060800207', ' -    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('064E5EA9-C91A-4F40-9954-B6B8AFE1053F', 'EFC09BAA-3C1F-4986-8244-A7ECFA0ECC05', '4823060800238', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87B6BD49-9968-449A-BECD-B0ABB19245D8', 'A37A7D4C-B56B-45DF-B009-7AEF422FCE00', '4823060800283', '   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27C9DB37-594C-4E8B-9C15-15D37A28814C', '368F9CBB-9650-4C81-889B-E04F8E3DAB56', '4823060800290', '-   /  -2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E2F1415-9EBD-4E6F-81F4-5B5C863E4860', 'B8591191-5BA8-4C39-84FB-66A2C0A2536B', '4823060800313', '- ""    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40229BED-833E-4B69-891A-A351F279C06E', 'DCA047BA-2787-4A39-AEAA-633149D37AA1', '4823060800627', '   .  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('795E5893-3505-479C-B8BE-1608D49FCA1D', 'BFB78E9B-3629-4E8A-8BA4-C1E05C36071B', '4823060800917', ' // . // 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6995EBC7-C9DD-4D87-8E76-70B0DD92BA5F', 'E01C63EC-8A55-42C3-B62D-49BDB1CAC312', '4823060800924', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99714E15-0A29-414C-AA54-A88E2BBC9B13', 'B0774C4E-DFD0-4B9A-91D8-BCD6B2421775', '4823060801013', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A073AAE3-C819-4737-90C5-15F8767F113C', '76F65C1D-0C9C-4E08-B59A-D086F3C3075C', '4823060801020', '  3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6703DD8-AEE0-4F05-8D35-4E8A2E28DA53', 'D4F85A2B-0F8A-4D93-AD85-94706C0F44B8', '4823060801068', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EE1E9AD-A582-42F8-B5D5-1426D1B6EECB', 'D4F85A2B-0F8A-4D93-AD85-94706C0F44B8', '4823060801075', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('036B7FD5-EA32-4949-985B-3A91411549E2', '341E35EC-B846-4C30-9899-B2969E0FB70E', '4823060801389', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0EDEF18-3FDE-4885-B744-E9E76C4A3197', 'C1E67E8B-B244-4593-87E1-F298F63E0141', '4823060801396', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDB24B96-1085-4F4C-996E-803D68C1E957', 'BE3FF87E-3563-497B-AFEE-829DE13E9EA3', '4823060801495', '   1 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E82369B9-3632-41F6-B85E-BC11E2A22ACA', 'F3C5D6DC-CF41-482E-806F-AC29F40FA007', '4823060801501', ' 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC0672EC-99CF-4431-8325-891262AFC9A3', '26AEBB01-BA53-4910-BE24-4A139A316359', '4823060801761', '  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57F7195F-A434-4415-B02F-7824B6AF20E5', '43D7AA97-7D77-416F-A144-30C22953B8E2', '4823060801792', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C456430-F3F0-40C6-859D-F81C66A327A7', '3A228DD4-AABC-4BDF-9E4F-4170966358D2', '4823060801822', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F72FC15-4725-4721-8BA2-C586B628878C', '12EB1D2B-D8AD-425F-82B3-D930D4B1C307', '4823060801853', '  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('605C835E-9376-432B-86C9-D969BE6D7194', 'CC11BFB2-C35D-480E-983F-32D29E6074D5', '4823060801976', '   0,782', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D982095-91B6-4CFF-AF3C-ABCC328009B7', '59D0F50D-4EF3-4D99-B4F1-8CCCA5CC92C7', '4823060801983', '   0,72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF99A000-3989-4E77-8B1C-C2B6823F5EE5', 'CC848C85-CF3E-4460-950B-87C81E663E2E', '4823060802010', '   0,781,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B9CFFB9-8616-4123-9E3B-C17C843A8474', '746975E3-A41A-4C76-8AB0-9272EAF427B9', '4823060802027', '    0,7  1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3039E86-13EB-4F98-929B-AF04B265CA0F', 'D4697F0B-43E9-4250-AB23-F22D8CCF41BB', '4823060802171', '      /19202/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4753289E-4127-4580-AB1A-F1C7680C981D', '6E5B1E65-863A-4FB9-8B7F-78F47E661952', '4823060802195', '-    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('530C4BBC-4D54-4EC8-8630-299AF45E8C83', '4EBF1522-227B-4D43-9D05-BAFEE11FE930', '4823060802805', '- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98BAF0A6-3D71-4C64-8CF1-A1E368B7CBDB', '61E8C608-B28F-4EE8-A23E-B26E2E457E90', '4823060802829', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F98C4827-1215-4317-9723-99888D20ED1D', '527942B2-B5C3-4403-B52D-7E945A522997', '4823060803598', '-   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C766D9F-46BA-4C8F-BAA2-AB668C2E5DAB', '77155D75-554A-44BF-965F-24A86F59A0E2', '4823060805448', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DE8D3E4-04D4-4F8A-9951-A0769D633D2D', '4B243773-3984-459A-8784-6C40F64B05FB', '4823060809101', ' 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68CD6E09-1AA7-460E-BB0E-A01490673460', 'B0774C4E-DFD0-4B9A-91D8-BCD6B2421775', '4823060809224', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BD786CA-88BF-40C1-9FE3-D4807FE52C53', 'E6F96716-EB34-4452-8293-31DED7527FCE', '4823082002344', 'Ma health     12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC0AA735-C23D-4A7E-9810-D897B495C857', 'AB015D0A-5EF0-425A-9645-C99B92578409', '4823082003297', 'M health    - 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE90931C-A6C3-429A-B86F-6296914967AE', '6C5C75B8-2457-41E2-96AE-CF57103C0635', '4840456000133', ' 100  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EC8452F-55E9-43E0-B46E-3BC5817F21D6', '86DFF967-38DA-4ABA-B02D-A1CD7B80D8B3', '4840456000171', ' 50  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('996911D0-5877-4E0C-A877-AA31556D0250', '88F75AAA-A4B0-42D6-88E5-BF6248F5AAF6', '4840456002205', '  0,5   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A8D64CB-757E-4957-9BDF-636039027948', 'E31A49D1-2983-4D4C-B795-B9A0072A53A8', '4840456002212', ' 100   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98AF4C5F-47BE-450D-98F8-A9E2FE46AF65', 'ADE74AD8-0155-4B21-863D-7037037B774F', '4850001740032', '  1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42F68BEE-96AF-4264-AE67-29B9178570FB', 'C9CCE8EE-4550-4257-9719-88FC8444F093', '4850002160020', ' 200   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F6E728A-634D-45F9-93D4-801290571AFD', 'A4DB2B44-8C5F-4677-BCFF-2567573E1E21', '4850002160044', ' 180  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C348ED93-EA0B-42E5-B463-589C0CE11009', 'C68EA8AA-8587-46BB-9A8A-E002B6659B47', '4850006881327', ' //  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6C97A70-9108-4CE2-A028-3AC275E43C3F', 'BFB0FBAA-4070-43DA-B605-69CDAF61F74E', '4850006881334', ' // 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9E4BDE4-B8A4-4B8C-BCE4-3FD7F56A971F', '1FD8F99E-BD71-44FA-8430-631DA5D56E73', '4860019001339', '  .  0,33 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D303642-2C4E-483A-B941-A82AC7E211CD', '7CC28A21-0CB7-4EAD-9927-E92A87AB729B', '4860019001346', '  .   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C67359B6-DFDD-4539-89AA-5D2B4E2EEA1B', '3CDA7E88-0901-43D0-99A7-F5AD6D0DA599', '4860019001353', '    500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AD0EFDB-533C-4F3F-B4D4-4EE272E35EC3', 'F76D5363-F65F-4244-82C9-5DB7D1C7F3CB', '4860019001414', '    0,75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFAD24C7-DAAC-4D9D-85F4-0CADB867A03B', '79C7D787-924B-449A-A020-F2DAB70EE984', '4860019001810', '    0,33  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D7EA086-CB9B-4AB2-94EB-ED3279AA010E', '029D54FF-2ED9-4067-95EA-660A1124D11B', '4893949230548', '-    /23054/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33DB4C41-1EB2-4299-BCC8-BBB7DCFFCA2C', '2561F853-AB91-4836-9500-BE9C0AA19367', '4901301230782', ' merries /. 5 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55CA0BDE-8BA4-4B50-BE9D-5EDE8C9948F7', '4B969334-3EDA-42A0-BE84-3C7AF56AD9D5', '4901301230881', ' merries 9-14 54', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DBD8F27-10E3-4158-8224-07AF9B94AF28', '82183DB5-A468-4237-A7BC-D739C075260F', '4901301509055', '  /  5 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E23626F3-A9BF-4EEA-93F1-BE514B28ED73', 'DDFF1B4B-8802-45D9-9267-02410E225B52', '4903111181339', '  moony  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A179C26-754F-4216-AC7A-25587B84BB4B', 'D957050D-C072-4927-B134-188B72CC3909', '4981046050074', ' A&D UA-604 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D9331F5-60A6-4FA4-8E2E-51CADB63E708', 'B87E0FE2-F99F-4649-84B9-B075B9A61D4E', '4981046050104', ' UA-668 /  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2318339E-B2D8-4442-B561-EF3AF10B4C74', '761D84CC-6076-452C-936E-F031D9D63A62', '4981046050142', ' UA-705 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB0DAEB0-450A-48F0-9FFE-2B0A710B3A4C', '2A5E8832-0E1A-4F3F-BF15-D631F6DED928', '4981046050197', ' UA-777 // /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C479E2F9-2AF5-46B1-9865-50B21D77CA54', '33A8D0A1-3932-4FA3-A10B-0101D0DE2B05', '4981046050258', ' UB-201// / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6E0A39C-08C3-4E87-8B9B-5D310B8A28C6', 'D5A0274B-17F1-42F2-8FC6-1CD26B6F6B2D', '4981046050463', ' ua-670 c ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22F20A24-C608-4F16-93C7-D329211E84CF', 'FE9B2212-E3E7-452C-819E-5B88F53EA173', '4981046050524', ' a  d ub-202 .   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B820629-4900-42B7-A7B0-DA48B9CFDF01', 'E6F74208-5D72-4EE0-9449-885EF014CAC6', '4981046050562', ' A&D ua-888 / 23-37/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E2A1E38-5A2A-4571-ABF1-F024CD6B44D0', 'F866FFE6-5A2B-41D3-873C-BBF8E2227366', '4981046050579', ' ua-888 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2479D1D-BC7D-400C-BFE3-54B3F571C545', '4378EBBF-5FD6-4FB6-833A-0D0CAFF591D4', '4981046050593', ' A&D ua-888  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C991CEDD-69D9-441B-8164-B97292783ABE', '9FD6C41E-EE71-44A7-A60A-F86B310203A1', '4981046050609', ' A&D ua-888     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('351F49F1-1EF2-4A5A-8D49-D1514D84CD53', '89EDD0E6-26A5-42A8-BC62-DB081F816E10', '4981046250016', ' A&D dt-501 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAF48CB0-3D71-4289-B68C-EA30CEA69B73', 'CE360867-CF16-4788-B16A-504DAE89547F', '4981046250108', ' a&d dt-623 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21E9A0E7-171A-4CFA-B476-F81A5B3FEFB7', '8327C442-31AD-4607-8B57-C4677831F82C', '4981046250139', ' A&D dt-624 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C809EAD-92D9-43E2-A7DE-B81BC5CC4FEA', '5681C74F-0095-4ECD-A772-514B76AEA0C0', '4981046250146', '  dt-624 /-/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('090CBAA9-BA28-433B-848F-EE5E4F03ADEE', 'D3CF9805-35D8-4A2E-811A-0DDA344859DC', '4981046350068', ' cn-232 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CD30FD8-313B-49C3-A3F5-529C8C3D1F1B', 'C7A8E0B1-013D-42C0-BCBB-C4D0DB0B9B58', '4981046350099', ' Cn-233 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E173E915-A1D6-4993-8D65-AA9AB39A394C', '7F0765E2-5F8D-41C4-8FBA-9D0408DA38CC', '4981046450010', '  / ua', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D0843C2-25A0-496B-9A3C-29FA51595210', '00ABFC8F-8B2F-4641-9622-718078FEF185', '4981046450027', '  32-45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8213C7D8-6C0B-43E5-826E-B58A24F6A12C', '270CBE6B-25B4-4063-9A24-A43E2A8BA0F5', '4987866407203', '  /   +- 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C065385-0112-4436-8F9B-2A98FE1D3CB5', 'AD7BB78A-3AEB-4FA3-ABBA-D8861FA932A3', '5000158066199', ' // 150  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9F0B70D-AA4E-4D4C-8D0C-02321163D515', '458DEE77-44B9-4F38-8464-09EEE3C80360', '5000158066205', '  // 150  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F34D04CF-A4A0-46F7-AAD5-48CD3EF572CF', 'B5A504CA-7ECA-4A19-B698-1E34F0A82981', '5000158066229', '  250 //  32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C45DC4DB-73F6-4481-B1F9-1E9868165B54', 'C2776077-F368-4610-BF15-6D284087D4B4', '5000158066472', ' // 300  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E211F945-90F6-487B-91C8-436AC290AA9A', '87E805B9-F991-43F7-882F-918174BDA6B7', '5000158067059', '  250 //  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6494E3A2-5ABF-42E2-94A6-C5DD96A4080B', 'CD9D2127-C356-4F88-BB2A-FA5241C39444', '5000158067530', ' / -   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D15821C7-6D84-48A8-B23F-DD235261454F', 'B828663E-644F-4ADF-9F2F-53826E7D78C1', '5000158067547', '    4,8 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39843EEC-5CE2-413A-B582-28FC5457A497', '74B59F96-D847-49FA-B869-097C70B3AF02', '5000158067554', ' / -     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95E22E90-48E2-4C59-8726-46E934713DCB', '31A01989-0630-44D8-ACCF-13151AED21A9', '5000158067561', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEEE3E82-54C4-49F7-BB4A-C786E316D0EB', '34C06310-84A5-4114-AF7D-D405F95EDBE4', '5000158067578', '  /. -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4257543-D475-49AE-8CE1-1CCFB0D3AEDB', '228164B8-71C1-46A6-BC21-309018003B9A', '5000158067585', ' .. 5,2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA1798F0-053A-4135-A5A2-F15F1D0BD9AB', '1DA62710-1E1F-4FF3-B8A9-F3AB60D1C906', '5000158069237', '   //  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E97A633-19E0-455C-A4FB-DBD7C79281E1', '0B051D7A-D5B6-4D04-A44D-3D5337061D39', '5000158069305', '    150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1F3B4B3-776D-469E-9EE6-8E996AFCC1AF', '99523D75-EF4D-4A67-9B82-5F47EF1E724F', '5000158069428', '   5% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B412AA0-88E1-4D7E-9DFE-DB39A8BBF321', '16E5E9D6-DB62-41CC-B679-A6554B2C722B', '5000158069695', '   10   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8CE4054-F7D3-40FD-904E-7E38C3C379F1', '33008EED-2730-4658-83F7-0369F4E32146', '5000158069923', '  // 10  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2701A436-D741-4EBD-8D8A-706D98A129CE', 'B1E1395C-A247-45CD-951D-1591B550384E', '5000158070608', '    //  32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB4D194E-324D-4E46-8E3B-CDCD61EB0A6A', '1DC7B276-5945-48D0-975E-8119C506227C', '5000158071025', '  //  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC316B90-609D-46EC-A8A9-9163342239ED', '9D0D6E6B-2563-43E3-B179-6C91D3189084', '5000158071032', '  //  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65C74CA5-9325-4F37-94E3-582CF06499C4', '2F7CC1E3-BF16-464E-9290-5642993DF5C5', '5000158071421', '   //   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A1E11ED-2E98-48C0-8156-67821ECD4B78', 'D5C2715B-79D7-4166-AED9-A1E1E90C2426', '5000158071438', '   //   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A10F89D-0726-4E7B-8775-1C5C93A33088', '8DB8A041-55CB-4F96-BA7F-45D034251EC0', '5000158071445', '  //  12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27F9AC10-7DF9-4C18-BE84-0D04D919E664', 'BF7BEDB6-615A-4B91-BE20-775898854693', '5000158071452', '     24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87D2ECB4-7C7B-48E0-ABFF-321876B0BBD6', '00454CA0-BF6D-4457-9619-A8DBDD084F6B', '5000158071469', '  //  48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83755368-D3C8-4521-A5A7-2B1F0F83A4DD', '9A0EACF5-C86A-45E6-BE2B-300577B975CA', '5000158100190', '  /  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCADE2BE-CE4D-4B3E-B7B3-304A9C6F53A5', 'DD10D92D-8B40-40D2-9596-0F7AE35195A3', '5000158100206', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D31DD4B1-C57F-4F4A-B689-0C4B61F6C6AB', '7C72AB0D-D3D0-4B9A-85DC-2CA16F3F42A8', '5000158101784', '      24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7CEF4FA-CBB3-4A64-95A3-3AC79B6FBFEA', 'C8C0CF35-9E8C-4262-8701-1EA623DCB497', '5000158101791', ' /   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC65CB13-912B-4F99-A1BF-D97202EE4F3C', '63A23945-83EB-4F97-B6B2-FECAB8C25A7C', '5000158101807', '    36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CEBC026-0593-4E34-87E3-3D9F2EFB1FC3', 'C22ADD4A-1536-40ED-868D-4F480E7DC376', '5000158101814', '     36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB3348B9-7962-4368-84FF-D11F6BA8553F', 'DF46012E-4D16-4AA7-A093-73A4B7AF19F1', '5000158103733', '   / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF5BEB6F-B26E-40AF-A6C0-45084F642541', '8944E3A8-8CDD-4EFF-AD1E-D22411AFEC29', '5000158103740', ' /    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FED0583-8647-4CC5-B149-52F0F2FE9AB3', '40BC867E-D9C1-44A0-9B23-E7BA000137C2', '5000158103993', '  .. /  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FC58F27-1909-4532-8ACA-6CC96B149F9D', '51141D12-8F9F-444F-82AC-05E65EC9B065', '5000158104075', '   / 200 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84761B5C-4C65-4D3A-A509-B42B0717BCF2', '91C7EC5E-0BFC-4D55-B6FF-020B63D64B75', '5000158104136', '   200  / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3F634C7-10EB-4703-AF02-23F0E1C84A30', '0C6F7ED7-AF7D-405E-9CF3-12D03A6AC9C3', '5000158104501', ' // / /// 16 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63837C9F-FBF2-40DB-B928-94CF7EA551B9', '5D1764EC-3358-4146-A01D-40BB66828C58', '5000158104747', '   400  / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C818105-0605-45FE-B1E2-CF3CEA4B26B7', 'DBB00E0E-25F0-45C5-97CC-E6780FAFC1F0', '5000158105553', '   0,4  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3D275D2-D1E6-476A-9123-6A040085EB0F', '5E9610B7-2619-43AD-A88D-1629EC15C774', '5000158105713', '   40020', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('837D9145-8B24-435A-AA1B-A165FBF19EAC', '37A3CC5A-378B-4EB7-902C-D7857171AF39', '5000158106116', '  200  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91ED53D7-49CD-4FF7-9216-589135ABC84B', '8AC6D52B-C74B-43E9-B446-FC6677CED8AC', '5000158106123', '  200  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65C7BEB4-FA4B-4360-8996-F5136F9AF57A', 'A9B9B66B-113B-40FC-B7F3-01491D41DBD7', '5000158106819', '  0,2+0,5 //  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9662EA7A-FFCD-4E41-A147-C40B79831BF8', 'CF9344C7-4F0D-4C3C-8761-591DFE88E395', '5000158106826', '  0,2+0,5 //  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09E01461-8217-478C-8560-08B377BD3DE0', '0E32E19F-BAC6-4CA1-8EA0-E30E338F3B20', '5000158106994', '      24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA81C6D8-6ABE-4002-ADAC-A0CBDCD40B2C', 'B6FC7B28-7B66-44ED-9609-39B8FF897698', '5000167009682', ' 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1260973-90BD-44DD-B524-8998611E25FA', '5C8C40C5-03EA-4574-A13F-895816E120EF', '5000167036411', ' - / 31 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67DD9680-8227-4ADA-A1A8-BE33D07E7C0C', '481FEF4D-35C1-45B4-81BC-48794CF70447', '5000167091977', '  /. 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2106E204-7E2C-4659-A201-F54FA0BB718C', '735F20D7-CAFB-4F29-AB6F-770D1A57CA5E', '5000174415506', '      7    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8597BB50-C509-4EC9-B0F6-9F363CFD91F2', '2C966BBD-15DE-4AE3-8918-EA2918B6DB2D', '5000174415698', '  -- 7   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6B12DB9-EE83-4967-BC22-1F7FB89872E7', '6BB1F69E-B1E4-4C38-937B-7D60AC48F6A5', '5000174415773', '    /3D White/ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('665320B4-CE3E-4516-8C8D-F54415F68E0E', '0ED0C856-A3BB-42A8-9246-98136EBA4D90', '5000174418842', '   _  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D11DFF6-CCDA-456C-9528-D8AD9EB56EE0', '1C5B0185-38AC-42F2-94B9-BD1D64B7D280', '5000174898569', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8899E832-5B25-4122-8702-461070346F37', 'BA044663-1CC1-4E8E-96A0-31D5170496AE', '5000456015066', ' 160/ 60  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A9E9DAF-852B-4930-9A20-A1456E6F1692', 'AA420606-3937-4139-BEEE-0C85C7FFA5B9', '5000471709896', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53423F12-EFA2-4D75-958B-679FE832194E', 'FB78C61D-B9BC-427E-BF52-382CF9D723F2', '5000471710571', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D644F28-DD25-4FA7-BCC4-2E2F340188C9', '8160BA36-59A3-4884-987F-0C6B183A6FBB', '5000483318000', ' 125+31,25/ 5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08099394-6BC6-4DB2-97ED-96F38E2CEF04', '8DDE0775-D874-4B03-8083-61DC7C8F377D', '5000483349301', ' 250+125  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5C466DD-7351-43E8-BB01-F157EF439C43', '8838EDF4-BB32-4AA6-874A-35D019B53F26', '5000488106220', '  //   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E66ACD65-5763-4064-9B84-97CD7BEEB44F', '4F7E4EC8-AC05-417F-AA25-A8FA1B0423ED', '5009612930014', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('563A3F3E-A770-40BC-BB2B-5C4CA04CC91F', 'AF7ACF04-4CBB-44E5-B48C-481A1544E70C', '5009612931066', '   /femitest practic ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1ABCE03-ED4E-42FA-9C9A-49417AFE0A6F', 'D663D5B0-A8A3-4A1A-B2E5-39C8D3CACD0F', '5009612952030', '     1018', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A5632A3-BE82-4582-AE6A-22DF97A67A13', '36F3BBC5-3841-4F1F-B3E1-43C53006FADA', '5009612961223', '   2250   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3046CE70-CB49-43B7-AC67-05A38B6811A4', 'C46B2052-47BE-44FB-9D23-A9CCB0116467', '5009612961230', ' 2500  .,  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB27239-01B1-4C78-8028-2B6F17636F50', '864DEADF-3E0B-4126-BB92-BF4DF8B53D80', '5009612961247', '   3250  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC19E28A-072C-45FC-B6FB-DB3F33B46B05', '9DD59C43-9D29-4FE9-AEAB-959C3A5FEDCF', '5009612961254', ' 3500  .,  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDD148AF-F4A6-49D9-9B46-42CD919A80A1', '4C48F1C5-5301-44EB-BB12-23F910C2454E', '5009612962039', '      5500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('532993CB-DDFE-4343-BC5F-602964C56D98', '379225A9-F692-4C68-9A57-35C56903B125', '5009612962053', ' 2500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1A3F9BE-CE73-4DD6-B0A2-2ED22EC31C75', 'BB572A02-5B12-453A-A53A-CDADFD0ABFFB', '5009612962060', ' 3500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C978053F-5AA9-4E16-BD94-07B45D143C27', '44CDDA39-3E0F-49C2-8EF7-C04652E2243F', '5009612991060', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66067A2D-0C34-4733-B195-592753AE22D1', '6F9EDDD9-786C-4D16-8BC6-BD49CA3EF18B', '5010004055437', ' 2%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA42602F-7E26-477C-BF04-871B5F473569', '54824086-CE9F-4B06-9956-B6A575639113', '5010004055529', ' 2% 3  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('766EE63C-8E4C-4395-8751-4457B9B00D48', '05D23DAF-C0D8-49FA-8014-9ACEE08805F4', '5010006101392', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA939544-FE74-4CAA-8D51-CFBF726E6573', '3FA58F10-EDE4-4A5A-AEAE-EA5EC4890CF5', '5010006106267', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3324BB97-1DCC-4CDB-BC82-28FFFFC04928', 'F6C34E05-848A-4C46-AB24-F3F31E1031C1', '5010232098176', '  12 elite /30*6/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AFD4CCA-B5BD-449F-B3F2-437660B56666', '6081353F-560F-4453-A08E-AB9334063965', '5010232953833', '  fruity mi 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E94026B-1943-4FB9-9779-C15DD5D30CCE', '1C52C5A3-87EB-49CA-A798-DF1E145F0965', '5010232954205', '   /extra safe/ 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5DCBE8F-5431-4DE7-88B7-6A3B2EDD5FDC', '798B0EFE-26D6-4E22-B625-48F48C803623', '5010232954212', '  extra safe 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B87DC56A-249E-4D77-A628-160297F944E2', '91E99E37-9B85-43E6-AD53-999C52C30849', '5010232954236', '  Elit 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62A49BC4-E3C7-4903-9BCF-A489D7B0798C', '5BB0FD01-88D8-42A2-AE29-5EC34C5E23EC', '5010232954243', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('646E0AA4-CD0D-43CD-B1CE-0B9B46B79109', 'FA01D6E6-7174-497C-A77B-AEC42173BECD', '5010232954250', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B8A6B45-8507-47E1-8252-489EC4EA9FE0', '3865EB5F-4BEF-4C2F-A83B-D41E5231E3DD', '5010622005012', '  - e 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82C6D3D3-C0C9-43C9-AAEA-D52F84358419', '3F6B7D96-9CC5-4A01-9CF7-D0EEFC75A4E9', '5010622008204', '-     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3905EB0-7134-48A5-9DA3-76A28DC92698', '91FCAF1B-94D4-4848-8FB4-1E27FF08F599', '5010622018258', '  - 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AADBA74F-CA13-4454-9EE6-F1765DA4CC78', '1CB2C648-FD9B-45D0-93B0-24543998A430', '5011025083300', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B205E49A-6D92-4229-9422-BCDC84A99831', 'D0CDD5CF-051F-4589-81B0-45506A9754FF', '5011321727373', '  - /.   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5197BC0C-B3DD-40D8-BC2D-A4FBFC2D4989', 'BBEF5DBA-CFB9-4900-9D3D-2320674EBC10', '5011321748767', '    0,05% 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('184800DB-C11E-4F1E-8E53-04A6BDABF723', 'EC2A106A-3C7F-4945-959C-C714FE2A2BF6', '5011321748958', '   / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3389C623-1E87-44A9-A2B4-FED02E84BC36', '4329F15F-9616-4465-AFAE-F4163B7C5878', '5011501011322', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C29F0A9-B53C-4EA0-B732-7B9C3EDC27B3', 'E254A0A2-1358-4781-8128-6BA95F4AFE94', '5011501011353', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AC946D3-87C6-46B5-B4F2-E97E36A85A26', '24128037-A441-48F4-BBCB-D121E77E89F6', '5011501011902', '   67', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A31424B8-06FC-4BFB-9D46-09D121020CF3', 'FB275FE6-D9E0-4852-9502-256AD0C917DE', '5012748884014', ' / -   2+ b  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEFC61D3-0072-4221-B192-B83DB5DF130F', 'E08F9E66-7C2E-4B6B-9039-A06B0DF213BE', '5012909001656', '     2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49CC8184-383B-4AA0-A330-F5A470EAB848', '394EBE77-4E04-4007-997D-77B1CCF86F9C', '5012909007337', '  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9A83275-0776-470B-B672-914C64293983', 'FF4AE235-199E-4F4B-ABD1-1FF04E5E6616', '5012909010436', '  /   2 81840/SCF156/01', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0BB5FFA-D48F-4152-8995-79E2F712F68A', 'C33DC319-E75B-4A48-87E3-B7FD3289DB87', '5012909010481', '       2 SCF150/00/80170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C357756-EE4F-4601-9083-3826BD9C384E', '0A2D95E2-0E76-444E-8AF0-CB8E0DD85601', '5012909013055', '    /8060/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ED49E4C-0669-4704-9F03-D87A2B45F3BE', 'F3C9FE57-6D48-457E-BBFE-66F447D25CE1', '5013158773622', ' 500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B5F3F1C-0483-4E0F-8565-0ECA45A73748', '92CC2D0F-66DE-4D26-99D8-2E768D9E4089', '5013158773677', '  0,5  //  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E78EE57-A616-467D-895D-6F5BC029FB2F', '850D59F6-D35E-4F3E-83E6-BAA1FAA3699D', '5013158773684', '  0,5  //  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1C98499-7FA9-4DE1-96F5-662B4B8C261E', '81154B4D-958E-4970-8481-E4E767E28C14', '5013945195828', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77B8E711-7C33-49C0-A55D-3401653790EE', 'F9390FEC-5F44-4531-9DDE-691F6AE003FF', '5013965617195', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BF0708B-FC97-4B1D-84DA-B6C869C692BF', '52A9EAEC-6F4D-445F-A89A-75273ECEDCB3', '5013965631290', '    // 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B224DC14-5471-4034-89F4-175173A7FD0E', '7A16F757-9DAD-42B7-8349-246BFB078B3F', '5013965631306', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F406AD10-A107-4FCC-B4B9-BEC457AB4AB7', '39BCE2E4-CBD3-4365-A38F-72A2742E22A1', '5013965631313', '   // 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6945168-594D-4167-89D3-A71A083DBB11', '1FB5E773-EE9C-4E66-B777-18169AF7E687', '5013965649110', '   / / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55AE8C19-4053-4159-8D78-15139DC0E0D5', '5E991EAF-33AE-4D4C-9F8F-6FC6C4EA4B9D', '5016003182105', '-     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7837E252-9FB4-4675-9D62-6C4B26842769', 'E5BD122E-6401-44FE-918F-60DD7603E4F9', '5016003182204', ' /      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8379583A-9BD3-47D8-BD8E-CDDDB5D61429', '8C172D29-5E41-42FF-91CF-D4A72C222EC2', '5016003183003', '-    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBFA1227-5926-4240-AD9C-0793B98AB981', '5E991EAF-33AE-4D4C-9F8F-6FC6C4EA4B9D', '5016003191701', '-     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D75DE79-20E2-48B1-AF21-F3916F9DA020', 'FA3F3BA8-7E76-4DC8-B6BA-AA3B3BA64A9C', '5016003191800', '- /.    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAF72355-4209-48F7-B3C4-795AD3C1388D', '9B976616-2C9A-4451-97BC-60C9B078F451', '5016003191824', '-   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CC94C65-B1E3-4E5C-A8BE-1AB4D29F8805', '68701929-A768-4CCB-A699-C74E60D4C880', '5016003657504', '  /.- 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69D1106B-17C1-41B5-822B-ADF1722CF0D9', 'FF24071C-42A5-4F0A-9176-130724BD6D1D', '5016003659201', '  /  200 (/)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22C6DDA8-6E78-4045-85DB-363907571695', '0F436B19-C590-4C30-8B80-5F3FA3D0AD4F', '5016003761508', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72FFEC2D-F11C-4CE5-9C2E-F44FACA8182B', '43F4F09A-0685-45AE-B3A3-472B413A2394', '5016003766800', '-   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5827304A-7FF6-40DB-9209-23091C1E138E', '9C3B8739-0833-4196-8895-BF0EF7C663A3', '5016007202809', '  0,15% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD423936-0824-4457-A520-146DA0F84F36', 'A25EFD1E-DAA5-4302-8790-D4950531DF28', '5016007202885', ' 2 +5 5   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E190C50C-D4EB-47FE-84D2-E4A1A5EB2DA4', 'A883D2E1-9C5B-41A2-9C28-FFB274DF0972', '5016007202915', ' 3   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7746D0FD-52F0-43AA-B14E-4759C6ABAB36', '172DACA9-D1E7-4AA4-91E6-FF6946A115A8', '5016007202922', ' 30 0,05% 0,4  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAD67FD3-94D1-4C1B-924D-E40E8661EADB', 'D760E66E-4A43-454A-87BD-09B60AE236D6', '5017034541008', '  5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5D9E56A-CC89-4880-9190-D75325BF883C', '65607692-80BA-4D4B-867F-8EEEAA01E373', '5017034541015', '  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45AFCF57-B6AE-43F8-8B27-3AA47B53E03E', '84BF27AD-2802-4B76-A94F-1FCEA6778AF3', '5017034541022', '  250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6E123F1-8125-4F00-BECB-A53FC72CD40F', 'F61F3CBE-188A-4D99-BDFD-27674454BF92', '5017034541039', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41D7DBE8-586C-48BE-870E-5AB15614EE29', 'A8820CEC-14E5-4BD2-B624-096D4660FD2E', '5017034541046', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16B30F6C-D5CB-4102-8A71-9704ABF699C4', '90CEE6C4-B243-4D9D-B607-D7CD70737D04', '5017034541084', '-    . -  1 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62AC668D-F6D8-45C2-A6DC-292EC6B64350', '9398DF1D-F24C-47F9-B771-5F3E1B042F1B', '5017034541091', '-  0,21  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25A85AB9-4EB1-43D9-80FB-A3C75C039C58', '280D4E2C-D5E7-4561-B744-DE3754D02120', '5017034541114', '-  0,21  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E130C82-B89D-4A2E-940C-987C49C5196E', 'A91B1958-37AA-4815-96BB-EDC7F5D527D2', '5017923001712', ' 5/ 112  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46A7D09E-ECBE-4154-9534-5043BCB23CC3', '08BE6608-C381-48DD-9FC2-FD991CF42AAF', '5021265223060', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1A71C5D-CA56-4149-9887-557E08A59AE6', '151998F0-9BA0-40AF-98D9-059FD2027B47', '5021265223206', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1404457E-2548-4FCC-81DD-3301B0E4651B', '5700FE6A-1A8E-40A9-A1AC-EE555A953CCA', '5021265223831', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E503DBFB-17BE-4BF5-B3B2-9EE79C8D981F', 'A0F6EEBD-1CA5-4E12-BF6C-8C57199B1242', '5021265225057', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C693E119-5FBA-40B1-9982-23EBACA63B5C', '13BFAE9D-5F26-4FC2-ADF1-31479FF2E54A', '5021265226122', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2AC57E4-FFA2-4A1F-B619-C41CE85A6AA5', '810D2D31-A1F9-46BE-A118-CC9A8B2FBC8E', '5021265227105', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1A6D1F2-B0F3-4BDB-8A7A-48348D373D81', '04A638AA-22BB-4F98-AEB8-78D4499D9920', '5021265229161', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4D7B7E1-FF9B-4FE1-AB51-F898BCEC9A00', '5642A87E-CF6B-46C6-B173-51EB734D377F', '5021265231096', ' b-12  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('639E9417-4468-4B9C-9187-FF1B8AE28D59', '2B25A8F8-446B-4CEC-AB6A-52C8014B3026', '5021265245161', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6700233-DFFF-4B88-9265-2461E6E1CCD3', 'A0BDE878-5297-4448-AEDB-60A06B782BC7', '5021265245291', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D290D3D-DFAB-4B5D-A491-3913B76548CD', '69BD8B28-F62D-4109-AE99-A7B2F35A07E9', '5021265245468', '  28+. 28 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B625252-58BE-4D23-8E4D-639C974A9345', 'E6A87F2B-53C9-4765-80DE-750B443F9474', '5022690005986', ' 1,2  / //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('024A9D58-ACA8-44DB-8453-DBD35C6A499E', '422A862C-0EC2-43C0-9E1B-96E2B7CC7612', '5023497031697', '  100/ 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E32CAA4F-54E1-45F1-8642-D962ED688FF9', '3FC148C5-0DA6-45C0-A0F4-CD91F299F108', '5023497782018', ' - 0,5 2 /   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F6A9F25-8134-40F4-AD9F-654D77567C69', '0146AEE9-2EDF-4D11-8F96-EA935FA48717', '5023497782117', ' - 0,25 2 /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BBBF7F9-4F7C-4AA0-9AF4-28B697C4DA24', 'B1221F67-C746-493C-AA0B-762A38DAE622', '5023497782216', ' - 0,0005 2   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECB7F723-D1C5-46E4-8BEE-8A0A378F3ACE', 'E9A091AF-7F5C-4D57-8825-099034320816', '5025381000031', '   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DB4DE46-D63F-4421-BB23-0C30F05B8535', '56DD2F70-8F06-435D-9928-025F2952B21B', '5029053028323', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80204C1D-0522-456D-A255-B890E9F03A94', '19210D82-622E-4D42-A499-7E802A0973F6', '5029053527574', '   / 17-30/4-7/ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D739DE8-534C-4C70-9460-621928629339', '03CD54D4-2CC1-43B8-9F50-97F4FA7AF1DF', '5029053527581', '     4-7 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32595391-0FA6-46A9-BFA4-F6707533267F', '9CF1D497-4153-4E2E-A963-211246E19E6D', '5029053528373', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E45544E-C897-419B-99E6-09A4C8A15662', '8F17FD47-6632-4E81-AC2E-07DC12B20A07', '5029053528427', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B48A146E-2454-47CC-9DE9-966FC7A63B8F', '0FECAE6E-09DC-4493-A7C4-60E3F3AA38A5', '5029053534527', '   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95D82028-D07C-4E10-A196-5948C5895B1D', '23AF62F6-A5FA-40C7-B9DF-F1215CE0C4B0', '5029053534534', '   / 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85484F75-E49E-4739-A7EB-DF74143584B1', '8E124486-A4F0-4DFB-8551-E90BF2552A17', '5029053534541', '   8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56187D8C-1820-4643-BD08-9FEFF4F11364', '823EAAAC-689D-493B-9718-FC3EEF275CCD', '5029053534558', '    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('513CA6D8-4E92-41A7-9A54-EB984F6762FB', '3B12B2AD-35A4-470D-83B3-37509818D659', '5029053534565', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('056B4050-04E8-44D1-8A25-943E47DEECBA', '087DD123-FBED-4BE2-A208-3839D25222EC', '5029053534572', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A97FF475-E016-495D-B1AB-F0B54F1095FB', 'E0DFCAD4-2066-4FD8-A08E-6F525D4CA0CC', '5029053534619', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A698F576-ED60-4FD3-AE4F-65C075952156', '80BE0522-190B-4C38-B8C0-B10F940CA501', '5029053534626', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('115C7B8B-D40B-4AE8-A9CD-EAC34C2B84F3', '01D10215-B4F2-43E1-86E7-9D8C4A326C3D', '5029053534725', '      64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('544A5879-82BC-422E-8AAA-6A67BD1A74F6', '8BFDF43E-673B-4697-8E90-E04492CFF515', '5029053534732', '      64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('313504EE-390D-4C30-8911-A889CA295F13', 'DBB7BFC4-76CA-4A73-AB12-77699A633EDE', '5029053534749', '   elit   128', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0E7F721-216F-47B4-9BF6-78B8DCE572BF', '798E9E1E-DD1E-4D3C-B8CE-9F69F354B6C8', '5029053534756', ' .      128', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('303754D7-DFBB-4751-BDED-01E4779F516C', '3A97EF19-0E98-4492-A7D6-59402F5E5EDC', '5029053535258', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4872653A-81C4-473A-889C-7637490E55CF', '6AAEF423-68FE-4964-B267-8E810C29639F', '5029053535265', '     8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07DDD115-A4D5-4E60-997B-0D32A0B5760C', 'B5E98EEF-0A59-4D03-B855-47FF3D21C7C6', '5029053535289', '     16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E6F42E7-BEBD-4517-A696-07D356FDE94E', '663421BC-76E0-455A-9C27-29219F34D8D8', '5029053540108', '      7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05DDB975-22C0-46F9-B1DA-73CAAB0CACC2', '5485AB85-CFE0-4563-9C92-036963354EE4', '5029053540191', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFF3A3D4-9DAF-4D73-A0A8-D4EBED39E302', '12CEE579-C282-48A5-852F-6C01B7B8491A', '5029053540207', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39985C12-8E5C-4702-999A-6B0497BC968B', 'B747A499-F2A3-4F26-903D-B380B97DF3E2', '5029053540214', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53560680-FD82-46D4-8DFA-DB6FF51B727C', 'FA88FC30-A307-483F-825D-823A8E06C981', '5029053540900', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C8A1327-FB6F-44DF-819E-A55FBB04FC7A', 'FF72F14C-3F51-4FBF-9BE7-8990D054BA9A', '5029053540924', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4633E99A-3AD4-404E-9FFC-213F19153F3D', 'D24E949D-D2CF-444E-80C8-085D980A2998', '5029053541266', ' .    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A74BE364-AF81-4167-9948-D73686F32A60', 'B2906474-3DC6-497F-8347-97903F628E79', '5029053541921', ' kleene decor oval 64/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A200FAA4-AA9B-4154-9554-739BF32ADA6D', 'EF075AA0-6151-48D5-94F0-B08081F8C92E', '5029053542126', '   / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E35393F-E041-4BCA-8C56-C834D8429611', '3C7EDCC5-AF95-4171-9E4D-D7FCCDDD45AA', '5029053542133', ' .    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('686E041C-F5D5-407B-8AC4-3311ED90768A', '38043FC8-3780-4296-992F-15B7FD6A8205', '5029053542492', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6061D252-AB26-478E-8D88-341975B9E72D', '75B21BC6-9E45-464D-ACCC-EBF7E5FFB1EC', '5029053542621', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C392C2CF-7D43-46DE-8137-4FBBE27E9C2F', '1857E030-3FF6-4CAA-927A-41BC68CBCCAE', '5029053542638', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDE9BD19-2252-4715-A538-91F953584A77', '9429A365-F503-4620-A69E-9F50597CF674', '5029053542645', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE96785D-1E16-4841-B996-D163C1328826', '38486570-1340-440F-A6CE-7DBF2B536F56', '5029053542652', '      16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C098A88-A6EF-4F3D-9A12-9E4963C5257C', '35F04C16-421B-4414-908E-14EF346A398E', '5029053542669', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('119D2956-3D79-4D54-B22F-42E4647AF4CA', '12DA8141-1EC8-4CFF-8793-F8228B5EC2B0', '5029053542683', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FDE94FC-A00D-49D9-8D82-8B1CD3B030BC', 'A2CF0E31-C1AC-4DA6-B062-FC40E3F4A819', '5029053542690', '     16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BEEE102-6DA0-42F1-BD1C-40307FC9DE08', '368C36F7-93A6-4EC9-B464-9E4863784206', '5029053542744', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('651F7B83-3086-4AF7-A07F-0015611C7A90', '677E29EF-0DA5-48E0-8D1A-E80648F9AC5B', '5029053542751', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA05C7F7-3E5A-477D-ACC7-E4CF77046B52', 'FB1ECF7E-7DED-42BF-A484-A70FCB83109D', '5029053542768', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E73D3E21-9711-4F29-A7CD-071B4A7FFE2E', '4532BAD1-2973-43DC-85B8-1FE30B0CE940', '5029053542775', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('982F2057-656A-4C3E-8FF3-068DE1043B57', '3AC78F87-CF60-4DB7-A4D7-9429FB507B81', '5029053542799', '   /   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06309113-D4E0-45E4-BB82-92D5A628E86D', '0CECF7A6-D04D-4591-BEAE-6E2E9DC8CAD0', '5029053542881', '    10 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6071B48-F85A-4608-91E5-0B77D4667CE1', '49A88487-C308-4F2B-90F5-330C40E9B8DF', '5029053543055', '   /3-6 / 18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B44AF3A9-10FA-4811-A29B-922016A8D5B9', 'BE31EC80-A6E1-4A0D-B401-58283B8F9FB9', '5029053543086', '   /4-9 / 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('126E3A68-04FB-4879-B727-7E229138DCEC', '44FEBACE-010E-4DCF-9346-3D3F2F0E5D8B', '5029053543093', '   4-9 31', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9F0561F-3C40-44DC-8C9A-5594B784C5A7', '92827658-CFE6-44B2-A9B2-7BCFC87B588F', '5029053543123', '   /- 4/ 7-18 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCDEFD4F-F8A0-4F92-A180-1A8E124715C8', '9122F741-5D2A-4A08-B422-FF3A7EA7435A', '5029053543161', '   (11-25) 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AB7E1F4-00B8-4548-A80B-A4079EE836FF', '57723789-6FC7-49EC-9C62-660D415F0124', '5029053543178', '   (11-22) 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A9C2627-98F7-4242-8459-64C1973E6896', '3F82C3BC-5142-4600-AEFD-32D044C15463', '5029053543536', '.    /. 3 (5-9) 21 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FCBA266-C7C5-4B14-8132-694A95F0D37C', 'BD8B8CA5-29F2-4FAF-8035-4C6E103999EF', '5029053543550', '    /. 4 /8-14/ 19', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65639481-57F4-4D9D-98A6-70A0FA84E30B', 'C4E43128-FCFA-430D-BBAD-91B1793F981D', '5029053543567', '    /. 4 /8-14/ 19', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C636EF6-DF5E-4580-B3FE-914F058D29FC', '50B387AD-8329-462E-A664-2AAD741250AB', '5029053543703', '    5 /12-22 /  64 /3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('959B1893-F54F-48F5-B247-66873D42E992', 'F6D17AAB-43D2-4780-8C7C-AD12984BAD4C', '5029053543710', ' depend -  m/l 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0AF6596-A1B0-4E48-B706-83FB66648107', '51F31CAC-14EF-4972-AE83-2968D834A54E', '5029053543727', '  -  / l/l 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('504549F9-19C1-4EE6-BBFA-251F5D3771B6', '49F3E977-7A22-4866-B07F-B9D132A3E442', '5029053543741', '   comfort / /- 4+/ 10-16 17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74B76558-145D-4D0F-8EF8-6C1602292D5A', '7F0B45C2-18E2-465B-B1EF-95CCB5625F08', '5029053543857', ' Depend     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7F15EFB-7A62-411B-9544-B7D6611EF35E', '181E6D0E-9580-4874-B7AA-0A6F3713750B', '5029053543864', ' Depend     7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFD6EEAC-9A90-482F-A1B8-C023E97EA555', '45B65F97-0FEA-41B2-A51B-EC5EF3030C2F', '5029053543963', '  -  4 17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('910D0463-413F-4D44-A73F-EEE89DD0B3CF', 'B36188D8-E610-4845-B704-7005146BDDD5', '5029053543970', ' - / /- 4/ 9-14 17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('318B6FFB-A329-4AAF-AA1E-E7C5077C669C', '3B085E1B-5185-4E1E-B399-7998BCB00DF7', '5029053543987', '  / 13-17 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C4DACC7-6390-4CF2-98D2-5F60DA5FE6C6', 'F527C17D-FAFE-4D57-97E8-A5D63FB2A0D4', '5029053543994', '  -  5/13-17 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('786F0155-E45F-4D88-9993-DA8BEDC2092C', 'B0AC853F-E610-4C83-B7A1-6AF8017B0DFA', '5029053544038', '  -  5/13-17 32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C34F6A0-8495-47A2-ADC9-07D05C4D385D', '4C89E9D4-A4F8-4A24-99B3-DD9B51C076E7', '5029053545226', ' Kotex ultra night 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FD4F628-2024-4BBA-88EF-7020E4E37406', '0C4CACB9-ECC5-49EA-89FB-2F59017E1F2F', '5029053545271', '    3 /5-9/ 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91D620D5-E4FE-4F0A-8B3F-B81616DE47C9', '4BFBF7E1-5F60-42AA-84DA-6DCD86A48EC5', '5029053545301', '  elite  4/8-14 66', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CCE4E7D-4E23-4529-A8A6-78956D5DC731', '85F44F4E-01D3-41A0-B06E-4DFED9CF6DA9', '5029053545479', '  elit  / /- 1/  5 27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9A3052F-1A6D-4BEF-84CD-840D096F54EE', 'EC5ED93B-28E8-456E-BEA5-AEBC969EA4BD', '5029053545486', '  elite  / /- 2/ 4-7 27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CD26B4D-F2DD-4C66-848A-37A8993A81F2', '79D1DA67-5D85-46D6-86C4-EFF9139F60D5', '5029053545806', ' - / /- 3/ 7-11 19', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B34E79C-0D68-4E2C-8917-8E50224804C5', '2AB889FA-0025-4349-AD4B-C1AE3C07F7AF', '5029053550312', '      16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F86372EE-FE8D-4B8C-B180-754B660D780E', '96CDBA80-41A0-4B43-90C3-EEB918A68077', '5029053560724', 'Depend   / m/l 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E0D77DB-EA7F-4A27-8E21-83DE77DADF2B', '13F1F5E2-7505-447C-9078-512A224985EA', '5029053560731', 'Depend    l/l 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81AB4DAB-75D4-4B2A-98A1-16652E1E3121', '82EEA509-6FB6-4CFB-9CDE-9C9103FDBDFD', '5029053560748', '   / l/l /48-56/   9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('442C6544-B2F6-4EFB-9CD3-EC5C925911DF', 'EE916ADD-4E49-4C9A-A715-3B1B01E64A96', '5029053561097', ' .    64.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56154D5E-57EC-4F0D-9B5C-06854D7F782D', '19DE21EA-B721-4FBD-A3A7-7F1605879B4E', '5029053561103', '    128', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02A1646E-CD10-4C24-96E1-A459FE6D21AD', 'B61331B2-59EB-439C-8B4A-EE453213D373', '5029053564494', '    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('936B91D6-E0DD-4527-9ADC-D24ABED3FD38', '86798E2C-7D60-4078-9316-EB00F05FC837', '5029053564500', '    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46FEF450-2F74-424D-8B23-9ED580633610', 'BC104D86-F5BC-4CA2-A7DD-AF0ACDE7A0A9', '5029053564517', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38B80C3E-A0EC-40F7-9329-053763A94B0C', '7FFB4811-CA95-49E7-87B8-EBA1944AD3F1', '5029053564524', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2D9F0E0-5ABE-4DF9-AF62-A45A36DEA273', '924F0B22-D198-464B-9AB0-4BB3B6CB7D18', '5033439011380', ' 125 5 50  /. / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97B3E66A-FFA3-4A6B-90BE-D141887628FA', '69B2E1F0-EC32-44F7-A23F-1CD682C3D294', '5033439024526', ' / / 125  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C03A668B-6BEB-4D6F-BE31-E7B32DAE1B00', '92F9C4DB-E364-4BE7-A11E-821C546223D1', '5033439024533', ' // 250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D3094F8-1520-4A85-B29E-5D18F206B00D', '2CD185A1-B502-4868-BE8B-5E4E70E522FF', '5034642019194', '  50+100/ 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F470CA77-1A35-440C-B4EF-A3D4BB6D8FD3', '62A9FD3D-4AE6-4699-9A2F-BC407D01815A', '5034642019200', '  50+250/ 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4444A9A3-CF9F-455A-8A82-BAA395950D14', '56BCAD3D-79FC-4AC1-8D2B-16AE60B2ED43', '5034642020572', ' 100  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B31913E9-D13B-487E-89B8-A99F47F2C0A5', 'B6069E79-D62D-4633-9A46-B582F6838164', '5034642033725', '  50+500/ 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29B0BA7D-BABF-43C5-AC84-D3B5F188DE87', 'F9BA1D94-90EA-4816-876E-167162501424', '5038483002834', ' gel    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDCDFD37-85F2-494B-8B9D-B0105C14A2E7', '78631B00-BB59-4B52-B654-7057127C6B82', '5038483002841', ' Gel Activ   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71DE25A0-30EE-4148-AA72-D0CCAF25A722', '10697EF6-3593-4C66-90AB-72A59B81432D', '5038483188750', ' long play   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11278320-4BF0-491D-9E78-B750C7FFFAFB', '23DC9438-AEA2-4C19-A4AF-0B1C0291B06E', '5038483203989', ' pleasuremax  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1270994C-4FA9-4AF1-ADCF-F445F2C77A97', 'D730523E-BFE4-457D-9AEA-DD5454A961A9', '5038483204016', '  12 pleasurema  .   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DB83B84-2167-4457-90A7-5B85683AD273', 'DB8696FD-F073-48ED-9AFF-EFE4C6B8225A', '5038483204047', '  sensation 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('772F62C3-A1DB-4299-86F4-CB64558E7FEE', 'C26CA3E6-8F36-4923-9664-21C0219BFDC7', '5038483224168', '    / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25E80B96-F99B-4949-8A6B-402C8E762373', '1919DB11-C614-4A02-B988-0BA5B6B1C3EB', '5038483233634', '  fruity mi 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC6F8EDE-D6E9-45D8-8AE6-B38A169D8CA3', 'A2B563E8-C3E4-4D31-BBBD-E267645C91F3', '5038483233665', '  /sensation/ 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB7007AA-2957-49F3-9495-EE3128914F12', '373A2CB3-4E03-4164-A78D-4606C63CBFE6', '5038483234136', '  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10592141-EBFB-4B69-B121-52B1A70AC2DF', 'BCEAE4EB-ABF4-4D76-9426-1FA931492E0B', '5038483237434', ' l  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7096334E-3A4E-4C23-B94A-715BC27D8600', 'DEA4DA1C-6E51-43E4-BACB-99B959081FC0', '5038483237465', '  l 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD131A09-7910-42C8-A431-5C649E439097', 'B5273FEE-7C9C-48B9-BD49-5FDB983361F9', '5038483437247', ' long play   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('468C4DBE-AD13-40DB-ACC1-D6DE5B271587', 'F82A4F89-E734-447D-A81E-3D850F4CC4B6', '5038483495285', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B46A6BB2-C483-4881-A03B-166827A2C98C', 'B131A689-F698-4111-98CF-04CA4FDF5AB8', '5038483673607', '- dure play hate 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5936C6F5-F048-4224-A1C5-5A0F10592FDD', 'AC4E780F-9D46-4E51-8DAC-87205A109F30', '5038483673638', '- Dure /lubr/ play-tingle  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80F00499-5778-4EAF-AF9B-F9BA3D134096', 'EB88A851-736E-4B69-A9DF-A58E4C724DDF', '5038483673669', '- dure play very cherry 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4C137F8-E39E-49A4-9211-FAB7FFDA9F44', '10BDD40C-43F1-420F-9B48-0F300A95B1F5', '5038483673690', '- dure play feel 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4300D6BA-0DB4-4CAF-BC6F-66B2579D24AA', '68BE387B-7254-4B94-AF40-39994CB7D200', '5038483679326', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34C8EF40-2531-4D71-9250-8A2AA4BE9933', '727BF492-22E6-45D3-BECA-BDBBF7971376', '5038483745915', '  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18FB8FE5-F09B-4A19-9CCB-840058102734', '653A4C02-950F-43F2-879A-0FC4E5A76328', '5038483745946', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F2C5434-B33B-426A-87D9-48D47B2F030B', 'F2AC83CA-CEF1-4F6E-908B-421A650968A7', '5038483746004', '    /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCBF8EDE-C9A0-4981-A80A-3FDB7580A0E9', '2EBFE722-EE31-4205-B88B-2F6527AFF74A', '5038483746035', '           ,  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ED61FCE-0A4A-422D-B6EF-A90B071BFADE', 'F631A37A-31DB-4876-BBE5-46660EE27F8D', '5038483746066', '   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94ACD9B2-A934-41B2-ABC7-977FA4D9F73F', '903827EE-33E8-4421-B8B2-C04B1F5058F6', '5038483746240', '       2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60888F88-204A-4E3D-BED6-D1FEDC062B7B', 'A1738CE8-D899-440F-A949-27A5A32CC626', '5038483953129', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E0C1CD5-6F9B-4470-90A1-25525C20E49D', '5F0C4F2B-D4AE-430B-9313-70AD96E75F4D', '5050963014632', '    250/ 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92BAE4A0-C8CB-42E5-A0F9-051A08B9FAE3', '0777716D-EA2F-4C8B-89C2-89E71405974E', '5050963015615', '  200  /50/1/ 1 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF7355B7-4E8E-4E4E-8647-399C0B08613E', '422A862C-0EC2-43C0-9E1B-96E2B7CC7612', '5050963015622', '  100/ 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D3B56A3-15C7-47DD-BA8C-F3B157E31023', 'D4F1DC09-3971-413C-AF82-49019FBCE42E', '5050963017619', '  100/ 200  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90610E52-4F56-41A5-82C3-910E2CEB42B8', '3F269AA8-6A65-4DE8-9374-ACDBA5538BFE', '5052197013603', '- /  step scholl 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12238EEE-95CA-49F1-B8A2-38B074DDD3D8', 'BDABEC54-5A86-441B-A378-79F1EF12B9D1', '5052197013634', '  / scholl 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87A78E8F-ACC4-4654-987A-2AED9A33A2E8', '6FF470B6-685E-4C43-B985-BD219329E915', '5052197026689', '  real fee 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D2783AA-F65F-4D73-867F-644810AA1CF4', '7DBF6BB9-A316-4686-8E68-FA9039E79CC4', '5052197026719', '  real feel 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B7CD994-F563-4E7B-B711-E7DC41D581A3', 'B4EB2A80-764A-4395-A10A-D648F4A90735', '5052197027914', ' scholl /  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EF0607E-EB87-47C3-ABC1-A0A14FD15C71', 'BAE5C12F-6D17-4272-8F7F-2C32099F84B6', '5052197029802', '    scholl //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C0CC198-B0EF-4121-A976-BB1A51E979D8', '31E0D0D8-51B8-4AA4-B00F-9F278F93C2BC', '5052197029833', '      /.   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60E90D8E-62C0-4F9E-9549-921360DD7A5B', 'C5E21894-B7A4-4A8E-9DF6-0752EC970C0B', '5052197033816', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F626DEE2-08A9-4848-B61A-0D580F699D2B', 'A6AE5B7A-7D74-4511-A655-3FF45D170243', '5052197033847', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6421E487-558B-485E-93EE-3EECDE3676D9', 'A12F580A-EBBA-42D0-96BE-2BCB710B7BC8', '5052197036107', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('487F0173-2508-4154-9888-28D7E1B1EE15', 'ADD1447B-FAED-4D1F-9A95-C30F37379FE9', '5052197036138', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4F81055-F12F-43BC-AD25-7367BF6C7BE4', '9B93D3D0-5ED7-4142-B2F1-E78E6E9CFDC7', '5052197045727', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80B0A671-AD55-4FD2-804D-72798B103BFC', 'C02488F5-2C3A-4083-93BB-4735614A3723', '5052197045758', '  invisible 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7721241-372E-4CAA-A1BF-DAC4C388FA85', '51C7725B-29D8-4B32-AE57-71C1FB5A154F', '5052197046786', '     2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0590A4F3-9816-41E5-841F-7D77386E40D8', '3ECE3DBF-359D-4D23-96C7-083395C9A6A6', '4620006276405', '  - "". . -421', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01258EF2-FB6A-4B09-8DCB-4314B82345B1', 'BE3E5C51-3F99-4A80-A48F-672DEBB83CEC', '5052197046793', '   + /  scholl 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('000D1991-770B-4EB3-B942-F5999C7FADB5', 'C8A6EA93-0DA9-4CCE-8E3D-D6ED9786B778', '5052197051254', '  magic bo  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D6A71B0-558A-42DB-BBBB-5A990DB2E22D', '0DE63884-6934-4E5B-8D32-7FB288455B0D', '5052197051667', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6D01503-2E73-46F7-96CE-6D2225E09AB9', '40005D8A-F79F-4FEF-9116-B666B1A3F3F8', '5052197051841', '  intense orgasmic  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41DE8CAB-85B2-42A8-8BD6-0AF18F2232A0', '48160783-991E-494E-9A23-90C02BD02B82', '5052197051872', '  intense orgasmic 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2FF0FDC-AFFD-4CDD-BFB5-FEFFCA24CBF1', '5340CEF1-DA43-42B7-9D86-E840A2B6294A', '5052197053500', '  /   7,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40868FA5-92B3-404D-A037-ABD0886B289C', '299D9961-8EAD-40E7-A3FF-76D5552A4362', '5052197053531', '   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF63A56D-7521-4ADF-B800-B1FC042F53B5', '4C41783B-F5FE-4797-82E3-AFD4F7CE606A', '5053173000013', '   200   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E96D22A4-0434-4BDE-997B-E3D86BEFCFCD', 'C1B87D0E-9003-4060-B9CA-1E89FC9FD578', '5053173000020', '- 200   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BB2A627-DF8B-4757-9792-D118A0085A6E', 'CE3DB8CB-C013-4EEC-B426-C0CEC1419CBA', '5053173000037', '   600   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92182A06-1450-4B18-B407-3B775DFBB5AF', '3F3753D1-B0F5-40F2-A291-D17858D88474', '5054563006172', '     /.  . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4E4D54E-0DF8-48B5-B19B-7CB391E942C1', '384717D6-2364-4AA1-BF25-1CE64E63A3C6', '5054563011190', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B9D2F03-88F6-4F72-8F3B-43C7730CEA6D', '3A60E6D7-4A13-497B-BBA3-1AC9F1569649', '5054563011954', ' /  / / 1 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30468028-4A4B-4368-8B88-E0A23C269B7B', '55CABBA8-78CE-4C39-879C-8C1135A97708', '5054563014375', '  /     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5260CEA6-5975-4509-A531-F7FCED7C5F68', 'BBCA0FDC-D117-4886-9F50-0A2A76A014F4', '5054563014818', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC321D95-B5F9-4F3C-8FA6-3422FA49C8DD', '5EF0A4AD-3D1B-4FCC-A414-6F73FAD310BE', '5054563027320', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FB7AD37-369B-40F2-B168-C20B6AE2451B', '4EEA918A-7CF7-47C3-966A-A693B8D9CFA2', '5054563038296', '  / / / / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B188179F-0ABE-42E0-9259-8307650B3A45', '0A3EAE2E-E9AC-4C16-BB09-2D73285531FB', '5055822100006', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('550B5E39-59F4-489F-9B5A-6C47C7CB3CC4', '43999D46-91D9-4485-AA6E-F7950798E71D', '5060038500052', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('118DA411-4707-4C8C-BB1D-510132D07383', 'E9AB1E28-C8EF-4347-8FAA-71F270AE4394', '5060038502193', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4226025D-813D-4970-BEC3-A418AB35CD52', '096CD80F-6FF4-44B5-B8CC-A885E8B955B8', '5060038502223', '   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE5C1DFA-2624-4357-B141-FFDF37B15A9C', 'EC5E3087-C594-4333-A815-ECC90805D2D0', '5060038502254', '    - 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2B114DD-C562-4D94-B050-ED48479BB547', 'E9C18C3E-5BCD-4610-9DE4-5E57CC01E5DF', '5060038502391', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A4B7AB5-6748-4D22-B724-D3D0480A4308', 'A0D7E235-29D5-4AC9-9540-F1D12F5D6E5D', '5060038502483', '      6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B8A2214-6C43-4E69-917F-1C55694B9951', '71C7A015-0DB5-4E81-9162-5D8EDCB6F490', '5060038502667', '  multi-pack  8+ 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DA26DA9-7378-4F17-BEA6-826FAC26D51C', '3D65C569-F113-45E2-8D72-7ABA628EFEE3', '5060038502759', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A257B983-A510-44FF-A1DD-AD76E546E640', '75F64D52-21BB-4905-B4D0-F01A138FFA0B', '5060038503800', '   /silk sense/ 30 /3800', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE715138-6BF1-4B0C-BD26-F70220F3BDBA', '6097B100-9813-4BE6-A88D-8111542F4A64', '5060038504081', '      15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('398313E3-2E7F-489A-AC03-5BF7CFBCFB8B', 'C62FA519-0DDC-4DAC-B38F-206B624E50CB', '5060040300022', '  imperial // 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F53DCD5-75C2-4325-B728-1AFEA6983300', '723DF2AE-555E-4B7F-8CDD-E5DA9C5F15AD', '5060040300046', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3A32ABA-22C5-4713-8259-85BEF4CEB4B8', 'DE85106D-2BF7-49E5-9336-EA55B8B73B2C', '5060040300077', '     3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C9C08F7-917A-4421-AE3A-0C5AF5284A32', '33E97722-C51A-421D-A127-61F674D8FF2B', '5060040300091', '  tornado / / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08AB3391-EEE9-49F4-A0DC-12DB97936D3B', '7FB9CFC5-616C-4664-821C-529A4701BA58', '5060040300169', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D2A0002-2BAB-43A2-A129-E68EFAB0B36E', 'E0CF808F-DD2C-495E-AA46-85AC5AC021FD', '5060040300176', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3D93852-E558-4E21-A933-79D0BBC6C20A', '73FC1914-A836-440D-8D7A-0C7BD505CA2A', '5060040300459', '  forced   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99599090-6A1C-4FD5-B178-1C102DF1A1EF', '0A83B559-214B-4E20-BDE2-A0E17EEEF8E1', '5060040302064', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('377EB487-6DBC-49AF-90B7-3955E2AD0A7B', '95E474FA-5DD6-4175-8490-67CD97EA5A77', '5060040302088', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7E7A39F-3467-4D67-8AC7-35897218203D', '9DAFA6F6-770D-4954-AA2B-C786EC693B08', '5060040302095', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50275A9F-CB88-4F3E-A656-92C3E38BFBBD', '33159DDD-72E5-47C2-B774-60EFF6BA8D69', '5060040302217', '  imperial  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67AFA749-280B-47F7-A64D-028C65699590', 'F0C3AD65-B172-4E20-96A0-04B526F67621', '5060040302224', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7140555-F9EC-425E-B3DA-A0FEE795B094', '32639659-0B9B-4E54-B344-0D0E3C661B71', '5060040302231', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('456B8B43-F21F-46A1-835E-653C0E35C243', '9DA39862-7131-4C83-806A-9FEC4C4F54CC', '5060040302248', '  colour 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCAF15D8-3EAD-4461-A7D0-54B800B6A3B1', '805BBE19-4150-422F-AFAB-3421239450B6', '5060040302552', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30B5B577-8DE9-48B8-ACE0-139184FDB6EB', '27C81133-8882-4798-9F8B-D325B1C50DA7', '5060040304020', '-  wave  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAD4A835-1FCD-401B-8421-59CFB90521CF', '210E393D-1FC4-43A2-AC83-7243E48B9A44', '5060040304037', '-    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F9481BE-500A-47E4-8390-4904AA94E5A0', 'B75AE067-8C23-4D82-8E75-762EBBADF2F9', '5060040304044', '-    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2511EBA-BD0B-40AF-A5D4-56A4AF0EC1CF', '0E20258F-AFA5-4036-8356-48D57EB74682', '5060040304099', '-   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14F89C2B-F5E5-4C35-B7EA-407009BF709B', '4BBF79CD-4655-4C3C-B780-0F125B404584', '5060040304105', '-  green  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB6D4939-10E5-4922-9127-101A60428546', 'CA083632-828A-48CF-B8A4-FFB3B3EA9F65', '5060040304556', 'Conte /lubr/ long love /50/ - 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('398F90E3-3AEF-4FF5-8888-7F2A4D3511FB', '980CCCF2-E9CB-47D1-900A-726CD6EFAE5F', '5060040304563', '-  silk 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0316C0F8-7C25-4A81-B115-D0785419D287', '7BD9A431-529A-4D0E-8C01-E74A86DC23CA', '5060040304570', '-  silk 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8FC8D44-3AB2-427E-9E65-489EA21E1F3C', '5840C4AD-1F3F-46B5-A363-1D8B7FF3A188', '5060045001337', ' 500 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50E51E18-897E-4F94-96A4-5E6699A183B0', '78AABBBB-DF30-483E-8544-5AA3762FCA6F', '5060045001528', '  500 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('691B7238-101B-4FDA-A06F-4DB34B0D8CB8', '4617EA86-B378-4D56-8EDD-64A526E547DF', '5060068526336', '   /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC606D44-31A1-45C4-B482-CBB3B5965936', 'BA80C901-F27E-401A-8961-329FC3E28AE4', '5060068526343', '   /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B335631-79FC-46B7-92CB-E205C6A37436', '43D1FDC7-EC3B-4FE5-9E43-9B52B9778C71', '5060068527036', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2EC889E-A7EA-4E3E-B7D1-3F471A0E8F6F', '3E4A59B5-2B99-47A0-9593-DA7F90273884', '5060068527043', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('177558DB-815E-4296-AB2B-87F425CC650C', '9BC3A5AF-2C2A-4B8D-B64B-64E2A316301A', '5060068527050', '   /.  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29043538-2624-49A1-BD5A-8413A2D37FAC', 'F582C822-7197-4145-B43F-37DB41FC9445', '5060068527067', '    /     25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E1297DF-E0E0-4E3D-A046-4D08C82FF096', 'C5841DC6-4FD5-44DD-99A9-0DDE1F748388', '5060068527074', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25F7D87A-6B6C-4F5D-A69D-62E241E55888', '95A53EDB-E718-441F-A5A0-54FD922C9D01', '5060249172604', ' 1/   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F486BFE-5291-4CAB-B22B-85329EB2D0D2', 'A4113E7E-03E9-4A54-9BBF-31BCD6140A61', '5060249172611', ' 0,5   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('303CF8A8-FE5F-4124-80B2-CE88299431A1', '3DC0B2AD-2D6E-4AD9-A027-C65D636BCBAB', '5060249174356', '  5% 5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C0D48B9-8F13-4C47-86BE-CBF8F6BE97BF', 'FCBF86B4-F2D2-4EC4-81E8-ABDAD74E9AFC', '5060271010134', ' 10%  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('495E37F8-58E1-46AD-A1C2-CF76E83406A8', '01FBFB66-AB01-45DD-A16C-0C446491A5B0', '5060329480001', ' /   u   l 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7D45938-399C-4AD7-A8D8-24D3918DF7D9', '6A29FAAC-A8AA-4ED4-8136-EB9D8E403DE1', '5060458170811', '   2500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F0EFC3A-E4DA-4668-BB7B-C6837DCAE42E', '76EF76AF-0536-488F-AD03-4ED8790DD5F3', '5060458170842', '   3500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18BD0F30-D665-457E-9CCF-370A53A3F4DC', 'B64C35DA-6A2B-4AC3-94A1-619C6166C727', '5060458170873', '   4500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1884884-327E-4E02-84AF-3E29FF64F0E4', '3243BB33-5D2E-4474-B71C-56AE3A8BD351', '5060458173812', '  1018 / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A89D351D-0CDD-4EB0-B091-7D8282B8BD27', 'E5B4B65D-A7F4-4979-95C0-0E823CF16B42', '5099864007640', '  1 0-6 350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFBA843E-19BB-4EEB-A647-3211B13FD794', '15CE1C72-266F-4612-B07E-5EE57B60ADD5', '5099864007657', '  2    /350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE0A8139-6717-4A30-9B78-BBB97C21CB81', 'D139AE2E-90BC-4869-A7EC-DEB0B950CB53', '5099864007664', '   3-350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63419987-2CA1-4ED4-A1CD-FB815ADBBE86', '5BAD956B-1DD5-4C4E-9E54-43B91A33B7AA', '5099864008531', '  1    /700', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03E5E513-95A7-45D8-ADFA-F4004FA171EE', '9CA9842D-8CA0-4935-9ACF-7082B54CF799', '5099864008555', '  2    /700', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03D503A7-E300-416F-AAC7-E1DB27D340F9', 'D957050D-C072-4927-B134-188B72CC3909', '5170210050074', ' A&D UA-604 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E34B4E9-0C61-4BE4-9F45-3B7EFCCA0B59', 'A08CD405-AC94-4A91-956C-9E8276356CCB', '5283726759024', ' /  120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B7E0DBB-0B8B-47CE-B9B6-C39904DC2B55', 'A873F2CE-8919-44B2-B333-FA1676E02503', '5292452000553', '  / .  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('104460E1-6598-4939-95E5-CCCA997512A6', '190DE07E-E9EE-4133-A134-3C505A5779F4', '5292452000669', '  / .  1 2 6+ 100% 36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C91A533-7E30-48A7-B62E-4F47E5ACC592', '75DC77F3-077E-4F7E-BB4B-8BD61998FE00', '5292452000676', '  / . /  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BF9B62A-ECC8-4074-A2C1-57A2C21DCE64', '8A46BE06-8BC6-4281-B40C-AF824879020B', '5292452000836', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB1A64CA-26D4-4F5B-B146-F277DA1F00EA', 'BE7C5FEA-913B-43A2-B448-C4D3667C766C', '5292452001451', '   / .. 1 2 6+ 36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97495DCE-D270-42CA-8E42-43AEF944893F', '760D05DC-94B9-4B9B-85F2-658FE678C952', '5292452001598', '-    /   2-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19BD13D4-8404-4C38-9555-E2E05F1D4228', 'A3126588-9919-4B38-8994-83DC2DB83AA6', '5292452002953', '  /  3 6 9 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8375636A-F018-45B8-84BB-9363F0A83B9D', '3D64CB22-3458-4C72-B214-6BF6CCB2D2B8', '5292452004605', '    / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1BB4AA2-4700-4DAE-B2A2-EEEE86877FDE', 'A4B4BEE5-1586-44D8-B202-AA3D3627D20F', '5310001059545', ' 60  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7913D3F-9AEB-4070-8139-839E03874171', 'C25BD1E1-17F2-44F2-924F-C8267B842FCB', '5310001155261', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6980A785-854F-42F1-BE4F-383F74A9B9CD', '0030567D-8511-4736-BFC5-FF8DBDFC7668', '5310001155285', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7D544C7-A5B0-4F6B-8E0B-72F1BDF18658', 'B8B1C13E-A35C-493A-9AFE-5F070F1FB323', '5310001155292', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FCF9EFF-01EF-4153-828C-3E5660558BBB', 'FE13A48E-0783-4BD5-B10A-D0ED7A444D64', '5310001178468', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC29BD82-1A91-4BB3-AEDF-090F97DC1261', 'E91A3055-F974-44A7-AE7C-646FBB5C10F6', '5310001178482', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E96FFEE9-E429-4EE8-A4BD-C421BA3647AF', '68F87819-16AA-4482-BD8C-19EBC24AA80D', '5310001178499', ' 40  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02974DEE-260B-462C-A891-CE691BE18C1E', '5A1E80CD-476E-4492-95C0-DBD877CBAEBB', '5310001203832', ' 240  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0E9FEAC-E79B-4874-9A1E-857B03B2FF0B', 'A8DC5156-E710-4BF0-99D5-1277EDB45E1F', '5310001203856', '   90  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C57BA48-1E72-4DDC-B3E4-991853ECB68B', '15747E8A-F130-4C43-AD85-13855B5F4CFD', '5310001206628', ' 400  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E92321B1-C627-48C2-ABD3-B70722D6CBC2', 'A29AEEEB-D1A0-4AFA-8392-8A6B7CBC4B7E', '5310001209322', ' 100/5  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E413A7D0-E7A0-404C-AB1E-A66531FD2F1C', 'C9E973A4-92D0-4253-B1BA-5D9655687189', '5310001209339', ' 100/5 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7604CDAB-CCC4-4554-8675-16F73FC61A04', '67A21F60-DBD0-4527-A7ED-9E6DCD87FA2E', '5310001214326', ' 75  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B1EAFDD-A7B5-476C-AF41-536F8AA9CED8', 'B1CCDF84-B625-47BB-B710-105F2B80FD08', '5310001214340', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A00A4C4-CA42-4DA7-9AA2-B1C54DD1D45E', 'FB6FF834-3CD1-4B24-8A60-5AB176DC3B94', '5310001216672', ' 10  20', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A925B33-61C4-462B-893F-7CC52B7AEF66', 'DAFF09AA-D4A4-42E0-A713-954556DEB8F4', '5310001216689', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68AF7268-3852-4159-96D6-4AE06409275A', '0134BFA1-6C45-474C-A55B-2A34A8756810', '5310001217808', ' // 400  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F983FF3-1E44-4A7C-800F-8202C1801D13', 'F3968626-BF9C-4AD3-8F13-AE32D2F08C6C', '5310001220945', ' 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97161C32-3B58-4627-A1C8-F09E2E90ADD3', '9B2447EF-0E91-4458-8EFC-7C5BEE7A344D', '5310001220952', ' 0,05 30 // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33F4E07E-DEB9-4D7B-B8FC-BA706A41C4FC', 'A7E17931-DD89-436A-8C95-3CC9D0FE593B', '5310001220969', ' 150  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2276AE16-81F6-4D40-80B4-46B08D328E2B', '4C85C0AE-0B5C-4135-B66E-3E6E1FEA193E', '5310001220976', ' 150 //  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('770F38A3-27FC-40A4-8853-A91F644E4AB9', 'B291030E-0001-4D85-9B38-62E5BD85E4B7', '5310001242152', '   / -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B90317B9-4901-497C-88C7-F7B8EBB661C7', '969674FA-50B3-4E4A-BF70-A742501A1A42', '5310001245320', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29B4DC47-F6B4-495A-A5D4-0481C18BCD7A', 'F1E42041-25FA-4432-A81D-178FE2A3E12C', '5310001245337', ' 2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C328FC0F-750F-49DA-B79F-E2E5D6DD70EC', '529E9562-535D-4C9F-BA45-59B5558F08F0', '5310001245344', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BED013B3-284F-4183-8218-1D455D205864', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '5310001880293', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B53E5CA-28E0-4CFF-BE53-6CD73DA7667C', 'CD03EC6A-0D94-4B14-A545-EFBE4C32EE66', '5310090005737', ' 0,255  176  30  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27935513-22D9-43FF-BDD6-C680EF8170D6', 'CD03EC6A-0D94-4B14-A545-EFBE4C32EE66', '5310090010489', ' 0,255  176  30  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37929F6A-9E67-44F5-A71C-9E21D99FE457', 'C46AC406-7D4E-4E53-81D9-C391DB5EE3B8', '5390387001048', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6546CD24-41E1-4279-9628-578FA8503059', 'FBA844BC-53B3-4CA9-B836-98C4BAA46C30', '5391189290043', '  5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEADF9D1-C6C4-453A-9860-B1CA36B3A158', '86A434A3-8361-4586-BB44-E0142B79B204', '5391189300049', '  //    10   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E16E3BA-116C-4CD8-9AE9-2409941E7604', '194DCD0C-7D95-49EE-A6FB-3AAEB62FD427', '5391519920077', '   2% 78', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3BD5F5C-93D5-4E85-AAF4-930B37B73A75', '9970CD8B-8860-47BD-8A41-6C4C3D32E35B', '5391519920091', '  600  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D50A77C4-D6B3-4EAF-B729-19BCCA5DBB77', '0B3F080C-7A94-4EB9-86C3-260617588D33', '5391519920138', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5F96FBA-B813-412C-AEED-8B390F9CEA25', '45E481D9-188A-4292-8B84-F4C6FED66DB5', '5391519920206', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60F606CF-72E5-4DF5-973A-5FF1299078B0', '16E669FF-56DE-4B70-9AE7-44EE16588578', '5391519920428', '-  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4D78D77-2F14-4DF0-8ABE-C140B718881D', '0F496A93-D5CC-4D4F-8AEE-A0038398B8C2', '5391519920435', '- 400   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CB5DA64-59FA-4577-9A65-1F0164A1D1C1', '5A1536E7-0C4A-4EFA-8D7A-50C1C6C8EDFA', '5391519920879', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E2431E3-0F90-450E-A14B-3E9F048D58BB', 'DBA804BD-7647-4E83-BE82-5E972F756B65', '5391519920886', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('498A0ECA-781A-415C-BA19-D735567412A4', '68FD246C-5B58-4388-B317-23B492FE7F68', '5391519921272', ' 0,01+0,01  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2425A24-5DF7-4A27-B422-985964545EA2', 'B2F6A45D-3C3A-47E5-B4E1-ABABE7BFB6AC', '5391519921289', ' 0,01+0,02  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEFF5DF6-2C55-4545-9141-9B38F19E77B3', 'A1B92C68-A703-4B57-85D3-EFEBC17B09AA', '5391519921661', ' 4  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4F2EBD4-334B-4A3F-9354-BD2C1DF25598', '7D7F303E-E4F3-421C-B00D-FAF5C31C650F', '5391519921807', ' 10  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73B69274-BFB7-4066-8BAE-B58E8836BC75', 'F2961D40-5AB5-4F25-A85C-8F15D9CBD532', '5391519921814', '  20  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B5D6D83-6890-4742-A0D7-150FE4AF481F', 'A5AEC436-6083-4CA6-B0D0-7B9710463C73', '5391520940415', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A37EE8E8-9FE9-47B1-ACC5-BCAA8A340C08', '33678BC5-95B3-4686-A9C7-E2039A231E8A', '5391520940422', '  100 + ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6A1F80A-2DF0-479F-A62E-2875445B4054', 'CA204FC7-2AB6-4D60-8321-6ED5AA7F0401', '5391520940552', '      - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('815CB591-2C96-4C23-B9A0-5518F4C5B142', 'E5585829-2EBD-4FAB-A429-AED11C3834B9', '5391520940606', '   20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52660C27-5864-44E0-BF0B-1D4C23935388', '2E62AEB4-48DF-4838-B892-98D5CF30E496', '5391520940613', '  20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6696F0A1-906F-4268-A31D-F17D690CDEF5', 'C58F3616-FE20-45C4-8AF7-0450EDF58C92', '5391520941269', '       150 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D34FA3E-C6FF-469E-BBA3-B6A44DD22D4D', 'BF15BAB7-FC70-4769-B3C3-E85D8E9043D5', '5391520941351', '      100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD27D3E9-C676-4C88-BFCD-5AF3BD8ED986', '3CD95336-5797-4792-B76D-2E433C20D44D', '5391520942594', '  /   -     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C1405D0-9A01-4450-9F7E-D058FD70506B', '7CA244AB-7559-4A52-ABDF-E03DB1AFFED1', '5391520942617', '  / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4AFEA34-6CD6-48EF-9995-11A6D8EA2DC4', '969176C0-C52D-443E-91B7-01038148C324', '5391520942914', '  Antibacterials 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C43876E9-4CB0-4218-98D0-C93AF4DCDDA5', 'B67D95B3-E54C-4A8D-BB61-579073DABCC6', '5391520942921', '  /  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27FFA0CD-496A-4FCE-87D0-2C7075ACF53C', '9536BFF8-E166-494C-9A04-272D53A79076', '5391520942938', '  Soothing 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('650699AA-1705-46C9-AFBD-8E1394FA99A5', 'C262B8D3-27F6-49AC-B9D5-E5F4E7CA7EC0', '5391520944659', '  /. -/.250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D477A87B-BF4A-4E4B-A7F0-1FFFCE40D424', '5115358E-D22E-407F-8ADC-92BEF1968422', '5391520944994', '  /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F2D9063-A042-40F2-A0AC-6A24DE53F671', '9843BDC1-9228-42D8-9306-DEB4619A93A6', '5391520945076', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5D320FE-2E81-464B-A127-873B944F980D', '9BAF5A21-BEBA-4398-A76A-4EBD03FFE81F', '5391520945083', '  1  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88FFF4EE-77FB-46E3-B74D-B2B5E779D917', '5115358E-D22E-407F-8ADC-92BEF1968422', '5391520946646', '  /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B3331BD-B3D6-439A-AF07-913255CD5606', '23A2AFCC-0AD0-4381-AEB2-2BA34178F1BC', '5391520946813', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D2AFD57-04F6-4626-8051-7570ED632062', 'B3400566-E785-4F99-84C2-D218C41DC5E4', '5391520947216', '   /     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7CF6A76-057F-497F-8753-9813C109842D', '69174248-5656-4EF2-82A2-AF8617E83EF2', '5391520947261', '  250+50 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37FEF156-BE93-45A1-AFDD-DCE05D0E33B9', '13FC4BBE-23BF-49AE-8CD6-7A5FDEDB19DC', '5391520947605', ' girl 3+  /. 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C29041CD-8934-4015-A1C5-B435AE89F4D1', '93D817A1-91A8-46AB-AEEE-CD33473380BC', '5391520947834', '    /.  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2893933-3C19-4771-BC09-C9D9463F12D3', '592B044C-E825-47CE-9649-6BBDE60C12A0', '5391520950940', ' - /  1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A261C62-8166-46B1-BEB5-11374BC6361A', '1162D637-D45C-4DD5-B529-6EE90E0A1201', '5391520950957', ' / -4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFFB6938-246D-4968-B5AD-DA145ECAF289', '817E0606-ADFC-417F-B89E-26555D736321', '5391520950964', '  - /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A80CA8C-F18F-4A4C-B15C-AE7CF07421C7', 'E91673A7-1574-4D4E-AC7B-AACB97442DA0', '5391523052696', '  3     700', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6326B9FD-3EE8-4B9C-BD5F-9E28A6D25A52', '7DF49DC7-9FEF-4A6E-B297-D98FF09EA901', '5391523054614', ' 4    350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('625A2BE5-664B-4B9E-B786-5C46896F6AD2', '933609D9-4A4C-42FC-8B09-EB006E6C374C', '5391523120029', '  160+4,5/  / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D2A29FD-6124-416A-865F-5FCA3AE4E5CB', 'BFD1C89C-0D99-4FAE-BB42-40F07B701160', '5410076260904', '--  7     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0710B25-778A-4519-B73F-5D5DE42AECEA', '36B4376D-6DFD-470C-8FC4-CFE558F2B730', '5410076302642', ' / - 3d  lue    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D93B133-23EF-4528-95EB-99C8F267C850', 'C23D3543-8725-4B36-A635-249C63DC85C0', '5410076400607', ' /.      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('648A63D2-83FC-4D91-A8F8-88F3EB8F72DF', 'DF42275C-CE98-49D5-9533-02824192737A', '5410076600649', ' / - -  250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B3F2265-BECB-4D05-802B-A6BCCB53E582', '91FCAF1B-94D4-4848-8FB4-1E27FF08F599', '5410076635078', '  - 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C83B4023-0EC9-480D-8546-60946B41E406', '38D41464-C776-4EDC-94BD-E275700A312C', '5410076744787', '   pro-ep    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('236DEB6A-86D5-44A5-A580-1C8992DC5518', 'D28181C7-6188-4121-A069-A79296D03D2D', '5410765002457', '  -100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B969A130-D746-418D-BF14-52F996DEFE72', '97F0771C-91CC-4BFC-846F-8DA6E6024E38', '5410765002464', '  -   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86E029B7-A613-4CF9-8145-01AC34504522', 'A0032F16-A6F4-4D78-B1AF-4ED54250FB46', '5411416003731', '    3  / 10/ /39039/ /390391/ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D64C1511-0176-47B0-BF39-EF88E353603B', 'A70C0E2B-4865-4DCD-B81F-A5EA796E5EE2', '5411416012863', '  6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B888831-65E7-439A-AB8D-A422FC8209BB', 'BC3EC5A8-AD1A-426F-B842-19A584A42C6B', '5411416013808', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DA0F729-0029-4D4B-96A1-FD6E725F99E7', '6F120E7B-4602-4234-B485-D28C643EA83E', '5411416014515', '     6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EDC67C5-629D-4940-84E0-98189FD4E122', 'C7273E2E-01BE-47E8-B875-4C0C1124ACD1', '5411416018636', '   / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF9D1137-8E34-43FC-B241-0488C8859D50', '0F4B1C2A-1D27-4E0A-96AF-2F914239EE34', '5411416018674', '   /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A290C00-DB7A-4C16-B809-548766508020', '14D2FBF9-B225-4625-A449-135A78874B55', '5411416020028', '    28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B7BA8C1-119B-4FD9-A463-4755782A9FB2', '793BBC3D-6682-44C0-B67A-D241B0A910D2', '5411416020066', '   . 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0DC265D-7C63-47AA-BB31-4E4EF3D3F567', '54E04E87-D89C-4D44-864A-DD2D7CF7AC27', '5411416027652', '   before  born /.  1-3 /231429/ 32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2F7513E-13F5-4619-89D5-4C6AAF0FB1AB', 'ABFEEEB1-B12B-4094-86C2-65321BE74C0D', '5411416027997', '    90 x 60  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAF31126-EFDD-447A-98D0-1EAB0B62B5F7', '3235C733-129B-4E67-8C2A-23245401181A', '5411416028017', '     6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AFFFBFE-525A-4436-A176-20A18A3DAB33', '5823061F-7412-484C-AC79-8897091BBCE5', '5411416029496', '     (4-9) 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96C1112B-E240-46CD-8140-2F9ABDA92E22', '8CA97060-C4C9-42DF-B05B-9DC7876D1D41', '5411416029816', '     2-5 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52B1DBDB-6443-4830-B8DE-74AEB5567214', '1D7827B4-ABA9-4D44-88FE-32B6562749D4', '5411416030454', '      /851006401/851006402/ 64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0D10EBC-D93D-4033-B00C-8A943E326399', 'E2C9859E-7EA7-42F7-ACA7-D5FD45E08DBC', '5411416032243', '    4060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9887A7F-1EA9-4903-8C79-ACBBADFC7998', '6AA9EBE0-58FA-4AE0-8C22-93775E1B6204', '5411416032281', ' .   6060 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('259BA0C1-ECFC-40DC-BE4E-2BD0235816C0', '2FB09A2D-7CF9-4AC4-9D35-3CDCF6F80BB0', '5411416032649', '   / /39050/ 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05FDC34B-6556-478F-AE4B-78BC995FE06E', '34DA323D-3445-4B82-9BD7-03F6887AC656', '5411416044093', '   .6090  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('830309DD-6247-42C7-930F-8229C732F5F9', '67FB1A3F-60C9-4732-97EF-CBF0228324FB', '5411416044116', '    //   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89F30CDD-8DFF-405E-A797-AAD88C2E1DFF', '5F8F92DF-A4CD-4420-9BB0-A4FED67A959D', '5413787007448', ' 1,25  /300/ 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBCA5D20-8D32-40D7-818A-DAF3198656AD', '0BE58483-7EBA-4AB0-A162-36C02FDDD463', '5413895001000', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBB4AC7C-31D3-4AE1-8C28-F3A549653CA3', '754342B7-28E4-452E-9A5C-7FB3FCD3CBD1', '5413895001703', '   -  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D91730BB-1529-4E23-BE10-3B117E553872', '9EC34F31-241C-4068-B6B9-9C97F82DE4AF', '5413895006159', ' 0,1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2098B6A5-93E5-46AC-8343-E816DAF41A03', '3E81C2DC-A8DB-466A-B872-C2ADCBD5049D', '5413895006302', ' 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2336F94-2330-4858-9332-BEA5F26E7382', '325C2527-EDD4-461E-8E97-CFBB801AA3A5', '5413895015755', ' 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FAD5545-071A-4879-9B79-325A7E6626DE', '3EE00DD0-CA07-4EC5-890C-E9DF062741F5', '5413895020919', ' 0,1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEAE6559-F196-4641-82E8-464022D9DD58', '14F54D28-DACA-472C-AFE3-67607DB1C71B', '5413895021381', '  0,1% 5   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4E4D336-F317-439F-8A0B-83E0E2249224', '9C7C9748-C062-443F-A2AB-A40BFBF83AA3', '5413895021466', ' 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C25021CA-6EE5-450E-AFF1-99A925596F30', 'C8C6B8B0-6F8C-4D78-A760-20A962AB5186', '5413895022944', ' 2,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('096F099E-B4BF-4F64-9172-C3AD97F6B18F', '44FF8217-FE6E-4D40-9D5A-A262FF64DEA8', '5413895026416', ' 0,004% 2,5    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F64E1FC1-E4E9-4618-8DF0-08216C890B32', 'DC0C2A22-8D8D-494F-8E40-412BC146BB8F', '5413895027093', ' 0,3% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3642D4A0-C3BE-4BB7-868A-22CBD9D59A59', 'AD6EEC01-C9CB-4B3D-90D8-6B1E67D0CEB8', '5413895029233', ' 0,5% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('949C7CE2-AD89-47C5-AD5D-4A2DAA69C124', '79EBED35-BD6B-4226-BB9F-9C1104B537BF', '5413895090486', ' 0,25% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAD603A6-C404-486D-A4F1-458FE8445A56', '0A59D6AC-04FB-4925-B31D-80471782FC38', '5413895115134', ' 1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F03037A-9457-4006-B424-36CED9E73E75', '65783D16-484F-4F89-AF5E-E8B233F5E1B0', '5413973012317', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82C85622-0A48-4ED9-9836-EAFB87C21B80', 'E2102DDC-D681-4B14-8936-1275B1634E7D', '5413973014311', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('099E717F-C64E-4A82-82EA-551A607D7633', '44F30FD2-E39A-44B1-A76B-4B1354B52579', '5413973112116', ' 5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A847B632-31ED-4C5C-9DD0-CB703278B3F3', 'ED570FA0-B2D3-4159-8B27-78EC40C9790A', '5413973112314', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('808871D5-19C5-43A3-997B-9DA094C2D99D', '06C6A67D-9964-44E5-8BB2-86230A7040B7', '5413973113113', ' 10  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34391D7C-D96F-412E-9859-96ADD1B30607', 'F12C2C13-4B4A-4CDD-B77E-5D3F30B29A71', '5413973113311', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F6DEE03-93D3-4368-98EA-38B952A5A457', '5C80DF28-D569-4882-A16A-55C3FD3371A4', '5413973172110', ' 50  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70E70218-1178-44BE-A7FC-65EF19F4EA67', 'A76EE7CD-6F82-43DE-8A59-759359783387', '5413973172219', ' 50  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5A6683C-5446-47E6-978F-3C399474A43E', '97E5A12C-4FD6-49C5-8FA8-2130AE373B55', '5413973243490', ' 100  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF7E3FA9-F4E2-4276-A3D0-A58DBE307CF4', 'CB4C2093-0CAA-444A-BE4A-DD378405631D', '5413973262316', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B50D894E-A75E-43F3-B501-0839F2299B45', '57104801-190A-4EC2-9D56-EACD23A01969', '5414789000017', ' 1% 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('038ADAD4-6BC4-4B3B-8040-B264A95F85FE', 'FE56C5F8-204F-4BBD-9A48-1F2EA813575F', '5414789001007', ' 1%  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A5555A8-23F1-4117-8933-9C66EE1C1FF5', 'F1885A1C-A9B3-4866-BB41-F6E42A2BE254', '5414789001090', '  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9709C220-58FE-4C81-8394-A1E1AD801456', '2BF92762-01C3-41C8-87E4-78EB662936B8', '5414789001403', '     80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3197405E-9301-4822-832A-ED176ED9361E', '8C283EAB-2002-4F2D-A798-FC81108D8CF1', '5414874004616', '    60*60 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71E2D524-C11F-4D36-86E6-E0F8DEDDA7FF', 'F2DB341C-B52A-4431-9EFF-42C5DD960A8E', '5414874007112', '    //   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9A22EDB-33D7-451C-94E2-05CA4599F607', '5F87AA65-2A11-40CF-8C96-024D6DF7A1B4', '5414874007136', '     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0C93CC8-CA87-4C24-BB54-B363EE30428B', '09E764BC-F09C-48D0-ADB7-59B082E85AF7', '5414874007150', ' id ana    14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2F58681-32D8-4AD1-9440-BD988730845B', '2EB9C3C0-0821-42BC-BD5A-855D82E0ADCC', '5414874007174', '    //  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F44B8CF-7737-4992-9A3A-47DF3054B751', 'EA0FF7D1-3B37-4B8C-A147-9EB30ED8C774', '5414874007235', '    -  // - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CDA7930-1D5D-4B5B-B682-677D00E2E40D', 'E234576E-72BE-4147-9E6D-32977D093BC6', '5414874007259', '    - l // - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('805DFAAC-C1E4-4B7E-95F1-A489632C700A', 'CED2C5DC-A90E-4359-8D6B-6EDC57FA511B', '5414874007457', '   4060  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB2E6415-0B57-43C8-8757-BB132D41CF0F', 'D3D84305-C586-4BC3-A9F9-C93849185B15', '5414874007488', ' 6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05BFF60E-A60E-4DC1-A8AA-7FDF9B285EFB', '47B9356E-2005-49F5-AB3E-E7CF52FD1D20', '5414874007495', ' ID 60*90 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B706F30A-8700-49D4-A035-3B5F70BE2AE1', '2D5E2759-C87F-4CBF-A4B8-84EF856BD848', '5414874007518', '    6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('745BCC1A-9E66-440D-B26B-0C5A9D975FA6', 'C2BB3D3E-7439-4333-BC63-13C289116A1A', '5414874007532', '   .6060  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E7E3A3D-E000-4CC0-A04C-2F041B6C0C98', '70986932-0447-43F8-ADB8-4836B1EAE6A2', '5414874007594', '  id l/  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8CCADC6-DE46-4C58-9110-380BA8E22926', '839CFBD7-0BF1-4FAD-868B-7BB1ADE3643B', '5414874007631', '     // - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E61F509-95B0-47B7-B937-77E3CC54EB07', 'AA60FF6F-85C3-4A77-9BE5-C8DD54B1E50D', '5415062323748', '  7  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26CD5037-DF6F-4E45-9510-8B3D5DF612C1', 'C3B9CFA5-94F3-45F5-B1AF-A04CA0E2175B', '5420044310326', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C937F070-C550-46D8-8A61-DA30B49D20DD', '1C052A7E-4D6E-4C19-BB12-0F5BB4ACA8A0', '5450557003330', '  /- //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('460547AA-C2E6-41B7-BFD9-052638F661D1', 'FC067E35-951E-4749-904F-6E4C00543E07', '5450557003347', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6C87092-8A08-40B5-8093-ED3CB8EED112', '87B377ED-A5BC-434A-BDEC-65DBE8475763', '5450557003361', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89FBDE2F-E599-4ADC-B8F9-CD29587217EF', '05FB98BC-E055-4260-AB8E-7561A58D5F69', '5450557005266', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6C99482-DFE3-4AD0-86F2-E94C07217649', '0A5B1D05-9586-41C5-8F2E-AD0D892A23B4', '5450557006720', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9459EBE8-7DFD-4548-84CA-8779F09EE8D7', 'B9CB6094-E98F-4B5A-A8DA-DB2C3681909B', '5450557006737', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F9E28FA-BCA0-45CE-9140-B33E0596E707', 'ED3B0530-F90D-4404-9E27-1330199E2762', '5450557009158', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12AE15E1-7D81-4680-B00A-051066F36246', '62E26D98-C32D-4FE0-B4FE-E01D274A523E', '5450557010291', ' 20  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4721FC2-18E2-4206-8D08-D0872A02B534', 'E57508AF-CC64-4598-B738-C1502547CC61', '5450557010567', ' 2  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1670124-D5BD-43AF-A78D-F5CC4DBC4A2A', '19D14B62-3872-410A-AA03-F95B4C4364A7', '5450557010628', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FEE6D52-06FE-4E90-B508-929134655C31', '45ABA6BA-05BC-47F4-A252-04970D145875', '5450557010635', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1ADB360-6F1A-4EB4-AE94-DCAFC5BD9446', 'C65BF5B5-A951-482E-A990-EE5E5418C1D7', '5450557011571', '  20  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02B711A5-CBAD-4E22-BA45-B36B46BDA359', '0BA8517D-E87F-451A-BBA2-D0853708661F', '5578411251021', '  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('958C8725-A9BA-458B-AA46-B3F4D8500CEB', '0AC03F51-CB00-47E4-A376-92B19D4984AD', '5690528249019', ' 500 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24BF5C60-89BC-4A55-BCCC-5BCCBD590895', 'C6DBAB75-325B-4D5A-9F90-C493E886AD0B', '5690528249033', '  // 500 42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD8AC8C4-D912-4DF2-BAC7-4F7CF01537C8', '8DA53DA3-1516-4B9B-92A1-75EE0ED76869', '5690528421019', '   10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46687A08-DE23-4D9A-8257-A098087407E6', '1C8911BD-3157-4AA7-9782-27E615A2242E', '5690528422016', '    10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31D5BD5B-29DB-4D60-A3AF-96DE996738A4', '6803629E-31C6-48B7-B8FF-BB18356674CF', '5700666012144', '-   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8B7EC4E-3F7C-4F39-B659-20FDA958C05C', '89D5E81A-DFA7-4CC1-B0F4-E9107C4621AF', '5700666021573', '-     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43F58570-A440-4912-BA26-656363D1891F', '59F07936-B89D-499A-870A-AFD100A48226', '5700666021580', '-  +   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C909D0B9-4409-4F9F-9529-01AA6037CB59', 'CA31C81F-9262-4FCE-AA81-B6F6B59E2331', '5700666021597', '-  1-4 +  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DACC9E84-3A94-4D3A-9207-3886A898880A', '7F035845-5974-4D62-98EA-CF155F503421', '5700666021603', '-   4-11  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78F94350-CDBC-4381-93D7-B18D5E74218C', 'DE90B347-1B6C-4D1A-A9FD-7D4E7318E9C3', '5700666021610', '-      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B46DD06-5C46-4921-9F64-FF0E3841DAB1', 'BEFF5D8C-99D9-4ED7-84E3-14361CACDAF1', '5700666021627', '- / 1-4 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A877A160-3BB5-4CC2-9445-7E1F3AB5CF1D', 'A1CDF11E-795C-4CDD-83F3-C10F4294881A', '5700666024291', '-   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64575204-D7AA-48B1-9A82-727F653BF110', '64AB5A0E-95DF-4288-A650-5B48479AD190', '5700666024383', '  500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EF2A79A-95FE-493F-ADBB-F883BAE2D6F8', '07924EB6-5DD4-4BEF-938B-ED25E9A17144', '5700666024574', '-   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D266C3DA-5512-4E2E-A957-91A8179948A8', '12C35477-3A57-43F4-8213-EE0FCEFA8D7F', '5701780942881', '058850    10-70 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25D95EFE-746C-48C8-BC81-318AFCD533BF', 'D52364A0-0796-4400-A2A7-B1DAAC7D1010', '5701780943123', '017790   60 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('082B2F8F-D51F-4D2A-A040-20FADEF21E37', 'A1A8A365-2913-41F3-9D5D-38C2A484C4E6', '5702071355458', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19E6115E-8794-4ADD-98AD-E5D71F6FAAC7', '43CF7A1E-F680-4E87-B605-CA3D94055A32', '5702157142187', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16E1FAC3-EAF4-4515-A3F6-2CBB6245CD5A', 'A6BB6460-021E-4252-84C9-79578149BBD7', '5702191008661', '  /. . 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D381BEFE-31C9-43B4-B058-B612458FE277', '1DC4AA7E-202B-4E01-8D58-B70440211D20', '5702191008678', '  /. . 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDAFBE36-FF81-4A3F-9BFB-3324B23539AC', '076725E5-3A47-4ADE-B2D7-0AA4AF971B74', '5702191009903', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CDCD0A6-95DE-4986-A57A-08402D9042A3', 'A1567300-7AA7-431B-A05F-FCF9B94DFBF4', '5702191009927', ' 0,005% 50/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AD07AFA-B955-491E-B5C8-0F83CC3B1284', '0D941D8C-AF12-4C27-9A76-3039E6BC5F27', '5702191012613', '   2% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEEB4F39-F139-4836-8799-AE68C70BD247', '62C63EC8-9DB5-40D8-9834-AAA1AE176930', '5702191012620', ' 100   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74B66AE9-2D76-47A2-81CC-283ADB1B4C08', '21205572-87F0-49C7-BD24-1BDB532F7245', '5702191012675', '  0,1%  /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9887A8A8-F132-45DA-90C6-B25034C87E49', '91E38B6D-7C64-404B-BBA8-85A8F7BEAA6A', '5702191012699', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D4E2EAF-7598-4843-94F6-41AE3D2AA57B', 'A7FCD798-C0F4-4400-B3BF-8DBAE486A20A', '5702191012729', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD2F7DFA-DA9E-4569-B1F9-42891C03A32E', 'B0A43B32-3916-4856-A18E-7EDF79E093BC', '5702191012811', ' 100   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9503306-A131-4D5E-9419-FE8498128725', 'D7A671F2-6C6E-418B-B8CE-CD40770F7399', '5702191013290', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98D60B75-75A3-46ED-8579-A01ADBDB84D5', '80AB18E8-D096-4EAD-9377-56059D39C773', '5702191013351', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('540BFC38-EB68-46E8-9DB3-16630B985BDA', 'F6DE4F28-5C0D-40D1-B159-1CAEF39D4ADD', '5702191014365', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57945339-2D59-4FB4-89B8-4FBF067945E6', 'AAB46984-B944-49EB-B6A1-832271A891DE', '5702191014372', '  15,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9AC1573-D27D-4C74-ABFA-C5A8B6505234', '748D11A6-BF94-4555-A385-EF154E95E405', '5702191014402', ' 0,1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C1D97EA-7C8A-4371-8B0F-B3FF130964EC', 'EC61A01E-FA5E-4FC2-968A-86B2C0A2DD51', '5702589307208', ' 40  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFC0F8B8-1377-4B8F-8A3B-6EC7EB5F0700', '35BE18BD-3C13-4BA9-B178-EE23D2BC9530', '5702589307215', ' 80  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CB288C8-B0EB-434F-A1D7-C312501C66B3', 'D2A8FB13-CD40-4BAA-B73E-62774FF4172D', '5702589307604', ' 30  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E8614E0-65F2-4901-9DD1-AE946ACE3920', '88154FB4-4664-4F78-B274-3FE2A1A6C629', '5702589307611', ' 0,03     28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65EF6390-7CAA-4E0C-8CEA-100B0523F816', '421C1FB6-4606-4FBF-8DCE-243C1128D2F4', '5702589307628', ' 0,06     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17A3EC68-46B9-4D0F-BB45-FC02C85AD5D0', '2CE5CBC8-8C94-464A-ADFA-D9F7129C802F', '5702589307635', ' 0,06     28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('075B8C90-4539-40F5-8C0F-EC4E93E51019', '73CE84B9-DD1B-45EF-8F67-081772353846', '5702589307734', ' 12,5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('808ADDBC-F20C-4113-AECA-09C6679C4AF5', '5BD31056-0950-4214-8428-7796EA444ADA', '5702589307741', ' 0,025 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D4A8C5F-C235-4D75-8BB5-259A76E9C836', 'E9AC449D-D205-4D70-ADB3-EA406CED442E', '5702589308106', '  40+12,5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('552ED812-DCC0-4CA1-B074-2D615FE1B91F', '441A8017-132C-41EA-98B7-95759F374A42', '5702589308113', '  40 +25  /  28 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A52C578-64A0-4265-B6C7-C335FBFDDF1C', '3F32FCFB-B766-4A03-89EB-E4087812661D', '5702589308205', ' 400  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A5FA41E-5274-4517-8CA6-EA864F33A486', '1E565A1B-6F54-430F-BD9D-99C547FA19A3', '5702589308212', '  400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBC72F8F-6E01-4B42-9C39-04E1D1B52C44', '4C191901-F981-49E2-985A-72D018671991', '5702589308229', ' 400  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1159FA18-6BC3-4BB7-922D-182B2CC90C96', '5E922541-2078-406C-BB71-1C70E1F4B8A8', '5702589913072', '  0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EE75085-8399-466B-B693-C522989B6AF4', '8384AC5C-1F22-46BD-90E8-A1E730E0B2B4', '5702589914062', ' 0,05% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B876E36A-855C-46A1-AF7F-6E763419D7D9', '3B5F0BC1-2B93-4094-B875-8329D38F6513', '5702589917032', ' 0,8/  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52A7BE9C-1CDB-44FC-92D5-26202D816F4D', 'AA84EFB2-597C-4661-A9D2-988C3AA05F83', '5702589922142', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2476EDA-BC8A-4243-9BAB-7193E20058DF', '476C2448-64DE-4B1B-8583-277759495449', '5702589925037', ' 0,025  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F571FAF-95E6-459C-BF2E-9BAADD6B4212', '340F9219-59A6-4568-8AD6-C12E112E3A45', '5705675088821', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C832DF9-34ED-4FCB-B7E3-1510206D08B7', 'DED79CAB-C33F-495C-BA46-37BF448B04AC', '5708932171199', '017590      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9C416BF-AA5D-403A-BF0E-64E020EEA788', '571272FF-D270-4BD5-A0FE-DFE7990CA172', '5709932003930', ' 3 500    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD0974C4-3DC2-4470-AFFA-62A96AA1CFE1', '3BB1EBBC-C7AC-4BB2-A03E-0C608BBFD449', '5709932003947', ' 3 500    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F1585C1-5BB2-4EC8-896D-442B28A7CAEF', 'DEE3A8E8-36FD-44DF-963F-C14A60B476AB', '5709932004760', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E37EF4D-0DB0-4286-AC80-0FEC8A9FC335', 'EA7200A9-8555-4E29-B15E-A963AA625E7F', '5709932004814', ' 3  500 //   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E55E2B70-2299-4CCC-BDEF-42246D17F217', '6296FE10-FCCF-4E16-8F69-3EA51F025036', '5709932004821', ' 3  //  500 +400  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4AD89CA-B8C9-4550-B14A-B93EE8696094', '9A20559B-EE0C-4C6B-A273-AA8DE5C0BD0D', '5900002025023', '        500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D562732F-197B-4E1C-BAF1-F91136D3D465', '578E7657-A19C-4CB4-B972-62FB0607A7D6', '5900002025030', 'Eva Simply  /  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F4E5D42-1AA4-4CC4-86AF-9D7485E4CA5A', 'FC1771BC-F336-44BE-B472-68BDA351763D', '5900002025047', '      500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A8805EA-13D3-45DD-B0A6-D168C5A45525', '7BDA8758-7C0C-434D-9AA5-207408D27AAA', '5900002025054', '         500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06CE4B5C-CCB6-43F6-A9AC-B332D6F8767D', '5E52DA9F-D147-43AA-9638-F74F5E158013', '5900002025061', '       200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6064E841-1C21-4015-A0A5-EDA1891373AD', '439C4533-5CA4-4CDB-8798-EB58351855BD', '5900002038122', '-    EVA SUN.    SPF 12 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('243EE008-4B57-42DD-BBC5-F4575864F0C5', 'E947BDBF-2E3C-4A2A-8921-C11E0775A91E', '5900002038160', '  "eva sun":    " ". -,     (150 )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25894C68-C8DE-4323-A7FC-B0C72DFFA1C1', 'CE0267C9-44EC-469C-9D1A-D16E8CF8CE9D', '5900002041399', ' -   "eva natura" 500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11D47594-4101-4442-8CFA-E8B5E36FEE7C', 'E2A2D3E3-BD14-4B0F-B840-9C9774C6A742', '5900002045854', ' eva  / spf 15 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C877956B-4120-451B-9CA2-3A53FDB9931E', '966588B1-804C-463C-8AE1-8901D53CFF51', '5900002045861', '   / spf 20 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F4C5565-E291-4898-866D-7158421695AA', '122E12EF-32C9-49E1-91F9-88BB8BEA2383', '5900002045878', '      SPF 30  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D426C787-4411-41E2-A5CC-D15182F578F6', 'F223CBA2-5536-4D39-B1B9-53F94BC9F865', '5900002045885', '       6  SPF 50 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42CF06EB-ACD4-4BBF-BE0E-A32962F1D566', '56E37535-3085-4DE7-AFD0-6118CCF4A698', '5900002045892', ' eva  // sos 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C24F594D-24A5-4EB8-94A2-5B114B77644A', '6223FA75-A34D-489C-9B53-86F6FFD1F18B', '5900002045908', '  "SUPER EXPRESS". 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B3A9357-367E-4401-95D6-69A4962CA87C', '0B8B7DD7-FB60-4FE6-8CB4-9949C25A82B3', '5900002045922', 'Eva Sun   spf50 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18382AD1-700A-45D3-A820-16CC06D32575', 'CF1F79B9-0DB1-457D-BE5B-7462A2597AFE', '5900002047933', '      Herbal  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6AB459F-EF9F-4796-8D85-F7AA4FB22754', '16289D12-FB50-4CC3-94B1-BE2BEC884CAC', '5900002047940', '     Herbal  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22899A16-76CC-4955-9234-AF84426C5845', 'F4367AF8-01B6-4D23-8D45-973A9FBAA742', '5900002047957', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F9F8569-ED56-490B-8FD8-FABE2342EA38', 'E259327A-369E-4C57-B4BB-4F9E104AE40A', '5900002047964', '        Herbal  25. ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2459E0FF-7055-48C5-82C1-7B270F4C8877', '88D538F9-989D-4C0E-9E1B-6A4CDAE96058', '5900002047971', '    Herbal Garden 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C97C1597-D046-4EEA-BA05-EC86456BFC07', 'C8C863B1-07BD-4946-96E6-B42DFD146ABE', '5900002047995', '     Herbal 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1564EAB0-C322-47C0-9A00-34F71A7ED8C1', '87FF8479-5BE0-49BA-BA52-A1617733C540', '5900002048008', '     Herbal  150.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61F463FA-15BC-4DB6-B729-E510E78D3A3C', '486F2995-31D2-4A05-A502-37366CBB7A8F', '5900002071310', '          200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('353FA898-4E7F-4991-A4CD-D6DFEB339A63', '7D7E69DD-3ADE-4AA3-B963-1C698F79A63F', '5900002071327', '          150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0DF407B-BEDA-4E0A-B8C4-4686297F7D36', '1BB7C0CA-223F-490A-AB90-9A416AEF0C2E', '5900002071334', '       50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B7C0D54-5D1F-4D73-B65B-A628F98BEF28', '4126CBBE-0AE0-4DAF-BFF4-612915128605', '5900002071341', '        50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A88CD4C-B387-4063-A8F4-0D5BD50D9181', '0C192FCC-2A02-4DFE-A7DB-17B760BA022F', '5900002071358', '        "eva simply" 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22DAABAE-587E-4D42-BF44-79D322E8D437', '61972599-231B-4B41-8F67-CF8C51C17741', '5900004070588', ' 250  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D7E2064-A67F-40B1-A146-DE4FF9DC59CE', '83885107-CA9D-4420-A666-A8D5985C6F0F', '5900004072377', ' 124  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4646A020-C93C-496F-8867-FEB7D3A025C6', 'D6080F79-8D64-4E33-BB09-FBE2E14FFBCA', '5900004072384', ' 124  / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6938CD0E-A2C9-4B5A-BA8B-D5B6DE689728', '86F915CF-5AAE-44B6-A227-E0D791CAC0F3', '5900004073091', ' 200  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2125D5F7-CE73-4F50-8B99-C8D504817647', 'F50B4E8B-27FF-47F0-ADB3-66165AC2C89A', '5900004073152', '  0,4  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C4ED697-867B-4AE7-ADBA-1E85E8AC37C6', '845B817E-4108-460B-A13F-E866B6515FCA', '5900004073176', ' +100 4  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA7F42F0-0D8E-4594-8FA5-AF9EB925A3A8', 'ECE71BFA-0462-4EC5-BA2F-55632734B3AF', '5900004073343', '    15 5 120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12484F14-C417-4E10-9D00-604546D5C085', '6C3FEAFE-C0BF-4126-8D76-7E629A4A210D', '5900004073367', '      30 5 120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85CD5FB0-892B-4F81-A015-936475678718', '1DFFF401-DA30-48B1-9B6A-53AA6614D321', '5900008006286', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E077AB5E-802B-4F41-A3DF-D3AFB17CDC66', 'F723737C-C104-48EA-BB4D-533F006E61D8', '5900008006453', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FB213E7-8FAF-409A-BC24-C9943CC51BA9', 'E800D3FF-4463-4207-A7E3-930DE38C7966', '5900008006460', ' 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F37C4DD-8161-4704-930F-675C947B1354', '5211E48E-1E1C-407B-AA78-458FF20F4111', '5900008011242', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2EAF59C-CA1D-434A-A8C8-047BBB3E45F0', '04165C55-D55C-49E3-9472-16F3E4919838', '5900008011259', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('531D7E4A-C2DA-4792-8FEA-35BD13D41727', 'F69553F5-6ADA-4344-8E62-A3638F393CD2', '5900008011341', '  55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D00D5321-6F32-4993-AE11-2AFF51636C40', 'EF7AFB47-0181-4392-9C56-A2F5B83E6571', '5900008011501', ' 200  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47AB94B3-9B77-493E-B109-C2E043C2C35F', '288C99E2-96B0-44F9-A8F0-6BCB07D202E7', '5900008012492', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5715B0F4-627A-4451-B566-D30AA85FCB81', '01354D5C-2D8B-4B16-A9DC-58F17D4313F5', '5900008012676', '  0.05% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5700FF34-C3EE-4F78-ABB9-7EF3B1B128BA', '3FA3320A-4FCA-4F17-94C5-1E1CCE25BD02', '5900008012683', ' 0,005%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A901C5BE-5D9F-4F66-B688-9D60A18F2082', '0B741F34-44EB-4008-9B50-EFB2DBE0FEEC', '5900008024150', ' 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('275DA700-DB03-4AF9-804F-B07DA12AD3A8', 'A8BD93D4-A60A-41C9-80C0-F4A79754C158', '5900008024167', ' 100  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('531E55FF-CE7B-4C69-943C-0D002B49C090', 'C1DA4934-F53D-4358-9C95-C80DAF1C14A1', '5900008025263', '  1% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E73D2587-BE8B-4340-A5FB-5CB4EB98E9C8', '72FB6804-A0E2-4A1F-B851-073D88FE9B73', '5900008028004', ' 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DA4B450-C733-4F8F-87C2-F365389F3D1C', 'A8A68B6F-78D6-46FD-9E2A-C5EC1C4D9172', '5900008028011', ' 0,5  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D7D8849-8CEF-4C88-B6EF-9F7ADA2B4CA1', '6B273045-D749-4052-8784-A6C9B98D73F0', '5900160510010', ' 50  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3678C465-4766-48D8-86AA-F94F41AE63B8', '7E9748FB-C453-45BB-ABBA-3FFC916206CD', '5900161005928', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1A5974C-F35B-4C59-A50A-65E78F44C515', 'ED814722-A009-45D0-8C4B-3CDB3778E392', '5900257022310', '- 10  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6586F483-778B-42A7-A5B9-51BE809B8E10', 'E6BC48D0-52D7-4FDD-A034-9ACF120B6FDB', '5900257022334', '- 10  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A9616C0-B844-422E-A59C-9989340CC5F1', 'FCBACDEC-F8C4-4BC7-8D88-AF81A842B9AD', '5900257037208', '  0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36BE0DD1-5730-45D6-B645-D58BD61E131F', '4B6B593C-635C-4C4D-B4B1-B1BB75374374', '5900273113269', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BC07800-496F-4A49-8940-E2CA2ACC4B52', '3C3B9BDE-8998-4F75-9F2A-3276D48F46FC', '5900273113344', '     /n2/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('963E6D34-3CC3-44D2-8DBB-7BEE2495E39B', '82DB5BDC-2888-48DC-ADDF-9908A3BA5CCC', '5900452072356', '    130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6777D3F-A8A6-4D24-9606-C7F5E835FE1E', 'CAD57F57-D450-462A-9CBB-0A35098C3692', '5900452078013', '    4  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE3C0D8A-EE8B-44EE-8A1A-7D74DDB853E8', '82313A53-5152-426A-A822-76631625FCBF', '5900452078051', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EC4F41B-EB93-43C5-9A4D-9002F4AC859B', '4D3A8AD6-DDEA-49D2-A167-08EEFD2E16A7', '5900452078419', '    4  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD1BBC1C-0D50-4644-931E-94157B8FC392', '5CAC488F-EB8B-47C0-8299-2B9FC40C4173', '5900452078426', '    4  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DFE9E35-B32C-421E-B114-13AF6BD2FE63', 'A89AF872-F456-41F5-B51F-4B6065230B4E', '5900452078433', '    4  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09BC8BC6-BC56-4BC9-8D34-1C2E74596869', 'B08AC8AD-CE58-46B8-A692-176A57411671', '5900452078440', '    5  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDA6F408-056D-4ECA-9FDF-84844848E2F2', '86A18043-02DC-44DB-ACBD-2253BCD5F0FB', '5900452078662', '     4  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B71B6F5F-FF44-4BF2-A7F0-587B8CE4B3A6', 'D29214DB-9065-44CA-AF7A-C8CAAD974F39', '5900452078785', ' .    130 (12101699)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('668FC7F0-3A2A-4CD3-A5D2-CA4E4C0DAE4B', 'E2C74269-0BE6-43BD-BE23-A7AEC3F71FA7', '5900516011222', '    10+10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F273B45-E612-4388-AE15-A9BEFBB5F3E4', 'EEAB97B1-87F7-4592-91D3-EDEA74BD0B7C', '5900516011239', '  perfecta   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA6DC463-7450-423D-818B-82A307F32CED', '6B24277F-AB1A-4E7C-B367-4F98E831193D', '5900516012526', '  "bella cotton care"  -      70 . 2 +   "bella cotton care"     70. ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45F6C31B-74C1-4E5A-B3A3-B84748015775', 'BDB0986D-444A-4DAA-9726-73A6F88237A6', '5900516012533', '   80+80 /+ /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36DAC31E-731B-4BD1-9A91-9522AECFAF73', 'D51BDA7E-A9D0-4A07-89D6-2E0741204333', '5900516062712', '    S (1) 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68AC5710-8D91-4F7D-83FD-AC067F67B412', '35CB13D2-FF64-4C09-BAF4-01931CD54EDE', '5900516068745', '   small (1) 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E63DC45-4540-4257-88AD-35CEC7824A4F', 'BE246676-ACE8-4D14-9EDD-D7CF7576E8A6', '5900516068752', '     2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7E7EC55-25E3-4309-9070-F2976ACC3C80', 'A9339E1D-E266-402F-9792-68B8BD5B8022', '5900516068769', '   Large 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA2FEA68-EC3C-4481-82E1-971C308F37FC', 'DADAE7E3-EBCB-4553-9F44-3C7C736931B9', '5900516068776', '   L (4) 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CA2262E-C17A-4F4A-9F19-B8A951E84FED', '6B1DD091-F00B-4C66-A47A-D2F407200CF5', '5900516070991', '  31 Seni Care 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97BD01F2-83DA-4B2A-91C8-0005931E735D', 'C1C8E22F-9C66-48B5-AC1B-72CB24375219', '5900516088712', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('848DE191-47FC-4EAB-A17F-C377BDF9C5E8', 'D66FFC3F-8187-439F-A2A9-F247B646E5A0', '5900516088729', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FE7AD8A-948F-45D6-B1A6-1917F099BEFA', 'F2A5A659-67EA-48FA-A933-E450AF7EF649', '5900516088736', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BC4F0ED-B29A-4D12-A06F-B0AB7C378B19', 'CD41BCB3-477D-41A3-B10D-7DAC1EC4876B', '5900516312497', '      Panty soft classic 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4D68837-3CF7-4437-A7CB-FF48428A432C', '3C1C57DA-F9E4-424E-A5F2-A3672E4D7331', '5900516312565', '      20 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FE83C8B-F7B3-473C-B399-FC0E2A229A97', 'C6BD5C6F-B681-41B8-805B-1FE0C25E04DF', '5900516312572', '     28 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E8CE7A2-7DE2-4449-8B4E-685F208FDB0A', '691B348C-DFD2-410C-8D2D-B541FBA927BF', '5900516320003', '    Regular  8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BCD2FE1-39DB-4ED8-827C-2BBC8C59D0F7', '864EA1F2-6F06-4794-B8D5-2B169068E0B9', '5900516320010', '    Super  8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('322A5500-B47A-4019-8EE7-9EF86A08C551', '882787CC-96BD-4614-8F0F-B7197DF7F440', '5900516320287', '    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('114C78C4-362A-4D2E-AB08-E551989EADA8', 'A938ABB5-B28E-47E9-AB73-90B724A3163D', '5900516320294', '   8  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6750ED4-C28E-4EC3-BCE4-F9D258B41FDF', '22846A3F-5D70-4029-BB07-BB23C9BAAD5F', '5900516320300', ' tampo   comfort regular 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6B61634-26F7-4D26-BF3D-D6621911A3F7', '0DFC603E-5200-4C35-A69D-100A543B2E35', '5900516320317', '   + 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2DC78A3-A007-4AE1-B10E-EEEEBF6491C4', 'E04C04E4-EEE4-43F8-BFA0-67B540E51E37', '5900516320324', '  tampo bella"Super Plus   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFF3C3EF-1A8A-446A-81D5-636907F7C157', '28FE0541-0A11-4204-8E1F-0F96A19776D1', '5900516320331', '  "bella" Super 8  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F5A0EE7-8D74-4521-90B6-19D2EA3E232E', 'A5663254-F603-4558-9BA3-B466CE994FB7', '5900516320348', '  Super  16 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8F4380E-D352-491F-B0BD-C1EC5443108C', 'D128DA27-B75B-4A9C-AC96-BBC2796BF7B6', '5900516400163', '   "bella cotton"   100 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D79B0EBD-4903-4E17-9618-52235B218B5A', 'BA20687A-9C61-434A-A0EB-0851773581EF', '5900516400552', '  "Bella cotton" 100 .  . . ( RU.09.02778 . 19.01.2014)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('712F2B50-DA37-429E-A64D-2880AD51F516', '8AE62ECB-88A3-46E9-B205-10094D4F73F0', '5900516401146', '   MATOPAT 250  100%   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('949E123A-75FA-40C9-AFF0-FD1825F69043', '2984D6AB-6A95-4656-82CD-7E92B22670A9', '5900516401429', '  "bella cotton" 160 ./. .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2E955A8-364F-4B6C-8D59-44EED7F44D89', 'EE3349FC-F46D-4CFE-A0BD-9EFCA98A751E', '5900516401443', '  "bella cotton" 200 ... .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCB92036-2EB1-45F4-B5E7-AF52D46344A1', 'CBD0A518-0443-4B50-A7BB-96F4E27F2183', '5900516401504', '     120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ED2596D-6556-43B6-ADEB-B1401B0AA874', 'BDCA8DA6-823C-488D-82FB-1FF4D80DEC2F', '5900516401535', '     40 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('091ABB79-C9A7-4DCF-A900-15CDE0DAC359', '05868BDD-8C40-47C2-874A-4C74E4079F9C', '5900516401566', '      70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7012ECA-5FED-43EF-90EA-49B3922F8838', '75B40260-D6C1-41CD-8847-D47EB8AA3AB1', '5900516401573', '       70. ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0370E7D-55E7-454C-B410-E87779328843', 'CC2CAA7D-FEA3-4380-AADE-33E30D1FCBC1', '5900516401658', 'Cotton    // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFE2BE4F-EA55-4988-BD90-16BAB16BB44C', '879C1922-0A70-4D5F-B6E4-B291AFE84B21', '5900516401672', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12B0697B-3716-4263-80F1-3B6494F17CD5', '33EB87CC-1F65-49B0-8F53-18AB9819C7AA', '5900516401696', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94DA547C-619D-499F-8B6B-91C49A71BF82', 'E9A97AD4-C304-4152-8F9D-8552ED2E731A', '5900516401702', '    120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5CA9FFF-8870-4CB2-B332-2AFD89980461', 'FAA723AC-280A-49D0-B8BB-48A768231502', '5900516402051', '  "bella cotton" 100 .    ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C305A450-17B6-4105-A734-9E83EA45ECEC', 'B16D1BED-ED8E-439C-A304-E87A69AA6CC7', '5900516402068', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43890A88-DEEC-47BD-B1AA-4298681A5F5F', '72E0750B-4D23-4653-91F5-8935D168667E', '5900516402075', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3BCE3C2-4139-4E3A-B5C3-F7CC67C1A5CB', '82C16032-068A-444F-A87C-79E647CAD21A', '5900516402129', '   cotton 350 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6179CD2C-8D16-4DE4-ACD6-4FC4DB0C7F54', '3F4E75AD-EF25-473F-A2BA-EB079228B719', '5900516402174', ' 50 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF47E17B-694F-4A6B-8587-197FA6737D2C', 'BD1091A2-F42E-4892-A4AC-2BA07CFFC8CA', '5900516402181', '   100   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E93DFF8-8D03-494F-8D9B-79DB608D4544', '2E5615D5-9B3B-4BDF-B5B4-570FB706B7F6', '5900516402211', '       100 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18AAFC56-65A7-4B47-B342-B196E29DF6B8', 'F2E8FC72-DC3D-4779-8D5B-A6071729E9D6', '5900516402228', '     /- 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F307CA5-3DA0-47D3-8A3A-F6D6F07E3F90', 'F2E8FC72-DC3D-4779-8D5B-A6071729E9D6', '5900516402235', '     /- 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A84E81C-B149-46F7-AB01-D1E1E7038F62', 'B22D2282-0E63-4522-AF0F-F1AD13143CFA', '5900516402259', '      56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('271BB8B2-0560-4779-B96D-1C52838E14E8', 'E6E97DDA-513E-4B68-BCF7-F414434E3B5E', '5900516402266', '    .   56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5FDBAE3-E1AF-4657-8CDA-075D306D6A50', '4D73C84F-2C4A-4884-A96E-5589909E7307', '5900516402341', 'Mamma    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03B28E65-89F9-41B7-86A6-6E1A0077D26D', 'CC85FDFB-1E94-483D-94B0-D46D101CF581', '5900516402358', 'Mamma    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5DE0F8F-BA7F-4819-A82C-6141B31B5133', 'F58593B1-C095-4AC6-BCB3-FD58A349E14E', '5900516402419', '   E`Vita" 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8D4BCA0-6076-4B35-8A87-9CD13E7A1536', '0D6AB5D6-3545-412D-ADCE-F44692314AD8', '5900516420635', '  "Seni Care" 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71DBF453-E949-42E7-B586-BDFD572384C7', '60A1961E-C299-42F9-8F20-4168DE47028C', '5900516420642', '  SENI CARE 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B51120FD-4B80-4E28-BBD6-704D8C349986', '5AAD71C3-9625-468C-BF57-B736E4BFBB6E', '5900516420703', '   /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADE4E9DA-3591-44FD-B088-F83542004D8E', '5A5461D6-A78E-4D00-A14B-5BC63DE1E44C', '5900516420932', '   "Bella"  10 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B0FBB71-B4FA-4B7C-A87E-98E83FF008E0', '2EB04643-3E9C-4D75-A4AF-B60C33D2D167', '5900516420963', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('349E2D40-528E-4E89-B3E0-707CCC307709', '6E12B6E8-9794-4BCE-8BF4-B3D4CDE517D9', '5900516421076', '      Sensitive (   )  68 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AFD5005-C55D-4290-85CE-E52796281663', '7D745446-CF3C-4F67-AA7E-F16DCC97BE21', '5900516421120', '          64 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED854A5B-0937-4F54-AA12-F997EEE96B72', '74043932-4E22-499D-B8F6-18DFBF9CF4C3', '5900516421144', '  baby Happy "ظ  " 64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E6A8DCE-4EEA-4C69-BD61-2EAA65F552D0', 'D2541938-5CD3-4A81-96CC-EFFF12967980', '5900516421236', '    . e    48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8DD1533-D3EA-4D5F-9791-F9DA4F52E0F1', '3E7EB3BF-B917-4A76-AEDD-403F0CD0B199', '5900516421618', '   (   )  68 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('140114D9-1F5A-4E2D-9F78-3B63DC500CAB', '9D3E7374-1EEC-43E6-AE22-BE058FE4E22B', '5900516421625', '   1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CADC0028-CB51-481E-8445-30380CE35927', '499FB24D-C3B6-4E18-94E5-42C762DDBE91', '5900516421632', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D814078-DE98-4B72-8B9B-DFD6741452D8', '5A6F74B1-4767-485D-B9CC-A85FFDECCBBE', '5900516600181', '   5-9 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('766E2C68-B708-4B4E-A50A-8345AEAA2F90', 'B1EB0B77-7646-4BA8-B015-EC9D28DDF60A', '5900516600198', '   8-18 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84E07A43-8966-4B12-B210-B1670CD7B842', 'AB9AE122-2511-4C45-B1CE-698FD524501C', '5900516600242', '   12-25 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF58908C-774C-4312-8367-83D8BF26A101', '18B17230-0F34-40A5-9468-22EF0D30457F', '5900516600365', '     5-9 13', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE1E0A2B-DAF1-4B23-BCFA-261CC960D5AE', '4A945752-8492-4BF6-915A-561442132612', '5900516600372', '     8-18 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A8070DC-65E9-414B-8C9A-886269345EAC', '4725C22B-87E1-4784-8B27-8DB82F3209FB', '5900516600389', '     12-25 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F715F20A-B3F0-4E7A-BFDB-5E98ABE034E6', 'C6D6EBC3-3047-4242-A656-80EB44D1BD8D', '5900516600631', '     6090', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D7B34E0-BC39-4049-85C6-2BF9C15386C1', '36919F15-B6C2-4054-9EDF-35156E09EF03', '5900516600778', '    5-9 32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E74A890-3F74-4190-89C0-B0E9DEE4396F', 'A0BEA5EE-2D4A-449A-8875-CAE4C959991B', '5900516600785', '     8-18 27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12263C21-8B79-47A6-A93B-D8F859D40D85', 'E0A33DA4-98F7-45FE-BC8D-59187B99AC10', '5900516601140', '     /9-20/ 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D1EFE5B-F807-4376-8070-49FBF8DBB98F', 'E9B2FE40-4280-4796-B2A2-DB6A1DD3BE23', '5900516601195', '       9/20 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA87B01D-7254-47E6-846F-3CAB66DA83AB', '5DC4E543-0E40-467C-A15A-A61689557216', '5900516601225', '     16+ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A63A730A-4F42-4E11-B725-DB7405A44DC9', '6CD9708E-AD38-4D78-9DCD-DAC26D65B85F', '5900516601232', '  "bella baby Happy" Maxi Plus  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1439FA4-2798-4C3A-8724-D5081D41924E', 'C06227D5-7719-4F04-B716-6BDE779FA93E', '5900516601270', '  Bella Mamma  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('932625B1-B3E9-49C0-B77E-9BB198BFD9CC', '737443C4-517C-47DD-9897-E47C7DDD885F', '5900516601546', '  Panda 60 x 60   10 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEFCAC03-7C9D-4872-8D53-7D06D71D111D', '74F39BF6-27FA-4892-B40D-D15C7F5D3250', '5900516601553', ' "bella baby Happy" Newborn  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E44004F1-0C4B-49BA-AF94-5126F96A909C', 'F21F6329-59AE-43BD-9698-54EEA96678DF', '5900516601560', '  .2  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A5D5D69-7798-4779-834E-4A59C0FA77A8', 'ADC90C7B-BEEF-4F52-82FE-F6102C2AACBB', '5900516601669', '   60 x 60  10 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4B5CB6D-8C04-41D6-954A-A5E3143DDC87', '29FF80F3-14D9-46FD-88B0-D19D498E95DF', '5900516601799', '  / 0-2 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('211523EA-8C48-4D7F-818F-034310F7C9E2', 'C8176500-B3ED-459B-AB06-8159CDCB5600', '5900516601980', '   6090  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('019472E6-414E-4339-9E92-7D3C14A7DD31', 'B3D5809B-89CF-4E97-A06B-6673AE7147C7', '5900516601997', '     6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9225E79-DD67-40F2-B310-594699A0D03A', '564EE5A2-4B11-404C-BF1E-EDA65A37E75F', '5900516700256', '   10c  20c 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52826BD8-0D3A-40A7-A552-E2C02D7F70DA', '5C22002F-82B2-4A70-9F27-60301A8DD40C', '5900516700461', ' ,  10cm x 10cm 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE619FCD-ADA7-4BB4-BE6D-FEE6B54947FE', '47D06403-7D9C-440F-87DD-138224CFAA3F', '5900516700478', ' matocomp . 7,5*7,5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18157821-0CF9-40F2-881A-600504848050', '95980D34-6EC9-412C-8FD4-4719E0255426', '5900516700539', '  matopat matocomp 7,5*7,5c 12 17 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C810E5E6-26B4-46C9-9F4D-6D59F279953E', '2C095AF3-DA18-492B-A49D-2CD7FDAC37D7', '5900516701093', '  10*10c  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('262EA08D-D994-4635-B9AD-8DB5795BE710', '7AF3B8F5-1260-46B3-ABD8-C7D6AE9C28DB', '5900516701499', '    5/5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B05EEE80-4061-4C88-8B4B-F9CE641DE11A', '7BBFEB66-0D80-4EE0-A6FA-3F6818728723', '5900516701642', '   77 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A13C310-C5C2-4749-B3D0-50DBEC9AA1B1', '9844055B-C6CC-4ACE-8ACD-77FB990F6E1A', '5900516701659', '   99  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2E5B561-282B-4B77-8BE0-764E77C4A89B', 'A701F7DB-4097-47E2-8525-B90AF3893E84', '5900516894092', ' "MATOPAT" : SPECIAL  12 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2891DC4-2E74-4AD5-B8DB-A916D2F4AF91', '343584DB-51D4-4EFF-A713-F33BDCC3398B', '5900516894122', '   6*0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57DC92DA-6D2E-4126-B07B-05C368BDC905', '03041F64-AA35-4325-9716-0EBCBB4ECB03', '5900516894603', '   .. Surgilex Plus .6. 50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27DF87B6-DE21-428A-81D5-D38F2FF61B01', '2EAD5226-F50C-41CD-9EC4-3DC983DDAB20', '5900516895891', ' M Plastopore  . 2,55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A71230A7-D59A-487C-B331-2CA06DF33718', 'EAB25D76-0206-4579-8997-6ADB65B26AC2', '5900516895952', '  2,5 x 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('890A42A2-1A3E-45AA-A68F-700ADD66B16A', 'C92F987B-E948-4899-8982-CE0366B7B54E', '5900516896096', ' "MATOPAT/./ 2,5x7,6 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('446FC45D-3AC6-4E1E-9661-68A50D19E6CF', '4D4070BF-C2D4-45A7-99D9-EFE706A868E2', '5900516896546', '    2.5 x 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F052A888-6616-49C9-915D-CDE2C8622EC1', '88D3251C-EB04-4505-BC78-8AE263471015', '5900516896805', '   17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('549CEA03-F065-4CF4-BB9C-F426D6FCCC4E', 'C290292C-FB67-4E33-8DF6-3DC559952898', '5900516897802', '  Absorgyn 27  7.5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43CAE05F-AE8A-4442-9F91-1C65EE02ED89', '8A22B952-4FB6-409C-9575-EA1CEBF09864', '5900516898359', ' "MATOPAT" : HAPPY TATTOO  12 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E15FDBC6-2C29-4DAC-B14C-491F348BD84F', 'ED538E55-0C5D-45C3-B08C-741918006399', '5901234123457', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36B2C124-51C9-489D-B6B0-B7395D70050F', 'DC4640E3-49F6-462F-9C57-68EA052B5EA1', '5901478905031', '  .  10.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B615093-9CFE-48AD-9684-617EF477F88F', 'FCE16F77-734F-40BF-89B0-09223458F6D6', '5901478905079', '   10.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BEB6221-29E0-4ACD-8BB3-CB9F4C593BF9', '26762D69-FC29-4CE7-9103-9177AF6F6704', '5901478905192', '  kleene  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B7D77EE-8858-4310-A09E-8787D6CFFD95', '55B16902-812B-49F4-8249-5AB09F46070A', '5901478905260', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B385BCE-55CE-4888-BE27-4064D122632C', '8C66D9DA-A705-4837-B425-1D7D84424263', '5901478905277', '     1010', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('016C8154-083F-4DC9-997F-4C0A3EBB22D7', 'B40D86AD-C14A-4632-B9C1-D0429FB32132', '5901845500210', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AA4BD0A-5E29-46F3-B2BF-8A70681FED58', 'C2C720BE-FC2F-4CB2-817D-1078B6A4F140', '5901845500227', ' elfapharm  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22994DE4-31AB-438B-B636-F54CFC071817', '0BFDC8E6-C3B8-4FAC-8CED-4CE8888FAAC0', '5901845500579', '  7   71 /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A01DCA4-680E-4538-B65A-B43A267CC9FC', '4D2FA65D-E008-40FA-9301-30F0E96BB937', '5901845500593', 'Elfapharm 7    71 /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED907399-71A8-4920-ACD7-3391F133179C', '0D9C4555-B51F-4BFB-9D95-036117CD2EA5', '5902020672074', '  75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0AAF1E4-E377-41E6-A82F-2B11AD782FBD', '9F5025B5-29B5-498C-99E9-46C7008DBA32', '5902020672081', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3EB33C0-35BB-4A19-BE56-019F9629BE56', '783A2C84-650C-49CF-8E47-0B2441758C15', '5902020672098', '  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4315B414-C2A0-4814-9B69-21704EEFD7FD', '3CD9139B-C160-42C1-8E88-8D46BA9760D4', '5902020672104', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12AEBEE4-9482-4EED-A7ED-5581973568B7', '2E456B12-FA82-45F1-B353-1519C12F94FC', '5902020672111', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6A72FA3-2A60-4763-96ED-1245AD24F5B9', 'E0AE160A-CD30-4D82-B48E-6DCE4EC56D1D', '5902020672128', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D36A744F-DD50-48AE-9206-C0A7BB6D8BF0', '0992EC18-6B0A-4BED-8A18-448A7F481842', '5902020672135', '  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74F34D47-65AA-4461-BDE1-A8E13872AA3C', 'A1CF1E1E-1C9F-4C67-881F-E9AE74AF4CE3', '5902614121063', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A43F618B-D803-4229-A6C9-A7B9E211B23B', '9E0D3D27-05D6-4162-8B59-23D5DCA3E352', '5902626311964', '  /    7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('322A2C04-2555-459A-9E2E-A28E3934E0CA', 'DA444C87-A174-4923-B779-13E06B30C201', '5903060000841', '  2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F0B3CB4-83AB-4611-B9AE-6A37D824E557', 'E1404515-EA7F-4F19-B3D9-74E42105297F', '5903060000926', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5132300F-CC3A-472E-920B-A3B77301CBE4', '73CF5479-8036-4AC4-A4E1-1C6E7760F680', '5903060003002', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DD624DD-277A-4461-8A31-06468DB124F9', '5511DD7D-0902-448A-A079-5C47C96DC42D', '5903060003101', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46F154E8-D913-46FB-AA80-12E07E8C9E03', 'E3C04F5A-8111-4AE4-B4EE-0D7FF7F67977', '5903060004269', '-   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70A8BD85-90FE-4DF6-82F9-346B0B9BA624', '9F994398-6230-4186-9DFE-5C1E0B2E5483', '5903060004542', ' 2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('097E0CE5-FAE9-452D-BF91-10B328A93346', '1D3E9C05-1BD1-4581-BE64-CCC80D8074B7', '5903060004566', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4D304AA-026F-4B5C-BD7C-0F8233F5C2FA', '66D7EAE3-5A70-4322-BA7E-D19ECC3AEA69', '5903060004665', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBB27048-9AE4-4A9F-A060-9CF182233400', '3B1EC476-4305-486C-9A10-DAD375979327', '5903060004818', ' 10  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C334A8F-42F0-4D60-B117-72D70037FDF1', '12043C16-5201-47EC-A352-40FE3A9BC367', '5903060005112', ' 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E065B089-B870-4FAD-B0C7-22BE72BA09CD', '239D1874-D90B-438A-AE70-BF47C8F9C1D8', '5903060005129', ' 50  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7FEFC69-7FCC-440F-B140-FCFB9628F822', '2F1A3A64-CC4D-4215-8A6C-1B0E4C4DAFF0', '5903060005136', ' 100  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1338C68-FAEB-43A2-8606-DD03BE0EC88B', '165123A3-77D1-491D-8382-BBCC737186A0', '5903060005143', ' 100 //.  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C344B1D-C295-4B35-B1E8-A3DB4E3D0A82', '335D4EA8-D4A0-4D50-9623-D0176CDB92D5', '5903060006119', ' 500   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48946CE1-8F40-4E3D-9D2E-89D9801B316D', 'AF7CB2A6-EC0F-4541-B445-DCF9617B9C21', '5903060008922', ' 70  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F9D96AD-9F4F-40E5-88D9-B406FEE3D13E', '2E61D629-DD66-4F43-9737-174CD5F698F2', '5903060009233', ' 0,05  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5384BC5-D96C-4D74-9828-96C039816944', '610B79A7-693F-4E8F-9C6B-0B36EB8D1FA0', '5903060009240', ' 50  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0075CBE-7A5F-4E6F-9496-622F5B04E27D', '96D9189C-4B53-415E-B5F4-C47E0536E12B', '5903060009257', ' 0,1  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B31B16E-FE8B-4161-AC73-C85DE4D2DF4A', 'AF6A6E5B-AE28-4DFD-8DFC-CA8CF566E3B7', '5903060010789', '-  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30149B68-AE40-4689-A08C-B29EE6583891', '54D4E9CA-4D08-4917-BCF6-7C7FEABAE875', '5903060010802', ' 75  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F024AFCC-A0DC-46BB-9FF2-64DDA67983A8', 'BAA18514-8CC8-4285-9AF7-A5F319EE82E5', '5903060012776', ' 10 1,5 / -  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50E9D37E-0A0C-4EE0-80B9-A9D31EE22420', 'B09094CF-A167-421A-9FFA-5DD988F3765A', '5903060012783', '  10/  1,5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E337C264-72A8-42D8-8444-108BB41E9FA0', '766CF8BF-AC5C-42D8-BD01-656A18C3D61B', '5903060013674', '- 120  42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14C03458-DA6C-463B-8A30-8BD13F87A271', 'FFCF150A-771C-4F8B-85DA-241D39DD05A2', '5903060013681', '-  120 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C5A38D6-35A5-46B7-BCE0-6CBC00D33B55', 'C42CD48E-5EB3-44D0-8F6E-51CB550F2589', '5903060016361', ' 2/  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2A1D328-2B68-4B76-993B-280B0829EDC9', '654310C3-90A2-4547-95E2-E3DDE91D84E9', '5903060016811', '+ 80+12,5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('058AACB1-45FD-4A84-A436-3F3038EA3504', 'DE2F8DD0-E237-410D-8899-E50D5C8D46F1', '5903060016842', '- 160+12,5 28 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD3E3319-D5CF-4C65-9E97-6DC76E7A8844', '9B7F86C7-97C6-4304-81EB-7343BB2630DA', '5903060020245', '  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2CFBFB6-5523-4835-A56F-365D6DA3BFC4', '0C82D8D5-CB19-433D-AB7D-6BC7D43308C6', '5903060020252', '  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('785F4C36-594F-44B4-ABD0-0A1A759B5B3D', 'A7B81CD1-77D5-4572-81CF-361E5040F8C9', '5903060022430', '   3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C311ADE2-A5AE-4E3B-87ED-2016D5B05787', '5D2C856C-0FD9-4B70-A854-5F5779489A02', '5903060603844', ' l  3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A28CF4C9-CEEF-47E8-9DE0-74A73EA57E8E', '17F31259-54E6-4386-8DC5-4D2C80984305', '5903060607071', ' 16  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29BBABF2-1CD2-46F5-902E-83A53916081C', '15B384D7-5441-42D3-BD49-343EF48ECE76', '5903060607088', ' 8  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE7BC3C7-DAE2-41B1-A978-B26B45A10D74', '8B64DC10-EF92-4D8A-A366-0364E2585EA3', '5903060607095', ' 32  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C95A9D0-90E2-47C3-AD69-C092E40E4D6D', 'EA8F12DF-B023-4805-8DC6-28FC3FC6871C', '5903060607286', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE22AB96-3198-4094-950B-A95CE446A576', '054FEBF4-8D14-41E0-8344-1163A0C956D0', '5903060607293', '  25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AD1B8E3-17DF-42F1-AAEE-8049A9AC2703', '07ECF0E8-5385-4A2A-85BB-E4C97603AA04', '5903137171023', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DED2595-54A4-4755-9C50-7328630D014D', 'E5697727-76D6-4B5A-8936-4BF0B2045CB4', '5903137175014', ' 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7F24B8E-2EA2-4A38-8E41-F86A96B6A43A', '971AE1C5-AEEA-45B4-9513-BDBA507032BA', '5903137175021', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F526455-853D-4241-A7F8-6909AD04175E', '62B3323D-BDB4-43ED-8B7A-E33D76F21853', '5903263245728', '  /   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D602AAA4-24C5-4DE0-81E4-8E7D847611A6', 'C0F38D98-0C68-4777-BF8C-17292BB18C5C', '5903263245988', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('976412FE-0AE3-4052-AA84-BABD8610E1D0', '4E129719-B5A9-442A-9223-F812757E2FED', '5903263245995', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19530D8B-FF0E-4B30-B38A-31EDFC438B3F', '7C4CB005-E99D-407D-B815-44A8C3E89417', '5903263246008', '   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43512574-81A2-4AF9-A6C7-FA85338ED2A9', 'BD5BB795-BDAB-4794-ACDC-073BBA5216FC', '5903263246015', ' / 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3EE4753-1995-49E4-83AE-9968ABD37007', '4109549C-A1FD-40F3-91E0-2186EDECFEC6', '5903263246022', ' / 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C31075FB-C9B0-436F-8D81-520C49BDFB3B', '4854010C-5D6C-4F51-9581-7BA9F5C7FFF0', '5903263246039', ' / 200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D67F7DA4-2CC8-492C-98B2-EC34694532FD', 'F3D8E1CF-8E83-4F1E-A4E1-5513BB26F6A1', '5903263246466', '    / 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAB33E77-6226-4576-A544-B1F391993FF8', '269932D0-CC3C-4A71-99FC-3D35973F54FC', '5903263246473', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('366BD14B-07F7-4CED-A0C7-A1F9711FFC55', 'A5412E0B-4FDE-435B-872D-CA6F1050F13A', '5903263246480', '  /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('334AC224-D170-402F-8887-17A97185C067', 'CA315A23-F41A-4359-AF05-BF1AFCC02DC2', '5903263900450', ' 2,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79190578-E56F-41D0-8BF7-D0623D7F0321', 'CD2B2D01-0763-4AC7-A5BA-6DAB20C74B56', '5903263900467', ' 2,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C422BD3-78BD-49D1-B621-D75D627D14F7', '9E1AC090-197E-4BC8-A7CA-70AB1E12BFEB', '5903267902498', '   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15D000A0-587B-4A46-82A2-D4832C44A0FD', 'BF6562E0-1B6C-4CA1-A398-680DFDED0E27', '5903407022048', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76057A5A-6C3B-401C-9497-453D75A0951C', '869431EE-F70E-4F47-9C10-C39D3A56ACB4', '5903407022215', '  2/221', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12CBAF6F-7DD3-4BA4-85B9-CA52F617FD7B', '027BCABB-1C3E-4C19-8DFF-6BEA59366031', '5903407022246', '   +0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41442EE8-248D-41DC-9549-0F1E1301C6D7', '5D9B16AB-2363-4DCC-93A1-495167C62B48', '5903407024103', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9EAE451-F483-4F3E-A9EF-80A8C402F5F9', '90122CDF-852D-42EB-A90A-FB71144C652F', '5903407024134', '  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED61BDF8-AFD5-4660-A6B3-E2F51423DB85', '24FDEF8C-37FA-41C8-8404-4A4D1B28A6AB', '5903407024219', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A63F2066-BB55-48D3-996A-FD564A910851', 'CC602BCE-AD77-411F-8A85-F15F3C7D73DF', '5903407095011', '   9/501', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7F1DA40-AFD0-47D6-918E-67537962CCB6', '3C054ED8-7523-4364-9F5D-B3BD6FB8A9EC', '5903407095981', ' / m  - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDFFFBE1-C895-4450-A83F-363A4F44B252', '3D5BB7B1-FCF3-45FD-A511-E26E8D09F04A', '5903407095998', ' / l  - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19A6E028-4015-419D-9135-633F892FD73A', '9D41E250-8385-4572-9234-195B0CD94F21', '5903407096001', ' / l  - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E546DEBC-1FC6-45D3-8B82-7A28D9B6E319', 'AF87C0E8-29A1-42AF-A523-65EA1639AB93', '5903407122014', '  hl-0631 easystart', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB38F374-1B1F-4C1A-AFD7-D36334196F4A', '9015D748-C684-44A7-8DD7-07397DB29172', '5903407186023', '     s 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B71664D4-365C-45F4-8CA9-B32E316EDCE7', '4F849C06-DEE1-4B7F-94A0-076214BDF6AF', '5903407225005', '    0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D66FEEA-A729-4DFA-966F-CA9229DA7601', 'F8082F27-3B7E-4CD5-A45F-C211F8C0A41E', '5903407225838', '    pinguin 0-6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('105A92F1-B327-4997-B696-3A0498506D40', 'B82E06AC-060F-40E7-80C9-58FC653D10A4', '5903407225937', '-  animals 0-6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('667C11D4-BE1D-4358-A1D8-D17847E46E09', '45169112-FB8C-47D9-A797-CF0761C060C0', '5903407225944', '-  c  animals 6-18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEF960EB-B311-4D99-B144-0CA8364399AA', '5B49FBFF-B15A-4F50-9E98-3412603096D9', '5903407226163', '-    moonlight 0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ED785A9-7215-44B6-9F5F-7F61F2DCE09A', '0450A638-8145-4C1F-BB42-4E9F20D2874E', '5903407231013', '     +3 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15C01C89-75EB-4CE4-99F7-1B4F90D64E19', '4E81037C-7296-40D6-B717-25E0082D9ACA', '5903407315003', '- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71FD7388-1481-4E2E-9821-A3DE995053C3', 'A84390A1-A8F3-402A-8C7C-A9B35D0CF223', '5903407431031', ' /+0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5E08CA4-BBC1-4C34-A26A-92D92838CD4F', 'E5DA320F-7F43-428A-A1FC-0C7825905589', '5903407560076', '   /19201/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CD406CD-0403-427D-B3AE-6E72F42A8044', '11DCFA78-4DB9-49DF-B1EA-8D695A98697C', '5903407561059', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E541D00-4E0E-43CB-9760-6CB59D42ACF8', '5615036D-75FA-47E4-8ED8-69124FCDC05A', '5903407780016', '   /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EB8059B-8D64-432F-8FA4-158FB8744BC5', '7CFC0024-9B8F-45A6-9AC3-36A31BF923A5', '5903473000827', ' 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('177FD699-EDA2-44FE-95BD-6C083BED0DE0', 'FAD1BC99-E7E4-4652-BD81-64C03F9518A6', '5903473006249', ' 0,25  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7C01544-FD5B-491E-89F2-07ED49260C35', 'EE38259A-51E2-4517-B820-11B4C6808C4B', '5903473007048', '     25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46535CF8-BCB6-4B9F-94A9-D1630A8A697B', '0BAFA0AA-D74C-46A0-A798-CEF5078C0325', '5903473009363', ' /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BAB40A4-B584-4DA8-B45A-E507CD338583', '5BEF80ED-A026-4799-B2C8-F54E6C22CE86', '5903473009370', ' /    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9BB8430-7BEA-4539-A71D-A6E29C32E897', '874DD0CC-8412-4B0B-8F91-7F1624DBC9D6', '5903546001423', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('947C950D-2CE7-4A84-95EB-6B62B57AEBE6', '87B645BC-7B6E-4E38-9777-197CC25015D0', '5903546002833', '   20% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D0D998F-4359-40D4-81EC-F17FA56A20E7', '1E234B1C-A9EF-48BC-AAC3-DD13039EAFF1', '5904016040553', ' 300+100  55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38E27E32-D2E2-4545-B97B-CFE311247916', '0C09129B-E45F-439D-9CF1-0811A11D3A07', '5904016040560', '  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B08525E-6F46-42F2-9090-2E404036B722', 'F305FB35-C454-4BC7-B316-5050611B3640', '5904374000428', ' 200  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66325D3A-6123-4D7A-92C1-F88DEF68846A', '5A7B3F55-13C4-4891-A53B-F8E4D31E29E4', '5904374000435', ' 200  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EA689BD-385E-4B0C-B936-AB82D77061CF', '9D01558B-66C6-4736-9C15-0D24D0D1FDA1', '5904374001586', ' 200  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1730CA30-6D7E-4585-84CF-D341ED5C8D69', '779980F3-40EF-4502-A857-C682616644D6', '5904374005898', ' 0,1  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2820B7B5-4332-460F-8D0E-387AA621B1F1', '41D3A7FF-8FD1-41A8-9DDD-4E83AB103C67', '5904374005911', ' 4  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA7D52EE-60F3-4475-BD99-73A156987B0C', 'C953C234-2682-47C6-B5F8-5DD2B95291B2', '5904398140025', ' 0,2% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E94F5B18-53C9-48C8-B53A-221254AF04DE', '56C2932D-9551-44B8-8D2A-612446091B97', '5904398248028', ' 10  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('776BD167-59BD-49BC-8C6E-CF4FE38A5511', 'C617D7A1-C9E6-4EB1-A8AB-3C65C2123564', '5904398267029', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52B3D567-C52D-47FC-A206-5CE75B7CE881', 'D2BAF1C5-4BFD-4E5E-B3BF-5448BA3F2106', '5904398401027', '  2% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE802E96-BA0D-48C8-87A3-690A847E732D', '64F915C5-2360-4399-BA95-FFF32797EB30', '5904398408026', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB6B3E14-BC05-4E84-AB89-FCF22FC543C6', 'FC2D8C3A-6205-45A6-B3D8-7B4191EF6F84', '5904398418025', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10B01A3F-B48D-41D3-BBD7-C5A830EED3EC', '9FA3CB95-1922-4E79-9191-EA21254569BA', '5904398420028', ' /. . 0,1% 20 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33ADF857-99C9-42DA-8329-E8A507079D83', '892912AB-BB8B-4449-B36A-FC0EA41BBAAE', '5904398425023', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57D9BB87-5FE6-407E-A271-A21D2FC5D39E', '58D1B3ED-1FA8-4275-9084-D9A2806DF466', '5904398427027', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DCF92ED-E39F-4D32-B696-CD53F504CE7F', '919438C4-47E5-4382-88EB-2C9B58D492B6', '5904398440026', '  3% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11A8499C-6349-4B33-B3BF-733DE31C1D78', '7CE8D562-B465-4741-BBD0-042177F59774', '5904398445021', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A00D075C-992D-42AD-AA90-C2BFD2BD1518', '7B5C3C9F-FFB0-45A4-BFDF-75846997ABA8', '5904398452029', '  2% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFCB5CA2-E23A-4E7E-B6E9-C0C3BA89332C', 'C2EFE246-438C-49F2-8117-141972F18E1A', '5904398455020', ' 0,025%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCE9F6E6-4CB5-48A5-8784-2E4490B2421B', '85BC69E8-21B7-4F15-8F9D-955EDB6ABE00', '5904398457024', '  0,025% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('744CAA20-D6D9-4A55-9365-2CF6B6C0B874', 'DD3655F9-47C0-4FC7-A0B0-7A1A8E451975', '5904398458021', '  0,025% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DC2A378-78B1-456D-AAA6-744DE8143078', '1011211B-5997-4111-A476-21771F280C5B', '5904398463025', '   0,5% 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E8540AA-5AC1-4174-8007-1B27D555F55A', '2845ECED-4359-4213-980C-780D55996813', '5904398471020', ' 0,05%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17321022-53E8-4C4F-A059-135FB2E70095', 'EF682747-9C96-4187-B1F9-4C9D83F61626', '5904398472027', ' 0,05%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('496BE067-0049-4B1B-B3DA-5B161CC67AAB', '7CA1B5A4-22C6-4B3F-BFCB-44E0D70233A3', '5904398474021', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17563095-AC0B-44B0-A972-74424B9B3892', '18A2A2DD-1634-4BF1-8CE8-4AD2DF401297', '5904398475028', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FB4158C-0E00-479D-9F17-9B7BB6D9FFB8', 'E386F6E8-3336-4C59-90EA-5924193BBFEF', '5904913544123', '  -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E4589F6-9A6E-4191-8FD1-C81FB5D07435', '966C0A3F-748F-436B-9F47-86B05C324C73', '5904913544130', '   4,6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E83A81A5-948F-4EA7-8C55-22F94E12C8B4', 'D8903D5F-640F-4240-8680-C7A096E0FF83', '5904913544147', '   4,6', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04CE0A0A-8DF7-4EC1-8212-1726D68FB40D', 'A7F00453-F923-4F70-99F5-3CEDD5D9D334', '5904913544154', '     4,6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD61A30E-957E-4556-A01C-975990531F83', '2B3AB807-AF50-4A99-8493-B0C542BE8A78', '5904913544161', '    4,6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77EEAB22-40BD-4A5E-BB29-014863598113', '4D080BF7-A68E-451F-B9B3-2E4B12875CF5', '5904913544178', '   4,6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D9EC3A1-72C2-403C-B4AD-239B3D0B5AC6', 'E386F6E8-3336-4C59-90EA-5924193BBFEF', '5904913544659', '  -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC7B8333-A39E-4E6F-B4B7-7E899FDB37D3', '0DF6D224-6F98-4D52-900F-E4FB0235DF4B', '5906615132295', '  , . /6-7/ s', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ACB4112-048F-4620-8D62-5913BFDACDA8', '97B257CF-2AD9-4B45-8935-0B7014FE062D', '5906615133292', '  , . /7-8/ m', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8056FC5A-E67E-4DE0-BC77-44B7426428FB', 'BEFE7136-D4EA-47FA-9A1A-46725449143C', '5906615134299', '  , . /8-9/ l', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C47AE36C-C4F2-4B18-8470-CA0AB6E5D85F', '51EA40AF-E4E3-47C5-832A-EAA8577441D9', '5906615303299', ' .  / . /7-8/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F9112E4-9A58-4D3A-83C1-EB6DAAC50480', 'F450AFCB-5405-44C7-9E66-CC0B603E4E70', '5906615324294', ' .  /  . /8-9/ l', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4CD4615-23AE-4BE5-B8F3-33024811F6DB', '818A4D17-17DC-44BD-8BF0-5BE5F0D084EC', '5907529411124', ' 240/5  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('598BCB85-7ABA-41FF-961E-BE382C4B7C44', 'EBFE6EF2-4BD0-4705-8593-9DF0A54A1CAA', '5907529416822', '  2,5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0429EECD-2E58-4EB1-A205-CA4E1B2920E0', '19CEF132-FF9B-449F-BDE2-7AE15B1072DE', '5907529416921', ' 2,5%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1166070-C81A-4ECC-A593-3A0621E56E3F', '584061A5-7C17-4BF4-BD8E-32DDB691991B', '5907529421628', '  200 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9729B86F-1F8C-4EE8-BFB9-491C0B05F139', 'FCD47B8A-AA48-4A60-8912-98ABA218D366', '5907529430002', '   100 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F82419A0-5D81-4B8F-B21B-3D0AD2602CD9', '24F3B661-1C02-4817-9127-8A0B4B1C188B', '5907529430019', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00FEFBB9-F2D3-4B9E-89DC-55A1987D2D6F', '35D3A9F7-417F-402C-B28F-626690D40835', '5907529430026', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0386837F-778D-4E62-BF32-403110AA4743', '9A74058F-4262-4980-B90D-3EBD5C6A19DA', '5907529430101', ' 3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E73FC69-20E6-4EAB-BDEC-ED30F57F5C3A', '5F5327A0-7ABD-4600-B5D1-8515BE633E8D', '5907529461211', ' 840  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('108F0576-AB7C-45F6-A1B6-A8F58BB7582D', 'EAF7AFAF-4DC4-41BA-95FB-619CA20DB3F9', '5907529461228', ' 840  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('720FA233-7848-4DC0-8AA9-325F96E35A8C', '23211855-4C77-4CF1-BFB1-0A6E1925FE17', '5907529463604', ' 2%  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6095227-33F7-48E6-A1CF-9678EFA0FAB0', '340608CE-113E-4ACE-8DFF-9EFB4DDD24A5', '5907529464205', ' 4/5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D239935-4C52-4666-AA6A-6127B32D1A5A', '84DF58DA-7D1E-408C-93B4-812B6E74326E', '5907529464274', '- 0,005/5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('455A71DB-66B9-47BD-8511-0EF846F52B11', '8491DDC1-D6AB-4716-988D-5D908681D981', '5907529465110', ' 2%  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AB001DF-6AD6-4180-B620-516BF73760A3', 'E853E90C-A8A4-4E62-9318-A43862186702', '5907589822700', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FA60993-034A-454E-AFB8-53FF1FE4E8CE', 'E0852464-024D-46F4-89E0-68F699636121', '5907594021600', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B11EDB5-1926-471B-A05E-6FF127916B2E', '82A00215-D11D-435A-8C98-3E926348E4D0', '5907594021808', ' 15  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87B22AD2-499E-4304-BCE4-0BDDB10E86C1', '50435782-441C-427A-BFDE-83F8BA2E9606', '5907724574167', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD8A381B-3779-4985-B110-2A7EA3515189', 'B8439515-D177-4E95-B242-9021B1096FF6', '5907996091485', ' . medlance   1,8 21g 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66A25BB1-631D-4884-BF56-CEFA01BB3B18', 'B8439515-D177-4E95-B242-9021B1096FF6', '5907996093205', ' . medlance   1,8 21g 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80FFD7A8-5409-494A-B20B-52D8328873E2', 'B664DC62-A356-4F47-9111-76431B56FC72', '5907996093243', ' . medisafe 23g 2  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62F46366-BB17-46A8-94A7-0A18AC0B82D3', 'CB08815D-A047-4A62-BEA9-BDF8F5CF11D8', '5908311862421', '   - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2295ACC-8A4D-4B8E-837C-E64425542BA6', 'AD86A147-0477-462C-8F4E-1478091B2A14', '5908311864418', '      /0-2/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CCAEA6E-16E8-449B-B713-ACABEE78EC87', '49807231-AAF1-44AA-9974-4B68EDD187AF', '5909990110810', '  90   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2564C56D-8810-4C4D-AA65-1D1901DD8D82', '8F646B4A-0A6A-40B8-8AB9-B15F85F1D90E', '5944700301010', ' 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA300D53-6106-4DA7-86FF-FB69773DEE2B', '8A9778AD-2F75-45FE-8AE7-22A7AA8AABB3', '5944702001864', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC237ECD-CEBB-44E6-B1DF-69A1D8571A56', 'E407FA43-F6D3-4133-B8F2-E658AFDC7B83', '5944702001871', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('347DD801-11F6-4687-A601-5303C46AF5AE', '8A9778AD-2F75-45FE-8AE7-22A7AA8AABB3', '5944702101861', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1CE7C13-E3E0-4BAA-BE6F-FC2EA088AF82', '8D212479-56EE-4E5B-B110-C3821E119BF3', '5944702205194', '  3% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('457D55BF-EB7F-42A7-BACA-D7CC60749C35', 'C9128074-7211-4C64-8A58-141BDE467B6D', '5944702205231', '   10 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('256F44D9-9B28-4B5B-9991-B3F4785E7E0F', '1538C6BF-8F79-46ED-9CFE-85332EEB1A96', '5944702205279', ' // 10 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('245E743D-BBFA-4576-A18C-EDAA678DF19F', 'A12D31EF-EDBC-4D7B-819E-7E8580F2CA8C', '5944704000049', ' 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CAB2C54-59B6-47B0-8EC7-E1E540B392BE', '18C57C23-1E20-416B-A12E-67D992A9BDC0', '5944704001091', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD78B779-A57F-4BF3-B572-EC61E984D6E7', '17653D31-B252-49F9-8EAB-F797C4544458', '5944704011618', '  100  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AB5D939-A5AC-4DFE-9361-F5CBF8E6E2B8', 'C5A49C85-21E0-4FC5-BFFD-37B3F599FC30', '5944706001631', ' //  / 200 5 16,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FDA8E51-3673-4469-B3CD-2476948962E4', '69FDAD52-412A-4434-BFD8-33E2DE430284', '5944709000037', ' 1%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C05B9977-7F2E-4343-86E1-0E8AEDD070C4', 'CC4EB546-581D-43D4-90B1-2BF19593837B', '5944728000186', ' 0,3% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('871AF941-2C2B-4FD2-AE61-5D8EF2341628', 'FB20D380-2CCB-4ADB-A597-4422767C4F4A', '5944728000193', ' 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('770B54DA-F7BE-48DC-A29B-399BBE4D58F2', 'ED59EDE0-D614-411D-87D1-C461F128C077', '5944728000216', ' 0,1% 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6179BC3-9735-485D-B364-E422EC27842D', 'EF5F3F36-1D59-4E40-BA06-119EDE54C82D', '5944728000230', ' 0,1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49CB6DCF-4E05-43A1-AD1C-70D67E4652F9', 'F781D328-729D-408A-9719-0741978A255A', '5944728000391', ' 0,05% 15 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC34B865-677A-4CFC-A09D-101503C88235', 'FDDECCF8-526A-4410-BB4F-611D39AB6AEA', '5944728000407', ' 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('535AF477-846F-4B06-B920-FA24458B4683', '27D61A32-AF8D-48F0-8F7C-7FF538A19C7F', '5944728001084', '  180  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F37FF66-0B43-4C63-AB5A-E70C19780202', 'E2212AFC-180E-473C-9B9B-662DB2972C4F', '5944728001169', ' 0,005% 2,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F359B1F-84FF-44E0-B61E-72F0391E309E', 'C357B94F-0518-478F-9640-0BF925DD0E46', '5944728001312', '   5   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAFFBF6D-6247-4602-90CD-CEB10F781CED', 'C885E2E7-C3F9-45F9-AF37-5F44F6E7C5FA', '5944728001329', ' 15   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F3F8CEB-F48F-4535-9E88-DE7D4BDEA70D', '3AC5DF07-2AF9-4D90-9138-DFB695492806', '5944728001510', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1888DA03-9CF7-4F7B-9CD9-1042422B6DAC', '18DEC796-7CF8-4D0E-BA61-62209CA83697', '5944728001596', ' 1% 1,5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C965352E-C1FC-4279-94C4-05B4192D8606', '280C7162-464A-469D-82F7-2E0CB3E654D0', '5944728001732', ' 2,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD270CB7-4EEF-40F2-A54E-2D457A6402B5', '920DF5F6-BBAA-49F9-A0CB-2384428C1969', '5944728001763', '  - /,/ 50/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D2279FE-CD84-4B93-BBAE-E2CDACF92F67', '5F3EA16A-DBCE-48E9-B8DA-04DE0BC56D65', '5944728001954', ' 1,5  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('927BB52D-81BA-47EA-93E1-164F408E638D', '721A2BBD-2173-4634-B37A-64600BCEBA8B', '5944728001992', ' / / 250 4 / / -  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ACDBFEA-F11F-460B-9AA6-82C08DFDE926', '41F3DA06-78C4-47DA-B374-12D5B68AB7D2', '5944728002296', '  0,1%   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59244DA1-53F8-44D1-8EA6-1A0852F2E5F9', '7BA1A5E7-FFB8-41A3-BE07-1E887F7D08AE', '5944728002395', ' 0,04 2,5 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5C4292B-E324-4632-B8CF-E63466C9EE68', '3876CF37-769E-4557-8288-A7B1F441CC89', '5944728002548', ' 0,025 / / 2 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5229A41B-A340-4C38-8ADD-D994CFA30653', 'A06672E9-81A0-4E54-83C5-8A61E27D3D36', '5944728002579', ' 0,005% 2,5   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('168FB4A8-A336-4E0E-AF40-0F43BDCFF917', 'BAD767A6-7F36-474A-84CF-E08B8576FE32', '5944728002623', ' 100 2 / -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0660EB7-5D77-45ED-ADEE-0219135042F8', '42DC381E-2458-447E-BAFD-C14798C59F93', '5944728002739', ' 2 1  / 1,5% -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7327FB5E-645F-4815-88E1-5EF2E52C734E', '753A4018-16DD-4438-B1A9-CA5FFFF952B9', '5944728002814', ' 10 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18B44D02-026C-4018-96B0-B51FCD9ADAB1', '1B663421-99EC-4579-A7BB-08E9E237551D', '5944728002968', ' 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65A1CF6D-0BCB-412C-8A35-7F25ED921180', '3E600C4A-1B17-4B5B-BF06-4A5D18F09D99', '5944728003033', ' 0,3 3   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3509936F-7BE5-4A08-9024-7828F6103DA6', '84D94395-C674-45AA-B389-2BE869EEBDBC', '5944728003460', ' cs   0,06/3+0,09/3 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('785037B2-8B0B-4654-9D1B-CD032E2A3847', 'B34AF8A8-4E63-4F5D-8747-99230B77EFE3', '5944728003675', ' 0,5/   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('136F4C28-D511-444E-AFC0-8FBACC6F2D29', 'C60A167F-6B92-4C2D-B94A-3A5C69BC93AC', '5944728004078', ' 2% 5    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEFF7466-5BD8-4858-938D-8D2CB66E678A', '91B71B3D-6DB5-43E5-899B-3406C9994F06', '5944728004887', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A4EFF35-5B10-417E-BB98-F8A910C0B7FE', '447A8B32-342B-49BD-A1E8-2E5F2873B684', '5944728004894', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D31DABBA-6EAD-4F79-BE17-8F9ADC4CF5FD', '1473BD81-7A89-4791-8B6C-17C7FBBA76A3', '5944736009591', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8E52390-95A9-449A-9964-A00A4940AA5F', '48827451-3493-4643-A705-FF5E00B5ACAF', '5944736009638', '  1,4 12  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1CE41C6-DFE8-4FC7-A9B7-8639F78DA702', '529E9562-535D-4C9F-BA45-59B5558F08F0', '5944736012614', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A65DE396-14B7-4B1B-AA37-ABBD895C258C', '969674FA-50B3-4E4A-BF70-A742501A1A42', '5944736012676', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('863564B6-E32E-4441-B65D-C66499463153', 'B4B28691-74BB-4113-84F8-FC1B6738CF53', '5995171239005', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27B6D45C-39AE-48A6-99C8-67C6B9335CE7', 'E9D652B3-B9FC-4579-AB3F-7DB3D4A6132D', '5995327111025', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A2C737F-84AD-4060-B852-314A41AD6CA0', 'E55BDD36-15C5-419D-A0F1-8D6FD1321F00', '5995327111032', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('961CCFC4-93C4-4D3B-BB95-457853D257E6', 'FBCF7E62-57FF-4403-B272-5AD95BCBFC0F', '5995327111285', ' 1200  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AF8C8CB-E5C1-413E-B5C9-DDA4438AA0CA', '3DD91AE5-B567-416E-AF04-8E966A1C2CCC', '5995327111865', ' 300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8979D3D-CC99-49F9-B3A4-A0AD1A106DD1', 'C3CBF58D-DAA9-4446-AE2D-8D481B6915E5', '5995327112039', ' 1/ 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E519A976-77D7-4C65-8001-00DC029231BE', '2D817C45-288B-4598-A0EE-08CB77799869', '5995327113609', '    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D37E20B9-1382-4E8A-B35D-24D0A51C2DD5', '0BFE60D5-A4DA-489B-AC8E-55E6DC46D091', '5995327113647', ' 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCA68006-B89A-4550-85AA-764BF5C7F497', '62479212-D2E0-4D1B-BDC3-E5505297076C', '5995327114569', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FEC0049-2132-4AC4-A485-65EABACEEA09', 'BC4522E2-AE70-40D8-AE20-F09A7882D039', '5995327114620', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('594F031F-2827-4220-93AB-F80BFEC3738C', '0D3CC260-2B6C-4DB9-A530-C907B5A8997B', '5995327114637', '  20   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E47EADE4-C7F3-4ECA-AF18-2D975E5DF7C0', '1F7EA03E-AAB0-4850-AF71-12643ED3C081', '5995327115214', ' 2%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D51A4E67-FC26-4003-B1B3-B7D83596C5DA', 'CEBDE882-86E4-4B93-8708-99FCF924DC15', '5995327115375', ' 200   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17DC0958-DBE8-48AA-AF4D-38EAD746DE36', '4E9138E4-F4BE-47BF-AC56-BC2C70433994', '5995327115412', ' 300   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AEAD5A7-9306-47D9-AE9C-08E18EE5093A', 'E480E6B2-8861-4826-9167-06CC55F3BF53', '5995327117379', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94959E83-1AE1-4593-8B4F-7DEA3739674A', 'FA8DCA1F-FC15-4069-8CFD-7F921C8F51BC', '5995327117386', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56399BE5-C5BD-49DE-96E6-848E65E6C574', 'CC06C988-ABA1-4581-A783-81AC3DB906EF', '5995327117652', ' 37,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('379305BA-4610-44B2-A464-F6ACD045D793', '17D2EE74-CA50-4DDA-A352-F1B1558E51F5', '5995327119793', '  40    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92C29983-620B-4527-91AD-A032BE0FA500', '836E7C3B-DAE5-40A3-9D72-54E4AB33ADF2', '5995327119946', ' 50  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF5DE812-F5AF-477B-99B9-DC0562FCA388', '743A8C6C-F71E-4652-8CB9-F784CC007D72', '5995327121680', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7425549B-7CFF-45AF-8D40-0C8274EFE6C7', '48FF0A17-1BE2-4B28-8724-45B19059748B', '5995327122243', '- 2,5 12,5 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08140A91-4B90-472D-A668-47D0D94FB968', '4BAA2EF7-FC47-4A93-879E-EDF9C0EE196B', '5995327122250', '  5+25 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('436FE152-FF11-4CE7-89FA-5AE828154DA8', '3B88D68E-09F5-4BA4-8F50-FC8A2CB6D37B', '5995327124988', ' 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('521D308D-D226-4F62-A061-B475BB6CF012', 'A908B74E-E7B1-41D8-A51A-6F0708D2B26A', '5995327127781', ' 75  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E9D6020-DDF7-4951-9D0B-EA5DB7C4F627', '6DB55861-EA1D-4864-AAC9-B9C4AC47512D', '5995327130064', ' 5  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0AA2732-47C3-4EC4-845E-59BCD0929B11', '9237E708-684D-418B-8E12-9F1BAB7A0896', '5995327130071', ' 5  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C3A2A0E-601C-4641-88B2-6BBC4B73F4F4', '1166C9DC-B896-4ED3-B62F-CEB23578F3AC', '5995327130118', ' 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B47CA22B-19ED-4EC3-8126-A1919FC3AF97', '79E7A45D-F599-4D03-BFCD-1BA7D59428B6', '5995327132181', ' 5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B90B7DD4-26D4-454E-AEC6-91982DDCDA3B', '247AEB61-DE13-4E0E-B430-2694DD31FA63', '5995327132198', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BD614F3-154B-45FF-A4CC-344D317C7071', 'D1E90B27-1CB7-4BB8-B2D8-B22E4398BC54', '5995327136974', ' 0,01  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5847257B-7548-4F03-ACDD-3D2E40830C59', '4DA4F994-F0AE-4499-BB00-28CCD10D6447', '5995327138008', ' 25 //.  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FED83EAD-4D62-4714-BBB3-18A6AB65FEFF', '1EF25A65-0CAF-4EC4-BEBA-52A2B83FE1A5', '5995327138497', '  25   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A478D259-6ED6-4731-9150-4FA3D857A85E', 'D82C1521-EE87-45C9-A202-024CB04FCA23', '5995327138510', '  100   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FBDEB30-B673-41B2-A2BE-87484D111A84', '8E7B0AFF-0296-4F4E-A4DF-8BB67FEE49F9', '5995327143217', ' 2   / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE129EF1-051D-4DC4-87E3-6C0748E31D81', '0D4729B1-FD59-4950-A307-7592562DBBE3', '5995327143224', ' 4   / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBF976D2-FE9F-4EB5-BDAA-E98B91AA41BE', '17237695-71AE-498F-AB23-DF6D73D4E508', '5995327143231', ' 8   / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F6AB1A9-9641-4AAF-8E14-7849E5EFAC7D', '2FA78C6B-C8A2-4384-9A7F-CE4BFD7DA511', '5995327143736', ' 5 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('579B6613-FBC3-45EE-9C08-9549017D1038', 'C63DBAC4-BF3F-4FC1-8290-47212D1793E7', '5995327143743', ' 5 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FD685C1-5725-4C78-9BFC-FCF372FC6C9D', '8FBDDA32-CD94-48AF-83C6-AC31112507F5', '5995327143750', ' 10  5   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C949CB9-4614-4D63-A0D2-6CCDBAC64FAD', '712517E1-2B6E-4728-BB9C-DCFF3EDC5360', '5995327143767', ' 10 10   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF17C83C-C4EE-473A-A93F-D05B7088EE04', 'D8A1529A-EB31-48B0-9766-8BE7703352AB', '5995327165363', ' 10%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DF9528A-4A8E-4193-B261-1477651226C1', '35213DE0-3C4D-4364-AD48-0BF572D8D126', '5995327165370', ' 200   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D9F4054-9730-4520-95F5-4A73A420ECEF', '06C08330-DE71-4320-BDE3-8B05FFCF74BB', '5995327165387', ' 10% 30 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('047805ED-00C1-4D96-96BA-2E70FCFF2B5D', '60F6172D-0A06-4E08-BECF-743991D0579F', '5995327165394', ' 10% 120 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAFE3D8F-C5FD-4462-BD09-AEBF9BE17BF9', 'BBD5AA0F-EA19-47DB-B52F-0305615BDBCB', '5995327167268', '-  5% 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('164DD4F9-4EB5-4536-92F1-C7F2A7BBBD30', 'D7009BCC-FBC6-4A42-ACE1-7ACC3DD36DB6', '5995327167282', '- 5%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('453EE3E9-3AF2-4692-B450-6A1DC772C552', '689548F8-489F-4E50-BB38-D47EF1C64289', '5995327167299', '- 5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84EA8DC4-6E62-4A1F-84CC-CC4F32DC8F19', 'F9AB57ED-B6A2-4838-97BE-D105BD152A2F', '5995327167312', ' 180  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E938EAE-6FA2-4FD6-9777-5DA1DE63F18E', 'AF2B1D16-486E-4D84-94A3-B1401B00EE18', '5995327167329', '  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B69972D1-EF80-464D-9798-F850CE697489', '30285FD8-D789-4C5A-BEB4-FDFDE6ED69C1', '5995327167336', '  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EB25CC9-122D-4659-BBC7-067968C4F42C', 'BFEDBDE8-60CB-404A-BC25-0C06CAABF9CC', '5995327167343', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD20B31C-5234-4873-B3A6-51FC087F9E6A', '7DF33B25-DB4C-429D-8485-14856557F661', '5995327167350', ' 160  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BE873C6-2E47-4EF4-ACB0-EB05D82F4C89', '8E038268-7809-4C94-B741-36A1965FF4BD', '5995327170060', ' 0,025  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7913D4E-649F-4BC2-B947-E51D6B710C12', '1438A463-3D9D-42FB-8124-92F6CCA5F9DE', '5995327177014', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2EE5E9E-25FE-4741-A96B-EDA19BCB42B1', '66AC7DF8-6BD5-415B-B0DC-972D41A3482C', '5995327182063', ' 0,01 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78D252D0-76E2-488D-BA26-9464D0ACE3A6', 'DF5014E8-6D8D-4F0B-B73A-E96885652CAB', '5995327188256', ' () 250 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BF751AC-3AA6-4419-BA6E-04BB347B0419', 'C2A16ABB-E873-47E6-8F87-CD5FA4C45D6B', '5995327205137', ' 0,05  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CE1645A-AB31-4BC5-8AE6-A9E550A7176B', 'D00811FF-5CA5-46D9-A6BD-68D006FC6FA9', '5995327206042', ' 25/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AD96646-9B65-4662-BFC5-6920050FE113', '8E4E7D09-A3F0-4CAA-BDF7-A03F28AF8C9C', '5995327206219', ' 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D35C9B24-56FB-4CF5-9AF0-CEA74130F82C', 'F111F7F6-A5EA-4F82-9F87-AB014D6DA3D3', '5995327211039', ' 0,03  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9703A624-C280-4566-8B09-7AA6EFEAA7AE', '59538AC0-CD60-4EA2-BA34-3A9738E5DFE5', '5995327211084', ' 30/10  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD410DF3-248F-4B08-BB18-C8E023D398D7', '7AA25AB1-88BE-4D35-8779-4268B3FF9053', '5995327218199', ' 10%  38', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78BB0C91-9E5A-4205-A94B-D39CC6DED808', '816089EF-81B3-400B-81A1-E23E2533FB1D', '5995327225074', ' 0,8 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('552D258B-CF77-4305-B07B-C84BCCDBB592', '908A10E6-5224-4306-BECB-71B21F60B4EA', '5995327233024', ' 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15D9948A-8722-419F-BD37-1EEB233D34E6', 'A1358D29-BBB8-4425-A21C-90BAA9404A5A', '5995327262185', ' // 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A18940C-FC03-4867-A684-9A4C32DAE251', '9A842AE0-FE9D-4B53-A85F-422BA43219FF', '5995327275024', ' 2% 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D63A4B39-A3B7-4789-B07B-0F6DA0EB1B22', '0BE9CFCA-A3AB-4097-9F9E-74A3E132E9D4', '5995377011252', ' - 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D3AB4AA-6C71-47B0-8A7B-AA29B4D079F6', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '5995377011269', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51F85540-78FA-4EE8-A7E6-30206FEF51B9', 'F1BC6AB2-F8BC-4E4D-B5D5-609F0BA8C9D6', '5995377020148', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BFF08F0-7D24-4E91-AE05-486638366F4E', '93209699-C224-4238-8433-187D135E49A8', '5995377029264', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D619EA1-6AF8-4ABF-8744-7EB8E9A631EC', '7FA670F1-44AA-41A6-BC84-2BDC7C468916', '5995377104800', ' 8  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFB6A9D8-AE0D-46E9-903F-55B1C6B62193', 'F7B33774-9759-4851-B09E-43B78732F1AE', '5995377252242', ' 150  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F858C99-1F67-45E5-8016-F703FB8FA82A', '24FE3375-DBC0-44D2-8BB3-7048F2C6B177', '5995377281082', ' 500  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('143FD046-A84F-4180-B2E3-ED083BA360AD', '3D64CECD-C9DE-4572-92F4-2EC423A789AE', '5995377282041', '- 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC08CE56-01D8-45E1-80C7-30D13E55797C', 'A8F600CF-FDAC-4BB3-BA2A-9DB0DD687182', '5995377360244', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0A2F3D5-DF22-42BC-B43D-6704AC6EC586', 'F7363ACC-4A8C-47A9-BB30-7824DE23595A', '5995377361043', '- 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0047941-B55F-49D9-9114-0D53376DC28E', '39730150-0E2B-43DB-81B1-C7A1D0E7492E', '5995377378089', ' - 500  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EFB769A-D371-4805-975F-602D05A9661C', 'DFCEB6AE-6DDD-4771-B223-FD56201CC21F', '5995377402098', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C979CD9A-758F-4B53-ADDA-DE3E6DDE922F', 'FFFD72F1-8BAA-47FC-8EAC-725A0A8419CD', '5995377470110', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99A0B0C6-FBA4-4AFE-8FBD-0C2479105233', 'DDBA14DD-4B68-4726-9E19-9656CBD01F17', '5995377470141', ' 5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35D1857C-FAC6-4472-A070-9F62884DDBC4', '651208C7-AAE5-4B7F-94AB-5B51F7F11F0E', '5995377480102', ' 5 30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CC32F93-501E-473E-B0CF-AFAA3821E059', 'E295D00E-1E92-4A25-9575-FC782C358033', '5995377480294', '- 50  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0557ADE-1946-4B6C-82FB-4E4E638CD9D4', 'F0A32607-F27A-45F2-913C-1B8A3DD1A841', '5995377480324', ' 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B07ACC23-637D-447B-9F09-8FA4E61E1A13', '0CEE405F-CCE6-43D7-A4AB-494F4CC52FDC', '5995377480331', '- 10  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B045A587-DD44-43BF-AFB3-DB064D3CEDDC', '2BE21423-1362-4338-8B9F-1A11D03F5799', '5995377480423', '- 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('024C0C9C-EDC8-4152-8A50-F6136468EA35', 'A80D0EE5-BFDD-4F9A-B5DE-0BEDB5E805BC', '5995377485329', '- 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD335BB6-36B7-4BD4-84AC-4F9CC37E0E6B', 'A0AB5BCD-F3F8-4212-A3F3-97F5BBF6F98B', '5995377531484', '- 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12B8E7DC-E7F8-43DE-974B-5904B6FC87D7', 'CD55CC74-830D-44C2-BE30-E49E9465A136', '5995377657108', ' 100  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93C4B60B-0CD7-4E6E-B617-DDB614EEEA4E', '315E2306-61BC-423F-88DE-DC30594D14F5', '5995377692048', '- 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BB2B47D-694B-45EF-88E1-87B1B583B599', 'F99A99B1-9382-444E-91F5-9EFBE7E0A2E4', '5995377718014', ' 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AF012A4-5167-435A-BB33-E479864AE3E3', '185C963A-8A9D-465F-9DF8-685C43142FB4', '5995377718021', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E227574F-D269-49EC-AEE1-402C2F9155B6', '73BE1473-B535-4AA0-96D3-9E4A2D9A612F', '5995377728044', '- 25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE8D5822-9E37-4A36-9183-A729038A5A7F', 'C040541A-53AE-45C6-85E4-93B98C013EF6', '5995377745041', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE4F2C63-C740-4B10-9A09-168AA7998404', 'D166F9B3-BE82-48A1-8B50-F6EB74ACD80E', '5995377772016', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E7EA260-4F5D-45BD-AFA9-BBBFE6E86811', '6EEB7987-6A5B-4032-83AA-4228ED598B0E', '5995377789045', '- 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7456ADD6-1D86-426B-8292-E32EA6911C42', 'FB5DE96E-F2CE-412F-AC3D-AB34EF49E9A9', '5995377789106', '- 15  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64845955-0C55-4E86-81C9-D6D043CA21A2', 'BB075934-B648-42EF-BD90-6E370B8CAC9D', '5995377789113', ' 15  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92DB4BA0-E7C2-4053-8921-915C8E1D3D66', '50DE7466-5439-40E3-AC30-48DB48C74B1E', '5995377801082', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDFE91B9-523D-4022-9D66-743CE229C52E', '2AEC0EFE-1260-4377-B5DB-B749A15003A8', '5995377804274', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3D1CB31-B579-4894-9AAF-07B95CEF6322', 'E142FCE2-9E59-49E3-9213-7536F95D56BE', '5995377804281', '- 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C247DF8-95A7-4F85-A3DA-F9E768D9B8E0', 'C6239C51-5A74-4AC9-A16F-F5B27A156F9A', '5995377810480', '- 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('770E1622-3B23-4006-935C-3737015C0800', '71FFA257-EEBF-4ED7-97AC-CEFD1871608C', '5995377852145', '- 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83C3AA66-5A4E-4175-A88F-4B36ABA8032A', 'FB6FF834-3CD1-4B24-8A60-5AB176DC3B94', '5995377852244', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE3125F8-A200-4BBF-9B22-86456FBBA9FF', '5C5C4CB7-FE70-4250-924F-D1BEDFFB136A', '5997001301401', '  50/12,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A6B621A-E9C4-4375-9F43-408037170291', '22E8DF6D-3915-4283-8101-5BCD850C1C01', '5997001301630', ' 70  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('719BAE0F-0470-40F6-9FAC-2923B6CB61DB', '885B9BC6-600E-4CE4-BB77-26B039FE0CEF', '5997001302316', ' 35  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FF92A29-37A0-44D6-9CF0-38D743856DBC', 'E1F6F4BF-CB11-4AAF-ABA5-D7916E6D1600', '5997001302361', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99C74708-947C-4BE9-A58F-1C3EA3C56DFC', '8206D592-0A84-4CAD-92AB-0370894EBCF0', '5997001302477', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16457B3E-F2D5-4E03-B308-A5991B12A8BA', '719DB2E8-D058-4EDA-BB6F-35DDE3EA7F58', '5997001302484', ' 80  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CD28DCC-C2CE-4702-8F79-BA9C8CA5F602', 'BB2944C5-E3B2-418D-9B35-A66A8030D910', '5997001302538', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93667E48-CB62-4CC6-8B7F-9AB9A4C44D46', '90BE6146-C5F6-4B4B-96BF-0D3FBFD79E59', '5997001302583', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AC45EF3-E3A0-4314-8894-876B5097889A', '34BE19BB-4164-4665-81B1-C94AD3CEDC1D', '5997001302590', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF8689D9-FA04-4B3C-A292-20049B6457BD', '3999133A-C99B-468A-BCAB-19CD1F26F354', '5997001302903', ' 500  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27E60E16-7073-4705-A95A-7FDC3E17FC09', '7058CDFF-96A9-4621-B1B7-BA19977567F5', '5997001303269', '  4  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA670F76-320D-46E0-8B09-BF920C8F8D60', '9EBD68F6-F3D7-4F6F-9282-79F99D906A1E', '5997001303290', ' 5   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC8FC1FC-724D-45CF-BA1B-0CC5989D67A4', '3559E147-77CC-43A4-BE2C-B33D17C81CF1', '5997001303313', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D6D841D-3208-4B1E-80A0-7B89A30DB93C', '5805D180-0F20-4540-AA2C-CDB15547195A', '5997001304259', '- 10+12,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21E4EC30-D888-439A-B3F0-DA5A3A07B051', 'A63D9FA1-37EB-47B5-9ECF-D6053C842611', '5997001304266', '-o 10+12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7472E970-A682-4CEC-AC61-B8CA2CFE44FD', 'C682CCE2-6149-4697-B17F-D25279FE1688', '5997001304273', '- 20+12,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B0F1AD2-07FC-46BA-9377-4611A9940FBE', 'EEE955CB-80E6-46C8-8563-55E583AF3760', '5997001304280', '- 20+12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16720E8D-46C3-43B7-ADD5-2A03A60E6C2E', '3A92A9FE-BD58-43A3-9D9F-66EAA36E6E73', '5997001304396', '  100  3  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEE59753-5D8D-47EE-8B25-78F30624C639', 'AE2CC671-892F-401B-923A-E32D5A3CCE70', '5997001305119', ' 5   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27E51FFC-7FC7-4B7F-8CDF-FD507D15AE8B', '108061C1-4BBB-4497-A0BB-40ECFC9EF140', '5997001306253', ' 0,2 12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB774CA0-B76B-44AC-BE39-08CC21CE9FD9', '50A4A54D-EFA6-4FE5-86C9-C7A8B83498BD', '5997001306666', ' 10 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('463A8EBA-4F90-469C-A778-39701FD90270', '8D2AF0BB-D116-4C65-B75B-96CB2D997D16', '5997001306673', ' 10   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69E17F92-63ED-49CD-AB59-80511E16C346', 'A1EEBA80-C879-469A-A194-A2FD7CFB81E8', '5997001306680', '  // 0,08   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('736870F6-94EA-4F0A-BE94-F6181E8D77FC', '3C365A17-E758-4545-B729-A527788C1EC1', '5997001306710', ' 0,002 +  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63A91987-783E-43CA-B508-81A9447DC313', '775548F0-68F5-4559-A0A1-F7D77E3D1519', '5997001306741', ' 10   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E1B17E2-B40D-4E39-995B-6F6E97C2B661', '834B8C90-A4DD-4FAC-A7E4-20A17B1D9943', '5997001306758', ' 0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88D34439-D394-4188-BF8A-86DDA83A205C', '3139A5CC-7F3C-4630-92A1-1AB3BF893C99', '5997001307106', ' 0,1  / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD160C94-AF72-4F1C-9F98-10D617212BE1', 'D1F1ADAB-7B79-4694-B023-3C5A2185CF61', '5997001307175', ' 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CB42EAE-FF18-48EA-9FA2-5ABBDD8834AE', '5B851ED9-63F5-4A8B-9CDD-45CC343C277F', '5997001307496', ' // . 5  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1595DD1-B24C-4711-99F5-DC00055FE921', '3D7FF867-3922-4399-8F67-8A85E3A7E93F', '5997001307526', ' 7,5  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CB07C03-A693-47FA-B782-A823C676C735', '23761CAB-E834-4D97-856C-D508F0D1CA89', '5997001308059', '   6  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49FD6E66-1D91-48BD-8F67-3AAE43CBD5C3', 'DCDE2D32-0009-4B4A-BD98-474F1DE5AE6D', '5997001308547', ' 6/ 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FFAB020-39A3-4D89-902D-EDCF66A74778', 'D8AA418A-BD61-45A6-AC3E-5F6E92B316CB', '5997001308745', '    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5E05B84-F9DC-4417-B52C-E589BDE4B1E0', '34D8AECE-AF97-4F7A-BD69-8A8935A721A1', '5997001350331', ' 5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C151958-7CB8-46BB-9982-4ECD0A0CA975', '6D3E9C4C-6852-4545-B363-BB60FA5DE0C6', '5997001352311', ' 100000/10  25 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D0DA5AF-453C-4D1A-823A-4DFD8DBDE8FA', 'A057144E-32ED-4B00-BCAB-D7985F6FCEDB', '5997001357767', ' /.  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD8F3D33-867C-43BC-A6CA-74657022A47E', '7E68C154-2834-425E-A891-9E6232FAA225', '5997001357774', '  / 63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E015BCD-B67D-46DF-B7CD-3E2D525E06E9', 'BF02827B-4A03-4E34-A067-ECE64589250D', '5997001357781', '   21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7C5CD37-E868-4306-99A6-89BD0C25FEF4', 'DDE3687A-B2B6-4968-A655-EFB2A38A37B8', '5997001357798', '  / 63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A65E7452-8109-45E3-A5DA-BB1FF5503432', 'CA08D015-0F4D-4D2E-ADCF-0DDA2B22318E', '5997001358825', '  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0E6300E-E326-48DD-8B06-6104E1D2056E', '9AABF0A9-6844-4633-BF23-B2C2CD1A9241', '5997001358849', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21F4560E-FFB6-4DC1-8DD9-C5D0596B3C3D', '603B9E90-AA43-4884-AF69-48A3F28BE13D', '5997001358863', '-  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('595DE354-BCCC-4ED6-89DA-735D9A2848C2', '7ACB56FD-AF82-4CA8-9924-85A21CF6E876', '5997001358917', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D0D90E4-3180-4F8F-A67E-9F5D1EF1067E', '67E20D0A-BF76-406A-84D1-C5AF8BCE4B45', '5997001359068', ' 21+7  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCF573A3-3D7E-406A-A86E-67DA714D2E6A', 'C8D7B7BE-9D24-4315-BA99-A1684E56EAC5', '5997001359082', '- 21+7  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF5F24D3-990B-47DD-82B8-073D9B664B33', 'BCA041CC-37C9-4CB0-8AA3-9FC475BD9F65', '5997001359099', '- 21+7  / 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBE9A789-6856-4466-9015-DA08D2FEFF9D', '222C035F-19A3-45EA-8489-6FC299E49CF6', '5997001359174', ' 50  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E1C3BB1-167D-4D06-AFAF-64D06CFF7024', 'D1C17DD5-1934-43DD-A674-BBE01389DD72', '5997001359266', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30CC35A9-E592-46FC-959F-0EE7FC42203E', 'D8F9A987-2991-4879-B8C9-CAF4C4D1C514', '5997001359327', ' 5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5F71BC5-FE7F-4851-B85D-2BAC93732190', 'C342B58E-9F9F-49A1-810F-29D0B3661B54', '5997001359334', ' 10  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('062FF285-2878-4977-A39B-E017408EB688', '04B36D68-A54C-42C4-95EE-AA8E14E2EB8D', '5997001359341', ' 20  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25109323-D0AF-4CBA-810E-ABF8025850CA', 'ACFAF683-8349-4A3A-A789-57D3BF793953', '5997001359358', ' 2,5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DE2373B-47D8-4E03-BD17-470827CE640F', '3921A9E0-73ED-4085-ABDA-2BBEC810C2BF', '5997001359365', ' 0,0025  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB548D77-E5A5-4C3B-9E91-15DFA44D3C19', '8206D592-0A84-4CAD-92AB-0370894EBCF0', '5997001359433', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C4CE410-C299-4152-9EBC-E18C76EF7C65', 'EE56FC4C-93D2-48D0-96C9-570A09C23168', '5997001359662', ' 1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AD20AEB-4EA6-422A-9059-B7B74885ACCE', '1995697C-2998-43E6-8419-EA4DBB3656DE', '5997001359761', ' 20  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('608CC58A-E623-4FD1-BEA8-D227E4B5D659', '5C0A7181-6C44-4488-9BBE-1818CF7C8E50', '5997001359778', ' 30  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8D03594-27C1-4C27-B71F-F8199FED44AF', '80DC8B17-3548-4B98-9C51-76919C01E912', '5997001360149', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E11C851C-607D-42AD-BBFA-5880C93A7A79', '6B50D90B-D01C-4983-B8D7-CD8EE4A47BCA', '5997001360170', ' 750   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDC32D67-CFEB-47C8-9BF7-76836DE75506', '7B2A9B6F-38D0-4851-AD04-90D02687B189', '5997001360224', ' 2,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FFF5231-518D-4670-911C-DA35B192A930', 'BA81872F-8294-42F4-A226-27F6151B0A1A', '5997001360231', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F84A5A6A-DD0A-4763-A160-B014623C9AC8', '981918E1-D4C1-488B-A79B-74D6BC7F028F', '5997001360248', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9B83F90-5EF4-4BC7-970F-D2CBD00E9B75', '3DC4E5CB-DAEA-4CB2-9AD6-777D1FCFFC0C', '5997001360255', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11EDCBEF-A132-4812-B0FC-CEA1168B622C', 'BD84E4FF-7190-47DF-B529-B6E5714FF30D', '5997001360293', ' 20  / 63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('220C56E0-65B4-4CC0-B9B1-23106A5BA163', 'AE4EAD69-56FB-4AB7-A6AA-6B9F832CB858', '5997001360422', ' 300  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3890F01-B326-431B-A0DB-17E6160A38E7', 'B377500B-5ADB-4ACE-BFB1-E04BAA8A0899', '5997001360439', ' 300  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC23DED3-85DF-42F8-AE3E-4F486C8E408D', '58467F32-927C-4425-AE1E-4B44A8120BCB', '5997001360484', ' 1,5  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('901FD2BF-EC76-424D-9443-CFBC98FA4904', '7D22ABA3-9E58-446B-BCD6-3A79D5F4E421', '5997001360491', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37AD860C-D670-4E45-9000-090D1B994369', 'AD2E4CF9-1E96-4886-9AB3-93C573D037C8', '5997001360514', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1AB7947-F248-4737-8BD9-925FA7224E8E', '842C145A-E5A8-47BA-8375-B4847A6897BA', '5997001360729', '    20/ 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FCDA970-A894-4672-86F1-E7CC5671B42A', '39E1FC4F-5450-400E-A725-65303F39B2A7', '5997001360828', ' 5+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2E68D60-CFBF-4562-A0F2-92A145879D57', '7D19EABA-CADF-465B-AE80-9C9D512EC117', '5997001360859', ' 5+10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE8561B8-B3E6-4CDE-81D7-E7575AF68913', '76B4170F-B2F6-4303-ADE8-5F234AC2D0F3', '5997001361528', '    32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DAB2D30-9BED-40A4-9FBA-69D65ACB9C28', 'A980BA4D-C9CB-4AFD-8E4E-E40AAE66A4CC', '5997001361832', ' 0,000075 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF56039F-7DBA-4213-B839-03F81B5A9391', '303335AE-8D56-4F57-810C-72AE63B14540', '5997001362099', ' 0,5% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D34E7DE-77B8-4E57-9CC1-98F15AEC9F4A', 'A8B8C6E4-1B65-46DD-87B8-D4DCAAFC31C7', '5997001362105', ' 0,5% 10  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EF3025E-365A-49C7-B200-D7646F154322', '807D0787-584B-4677-9713-6AB010769F81', '5997001362242', ' 10+20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('591FBFA9-3DE2-4814-B218-E4F04FD08B4E', 'F992E8CF-D990-41F5-A6E8-4049B2D5D0CF', '5997001362655', ' 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7CF2218-52E4-4395-9C47-CBD50DC9A6DB', 'DF81C029-1A88-4287-9EB9-7D5DDEDE2693', '5997001362723', ' 2+0,03  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D05F2B4-58A2-409B-842C-D2FF4ADEE5B4', '1BBB3A5A-C0E9-4A67-8719-6A14B417871C', '5997001362730', ' 2+0,03  / 63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AC558D3-6D08-4A87-9E5F-4C5A121EE871', '04FEA0AE-0695-4F34-8F41-FA15D631B293', '5997001362747', '  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A448D45-0195-4192-BB09-883EA132DF02', 'D5409FFE-C77D-4E14-AF61-99142C0149F4', '5997001362754', '  / 63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0AB5FE5-7BD6-48FF-B7D7-4611FAFAB1D7', 'CE239DA7-F14A-4E21-88B9-D551D2E9596A', '5997001362983', ' 3 +0,02  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD71BC3A-A9C5-41C1-98CA-586A34409717', 'B46C1047-0B62-4732-968A-F05A8F379C93', '5997001362990', '  3  + 0,02 283  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFF7DADD-F620-4BE8-AE16-F9B710714FF0', '012E409A-83C5-49CA-B1B4-7DFDF11C5578', '5997001363348', ' 5+10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('165A6AF8-6FD9-4E52-A647-6B4EBCC233F3', '4655FBED-BEE2-40A0-ADE7-16A6BA179F50', '5997001363362', ' 5+20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('864CC992-EEAF-43ED-B946-38CFEEBF1717', '6C554B23-E67B-4A99-95AD-BCD20F2C4A71', '5997001363386', ' 5+20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4527AC7-1A69-4E95-9D55-A43B93EE5037', '37366B21-1C21-46B4-9A94-200D68E024F6', '5997001363706', '  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D37188AE-FD17-4A53-A6A5-FBFD758E9ABF', 'ADC89D0F-B40A-443B-BB9E-C65BA55FCE6F', '5997001363713', '  2 +0,03 63  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A00D675A-7FA8-4ECA-8C1D-6ED4B7B4B74B', 'C2C9D374-A192-4053-9968-8463A807A5A0', '5997001363775', '  10   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74C5F280-6DFC-4770-8B30-2FFDDBF6E24D', '3C2D6ECF-47A5-4095-A798-6D5AD8042F3F', '5997001363782', '  0,01   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48BB3F8F-BEF1-4BFC-9564-76085EAA0C87', 'D9BF10E5-7BEC-47EE-94EC-06F59223557A', '5997001365144', '  0,316+0,28 //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59F88FB2-3F90-4409-888C-EC8180981240', '5E77CE6C-D178-490B-80E8-1C8979EFFC06', '5997001365168', ' 5+10+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E9D2AF0-99FA-41FF-9639-19EC5B777A70', 'F950CDAF-5BFE-4027-8F07-CF3B697278FE', '5997001365175', ' 5+10+20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CB83EF9-1DC1-4207-9443-73C115F0C5BB', 'F950CDAF-5BFE-4027-8F07-CF3B697278FE', '5997001365793', ' 5+10+20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93ECCCE4-B3FA-409A-9D5A-1B42B8D1CA53', '5E77CE6C-D178-490B-80E8-1C8979EFFC06', '5997001365809', ' 5+10+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DB9D1A7-22D7-4CBD-9D4D-CFEF97F084A7', '83AD366F-D488-48EB-B890-75CAA71CF1B4', '5997001365816', ' 10+20+20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A403AAF-10DB-46C8-BAD7-3BF56952BEE2', '008F163B-42F9-46BF-BE78-1D8FAF172658', '5997001365823', ' 10+20+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D12E5F51-7540-4ED8-8D1E-D75C57E94460', '6D8F0925-0A9A-4C6F-93D5-52B2FB9F2B34', '5997001380338', ' 0,05  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FC8BD0F-E8D6-4F4A-A429-CB21E2F35495', '9A2F1AD0-3B0D-47F9-9EFF-CF5775906CC0', '5997001380529', ' 1,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C42ED15F-DF9B-4FBE-B365-C0EDDCA7CCFC', '173C3397-A65A-4B66-9338-50569AB1300F', '5997001380932', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1C9FB47-A4A8-4F35-852C-69FBF69BA04A', '30FFFF85-8ADA-40FD-952C-494824983AE2', '5997001381182', ' 2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64400D61-2505-45DD-A0A6-885F9D3509BB', 'E6AAB320-A284-4319-93E6-2AD64DC58CD8', '5997001381540', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B69D6BD-B389-430D-93A8-86672A54798B', 'E2062F71-FEA3-4685-B052-E2B52A057716', '5997001381632', ' 0,1  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C92E9846-DC1E-4750-B2FD-A9F2E4D6189B', 'D1C17DD5-1934-43DD-A674-BBE01389DD72', '5997001383797', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('996E2032-5D61-4447-A9D0-5ED8E38C88B1', '63E360EB-386E-41B2-8E02-00E824BFDE3F', '5997001383803', ' 40  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7DEE60C-091F-4782-A4DB-66AB9FEE6FA1', 'B94F3FC1-C245-4F65-894D-56CA1BD5BA8D', '5997001384251', '-  / 213', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF79BB5C-6ED6-4FC1-B698-9F4D2BD12BD7', 'A68C27C8-E2C0-496B-A5D8-FD7E12F79728', '5997001384268', ' 0,03+0,15 213  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D426F7A0-F078-4FD1-857A-4936797C6EBF', '3CE3CA71-B361-49A2-9715-46FDA85A0D37', '5997001390184', ' 0,5% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D5F75A8-A8B4-464A-8233-952340331675', 'E6326E81-8939-4374-8F32-F11203009BD0', '5997001390740', ' 0,5% 5/1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87CAAAA4-E38A-43B6-8418-83A71AF1A534', 'D3B095AF-D74D-486A-AC8E-381BFF0A75D5', '5997001391464', ' 5/1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60CABBE1-89F9-464B-B34A-F67F41419152', 'EE1429A5-5B38-425A-9C49-61CA8A7ECDF4', '5997001393253', '  50/1   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79E6FC3B-6024-4529-9A0A-4E9C7EC104E7', 'FB2018A8-2E06-4B5A-8CA9-1AFCAEC332D0', '5997001393710', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F05BCF6C-9640-4D70-8DB2-494A3D680A78', '08D290E5-240C-4E78-A831-7270FC272656', '5997001393871', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8171CB1B-E82F-4BBB-A4BB-C03334D1D67A', '13C3E177-4B1C-4270-82BA-DFB33B23A4BA', '5997001394977', ' 20  / 5+-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('768C7550-98CC-42D1-8AA5-08DB050A9204', '3A625DA8-FE72-49F0-97CA-4B209A62521A', '5997001395189', ' 0,2% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('075B7062-F60F-4A8A-9AFE-13ED5BF6CA98', 'C799B8EC-E3A6-4015-A2D5-FDDFACA7243C', '5997086103068', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F5EBD94-5EA4-468C-94D9-51D58248DCB6', '0335F636-60D9-4EFD-9157-0E39EB58C135', '5997086103167', '- 20/ 2  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3683C484-6D33-48DF-A0B3-94C4A3EB5115', '58CFC92D-4ADB-4AE6-A286-E1FB417F301E', '5997086103181', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83A9A4E8-03D4-42E2-A39C-12923EC4048F', 'EE62EA9B-9A2A-4115-B43E-6DF5627D8EA2', '5997086105055', '- 0,04 60  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41C62CC2-6C64-425C-85A7-8509751D2065', '1E003BF9-5D35-406E-B751-C833F8C002EA', '5997207711165', '  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30D0E954-FE23-4129-98ED-6EAB07C713C8', 'DCEFC185-6855-47B4-AB63-974997C847B3', '5997207711172', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF99A9F2-2811-4B8A-B313-60744FA7F5C9', '7A28AA7B-8F17-48F2-A4B9-A700270A8DFD', '5999518577553', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C96CDCB-7849-41BF-9308-0DC502D5F89D', 'E40F42F9-812B-4967-834E-2C1F0640BA93', '5999518577591', '   6+//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7077FB18-F9F8-40DB-A981-86F76AFBEA60', '6A1966BF-6947-405A-8EB9-CE10ECB5A220', '5999518577737', '   clean   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9D33D23-D134-4863-9D88-B012A6F2DCAD', '06B08898-F6F9-4858-8ED5-89CFC4577F37', '5999518577775', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A25F18A-6CF6-4248-9687-61E3524F73A1', 'B4B28691-74BB-4113-84F8-FC1B6738CF53', '5999886521035', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A964F92-B226-4623-BC7A-DCC06DA75018', '8C948D83-0E2B-4593-B2AE-C904D3C75F18', '6001076001209', '      /3-5//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F2C4DD1-0C33-448B-BA86-BC410E292E37', '185F3F30-9021-4E79-8158-44C4C700EEDB', '6221032140500', '  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37F1CB72-3926-483E-A292-71E3DA7DFD20', '82822C9A-AE36-47BB-B26F-375779347E66', '6221032321169', '  + - 2 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0542802-D9CC-46EF-8EE4-1D2883001B57', '738BD6F4-A58A-46A2-A136-278998E12114', '6221032336125', ' 20 / -    3 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C95906B9-64ED-4947-8C35-8316ED8DCC21', '69FCB773-ACEC-4317-B429-6EBF8527A28D', '6221088010253', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FE3D9AF-8B8C-4EFC-BFAA-5C718EAB6683', '5FAFD185-018A-4C11-9AFD-7F7CA51CA19E', '6221088021648', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A635A11E-F9E3-445E-A07F-0EBEE2899E11', 'A3E42F08-5697-475B-B279-C7A2AD9D3FA5', '6223000171547', ' 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7584BB2C-B21B-4113-B30F-D1097D7D8DD3', '73BE6B6B-ED2B-465A-B39E-97E766BFEEC3', '6223003737474', '  pad 1525 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32924000-DB03-420C-8477-5E07ABC75235', '8A4331DA-5FA4-436F-A35C-134184E9A281', '6224000549312', '-   20/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBBE3A4F-DE67-4011-822D-12149C36DFBF', '03FFBB05-3E68-41E2-94A1-7A73C83BB69C', '6224000549329', '-   20/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C9D3DFB-7F0F-4A5B-9B2E-CE13AEF0D155', '7CE71727-0D39-44EC-A892-C503FADEE366', '6224000549336', '  Aqua protect 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3BE4E07-0253-4734-B426-81514A6159AF', '031706E8-80E9-4F90-8594-1A8D1059D34B', '6224000549343', '  Kids 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F39EBF9-1925-4710-B12C-AFA2190D823D', '00500FD5-332D-4F50-BFF9-EA71CD43B96A', '6224000549350', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('480796E8-CF0D-4B48-9D4F-E3CC86A6F247', '994292A2-94D7-4079-B6AB-AFA1D538185D', '6224000549367', '-  sensi 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73C2A51D-CE84-40A6-8D0D-2F38A07B5F73', '4DA4E0CC-3ADC-4453-B6B8-12562CD11420', '6224007257982', '  158 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C2AF33C-4D32-4EEC-97F6-FAD1E4C91000', '90E9B950-0DC1-4B9A-94D6-EAA63C61F0E2', '6281001510390', '    0-2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1956C593-E516-4CE4-902D-A14CBCF91A5E', 'FB7E87F9-71A6-4C4F-A3B1-E84BB009C6CF', '6297000713168', '   /  /71316/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC9E6AA1-40DB-48B4-BD44-9B4989FA0F71', 'B313DF26-27AF-4AC4-9694-C503A6A97865', '6347257711018', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB1F407D-5842-43E2-80D2-032D29C5598E', '63EC95B0-9EBA-4D6B-918D-C1764ED9A55F', '6414100793009', '    /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB755AC2-0A66-4DED-86BB-1712902BFBFF', '2BBCF512-281E-4852-8471-02E57C3D8B2C', '6417150005504', ' 4    /   215', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB1966E-2C2E-43F6-BFE7-AB46EEA3AE92', '16E3EFCF-0ED3-47B3-A19D-E5CE9F1F90A7', '6417927102948', '    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D67A69ED-6BC3-4212-B4AA-CE3A60CBC840', 'EA59E2A1-58CE-4D8D-87E0-6E1FB59F4037', '6419716601137', '  0,1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('282EF8D3-F60B-4AA2-BF4E-4B08B36FEF6B', 'CD8A0FFC-B5E2-4162-9B14-3052B3B39DD6', '6419716601694', ' 0,0015% 0,3   - 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12CC56C1-ADF0-4A63-90D2-4F44F6040D69', '8372BA2E-909F-4DF9-BB59-87AA2CF55A8E', '6419716603292', '- 0,1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ED3AD2F-D3A8-491B-BFA2-50BA558B7621', '1CE57BEE-6302-4C5D-952F-DCC9AE71BC32', '6419716604442', ' 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87F402F2-609A-4785-94D9-E96CBDC4EEF8', '86582F81-C211-4646-952A-8C120692CEB8', '6419716604602', '   10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C6A7959-5603-4ED7-A8BA-37FB77C8E14E', 'E5F65B10-5478-4525-93BE-7C218BF1CFBB', '6419716606248', ' 20 +5 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('472CB854-04D0-4596-B9FC-22D0EAAD98A7', 'D531F3D4-3857-40D3-8FD8-E1A277DC748E', '6419716608204', ' +0,5% 0,0015% 0,3   30 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B95B2EA-BF2F-4BA4-861E-764C344FB630', '81F4C88B-46EA-429D-A24E-30CF09D39FE2', '6419716933320', ' 2% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90AD833A-C3CA-47B5-8876-71B68278334D', 'B4765889-7251-47C4-9590-849FD00AB3CF', '6419716933337', '  4% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBDB3583-5F3A-4706-99B7-6EBF68D807A4', '91A919B3-8640-4A25-B1F5-F73BFC84DEBF', '6419716947327', ' 2% 20/   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02875614-AC86-40F0-8058-DD9F765C297C', '6EA89152-EDEA-46EC-A8C9-182F8B86EFEB', '6419716950297', ' 0,25% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B35932A1-B1D1-468D-8B49-D33C1E10F754', '889C8CC5-6748-40E3-900B-E4BCF69BCC7D', '6419716950907', '  0,5% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C921A1F-60C8-4360-AC7E-9FAA79144C64', 'F6A6CD1F-0E85-4A95-BDBC-579602683B1A', '6419716965130', ' // 0,5% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64FB5500-3C32-4B8B-98EC-F74FE3FD58C7', 'C4367E29-98A0-4A30-A88F-D8924DAF2B95', '6419824961505', ' . .  20/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('539E8D28-811A-4BD0-9E03-8C529CDB75F1', '92480020-10FE-4328-AC91-2B3E176A4200', '6430046750142', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('860E1855-81B1-477F-9806-E84691F42947', '321B95F0-5AAA-435F-8998-BECF8EF0B229', '6430046750166', '    silum 1100   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6197FE88-79BD-4D40-B6FA-B86612141741', 'A0CB881E-21EB-43EF-85DE-92A424EE3EBA', '6430046750302', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6BDE707-D24F-4310-889D-6DBACF4051CE', '7A290F19-4547-468E-BB80-855C7C3ED80F', '6432100003218', ' 0,1% 0,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A481B2DD-392A-44DF-9690-7B48BD89DB19', '2504B6A8-2C30-4757-A3A5-2300E6FB1D88', '6432100003225', ' 0,1% 1  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4F8F072-FFC6-4AF1-9F9A-1D26E404D736', '10079725-E611-4C70-A70C-4866196E7C24', '6432100009210', '- 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21339827-11A3-4202-A86C-FF355D5B9685', 'DE277BB5-87F2-4E0F-9698-4D85AB56E7F0', '6432100012777', '  12/ 120  1,7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A6E20D3-A212-496D-A68A-C4E14E1A8B42', '1E2BCA15-8B69-489A-8C0F-E71A541C892A', '6432100013460', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76EEF03A-088C-4B98-863D-A1E15D0EB6BC', '4CF7001C-4F2C-43A0-9C1C-CC35480AF07D', '6432100021359', '  0,2  200+  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E87CF434-9C55-4A15-86CA-587036C937E1', '24EBCA74-1C93-4BA3-B0B0-1406A742714F', '6432100024640', '  6,4 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('249B0D3B-B354-4896-A46C-18AB89711107', 'DDA6FB6C-A089-4C60-81D7-2F05CD1C8E42', '6432100024664', '-  /   10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37407F17-49E6-4C57-8683-5DD7970FE08D', 'D13308B8-D156-4B25-9E9E-875C05A4B303', '6432100027245', '- / 3/  25  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA910DE7-5F36-4DFB-B151-C330AE4BAF9D', 'CDD02AB0-7BAC-437E-A939-DC3F182D5E10', '6432100027696', '  / 250 +-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C496B80-B648-487D-BC86-3FF543260081', 'DD918B3B-E6DF-4688-ADA8-9C6E74A40625', '6901986000036', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6A953B0-4531-409E-BDCC-299255BBFBF3', '5FE0FC61-E4D7-4A02-83A4-D8887C83C2F2', '6903883245862', ' 0,3  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77CC9E13-5C69-45A6-B4F5-3BB990081D16', 'F4E0F13A-FCBC-4B42-9931-5181D3ECBB4E', '6904566110323', '      22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('901161E4-1B66-4436-BE0E-EE997F42067B', 'DB5C99D6-B2B4-48C5-A623-541E9271742A', '6905321689429', '  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FD3C87D-A85E-48C1-B3E8-EC6DBD6BD55E', '3510E269-DE53-4F53-B7EE-362D97A5DBA6', '6905356472485', ' 10/ 1,5  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28640884-CBA1-4736-82A5-D16378206068', 'CC9D9B91-4AB0-4D36-B853-6EA8C9E38867', '6910181210607', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D801EEE8-6E10-41C6-808D-4EA5C00B18D1', 'CD527D43-D9F1-4D80-9CFC-D304B94230A3', '6913362801380', '  longa      3+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('211F1790-3213-4AD9-AE2B-E3C2065EDE7D', 'CD527D43-D9F1-4D80-9CFC-D304B94230A3', '6913362801519', '  longa      3+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('102B4268-75AD-4652-B03B-AE58ED4C8CEE', 'FA15C994-21A1-4F25-8940-BEF9A39F2B9D', '6916119060702', ' 2% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94736D36-38CC-4C93-82A1-CD674B5EDB54', '1FED5AB0-2E45-472F-8DD8-40021D59FDFD', '6920354812989', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA0E40DD-65A5-4DC8-885D-633433E91DE6', 'CEBDF32C-9ADB-46A0-B72D-9852BC33BB32', '6920354817021', '    12   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1536CC7-27FE-43BD-9839-14B0736BC1DF', '9EA8F0B5-B1AE-4807-B67E-F36C8D55EEB1', '6920548932523', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96227034-22DD-40CC-9D25-DF5D8F1B5F72', '6781E448-09EB-4F74-82A9-C3CC7C2D7583', '6920548978255', ' /-intim/ 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C5F9842-5507-4E4C-8257-50B153055984', '6827025F-CEBF-4BC4-9751-0F9F110274DE', '6920584692153', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCE03189-02DA-45B5-892E-B02E9C7A8D35', '60EE34CC-BD1E-4F08-BE2E-217326BCC15E', '6921570911821', '   /     80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CAD7110-383D-4D70-B7ED-E09481F4A8A8', 'D39961C3-D481-4735-9CB9-E9561CA174F9', '6921665004063', ' 10%  /  38', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAC75788-076D-43F7-A678-41070A86C984', 'F8E46488-4503-49AA-A19E-5ABAD28253E5', '6921936909011', '    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC83AB77-19AA-4C18-929E-6E1F78B7B522', '8920526C-EB69-4D66-A95A-081638814E5A', '6921936909035', '    / 3 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D64F29AB-0A6C-49A2-8EFF-30EFB8177FF3', '3135607D-DC09-4700-ACFD-9DB6A4EA0A08', '6921936909059', '    3 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('631D5D09-3464-4DC1-A81D-E8E1A9AE30BC', '4262B60B-2DE6-44C9-9DB2-FFF969EC4655', '6921936909066', '     3,2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7CA4AF9-B5DF-4BDD-986F-6E84FEAAA324', '35E12CA5-E337-4B4D-BDDE-2C4DF744C13A', '6921936909073', '    3 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('066175BF-5B5F-4EE9-845E-3E44C6A748A4', '5EC20FF3-F8F6-4A31-A0E5-B43F293C4C7B', '6921936909080', '     3,2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('428FD476-12E1-4CE1-AC8D-D93B07EA7EA1', '824E0820-86F7-4CD4-8B8E-21B4EB3710F9', '6921936909097', '     3,2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAA6CA92-F7D5-4443-B073-678C060D1EF5', '48664518-63B9-4AF9-B3BA-1F24FF71C4D8', '6923391320189', ' 350  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B926E605-1E59-4D3B-B82A-C455486CDE42', 'E34C07A8-F0A5-4A01-8FDE-1A4766D4969A', '6924217143678', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5A91B1A-91A8-427B-9FD0-44F88E37DC1C', 'C54EC415-21C8-4056-A911-106B1F13E949', '6925253921015', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83A84C5A-D027-4E95-8178-991E4AC106B0', 'C54EC415-21C8-4056-A911-106B1F13E949', '6925253921022', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('513179DF-F774-4711-BD64-0A762F4B796A', '5B140598-0F52-42FF-AA49-87F38EDCAE4D', '6925253922012', '     450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D6EF15F-3934-4888-9BA0-05AE531CA780', 'A3F1F791-9308-4C6D-AC51-2FCDA338AEFA', '6925253923019', '     1200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA5A68D6-1A12-4CED-9EE2-80A487CBEA08', 'A3F1F791-9308-4C6D-AC51-2FCDA338AEFA', '6925253923026', '     1200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DF242CA-25E5-41D2-9CE7-EA2D49779860', 'F9D3E836-BA56-4892-B85B-16D7E677D01C', '6925253924016', '     650', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('766465F5-A8B8-4B9F-B0BD-79B452328DC6', 'F9D3E836-BA56-4892-B85B-16D7E677D01C', '6925253924023', '     650', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D9313A8-AE10-4F9E-8F88-7E52D3F8B8B4', '918F7D20-0E8A-4E13-891F-7A6E036C84FD', '6925881200315', ' 25/ 3  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4FD1553-79E4-41CF-A837-8497BDEA0EFC', 'FBA20E18-8265-40BC-AC81-31D01A16B370', '6927091100676', ' 0,001  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E20AC20F-9CB9-4371-B33E-B2766D4034CB', '757F1D38-2944-432D-955D-3A186030100C', '6930169702580', ' / 0,1% 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EF508BD-726E-455E-8806-92818A4A3020', 'FA15C994-21A1-4F25-8940-BEF9A39F2B9D', '6930169702788', ' 2% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E415DE7-147F-4382-92C3-50E45A24A3EE', 'FC963FB0-4CBF-4F38-88BF-B85EF7E4033B', '6930169706526', '  10% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8289A2D3-275F-44F9-A735-4991A2DEA7EC', '2A4BCE3A-98E2-4446-BE28-7ED97F129E44', '6932511207491', '   /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E1EBACA-EC9C-4825-9944-25671A84F2A2', '32304E73-D42C-4A3B-9DE3-604CB1149FFD', '6932511208771', '   /   .  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C61A405D-A295-4A20-8558-3FCAEB86D429', 'BDED7255-2606-4101-8887-B47CDBA584C0', '6933298201702', '  2- . -18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('092CECEB-8031-4AE3-B9D3-FE67AC4E3A79', 'CEDF42C6-8CA2-4CFB-94CB-AF073614DB90', '6933298202327', ' / / 750', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACDB9023-437C-468E-AC07-921FE6F8DC88', '90A8B174-93D9-490B-A291-DA392391AA1C', '6933315515577', '     / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('963C2297-8598-4E67-82F6-44BB477862A0', 'CD60BC5F-B4F4-4707-9E99-9A3162881001', '6933315515850', '   7   / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC92113A-5612-4C1B-AF55-7D0AB7FE07B8', '8C7EB6BE-9406-4091-B42C-A54B7B802553', '6933315520151', '   7  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36C36F03-5D92-403F-B181-DA94A0937879', '754F780C-5655-4884-B70E-8E07C96BF324', '6934393806052', '       .. / 3 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BA818C2-0C5A-4364-B1CD-FEBE2D6A27A2', '7E08FE60-E8F1-4ECC-BBB0-C351D4C4F0A3', '6934393806199', '  longa      +5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE31F105-8BBF-46CA-98DC-3BB4D4A7A3C1', '1B643FBC-13AC-4A88-9120-041435A5F3A0', '6935563820021', 'Minima     12//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2206CFE5-2F3E-4DEC-B614-BDC756A6A859', 'B917F8F0-C0AA-4D91-8D0D-66D24D1A6224', '6935563820038', 'Minima     12//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCE1AD19-54A6-4EA4-9D0D-77EB498B0C98', '3A41B116-4BF9-49BC-A540-578FC311CEDE', '6936196700032', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FE470F7-75B2-4439-9AE2-6DA98F832AE2', 'B62043B1-E4C0-4ED0-9504-8B53E60CA18E', '6936689110089', ' 2% 10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('930C10BB-726C-4591-A6D6-B2D9979AA824', 'EB0D07B0-723A-417B-ABF0-8F6B228014C4', '6937144318415', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3B4F6B7-A174-4C61-B5C3-75AD53F146DB', 'A0D79A43-C77A-44F3-BF27-693E8C462257', '6937579910390', '  . /   .  100, .l ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47EEECB8-F300-4DE7-B1E7-D81CF2E71D0F', '6078620A-B865-4340-AA04-64A582637975', '6937579910406', ' o vietest   /hcg/  - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('655A0D01-1F51-4892-986C-A12E5B7C2307', '9E1494E4-D5E1-4787-8858-4362AB553599', '6938444901086', '   5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A176CCD0-A412-408D-BA19-C559DDC45907', '7E537EC9-BD2D-4E8B-8C59-551E41B95BFC', '6938588803079', ' 12,5% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C904862-1D94-4EE2-9028-7DFF91F37022', 'A346AAA1-B4DF-40EF-8AE2-18609F696020', '6938942287378', ' - /  shiny foot 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB6537CF-34A9-4B43-918A-20A4F7FAC78C', '976579A5-7C82-493B-9903-726989EE3133', '6938942288245', ' - /  1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5731C970-E90B-4279-AFAF-F1458DF1E32F', 'B9E9AC6D-90A8-4B4A-B042-2C8DF1ABD2BE', '6939007600330', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24405C0F-D913-45D9-ACD8-94822DD29490', '5DB21532-0219-403B-8DEB-531B34FA375D', '6939153800424', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82839491-DEA4-4019-868F-964BA3F33DAB', '7BAA82D2-34C8-4993-A824-400F5DAE6EEC', '6939153800448', '     55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18A74EC2-E3C9-4F99-8B06-38D7A07AF8FA', 'E99FE361-973E-4C36-B21E-431181265199', '6940456000060', '  /    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B9A381F-B044-4948-AB01-2B304345F742', 'AB68F265-D456-4AA7-BC20-466E56FCA54F', '6941298300011', '   itest ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0BC5C8F-722A-4FF6-859A-34C04A372E73', '848325E4-6B55-493C-B652-B3284CEE7C4F', '6941762650246', '  NEXT     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('279E0D14-E736-45D4-AABF-C80C7A873363', '10B2A8AD-E9B0-47D0-8E8F-D087E29D47DA', '6941762650253', '-  net       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A62ECA6C-D339-43AE-890C-1290AA65C06A', 'CAA4154D-9920-4D15-B5B0-5D7368785DD4', '6941762650260', '-   net     19*72  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04EB94BF-B8C2-4D2F-AD99-81D2436D5FCB', '08C075B8-60E1-4797-B93F-39D1BE1686A3', '6941762650277', '-  NEXT      19*72  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EAF9ADB-04B4-461F-8BF6-4FB3C72571CD', '335E19C3-98EE-4BAA-9594-15401A275505', '6941762681073', '    4500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59F5842F-E94F-40F4-8994-A68E0659DB25', 'E2F01C97-9BE3-417E-A521-C9495CD78BDB', '6941762681080', '  . . 5500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1C2ACA2-965C-4307-A8DC-3184263D5817', '012A09CF-C7C2-42F1-AF23-E2A645E80F18', '6941762681103', '  1500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7ABDEFE-4579-4475-A20B-ED8E503AEBD7', 'A39101CD-4B09-49C5-B6B7-315FDE652CE6', '6941762681110', '- silkofi   2500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1E6A939-2D2B-4767-925E-AD4C6E1438A7', 'B2C111A3-1051-466E-A502-2E5A2604C9D8', '6941762681202', ' silkofi 1500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('114A2E13-80C6-4081-B0BF-84B245D783AC', '7EDB886F-E61A-453D-A1F2-62E31DCF94C9', '6941762681219', ' silkofi 2500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D3D3AB3-3B01-49AE-8E5F-24D0AC7076F4', '6DA808DF-EDD7-48E8-95FD-D3F8C98B0164', '6941762681226', ' 5500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('114238F4-8DF1-465D-A0C7-944D863D7029', 'C072EFF1-76D4-4F60-92A0-FC3465E41EF6', '6942895980118', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D0736B0-1562-4A19-A24F-54535963572E', '91151964-6E82-4D15-B9CD-3B8CAF6B5D3F', '6943809100165', ' wc-150  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E1739C9-9F0F-4E77-97E1-4CF04023228B', '18625EBE-61B3-495A-AC0A-986C94DFEC83', '6943809100226', ' wf-1000  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7871E86C-B281-4A1B-85D4-4F4AF85808EB', 'F49F3256-E9E5-45B6-B2C1-9402082D2E02', '6946159500098', ' b. well wt-03 base ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D8A1370-87AB-4A90-8483-8DDF4EE17A44', '4E64A0E6-B58D-4381-BDF2-2ECA311E7CA7', '6946159500104', ' WT-06  .  6 , ,.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F84E5C6-F8BE-411E-B5BB-E8FAC7795FBE', 'E3467252-14DC-40C9-8EBF-58CA0E25620F', '6946159500234', ' wt-04    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DAC8A7A-AD4E-4752-87D8-18D860D131B7', 'D8F8BC2A-4543-4AE1-9E3F-0F516557F72E', '6946159500296', ' wn-117  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EF78418-6E9E-46CB-8AE9-855E5A505A3E', 'A89F1ACB-FF0C-49A1-A588-C2B864E208EC', '6946159501071', '  wt-05 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC6CB9E5-93B2-452C-9E94-9D390B12EF1D', 'E3839FAC-72D2-4477-AEC4-960477918E69', '6950570781714', ' spring  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BFF76A8-1B50-4973-8956-134F2456E876', '752AB082-E313-4D8B-9A81-3F8C07A636CC', '6950570781721', ' bubbles spring  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77D9D6A2-443E-43C3-BB9B-A725F8997301', '5C4F47B6-B8FC-4A19-89C2-B21935C4711A', '6950570781738', ' spring  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C86FDC6-9011-4A27-AB33-940A4774455B', '23B5750A-DD02-4803-B070-CF1551022D9E', '6950570781745', ' // spring 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84282A89-6F2A-4620-9E47-FF5F0CA52B65', '0EE1BA18-A7BA-484C-881C-6E522D58E4EF', '6950570781752', ' .    .S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B63CACC-7E7C-419C-97AF-F4EDEFAFB687', 'D49097B7-F607-42A0-94CB-C0662EBA5BF6', '6950570781769', ' aromantic spring  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47D561A1-290E-4F4B-A90B-D2F9B3528126', 'EB49A08A-23FC-4435-87B7-2B6E544C810A', '6950570782261', ' // spring 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A313C7E-011D-4B20-9319-6B981580823D', '67580709-57A6-4286-AB06-8D4461FBE8AB', '6950570782308', ' spring  9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3360B3A-BA61-4D53-9062-9719421F41FE', '53507AED-CBF6-4CE8-9236-5027B9F209DA', '6950570782407', '  arlette 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('579850BF-2C53-4593-AE93-ECA1EC7C2349', '9D59E7FF-1A04-4B59-A75A-BC7A8FFDE891', '6950570782414', ' arlette  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04CAA5D1-BDCF-475C-A01A-665ADF08539C', 'D4D844D0-27A1-4AA0-B3FC-E1232AC33BB5', '6950570782421', '   arlette 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('042ED3B1-1937-4071-8A89-3461DE14F503', 'E4E6B2CB-DA53-451B-93F6-CE676DF11A5F', '6950570782438', ' dotted  arlette 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E418A222-AF24-4A40-8E54-6D1753BE18EB', '98F1969D-2BB8-422C-A765-FAFAB90B84B6', '6950570782704', '  . .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('220FA9E4-000B-465C-AD06-3F18D41EA161', '8053E282-A319-491A-A4D2-2B33064986B6', '6953462900071', ' 16,1 /-/   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B341EF62-D24D-4807-9255-B9F56B4DE92B', '7D4292F5-3599-4590-AF97-E2A12C85A8D4', '6955454320218', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07B0A6B2-839F-439A-BE21-D3914F045D00', 'D35967DC-D418-4716-B82B-FA75572B5B2D', '6955454320355', ' 750 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05E7B5A9-AF6B-4A46-92B4-A3F6E23A6576', 'E76FDC43-E3E9-4097-BBC5-24A95D65F0E1', '6956756300106', ' 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36E40849-9E66-44C5-838D-B910F3238487', 'ECA1E21D-159E-406B-8D43-105DFA7321B9', '6958627514049', '     / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2ED51FB-A3F8-4973-8787-4C61AE108FC8', '47E0EE93-3C1A-4828-9383-F91A857C1F9D', '6958627514056', '      . . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E7DC308-FE38-48CD-B15C-194385863EB4', 'FF4DBB71-3304-405A-B041-82D7F2F39779', '6958627514063', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C91D0F9F-DD9A-49A0-854B-2BDEAA7C528B', 'C072EFF1-76D4-4F60-92A0-FC3465E41EF6', '6958627514070', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF328B0F-2888-45D0-93CA-01DA6532AE28', '5C9C2E7A-4E0D-422E-964A-ED344D297B55', '6958627516012', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('452E0541-EB87-48AC-84F7-F28C903F50D1', '9D62AD13-05FC-4FEA-B4C8-7935DEBB71E0', '6958627516029', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A6993DF-B082-4600-B198-61295BA627AB', 'B051768B-6111-4580-B7C4-ACFB3816B8AF', '6958627516036', '    3  . 20 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45E64744-5979-440D-B938-EE9817825E36', '9B154838-4E4F-441B-ADC9-964E815293CF', '6958627516043', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('878D9883-5843-43FA-88CC-60B1BFC72C06', 'DEB44228-A29C-4613-9D93-0D8449772B85', '6958627516050', '  610 big-strap    /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA796223-9D56-438E-9DDA-2B1498350B34', '379A2D84-445C-45C1-8582-577C33268E49', '6958627516074', '  3500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD01561E-E399-4E6C-AD80-2161AFC3618E', '28B93ED5-0310-4ADA-97C0-8F29B3B3163A', '6958627516081', '  4500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83E6E2AB-83D0-4F1B-B991-16DF59A1055C', '7D26C750-84A8-435F-86F9-54EB99749D54', '6958627516098', '  2500    //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BED5F100-1D47-45B0-B0C2-0541572AB23A', '936C48F2-0695-4CD8-ABF5-124AED88D063', '6958627516104', '  2500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC10292A-C299-44A3-947C-336A0F940451', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '6958697601663', ' 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31C68C4B-4E6A-4C30-89D3-5D0B39D40247', '977477DC-2090-41C5-B98B-8668E8B13F1B', '6959287500106', ' 1  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('973553E3-7BE4-4575-BA42-60A353F671D1', 'C939BF31-006D-4E75-AE96-45710223512C', '6959287560001', ' /   /150/ -2, 500 /, binano, ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('825057C2-D173-4DF2-BC7F-4DA40FBE062E', '80869B3E-BB82-4492-8EBB-2CE2889D7AFB', '7038310001007', ' 3   -   500 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F12BF7C-B864-44AF-A9DD-2864D1E5E472', '312F07A7-887A-4626-ACD6-97AE8CDEF8DA', '7038310001106', ' 3 0,5+200  /-/  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC89C840-194F-4398-94E9-852B5E6FAFF8', 'AB51CD8B-9B89-44AA-940F-C2C1213645DA', '7038319032088', ' 3 500 //   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEDA4F1C-4C27-4C9F-A14F-D2C1CBD9722F', '04C6C270-6F89-41E2-BCB2-9547F0A249C8', '7038319033498', '   0,05% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91ACB509-F7B2-49CF-9CFF-402D52C914CD', '3531BF79-B988-45BD-980E-74B8F0A92322', '7038319033504', '  0,1%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FAE046D-875E-4B0C-A18D-3133D5E06026', 'D342F5B1-69CA-4889-8B2D-1482C35440E1', '7038319033511', '   0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF0B20E0-E60A-4CA0-8B4E-56CCD6957CFC', '1FA282B3-0D14-46BF-9C77-57360E926478', '7038319033528', '  84+70 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B4867C7-5057-4F10-8084-BC676BD6762D', 'C6D9AA55-95D6-4E29-9F49-B99166C32AD5', '7038319109094', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('881D737A-8EA5-44FC-9E98-F14C0443EC76', 'D4D16A99-FE61-42E2-9632-A6AB8D9873B3', '7046264364109', ' 2%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5D76418-EF0C-48C4-A7EB-03FC098F8C13', 'B64771C5-F458-439A-8FCE-F2F58BBD5DD5', '7290000504025', '    300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A872C92-7F84-4635-91FF-5563503B3A86', 'B1EFEECC-A375-4FAF-9F65-D0C4B4F6277A', '7290000504049', '    1200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFF3EE21-05B6-450A-9102-CE69C2B30E89', '6A4B3B75-39F4-4A23-91F1-E480F4E5A9D5', '7290005211966', '     / 3 / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0597EF80-C71F-4C0D-A3D0-0BC3812C3BC0', 'C92CB194-E2D1-4F6C-91C4-FF03E4CD4F3A', '7290006558688', 'Frautest  // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66E5A3B1-6625-48DA-9321-0670DDB7B143', 'B417EA10-3DB6-4847-BA72-1C5A15399936', '7290008001557', ' 3 0,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A08C1E6D-94B2-4B47-BC33-F4718FDDDF98', 'BEEB9A1A-F87D-4AFB-AACF-8C3FC6EC1A48', '7290008095044', ' 3 0,25  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35288E2D-E141-42D1-A57D-804ED928454A', 'D828F90D-8624-49CD-A3EF-21AB0A1D4DF6', '7290008096645', ' 3 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC49E49D-90A7-46BC-9113-1BAD9ADBA8AF', '8875B188-0E91-4072-B84E-E4284AC5BFDE', '7290010035786', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F37AC66F-0100-492D-B229-C7154539418E', 'FEEC54F7-7171-40AE-B734-1B6B8A6BB647', '7290010207091', '  /  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37E47F51-7C7C-4452-96C1-6E76E8CA79D9', '02C179B0-0603-4BFC-9BB9-3CCC21B114BA', '7290014065161', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A844F54-8882-41FD-883A-2F3ED14DC1F1', 'FBE9A8D5-3120-462C-A12A-D942003431CE', '7290102062287', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBA1D030-BC3F-46A6-A0B6-EF586C5BA3EF', '2199825C-54BA-47A0-A20C-A1B14445AD2C', '7290102063581', '  70  4+1  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64D5F4C3-7B6B-4D6E-9EFC-300E68D77C16', '74D3F716-4B73-4D05-84A2-3A6047107C04', '7290102064809', ' 3 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FA2A922-F70E-4E1E-9A40-0E13FF144648', 'BEEB9A1A-F87D-4AFB-AACF-8C3FC6EC1A48', '7290102064816', ' 3 0,25  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18B4C876-5FBD-401E-8125-A338A21E8F7A', '18411A82-8B82-4738-AFF5-0452E1BE35DC', '7290102064885', '- 500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C4C8104-CCCC-43A2-A9C8-A8DCA05041B1', '4A97004F-C7B3-4B70-A55E-C013492CAE16', '7290102064908', ' - 850  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6931C1F4-983F-4E3D-B81D-CA94903A8BF0', '40F2B865-6DF8-49C5-8F50-EEAAC58FB752', '7290102064915', ' 100030  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98BA8E20-FADD-4924-BE36-1D80A2A5F4AA', 'C8335160-84DD-4AF2-A19B-ACFAB0041CA5', '7290102064922', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A7A5964-CA5B-42BD-A592-FE6DCDA1F2AF', 'D34C82F0-EF19-4055-9D91-2510D0748D54', '7290102064939', ' - 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37C142A2-DDC0-4AB9-B7D2-4A8489529429', 'FF2A6465-C1B1-4DE1-AC5D-B96BC6DDD816', '7290102064946', ' 1000  / 60', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F00C3370-5EB2-4975-A223-94C1EB35780A', '6384F81F-D083-4B18-A5F4-A45FF4A92881', '7290102065394', '- 500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7E84FB4-8262-4644-978E-7DDAED3A452F', 'F94B91B1-FE51-4DD1-BADC-DC2B615BF66D', '7290102065400', '- 500  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93D5ADC6-5CAE-42F4-8889-E4860DFE4C15', 'E8AECA8C-1849-4BBD-B82F-67B61CD68537', '7290102065424', ' 250  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AC48729-9908-4CAA-9DDA-1B48802A08D4', '5A46F9BD-6309-4CE3-8777-DEF142C3F811', '7290102065431', '- 250  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EC9AFC5-6390-4016-99C7-5D0A552C9489', '57AB73C5-E3BB-4427-8631-971925C4662A', '7290102066025', '- 75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8B585C3-A95C-4092-9A93-3A9A62AF7F43', '7837965F-1C2B-4AEE-BDEC-5101E571D3B4', '7290102066452', ' 5  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE127D1F-7122-4651-BCA3-5983F8ED1F9C', 'D41A823B-4481-4DA6-870F-1D94353BE8C2', '7290102066551', '- 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCDD4CF7-397B-4653-8401-2A3931FE70A0', '419EA223-17D0-45AD-90CD-F83433FF5142', '7290102066575', '- 10   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C46CB86E-8485-43A3-9B85-A7ABCC0496D8', 'CFB81857-8300-4AFD-B0E2-B911A4FD609B', '7290102066582', ' 10  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D3DA886-E424-451F-9293-6215FC295B87', '1F7B199D-54B3-4BF7-8BF1-080B79E4B7EF', '7290102066650', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D8FFF97-CF6F-410C-83E0-1B8552B89BAC', '9D4F9A09-820E-4E15-BCD8-166D18C99266', '7290102066674', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C46B28D8-CB11-4617-852E-75D547559CEA', '191A3F83-E82D-421D-80A0-8FE78472A1FA', '7290102066681', ' 10  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC46CEEF-CAE2-415C-8D0A-6FB108FA5B90', '3A17D487-C312-4928-873E-1ABA5B6E3BF1', '7290102066704', ' 20  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7321C42-9668-4BB3-AE73-EF9C901D75CF', 'F1253029-9791-4EF7-A9B7-A6E00ABC246E', '7290102067152', '  500   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D69072E-478A-4F8F-8194-503574CE59DB', 'D081869E-0F52-4287-86AC-A520E491CA64', '7290102067169', ' - 500   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D44B6E6C-6B37-4D47-A54B-B7FAC5C30881', '4C06AEDB-0E26-48D6-B897-F4F772D5E94C', '7290106064157', ' 0,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1100E275-38DC-496A-AD3D-707E15FAA92D', '1923662B-1FBA-4808-9C1B-1A9A296C1705', '7290106064164', ' 0,5  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0CE3492-5FB4-4876-8C9D-7F586366E2F0', '89DBBCDF-278E-40E1-8270-284B19C606B5', '7290106064188', ' . 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81518EBB-C646-4BFA-AC32-629D9C6819D8', 'A2A1512B-1E20-42A3-884C-0A6D2923B152', '7290106064195', '  12,5+16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75C25E50-FC0F-45CD-9827-6656AA0EBF74', 'CFC8958C-5FB8-4540-A10F-67FE136055D8', '7290106064461', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EADE651-4B9C-43CF-B3A6-C66FA68F4893', 'DA865D3A-12C5-4569-9C73-8ECF688F4F5F', '7290106064478', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D2B26BD-DDDB-4B42-9429-ABB7BAEE7870', 'E71758F3-4EC0-46CC-9561-0266ECBCCD77', '7290106064485', ' 32  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9C0603F-8136-4095-A8B2-9CCEA672C57A', '34401D25-ED1C-4C23-9D2F-A5BE95C41429', '7310790088731', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1E3AF2D-75ED-46EF-8896-56229ED04576', 'B086806A-6D44-4580-99F4-4245EC50F2EB', '7310791268002', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEC255E7-D9A9-4E4D-931F-6C045C31A666', '1F1B160B-1227-4C16-A8BE-89B4C45DE0CA', '7315514600114', '   5 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFFDF30F-73B9-4536-B775-3219A7B292C9', '7C4308EF-3701-418A-815C-4AF66CBEED0B', '7321838730352', '  /   . 5% 5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2188B98-12D2-4548-88F9-764D27BD2F19', 'FA61FDFF-F544-432C-B82D-BECB29CDAFA1', '7321838730925', '  100 / 200  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06808ECF-52FA-4D12-83B6-6CEDB114BF69', 'DA929B95-2371-459F-AD52-6EBECFC62104', '7321838730932', '  100  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E14B8409-8E9E-42C1-B7C8-1D0AAB310D11', '5948B008-9209-4043-A7F3-7027D3ACE1FF', '7321838740092', ' 100  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD9F9B45-4B65-40E2-9013-3A9838818967', 'DD497100-8761-4211-A2F3-5FF5B59BC5A3', '7321838741433', '  0,02  14 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C76C1975-3A55-4CB7-A758-7B0E5B9D3158', 'D3313F4E-54D5-445D-B9A1-D4A260C07F2E', '7322540013658', '     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F33A117-FBC7-4E44-9675-29884EC74C84', 'E94EDEC3-0308-49A6-8211-99E9CBDAECC9', '7322540016413', '  . / .2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F6F7BBA-2EBF-4BFA-973E-E213A9ACBF18', '02103B74-7C1F-44B3-8A86-69042FC1EEAB', '7322540016987', '   e 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76FFD8D7-4AF2-4129-9808-64ED5960B4FB', '77EC45A9-4F33-4F40-B36A-F8C2739ECF9F', '7322540024357', '    10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96D96E09-790A-4218-B89E-BD7D8724F9AF', '3F6C7063-BEC8-4A51-85FD-7F8ED3DFA0E6', '7322540043440', '   e 10  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B80352FB-CA03-4D2C-89A3-64489F5D2DA5', 'B6328CF5-7E7F-4363-9956-DBA573C276BA', '7322540043716', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C049DD7-4654-4645-B15E-52F247924976', 'CCF8D44B-BC89-44A6-9F88-D1E73193B85F', '7322540080933', '     28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9D32CD3-AC57-4CE4-A8CC-55F79BB8A169', '75B48431-FF54-4BF6-B5A9-E6DC42C1CA52', '7322540098075', '     10*10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98B96CCF-7139-4A9C-BAF5-3E1CA109D99C', '75B48431-FF54-4BF6-B5A9-E6DC42C1CA52', '7322540098846', '     10*10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BBEB1BA-8E95-408A-88E9-18E1F2216C19', '0657A59A-B1AF-40A2-A332-6F44F3097923', '7322540157093', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D562D7CA-E6DF-4F76-B3A3-AD925B61A71D', '436963FE-6B5E-4C95-A966-AE777919B3BC', '7322540245431', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D1EE959-7F77-4B4F-B68F-FABD8716B41B', '586ECFE3-1E30-40F0-B309-91A428998D17', '7322540310320', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24ABA9C8-7CCD-4495-9871-205C331E45B2', '4EF6AD34-75F2-444B-BBC5-04039181FDDD', '7322540337938', '     /5237/    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E99BF6C-8057-4135-9529-3EE7E90F4584', '8FCBAE80-E5AF-4E4E-8AE5-09BDDC0D417A', '7322540338911', '     28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44E79CF0-5C60-48CD-B0AA-2AF89D0AC133', '8A1090E2-F7BB-4952-88C2-0C99BFCCE239', '7322540388466', '  invisible  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58B62BEF-34DC-44E2-8A51-1EBA30F73EFE', '265DB71A-794E-424C-B44E-A1C69E7F8C1C', '7322540523300', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BC8188A-D595-428D-8479-D685C1263898', 'AF7F9838-8540-4234-A7AE-FF0C19095F61', '7322540523720', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A7E475C-EA12-445E-8A1B-C7B2586BFDC4', 'B3487AF9-0D32-47E7-BC57-63EC18B39E58', '7322540523744', '      9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40C8F7C0-7ECD-4B5D-A239-E48FBB7813F6', 'E0E4ABC1-F889-402B-829B-403E6B955714', '7322540545326', '   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18F615EB-547E-4687-9991-5FB089346632', '5B71534F-7C85-4FBF-A7AF-293F73207996', '7322540576382', '     6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8389B4D7-BE1F-4EE5-95B5-2F1EDF75BBF9', 'BC2D7E6B-8926-4989-8C63-053E35B16159', '7322540576405', '     6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42BD05E2-8079-4EB6-8424-FFC573341144', '4D3FA71F-0FE7-4678-A0A9-0E0FF9E4EB81', '7322540581171', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4A7D115-2268-400A-93D2-447A93C6D50C', '936165CB-40FF-45F0-9336-F69FAC98B09E', '7322540587258', '      10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('388A48E0-9D36-47F1-AD06-DCDA7240B896', 'ED0B97F9-95FA-4EE4-B972-B1E53669264B', '7322540587852', '    / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB2E526C-B3ED-4459-87D5-BBC58D9AAEC5', 'F35709C4-FDD9-45A6-A1B9-2079887230EC', '7322540611236', '     7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE93454E-8D8A-49C1-9F9B-64BEED6853A1', 'E943F804-76BC-4709-A817-AF00209E3FCF', '7322540630350', ' -     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F78B2F5-9A01-4BC8-A4DF-A04F2BA6EA0E', 'B10264E3-F647-4416-98E5-DED7B4C50298', '7322540636703', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2253B5B8-0171-4131-9C40-F5435E3497A0', '0E7358B6-0EBD-4C65-B5AE-A15927E0AE9B', '7322540646726', '     /m/ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FEC9132-5C86-4A05-BCAC-5ED96D2426AF', 'B96187D1-27E8-4BF9-B5F5-00D20307DD97', '7322540666861', '     6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0A3EE0F-F861-40E7-BC30-A69355F35598', '522EF5EE-6173-4B5A-94BF-399F8DA2E759', '7322540666885', '   6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18B91603-A3F3-4E61-86C1-514215CD257F', '7683E12D-7E5C-4B60-9A27-FDEF98723D2D', '7322540762235', ' proskin        20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D337E896-772A-41DA-A521-266F1B0028C6', '8BE3E459-56B6-4CB7-8FED-B3C170A55C05', '7322540762334', '  multistyle    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D396797A-20EC-4302-8042-0A3814965BC5', 'EC7D0554-309F-4A0C-AE1F-FC46AF353AC2', '7322540762396', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF4BE87E-7921-4527-997B-757F7D618AD5', 'C93AB362-FB45-4840-9815-9FAE10554A72', '7322540764185', '     /l/ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A998757E-EDE1-4D9F-94BF-7FE7B18EDD41', 'BC1A9158-22C7-47D3-88A7-6122955D2561', '7322540764208', '      92-144  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B88066ED-10AB-4A45-B462-66CC577D7E78', '365E113F-1A6D-44FF-8961-1BA3EBF8F2E5', '7322540789287', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8760EE58-B975-4E0B-A0F3-5A2FBBAE6464', '01214DB0-0EB9-4458-A078-D51D7C0B8A27', '7322540796551', '     42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4094F1F3-8039-4929-BB46-B12B81192ABE', '61339117-25D7-451E-861C-6520EBF3FEF3', '7322540837261', '      18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35D41568-5DCA-4764-A260-4DAC9D1FAE76', '3A09C206-2C1B-4BD8-B13F-D26DB4A687E7', '7322540861464', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18ADFE5F-D650-4755-8800-4EB2FF2DD8B7', 'D17C32A3-B49A-4E55-8B24-40DE001E8113', '7322540864250', '  multistyle    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89828AF7-6633-41E6-92D6-1832D8F3B4F9', '500A73C0-2968-4E8E-90BF-E4450625266E', '7322540903577', '    / 1010', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EB21FE3-105B-435C-9AC2-B6FA67D9B17F', '500A73C0-2968-4E8E-90BF-E4450625266E', '7322540905069', '    / 1010', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9426D1E5-DFD4-4AF0-BD53-D7A21075E32D', '8C7994F9-5E28-4A86-A056-6C30CCA6C989', '7322540949711', '    / 1010', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C89E8D99-935A-49EA-BD1B-E4158EBBA742', '0D89881F-6EA0-46E4-B127-16B4EEEA252A', '7332343001301', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F030EAA3-3E7F-42F2-92FD-87D9D2BCD7A2', '712AD229-81F7-4528-A4DC-7185BEA11D22', '7350012552756', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBEE7482-8A8F-4200-B5DE-405831E6625D', '70DB2E38-B6B5-450F-B405-C9A40560096A', '7350046330207', '   / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17444475-44AC-445A-8DCE-826AD5D7D108', '83901078-1DEC-4DA9-BCF4-63CEDD46E975', '7350061291019', 'Dry   -    35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A79092D6-E5A5-4974-A43D-71EA135F587D', '3DAE9282-04D4-4A24-9026-16ADBA86FBBD', '7350061291026', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('131091D3-0365-40EC-AAD7-47FC5AFE75E6', '0FE82611-0738-4E8E-AD68-4617882F05CF', '7350061291040', '   -    // 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C71A15CE-2CE0-4C18-AD73-FB76411F46D5', '74030990-F284-4667-AE14-897462800EC1', '7350061291064', '   -   / 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('211F7C3D-64F1-49A4-80EA-A053EBC919A2', '94860199-67E1-4D37-BB91-017CCAFC306E', '7391899237145', ' - / 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59ECE0BA-76E5-4EE9-A5F1-9698027DDF44', 'F0DF72E7-417B-4325-A3AB-F69979ECC893', '7391899829258', ' /     240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('116BB56E-25B8-43CA-8FA3-3B3AD1A75809', 'E0C9DDF0-625D-4DFB-912E-8F9ACB2C5CF1', '7391899829265', ' /    360', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8481D84-0324-45F5-A7F5-B3308AD2ACF8', '80E95A2F-AECA-42E9-8365-39A326FA7F61', '7391899829296', ' /  /. 240 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89C21BE9-9B72-42D5-8FC2-5003A7F5D037', '151D1311-9941-4CB7-B6C8-A1543345AD7C', '7391899829302', ' /   mps //./ 355-360', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('155B0EEB-BDF3-4BE7-9CAE-83036961539B', '2356CD62-0BE8-4FDF-A043-3AF91CE2546C', '7391899837482', ' /  /. 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C1FE02B-B658-4C65-B27F-73002458CA29', 'DF0B8FA4-42E3-46B1-AF9C-5D14A6863F8C', '7391899838823', ' /   mps //./ 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FC060B6-AF03-4320-A0D6-353D54B14F06', '3D22468C-F1CC-4E9A-BC68-5CBA3495FF25', '7391899840840', ' /    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('542FC111-AA17-4835-A131-57FEF2F27805', '6DB95D09-509F-4D6A-A9D7-BADEC6B05239', '7605816000041', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50D22750-5D8C-4A1D-822D-EC18ADB11CC3', '05D24078-C63E-4834-815C-105E25661C44', '7607496562550', '   /    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF85784A-5277-462C-9E25-FC893CB5AE3F', 'C052994A-F24B-4895-B8E1-36FCB3AA1FFA', '7607827011689', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('764215C1-48AC-4F70-938C-63C64D9F62CA', 'F1A93C6F-A8EE-4633-A527-2AF90B12F18E', '7610108020713', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DC3F169-7553-4651-8A4D-83CDA2E3A539', '1207DFF5-26A1-457E-8910-F3B7DE5053BC', '7610196003544', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B61C8CBF-5090-43C5-95B9-A672FC600484', 'AA16D85D-3813-43D2-B2AC-21E8AB1F449E', '7610939002322', ' 180  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6E0356D-3909-4520-810C-550310EC53F5', '244762A8-A30F-4554-99EC-ED04487CB384', '7610939002360', ' 180  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2430437F-0DF3-4785-8A19-5296589D3297', 'E33B3A7F-FA2A-4715-B3CD-6BD7A932A995', '7611645209005', '  /    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D10E6825-2380-4700-A1B9-6A96C055B4DB', 'A0CF5154-1419-4673-9346-E828902F55BD', '7611645553009', '   /     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC6F18B9-2EB7-4CA7-9EC1-A8982A851BB9', '3EA223DB-468A-4835-8204-7032438A308B', '7612367002578', 'Medela  /      purelan 100 37', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19A6F56E-B8E4-482D-A437-F662525217A4', '3A360BA5-5FBE-4497-AFCF-856A5F63C208', '7612367016605', 'Medela contact    M', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6294F49D-E797-45D1-B609-509B75AD95A5', 'DBF7D6AC-0805-45DC-8EC8-A9B086D2751A', '7612367016650', 'Medela contact    S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93ECDF7D-E854-4E01-860A-400F22DD26BF', 'B51E2875-D97D-4FA5-A031-65988D4A11E7', '7612367041614', 'Medela harmony  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FBDB5B8-4B23-4C56-9B87-AD1911A6529D', 'C6BBC98A-999F-4A8E-91A2-79A9534F1C6D', '7612367044820', '   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C011750C-EB36-4305-884A-D9B6129942DB', '41429947-FE60-4747-959A-0660B4A326D5', '7612729000013', ' 200  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBFEF940-8659-4D2B-AD38-0992BE91766F', 'FE9FE69B-90EC-4EE0-A230-64AFE452EB1C', '7612729000242', '-  250  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F940A398-AD02-40D1-845B-297BC0AAC10A', '4BA2D140-9D4E-4244-8402-45AAF4399BFB', '7612729000693', '  500   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6051D8DA-3908-436A-9339-99ED24F1E24A', 'A5839800-4122-4DB5-B9A5-C3AA594F2A08', '7613031251728', '  1 . . .   OPTIPRO 400  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB620B2C-2C2C-4A26-BD1F-CFA0ACB94011', '2A8D591F-9832-47CD-A84B-0A11D1F427AA', '7613031373710', '  -1  0  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5F5BFD9-82F7-46EE-BC69-DD5E95CB6D43', '07D69CD9-08A0-43DE-A14F-3138131D8219', '7613031375035', ' -2  6  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72FDC4C7-E213-4A6A-AEDC-5FFFD5FB09FD', '4C190C7F-C028-4017-BE44-1AEBB091E7AC', '7613031376001', '-1   700', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB019741-1A86-44D9-9332-F5D21580E9B0', 'A008166A-3249-4349-88C0-A6622D3C1115', '7613031507665', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33A9D29D-CFE1-4992-8B9C-DBAB5237718C', '444481C8-659C-41BA-A37D-0A63837DDD68', '7613031583362', '  -1 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD25775C-A05E-4A40-838C-8E89802811AC', 'B93DD8FF-4365-4500-9F54-0F6E3DB98D11', '7613032024918', ' 1    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9592CE25-F5B5-451F-B80E-8D199C000E7D', '11B5004D-8E46-427A-9CE9-CBD2B171CAB0', '7613032308995', '-3   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E1942FC-B0EB-4C04-AA91-CB846BC1E7C6', '17807D60-4BAA-4A4A-A41E-BD73B6BAC0CA', '7613032476175', '  -3 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88EEAA71-EBD7-4561-B439-A7969AD0652F', '8E9EF0DB-84E1-48E9-BDA9-B44195D763BF', '7613032477493', ' 2      6  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C4F9E57-6E98-49B3-A6D8-39A67E09C313', '99F1C1A6-EE20-4C28-82B1-3AC52DDF3A91', '7613032571283', '-2    6  700', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9377DF70-7FA9-439B-9472-839ABAF1A8F3', '905418CB-171B-4CFC-AA90-C0F660E881D6', '7613032585754', '  / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9939A9C-4EAE-4851-8FE6-8429690504F6', '81631B81-0413-4AB7-BA99-78D064E57FD7', '7613033768149', '   / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('691A8A48-DE09-4075-94BE-A7349AABBE80', '635B0DC5-2A0D-4A39-8046-2F4CDFDEB24F', '7613033768163', '   / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66040836-26BA-413A-9B0C-014C5279514C', '265D829D-B80C-4454-949D-F4B36CF676EE', '7613034812353', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C98E074-4973-49D6-874B-F8F8672196E0', 'DB8B8F02-797A-499D-B931-66A4C5DC6D90', '7613034884091', '   /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F34AD3BE-ADCA-4D4B-9C62-8941244C1C4D', '517EBDD5-219E-4C12-A719-BD657F4ED3F4', '7613034884107', '  /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7E123EB-5859-4305-870B-445E282A41C2', '5550AC98-711C-44E4-95B1-91AE5DB292E3', '7613034884190', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46E68736-AD22-4C1E-AE3B-D0171E5B07A4', 'F514F6FA-1C1E-46D2-BA1D-D9F9BB473BE8', '7613035058224', '//  /  3  - 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3486825A-480E-4034-9360-F6399846750F', 'B56541F5-6F14-4530-9B39-03D1DC9523C2', '7613035119413', '    4  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('499E7161-2A88-4DDE-8316-3717ED5FFE8E', 'C26C199E-24FC-4DA2-8C5E-F3BF47659F89', '7622210500243', '     33,5 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6505E4C2-ACFE-4988-8103-982FF4901F15', 'DC32F878-FAF0-42E3-8710-B811351ECB79', '7622210500328', '       9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('911DF9F9-EBFE-43D6-8CA6-D706330D3594', 'AF51E186-FCEF-4E9C-94B9-029B6E50AA01', '7622210502032', '    /12 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28331963-39CB-498C-A0C1-4FE5BBD3E796', '03ABA2E1-0F0F-45A3-B328-5C70FC43C81A', '7622210503916', '   s  9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9252C043-8F46-40D9-91EA-5C7F2490F391', '27E48B65-D6C6-4F10-8474-604837F9F855', '7622210505996', '  /c 25 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F39C0F1-86A4-4898-ADB5-95EC325411E8', 'B39E44A1-9E57-41E1-B861-4D93854A0F5D', '7622210647801', '      33,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84B7BCBD-4006-4206-B49D-26D601DA6148', '22445F58-3CDB-4F4A-BBB0-6FAB1BEC1DBF', '7630014918416', '17266/144/12   "S".  0 ., ., ,  , 1.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A960D556-5211-4A60-9BC7-2C8A6ED1D32F', 'AED9EEDC-F610-4053-8FB1-54F468FFA210', '7630014918423', '  -  3 .,  ,  2.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B32000D6-736D-44AD-ADFD-367CA69918E2', '074D8246-529F-47D9-929C-9C29D13D6FB3', '7630014919734', '  "M".  ,  3 ., ,  , 1.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5C5DA5A-9E8F-4E29-A717-D4D96B9DC3E6', '7FAE9E10-70A7-4334-B3D0-BC8E76CA3046', '7630014919741', '       6-12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2193558-951E-4239-B5A7-CF9694C32BB7', '20D5400A-5963-4C74-A295-309FEF9DDE29', '7630014921300', '   Lubby 250 ,  0 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4592FE4A-0EDA-4CB1-9941-BA237CCC6858', '0F658258-A3B6-460C-BD91-CE39703F7BA8', '7640107470950', '-  7  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6225E38C-ED81-4535-947A-753E2C45324E', '87965633-CE74-4AC2-8157-F6CA4870F39F', '7640107470967', '- 7  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D91A3BC0-8E21-40B9-998B-BAF7B148D382', 'FF5232FB-EA74-4269-844F-2BC5FB73EAD3', '7640107470974', '- 3,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F46F405-3204-4593-BE70-E4E3139AD5D1', '1DE9AD69-FC43-43FC-A5D9-CD9F32F8B70C', '7640107470981', '- 3,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB671C59-7282-4A28-A02E-79DD92703396', '443C41AA-25C0-40D8-8FA6-721AEF5BA643', '7640114721663', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F2D3F88-B47A-4007-9712-3CC8C05B33A4', 'D1652EFA-2A7D-4C8A-9DF3-09D589C18932', '7640114721670', ' 100   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62A4A13B-70F1-4C30-B322-A3FC68476891', '22996EB0-A593-4CC0-97DC-1E7141FCA887', '7640114721694', '  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('745EA3B9-981F-4D3A-A30B-6912DB49FC10', '93B9B2B4-D81D-408A-BF3E-299BA72B9D24', '7640123860025', '   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5CA84D5-6864-47F4-87B7-AC8F18052BC9', 'DFF4C8FA-8063-4D34-B2BF-A75B26A947D8', '7640123860599', '   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C941E54-8BE0-4D05-A49D-3D012F714270', 'D58741D8-FFF6-430C-8F0D-06FA03FF0706', '7640123860605', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C86A57BD-330A-49BC-8D65-58719FEEEF48', 'BD5B7DE5-20CE-4FC3-B61E-85B6A3713281', '7640123860629', '   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A37E725C-EA69-4EE5-B8E3-4B503E547D4E', 'F481B4C0-A5C4-413B-BED3-FEB82941249B', '7640123860636', '    / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FA0C0DF-8013-4118-809B-3ECB4338D955', '1E3269F9-5C5A-4633-B227-F79E7BD673A4', '7640123860865', ' 780  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFB3FB1C-52E2-4D09-A816-E0560B2399F3', 'E036802C-FDEE-487B-8D27-73A778FD23BE', '7640123860896', '  / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAA0F36E-3A71-4481-A743-8CA39490603E', '568D4712-3F5B-4497-8160-960CE4B191EC', '7640123860926', '    2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B27B68B4-6DF2-4C7F-9085-4DAD727940DD', '6EFCFCF1-2A4F-4060-9775-EEFEBB1B70EA', '7640123861695', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B911560-0DB2-4908-B3ED-8AF82AD5819C', 'EA744E2B-FF0F-4575-8D36-967E411BFB53', '7640123861763', '     / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCFBE5BF-336B-4461-A793-4D451DC8474C', '26FA4745-2594-46F0-A09B-F10A16877007', '7640123861770', '     / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8513837-C75D-46C9-BF3F-FB6E24E4D547', '48769F9D-89A0-4AAA-A757-8EA87921895E', '7640123861800', '   /  / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25B66773-AABD-4FC4-B640-3CF9B7A34A15', 'A929D2AF-C04D-48F2-8716-89C058C1903A', '7640123861817', '     - 125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35AB6A9E-B69B-4EA1-BDD5-E6CC98358444', 'E6E9D517-636D-42B6-9EE5-7F4286C5594A', '7640123861824', ' -   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1880C78-5BCD-46BF-8C1C-7B5169ED58B8', '69928C6A-F79C-4029-BBFB-2378ECFD20DD', '7640123861831', ' // / - 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE29314A-CAB9-46BD-BDC8-333BADEFC9DB', 'BAB35AF2-2D9F-432B-B34A-D3F999EE34FC', '7640123861848', ' // / - 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D141AF2B-4F94-4936-BC27-B9EDF223A680', 'BDD3A70E-E206-40FF-8935-D117B90CCC4A', '7640123861855', ' /// - 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73BF3D00-3320-4D99-A1DC-F9247F929CE5', '1642BEB0-8377-4842-ADD0-7DA3E5D2B9D3', '7640123861862', '   /     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C64D8610-3124-41EE-9694-20FB96DB2550', '4B8CC0CA-5A13-4C76-944E-A08E001CAFC7', '7640123861879', ' /// - 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67DDC5DC-FB93-47D6-9593-D8D21133656A', '9A5D45EA-4D60-4DFA-A735-114E1203B364', '7640123861886', ' /// - 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE2053E5-D31D-48B6-9E06-B27F15A64151', '15E91AF8-42FC-4ABD-ABD0-1905A69DE454', '7640123861893', ' //-  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D0F3CD2-53F6-478F-80A6-35F4B5F634AB', '4F6FF97B-C219-4EAD-9D9A-7E7E4B82357C', '7640123861909', ' //// - 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D70D2B56-1465-4B83-A9EF-3DE802212E82', '06EFFADA-46FC-43A7-B963-F4C595E31CC6', '7640123861916', ' / /./ -/ 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE5AE82F-F267-4A46-9C02-3C4490930926', '40DEC8AD-7E3E-4737-9C7C-3F27B70223F9', '7640123861923', ' -/.  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEB3E530-AABB-4419-BFF3-A15676C96FA5', '6EFCFCF1-2A4F-4060-9775-EEFEBB1B70EA', '7640123861930', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('687AACC3-AE40-4DA0-BE7A-A076263FAC8C', '252C1D2B-14B7-401E-A8CE-BBD8B1BBB1CF', '7640123861947', '  -/ 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B71E22E-1A7F-40E6-9E81-1A961BB7897F', 'B10ADDA3-105A-4231-AA09-AE8BFCF53A78', '7640123861954', '     / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8E998A1-57CA-4C96-8632-9490F3FA897B', '0A517873-9FBF-424D-B9A1-1EC4CB081A85', '7640123861961', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EBD2453-092E-4C78-8D2C-1FDFEB5DA618', '0B2EDD98-1101-44A7-861F-69E2870AFD3C', '7640123861978', '   / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F34CC6EB-C987-4FC0-9C93-154FAC8D2EB9', '00F5BEF2-618B-428C-BE93-78475B7F1CA7', '7640123861985', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('165E8C50-95CA-4EAB-A630-BE1BF445EB0F', '8605BAC4-31AD-4781-9AED-B73589A8DD9C', '7640123861992', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2B7F243-ACC9-4817-A948-3FAC57AA87DC', '86575624-3D4F-42E5-A330-8ADD7CAA1DAC', '7640123862005', '  /// 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24694C08-9F66-452D-9A81-5D73AC478276', 'FF1E2164-AAC4-445B-8958-73D77038E9A9', '7640123862036', '      /     / / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC47E830-562E-4567-9C43-F12CC4FA5972', 'C82119DF-D15C-448A-AB03-6C2592B5F8EB', '7640123862043', '   - / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58885501-213A-49DF-87CD-F585E9C2815B', '31C358D8-9369-4174-8747-720E8D595757', '7640123862050', '  /    / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E6FBAB8-C5D1-42C1-A829-2F4F8DA13371', 'D3B89834-9DB0-4A0E-B3BD-67DFF0009E6C', '7640128541424', ' 120   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59E05A8E-BFFE-4666-8AB0-B594A6849AB8', '75FE553B-F406-47C6-A8D1-BF0305CF16E6', '7640128544616', ' 1    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E15ECD8-B927-480F-AC96-736567C6F60C', '5958DE11-CA10-4149-9E21-459B3055E939', '7640130070110', '  .30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEF5D1EC-1216-4B06-BB6F-A606CB3C2B9B', 'D8AA418A-BD61-45A6-AC3E-5F6E92B316CB', '7640135180098', '    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7896CDA-99D8-4D0B-800F-2729F80902E4', '775548F0-68F5-4559-A0A1-F7D77E3D1519', '7640135180104', ' 10   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6D24FEE-93D3-43B0-B01E-2900E361B4A7', '3C6D3316-23FD-4CA5-AE65-6F6536623630', '7640135180197', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18331B33-80B1-4764-B5C1-1B6B15B70CA7', '33F0996B-641A-4564-B017-803F38F75F9A', '7640148938754', '   -1 400 /-6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('264C5D4A-932E-4919-B0EE-39AA3D04FB79', 'F111F7F6-A5EA-4F82-9F87-AB014D6DA3D3', '7640153060365', ' 0,03  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B62F97B0-1F30-4A2D-9A92-09C79CE4EBAA', '21609AF7-5B60-4F33-8110-458D7175932F', '7640156390087', '  //18-22   / 2/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E73B79DD-C13B-46DD-AB9B-F0F9254B500C', '29E44295-434A-4C81-AC5B-142024259506', '7640156390179', '   wi-911 c  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3F37A2B-B3AA-4AA5-9CFB-63CB8D2B9528', '5A709E03-39EF-4B5B-A5DE-EB670DE44E4A', '7640156391367', ' pro-33  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8DCBC7D-6096-45FA-82A3-1B6B167540F2', 'CB3E403F-BC6D-4441-A105-B43F319F1E7A', '7640156391947', '  fw-607  38', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21B6D779-2C99-4F82-AF16-EAE391E5E925', 'E5949969-ECBC-4CF1-B12B-854CA98826CB', '7640156393071', ' /. PRO-30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34A26269-4739-4D4F-8F78-1C3D1E88E7F6', '9F2BB7DA-E9F0-4B0F-A074-0215BE5FA697', '7640156393088', ' pro-35 .  / m-l', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('403D0CBF-6BC5-4EAB-84FA-56ADB222E33D', 'AF7DA861-79D3-4A34-B42A-5087BA9818F6', '7640156393095', ' pro-36  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6AD94B6-B330-45AD-B55E-F9754345C11D', 'A41AA0B1-9B00-423E-B8D0-D9B7A696F8A4', '7640156393415', '  jw-214  //18-22   / 1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FDC2DBE-D8D0-4F6F-A01F-6D04F1EA942E', 'E06CCBEE-939D-4E0B-8D29-5456D5722370', '7640156393545', ' PRO-33, ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7B0A7DF-B9FF-4074-999B-CCE8757620DB', 'ED82F90F-61DD-4135-AFFB-2F0D409A4037', '7640156393552', ' wa-35  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31DE9203-9CA9-4F74-B9EC-EC0A0CEAFFC8', 'B26475CD-C5B1-457B-AF64-CEAEA9C54D88', '7640156393873', '  2  1  /  WF 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4C18EB6-E556-460F-8A42-37489C0B018D', 'F49F3256-E9E5-45B6-B2C1-9402082D2E02', '7640156393996', ' b. well wt-03 base ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C325B043-9BBC-4A79-9E61-3705201EE5E4', 'E3467252-14DC-40C9-8EBF-58CA0E25620F', '7640156394009', ' wt-04    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CADD96EF-2DEA-44AA-989E-339062120D12', 'CCEF3903-E7C6-4589-9126-B94853BF0005', '7640156394016', '   wt-05-accuracy', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAEF1F28-8CF0-4379-ABE4-199B38C50E68', 'B7602816-8A30-403F-AA70-297095C4AD39', '7640156395426', '    1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08BCAF33-FDAD-47A2-ACAE-992A83043A70', '91151964-6E82-4D15-B9CD-3B8CAF6B5D3F', '7640156395440', ' wc-150  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09AADC78-9A39-4C56-BBA4-1D8D4BC04BBF', '69BB0F37-1DD2-4035-B8C5-A9048B743B52', '7640156395532', '  MED-53', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6556DFFF-DD4A-4296-BB45-408A5AB2EFEC', 'FD961EB1-1C9A-4A9C-8B06-33BC7B6FC2A4', '7640170370010', '        / /-190/ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAF44EC2-50C6-4720-ABAC-A9634BF1728C', '6DD8E03E-8617-4BC7-95F9-7FD63709CC6D', '7640170370058', '  biomed  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('111A2CBC-FB87-42BB-ACF0-4E74F5021517', 'E86CA568-B5F2-4F31-85E5-F228A82F05DC', '7640170370072', '  biomed sensetiv  /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56CCBDDB-98B2-4D56-B7F5-10D6412B2885', '026380D6-ADF4-43C1-AFDD-79200ABC3ABA', '7640170370096', '  biomed  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21D0F9E8-4156-4EC0-9180-69A7C5E80DE5', '16EDECA3-1D48-4871-B894-8B7E522DD706', '7680229580540', ' 42,5/ 5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4417990F-AA18-473F-AA18-6E151030A242', '7CDC6A73-5CC4-4664-A689-24B77915E27E', '7680263950118', ' 5%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C94A92E-EBBF-4DC9-B042-18EC49E44AC8', '319786D8-C6B8-4232-B7F5-71D34232FB5B', '7680275289008', ' 0,1% 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E70836D0-CD7B-4183-BF7F-E6C78EF54005', '09CF9909-F5FA-40B9-8636-4497194ACFAD', '7680297899032', ' 200  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D57C4CB5-D7FF-4DC7-9243-D2620286A4C5', 'D0CC2CE0-BB8A-49FA-B498-05CE4E8BA813', '7680312149005', ' 5/  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FCDD0C8-A212-476D-B7B7-384A0816CE5E', '04F66186-4FCB-463A-A505-580645DD7643', '7680329349030', ' 25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D02D945-E37E-4E64-8051-CF202961BD05', '90FD6ED2-B519-479B-BC0A-DD2B446E96E3', '7680387629006', ' 0,1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA521BDA-8491-4992-9F54-E66037C249EE', '294041F3-37CD-4256-9F6D-717FDDCF90A6', '7680392539000', ' 0,075-3 5 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ED4107D-96B2-4968-89AD-9368FF0776E3', 'EF1A330E-8EFD-4E14-A0CA-BC3FF2E8822E', '7680392549054', ' 50 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E29CEAB-F11D-40E7-AC76-570AD862F5F5', '6973AD63-46F8-488B-8E07-686913508228', '7680392549078', '  100 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B33F13DF-F388-493E-9EB3-69842567EE93', 'F4FD5803-B38E-4C0F-A2F9-A5578E877D82', '7680444840139', ' 5%    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51719627-13FB-4272-8D08-792CEF72D99D', 'FADAA37C-1E37-46BF-A90A-5F1D044FD44B', '7680474439037', '   400  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9F4CC5A-C391-437C-8E34-5D6F0492BE2E', 'FADAA37C-1E37-46BF-A90A-5F1D044FD44B', '7680474439051', '   400  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('682F828A-E77B-4EE3-B8B7-EB73D69B0B3B', 'BCDE8852-399B-4AF4-B3F9-C5547C41DBCF', '7680500089007', ' 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63252AEE-CA87-4A40-97FF-D9C5E00332F0', '0A739189-C713-420C-A39A-EE2F98E9DC76', '7680528459004', ' 12  /+- /  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B14EC1EB-F7CC-468C-B305-4D473D891DC6', 'A27824EC-1866-4561-9279-39F890846170', '7681900598014', '- 6  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAE2F317-1C5B-4566-8FBE-4C0FACB9464B', '9D59370E-4E6F-4EA8-9CAF-1F0E469A8FD1', '7702018085514', '  proglide  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B46D077-619E-4298-BE99-06C8BEA936CB', '94E8C727-F6FC-40D1-9D9B-D5C6E77F0CCE', '7702133218125', '     33,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4951F6C9-BCD2-46D2-A509-C96FD0F3AAFB', 'FE859650-520A-4954-9BF0-E0E04400E916', '7891024132470', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8773F81D-C89D-4C7F-9B5C-A384B6275B45', '6D66FE6B-29A8-43A8-8EDA-0349439FE40C', '7896070607606', '-   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2100F5B7-7942-432D-92A7-C8559B1560DD', '195B4A1A-3CC1-4C96-BDA7-738F3B4314A1', '7897930774490', '    /  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D3030B0-71B4-47F4-9D2E-F69F0B774EDE', '31C22A35-B98B-44FE-9B26-945C84F5AB11', '7897930774506', '   / /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61A2D826-77CA-42D2-B5F5-CE97A2E87E63', 'A8DB64C9-5881-4A18-8CD5-8E51E9CCD20D', '7897930774513', '   /    120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCF40B9D-F915-4583-9A21-E6F971508971', '9A1529A2-7C39-464B-A9B6-634529DD0DD8', '7930043490090', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA51D1C1-666E-4B55-BCB1-D6CC0B5303DC', '66157887-CEA1-45E1-A059-64A8FEF88690', '7930043490694', ' 280 /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('696BB745-1A9B-41B9-A20B-87811B73A292', '171CB5DC-4ADB-45B2-8D0B-BBD7B6029047', '7930043490939', ' / 500  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7858EAD-9476-48BA-8292-5A6948933F3A', '36AD5642-1861-4565-90A9-EBA957C43C4E', '7930043490946', ' / 500  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F05E74B5-56F2-4846-B74F-354B453045B9', 'EE54C799-365A-4FD4-8D48-96C0874775C5', '7930043490953', ' / 500  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0082A62D-671C-461A-85C1-58056FFC90A8', 'E22E9A07-CEA8-41C5-ADB4-11AF88FAF8AE', '7930043490960', ' / 500  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C48D6B52-E1BA-47BF-B38C-DB477BE32AF5', 'E125D233-8917-49C5-AF35-8547B43BA84E', '7930043490984', ' / 250  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E413C938-C084-4807-970C-CF5D66304E92', 'E28D762A-1CB1-4A8D-A728-C468404E11A8', '7930059760088', '---21g ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('696D1C2E-F15F-4B6D-8B8F-B1DA4FFDBC99', 'C1647F52-BABA-4857-9883-017477FAC073', '7930059760279', ' vm     7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C49E1B00-8662-4A21-9F52-CA120F1484B6', '5AF4E7DB-677D-42D5-AFD4-15C4694A2CCC', '7930064690028', '  /    .24-36 /5+5/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96015305-990E-4639-99A6-D62EC5A9C24D', '95A05C0A-A965-4C54-9183-6935E119872B', '8000036000069', '  0,15% 120 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD1C103D-D9F1-4F1D-9FFE-4F6CCB3C9666', 'C874D4E4-F394-4B8C-9BA2-5FAAF613E5D3', '8000036000588', ' 150  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7733FD7E-1CB8-46CC-A632-EE6806DFF900', '3FEFD7AF-0DDD-4CE4-93CE-201CBE496074', '8000036012000', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEC7E6F2-6FE9-46F3-BF41-735EA536F183', 'D7C81D24-9C9B-44E8-9BFE-B96A2AC2E8F1', '8000036012413', '  3 /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CE36649-4AD8-47FA-947B-01F3B72CF462', 'D1D2BD5D-526F-4CDE-B54C-F7420C74F176', '8001040084519', '  180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FD73C76-FA9F-418B-A0D6-17C8127E1514', '64908594-FBCE-498A-A699-E49399E82FC3', '8001040092460', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86C4FB56-8035-45E4-99D8-FC4C568DFC16', 'F9635604-F39C-4A4E-9D89-5F1ABE5934BF', '8001040094938', '     80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DB0BCA3-2D11-4ECA-8A81-8E4D5348FF16', '52B87E2D-24E0-4189-860D-7F1DE8D6E032', '8001040094945', '  80   4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F42C47BC-766D-4E83-8F53-7FD5528D49FF', '1C88458E-4DD4-4BCA-BCB5-481E70122F1C', '8001040094983', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04956E5C-991C-4A2E-9661-3999313FB040', '12D5B5A2-CD89-49D6-968A-EDFD4A3D6766', '8001040095003', '  120  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33A79BDE-D5A0-4B4B-8BC7-7DB81D4CD319', '96506A14-D29B-498B-9278-9ACBF48AB56A', '8001040095010', '  120  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1025FBBC-A18C-434B-9B09-26AFEA15718C', 'F15121D0-FD37-4A98-B73F-A05ABA262133', '8001040095072', '   - 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B227772-F0B9-4440-A10F-483A2436CCA3', '210D90EB-5B46-4717-B416-84F32393CE77', '8001040097922', '  160  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1F6EA73-AE77-40A3-BB21-08CA881E56A4', '210D90EB-5B46-4717-B416-84F32393CE77', '8001040097939', '  160  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0345D0D0-456D-48CA-A157-DF962C0B6C15', '63F3922F-1B89-4BCF-BAE4-453437FC8907', '8001040411520', '   6  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B28F8F1-EC8E-4704-943A-21EF2A8C628B', '08814F4D-4EA0-40FD-AFF0-AF1009E5AEC2', '8001040416297', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFAD0FA2-5121-462F-9288-9BA3097C6E7A', 'FB1D5D43-44FE-4250-9CB3-D5B206D85543', '8001090132017', '-   lasting  ness arctic  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9C78C05-33C0-4F2E-A6EF-826C18F44067', 'BFFBED19-5E4E-4CB9-9DD1-1E180C93FA38', '8001090160256', 'NATURELLA Classic      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA1E9D35-6E97-4E2A-BF74-0F03FD5AB84C', 'E1C3DC6B-0F57-4533-BB8A-970AC277841F', '8001090160294', '    ..../.8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1569271B-218D-40DD-AD38-B1C9A8ACF265', 'A545D0EB-F0A9-40D6-B2E8-00FF9AC1F284', '8001090161994', '   / irresistible  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A3C8B01-9483-4470-8080-232585F47F5D', 'F6FE6740-5C53-49D9-AA07-096561DE039A', '8001090170354', 'DISCREET       Deo Water Lily Multiform Trio 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F415BA19-3240-43FA-BC48-F9CF91882C87', '27AC4A8F-17CF-4363-8284-B62843195AB2', '8001090239327', 'ALWAYS Classic Sensitive    Normal Single 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('489C13BC-0163-4D0B-ADA2-37B6160227BA', 'B6F06E0C-5EEF-456F-8598-FC11A9CF52C5', '8001090239365', 'ALWAYS Classic    Normal Single 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E38B87C5-9F6F-4618-A05B-0AF15117949C', '4BAC17E7-F424-44A2-85CE-CBCC5137A4AD', '8001090239402', '  single   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CD7BB73-243F-4810-AB2A-2891DE5A684C', '62D634DF-C292-4DA6-AC4F-59C83BF0C51B', '8001090414359', ' - Extra Large (15+ ) 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24FA8F58-A567-40EB-AA98-3F12A8D2DDD9', '09B9C35B-159F-48C4-B087-A5ECE6000C02', '8001090430038', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B286DAE8-1DB5-4B48-B251-A3C0780A1A59', '0B5439AD-BE93-4CDF-9461-810A18C16442', '8001090430229', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C47C571-36DF-40A7-A3A2-8E18F356DA0E', '655F0151-177F-4105-A440-939E0629C439', '8001090430540', 'ALWAYS Ultra     Platinum Normal Plus Single 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A00E723-B73B-49F8-BDBA-A1E548A0AD71', 'DD578529-3090-4A3C-8F36-F256B4646B98', '8001090430625', '  platinum   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BB4F94C-6ABA-4D86-82D1-812F90035BF6', 'BB669A8F-C01F-466B-85AA-94BCEE0230CC', '8001090430700', 'ALWAYS Ultra     Platinum Night Single 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21D3DF85-079A-4BA7-95B7-317494D76BB0', 'F481C866-5E02-4E27-AD3D-29E7DA9E828C', '8001090585592', 'NATURELLA Ultra       Camomile Normal Duo 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27531F80-0FEE-43B5-908C-64E5491CA53D', 'F3D81518-2705-41B2-9B64-3F0B623057EF', '8001090586032', 'NATURELLA Ultra     Camomile Maxi Duo 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D980B40-7C76-4F3C-BCCA-66C76AD900E7', 'B9549276-E222-4B2D-BF9C-CCF9ED156029', '8001090586278', '     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCBA5B1C-4811-4AFE-BB40-6A7F71D25A7E', 'F20E59DE-6FD0-4187-810D-FFF73A52E499', '8001090603883', '      52', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('579AA111-41B8-4A71-A9B6-FFA78F17D0D7', '156AA929-8FCF-4EF0-9146-45C73828C3C2', '8001090604620', '    0 /1-2,5 /1,5-2,5 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ECD8624-157F-42BB-B0D0-A121DAC1222A', '93C73098-A2BF-4520-A8C2-863FDB2F18B0', '8002110311511', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B6D4C31-EA4D-4266-B623-74B4E5AA5A3D', '6414DCBB-4D93-4D99-9BE3-22DFD483022E', '8002110311863', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A80FDDBE-5F09-4B96-A8C7-7BE504ECA5DE', '68F6A54B-A7C7-4899-83C8-BC224D9BF596', '8002110313461', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC506CB8-FD7F-493B-AC02-E51989EF8830', '61BE61F7-9C30-472B-B7D5-2F8BDCC31348', '8002660000101', ' 0,05 40 ./', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE1CD7F0-9E46-494C-8AE8-7E31BDFC9B09', 'C8AA66B1-87A4-44FB-AD82-AD31F16F2B9F', '8002660000118', ' 50  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D8FEBF0-F7AE-4FD9-8C97-C82C110716A6', '9DB96521-14F8-4323-A921-824BDDC4F8AA', '8002660000187', ' 400   / 5+-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ABFA6EC-2745-496B-B8B2-468E702FC458', '9A2C38A3-0D48-4AD4-A579-3D5744CBCD74', '8002660000194', ' 0,4 //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D676BC10-2EDC-462B-BEDD-274FAEC9624F', '6FC79FF0-52EB-4233-92C7-FE034A5D732A', '8002660008077', ' 50  / 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5B5C31E-C994-4B9D-AC95-45CDC0380E61', '098593E0-0785-4392-B1B1-A8A682B06696', '8002660008695', ' 10  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('220D6247-FDEB-4AB4-85F2-0E0982F4840A', '4A4DB200-B209-485B-9D11-E5ECDFC86360', '8002660008701', ' 10  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6944B235-C583-4A76-9FAB-50D16AB72139', '77630CE4-8B6D-4B2A-9850-3C868720A4E7', '8002660011183', ' 50  / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F9B182A-20B5-491B-BE2F-2FF8B37CA0EB', '10721D80-1665-4768-822F-36F9B8A10BE5', '8002660011190', ' 0,1  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F38D949F-1FF3-4C98-8826-95E3313CB54D', 'EA947C2E-FE7F-4648-B0DB-369F38E9C5C7', '8002660013996', ' 1000  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F3104A6-40D0-4E30-B412-760ED5AD969B', '7ED0BF99-3B44-4492-B9C6-1355D8B5A5B9', '8002660014009', ' 400 7 - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6126BC46-CA91-45B0-BAA0-EF2DEEEBDAE4', '2C97F198-CBBF-467E-AC85-1EA01C8D4F81', '8002660014368', ' 0,005% 2,5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF9E696B-FD77-4335-9C0B-F65E47ABD8B5', 'B27484E4-E62A-4DE0-AE21-B27F30B12255', '8002660015488', '  2,5+0,5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B850614D-64C3-4BE4-8073-E6C1156FAF4E', '21FCB594-8763-4E79-9DD5-39834E5796F6', '8002660015570', ' 0,005% 2,5    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D4F34CB-8B18-4ED6-A31C-4A92F0169F07', '4EF993BD-9AB3-4DD1-A5E5-E88961A16A1A', '8002660017130', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70CE408C-2405-42A6-984B-A6032863492C', 'D8548B81-736E-4BBF-8A54-E93E3F370F39', '8002660017147', ' 10  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62B80B3A-136C-4107-AF03-1B5ACA275716', '82BB1C90-4C20-4872-BD19-A782D2FF7521', '8002660017864', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26C4ACC4-5DA6-48E9-BDC1-E7BA83FAEF5A', '30121D61-AFC4-4E41-AC9E-1311B020B081', '8002660018670', ' 0,01  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA5711F0-BD6F-4986-B310-D80D8A881FA6', 'F6D8E77E-0380-4309-A22F-5F53DF6DF18A', '8002660018809', ' 0,667      500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EC2CE74-E4B7-40B2-B673-1E614FF3C9E2', '71D88826-920C-4512-897B-AFC379A787F2', '8002660019417', '  125/ 5  60  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CE373E7-F740-468C-B534-B6AAD9D818ED', 'E3914CAF-0F87-493B-BC01-717F7827A2E4', '8002660019516', ' 600  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1D0B15F-BF3B-4D6C-82CE-6B425EE95C60', 'FF743308-E1D8-47B7-8805-19D944157A44', '8002660019714', ' 250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02ED64C9-B8C1-4021-A20E-51B7D02F42DF', 'F3C9FE57-6D48-457E-BBFE-66F447D25CE1', '8002660019721', ' 500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('596FB7CF-883F-47CA-B3E8-FA0EDF700002', 'DF6316B9-8F05-4E3B-B8B3-92C3DA383E18', '8002660019837', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49EB67FB-5ACE-46B3-80D8-E75DDB59C503', '92CC2D0F-66DE-4D26-99D8-2E768D9E4089', '8002660020048', '  0,5  //  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE755A32-198B-4604-AE8A-ADA4E8F1DC5F', 'B57B6031-889F-47D7-95D5-FDCD05A141A6', '8002660020055', '  500  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F38E5FD-BCA5-419A-9234-CF6F6BBA3481', 'BBD8745E-85D2-4E3E-8016-045605B43000', '8002660020062', '  500  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42073C9B-B948-4516-835F-D309848AB639', 'DA1CE521-5D2E-476C-A3E4-6F1CF8E4D637', '8002660020413', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A2D54B5-E637-4DB2-BCBD-14F8935161ED', '63FAB3A7-7896-4894-8C4C-712526FFCB33', '8002660020659', ' 180+2   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0E3F00A-0A90-4D02-AD8A-ED567531F2DD', '7A0676C1-7F2B-46C9-A684-5022C2C0348D', '8002660020925', ' 0,4   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9047D1C2-FB50-4363-8202-8D364D64FF4C', 'B85EE3D9-AEFA-48B3-8A6D-0A405D3F9C7D', '8002660020932', ' 0,2  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C2E01B0-D03A-4EBD-B509-D6799AE88A95', 'D8D23C5A-CE5D-47EA-B563-7CCEF296B037', '8002660024176', ' 0,2  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E76E52E1-45D0-4539-9E17-6512B8903D9E', '6066FEC4-10C5-4B51-A57F-81AE48FCE682', '8002660024183', ' 0,0004 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B21E9AF-3CAD-469B-819F-2DDFE6A08CCE', 'FE9FE69B-90EC-4EE0-A230-64AFE452EB1C', '8002660024336', '-  250  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA695F3C-D1C0-42CF-B817-4A43C36D1D9B', '00AEC15E-76D9-4058-9AD7-E363563CA1FA', '8002660024701', ' 0,145 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CDC77B3-4E83-445D-BE79-37BE3F418FDD', 'A43D0D65-8EB6-48BD-B7AE-2FD5AF6F5074', '8002660025067', ' 1 1+10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13A27603-82C5-4CAF-9F8B-0927DB39B425', '236A9FDC-16E4-4AA1-B961-AF3D8294EAF7', '8002660025074', ' 2 2/10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE993F57-5679-4449-9818-05372F7F68A1', '1686D669-FC40-42B2-8D88-76EC45D0C9D4', '8002660025081', ' 1/5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7EB9B8F-C982-44E7-A8A3-9D9AC68540B5', '96348209-C2EB-406C-B13B-9B1CF7733C68', '8002660026279', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB850ABA-29A4-4B3C-B919-04FC5E17F459', '65CFC9D5-7D61-48E6-BC88-F92D5505A0F2', '8002660026286', ' 24  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0337077-2724-4E6F-9CAB-B50BF3779945', 'FBB846A8-5920-45C2-AD72-4EB207DCB30C', '8002660026293', ' 24  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D90B7FF2-309B-4754-BAB8-B19F1AC7912A', '75A5061E-AF7C-466A-908D-55B78B00BB55', '8002660026651', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('985874D1-778D-45F1-B81E-B4C66E24D7ED', '50356575-D18F-4C36-A889-D8CD1187E6A7', '8002660026934', ' 0,4 //.  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83CD2121-F438-4A4B-A550-442BD2E7F290', 'D8D23C5A-CE5D-47EA-B563-7CCEF296B037', '8002660026941', ' 0,2  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72E497FA-6F76-43FC-9C4B-718B764C5880', '0F6B754D-CC02-4FD8-B1BC-32524D244544', '8002660027030', '  500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98E8C1DF-E947-47CB-AD31-5A6BF3AA19F4', 'B57B6031-889F-47D7-95D5-FDCD05A141A6', '8002660027047', '  500  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6A79C62-98F7-46D7-84C2-131EC91F8876', '2EEFEC4F-7EC5-4913-8798-8824D4BFEA28', '8002660027054', '   500  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CA6A7B0-D0BA-4DE2-AC27-6586E8759442', '02052AB2-315A-4C64-B442-38B400F4844F', '8002660027580', ' 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECEA3826-BFC8-40E0-B4FE-15292C6523B9', 'ACA6F9B5-BC23-4252-965E-413E207DF0E6', '8002660028136', ' 500 //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9979431E-5118-4EC0-803B-9D1F499F2344', '421E20B7-A844-4ABA-AFD1-A88284FDB1EE', '8003670851493', ' chicco physio sotf 1, 0+.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('617C86EB-EAF4-4641-9834-FAD80A0B9B0E', '9A5A63D8-4682-4991-869D-8134B3BA1D4B', '8003670863939', ' /- 30g /0,38/ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF0C2578-45FB-4788-A894-4D20247AD216', 'F83AD220-C125-47CD-97B9-FF143D53B4F4', '8003720020008', ' () - /  15  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76CA157E-CCC4-4AFA-9517-CD81A735F857', 'CEF6B4A1-9013-49AF-829C-E4FB910E342E', '8009315001322', '       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('196A2946-4659-40C7-9FC5-FD38A2DE2E13', '82464EFD-5AFA-4F36-9CA3-9023EE2D706D', '8009315001339', '    / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE20FB5F-B037-4EB5-9718-A0A50A94BA91', '48A3A01E-AC74-4DB9-BBA0-A00B79F49256', '8009315043346', '  .  teen  7  12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE9FEEE2-CEF6-4871-9FF7-77A5B7EF85AD', '2554F98B-D6B4-428F-B275-3509E93FCF21', '8009315043445', '  .    2  6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('805B0537-7533-4F4B-904C-814E543D9131', '20B1222D-7426-49EC-8C9C-2E94561E5DF1', '8009315043544', '  .    6  36 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56B92246-F43F-4F7C-B72C-9FE3052F729C', '37F7BC1E-F152-4C7C-9235-40DB15AA40FF', '8009315900038', '   z3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('677370A5-1AC1-4666-909F-1DA48443C453', '61E4D6A8-3EBE-410A-9F59-5A6F7980C9C6', '8009315901028', '    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D073AD26-B87D-4B75-AB6C-8E70D2882E9B', '43ED5D08-E911-45D1-8A69-9E8EEFA7EB33', '8009315911157', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC249408-32D8-4746-9577-399B7B8FA69C', 'C27E726A-5ACB-4098-9A19-E11A20A76F22', '8017990160715', '  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC6AC53A-B95A-42AB-93DD-0C1BADD44D2B', 'D115953E-CA71-4CA5-B66E-E057766E3DB3', '8019561020312', ' 1500  /-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD696A26-4776-4282-BDA7-C62C97B5AB0C', '2F223A21-CF98-4DAB-8F35-5204D9568ADB', '8019561021418', ' 200/ 2  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07CE484D-4F5C-4CA0-B3AA-A57E28E43A75', 'E0DB59E4-A4BF-42CD-8BEC-B3401D3C4244', '8019561022019', ' 0,75  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB3372DC-2B87-477B-AC03-217D14FEBDDC', 'CE50A63C-E09C-4931-8A42-8FF3A6C2B1EF', '8019561170710', '    /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F198A3B7-DFAA-4345-8AF6-7746089AF4FD', 'FF28A520-EDF5-4BEF-B5F4-C92D90387378', '8019561173124', ' girl - /  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39C3576B-DBCE-46C4-B990-AB91ACFF5C75', 'FB7FD6AB-8259-4747-9DCD-09AA6768AB37', '8020030053106', '  0,2 //  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3095155-2FEA-47F5-B0C7-C8E3148AFBD4', '1430D280-1512-470E-A07F-EE744E27A2E1', '8020030053229', '  200  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E71DE33C-9F93-4ADC-B584-543C13B449B2', 'E1636C66-F38C-4852-9211-03F042A9AD9F', '8020030053236', '   200  / 36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC002724-30F7-4EB8-B210-6E89627A8DAD', 'D265D608-BFEF-487A-9AA8-54D26719CEC1', '8020030091184', '   250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95BB641B-A0F8-48E0-BE3A-20BACD8F61A4', 'D265D608-BFEF-487A-9AA8-54D26719CEC1', '8020030091207', '   250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0508FCCA-3CA6-4511-A8F2-3DE94822D59C', '5D88B00E-4F5C-4294-802B-8B0CBBECF685', '8020030091306', '   600 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95A64048-9D2A-46EC-905F-0E73441380A1', 'AD07423E-02CF-48E2-9EF6-59E6F2732BBF', '8021961001532', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2399949-2565-48E6-A37F-C40763228E73', '1775572B-F438-4E4F-9802-5786192BD17D', '8022086001308', ' 0,05  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FF7D65C-69A6-44AC-9972-94593AA5192B', '9C1ECE26-2DC0-47E3-8FC9-F43351416E4A', '8022086001315', '  50 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D172B825-4B73-4EAF-8C61-F8302D3DB213', 'F3C9FE57-6D48-457E-BBFE-66F447D25CE1', '8023813093030', ' 500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACB5029C-2EA0-4D2B-AE62-48BA3B512F6D', 'FF743308-E1D8-47B7-8805-19D944157A44', '8023813094426', ' 250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('290C1224-F2C2-4A20-B8AF-CDB9B33D9CF7', '315066B3-BFAC-48D5-8C1C-F1D878CE13EB', '8024790041014', ' 100  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('492F75E5-0ED4-4B6A-8164-855C6E69AF55', '166A30DE-688A-4C7A-B09B-D17E7FB76706', '8024790041038', '  2,5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75E614D1-C31B-4614-ACE3-BD2025F89C27', '44D90AE8-033C-4403-BAAC-5C364BF29F5F', '8024790041090', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('151251BC-1E78-48E6-91EA-C5649A4DE52B', 'AC099710-0FB8-43B6-BE02-93E8E4727F1D', '8024790091019', ' 800 15 -  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACE470D7-3AF4-4465-B43B-6F4EBD69767C', 'CA44E67C-B8C2-4421-BE48-B2B83680832E', '8024790101008', ' 3   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32147736-BF66-4325-BC5D-2578C720F88F', 'CA44E67C-B8C2-4421-BE48-B2B83680832E', '8024790101022', ' 3   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('423F465C-2C6E-46BC-BC2F-B4D7B7CD0179', '70843E0E-BAAB-4F4A-9ED3-21EA022626EF', '8024790121006', '  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34EE0CC9-077E-4A39-AF57-5F2E9E7BD831', '7AD59BD0-835A-4274-AEA9-304EC8970F31', '8024790141004', ' 800 15 - / 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F793A46-1091-4B34-A273-FF5912A23C1E', '05248B6C-FE88-4C07-841F-B0B2192453D1', '8024790201005', ' 100   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('986BF947-288A-41E9-9ED1-054F0CBF98DC', '68D8E664-4199-4844-816E-4F254E903ED4', '8024790201029', ' 200  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60A08ACB-4D0C-40FF-854E-49D82284433E', '0443CE4E-14BB-4923-A110-99174D437DB6', '8024790211004', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D22877E7-9A38-40BB-A2DA-FA581029D26D', 'B1FC68A5-8CBE-4911-8B9C-867C4F9F2ADE', '8024790231019', ' 1000   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B819650F-CEA3-42BE-94B6-4467E4C302B3', '076A9789-DB7A-47DF-9B3B-53FB4FC6BE83', '8024790620127', ' 400  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2323AB15-76E1-41D7-BEE6-ECFE156B2732', '51C9DF73-1CD4-4E0E-B66B-2FE3E2FAFC1A', '8024825000016', ' 320  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FDAF182-6289-4882-B5BF-D32179568287', '0EE71A3C-C670-459B-AD6E-52D1F0094933', '8024825000115', '  /   2.7/5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('598E10EC-4839-4BEE-9F37-CB8A25E7AF16', '6540DFAF-24B2-4399-ABA8-477E51F20503', '8024825000122', ' 90/  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF382905-ED23-493B-95EE-2EDB474765B2', '73256E60-2CAD-4942-9386-59FAE91B2700', '8024825000139', '  5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46EB4FCC-2EBD-4A62-BA8E-67853E1E45B7', '59F28A40-A47D-4366-87D2-3322AAF8CEE9', '8024825000146', '  / - /  80  2 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3B218AB-A366-4F66-B4CE-D8A9482DFDDC', '1EDB8813-E31D-4668-9149-6EB5AF990B86', '8024861000018', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9C817AF-C849-45B1-8246-DBEF394857F1', 'BA82657F-693A-4C4B-AD9D-3E4C85970E27', '8027864050004', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40DCEF91-457D-442A-8474-7F4A8DF13D81', '67DFB6B5-A385-4208-B143-D8E6EE7171EF', '8027864050035', ' 0,3% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0179D2C7-2AEC-4C77-B9E3-69F4C757F232', 'CB12DEA7-66C0-47E6-8015-7F134844B2E5', '8030009400053', ' /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ED442A3-D7CF-4E6A-AA08-CB7C7A9F22F3', '10595F47-2964-4CA1-81F3-A89D23D90002', '8030009400060', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CC3EDA8-68CE-41A8-8434-DA127CA7438C', 'DEF89606-91B3-4922-9A40-C73F6D968BEE', '8030009500036', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAAF2B59-B900-4319-B415-AEB667C31560', '14EA5C52-18AF-445D-8531-BF152562307E', '8030009500043', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BA5149C-AB48-4EE9-893C-1449C1F96828', 'B7EC30A1-92D0-4206-999C-C8FA2D7CF002', '8030009500050', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A6F0AF3-F8A0-4813-AA56-CE0D67A55665', 'E9FD85F3-1D2B-47BD-AB8C-D4963B11B27C', '8030009500074', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58AD9940-D40F-4C52-8AEA-96EC75AE5159', '8DB45A1C-54E2-4107-B995-C69B3B9EE3F2', '8030009500081', ' /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE7558A3-D489-49F2-8F31-638BB675B404', '9A9D752E-AA26-493C-97DC-803C86851BF7', '8030009500142', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E82994C2-BA66-484B-AF16-6910A714B90C', 'F35B75F6-81A8-43A2-9DEF-1DEE9E1E0ACB', '8030009500234', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C515EC92-EDC4-4B70-88E4-DABC5C1DB813', '237F2B20-E27A-4F74-B812-5FE7566836CC', '8030009500272', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('041DA18C-EAA7-4669-8CFF-89912CF5C240', 'D7F386E4-0C4D-4E88-A463-E843CDE76719', '8030009500319', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2572A5FD-07F4-414A-A3F3-B58815E33809', 'B2701D03-D2AF-4BE0-B1B7-FFB71B340A02', '8030009500326', '  /   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EB8FAB3-967A-499C-B226-1D8EDB1D2110', '012E0A0D-4B8C-45DA-813F-FBCA61ECD771', '8030009501019', '- /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19DFE9F4-C8EA-4F93-880E-01078CB1403C', '97BFCA74-AC7D-4D31-8B1A-9FBF024DA822', '8030009501095', '    // 0-3 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF60B5C0-6B5E-4E9E-A8BE-1F629102DFFA', '6BA942E3-FE90-4320-8241-7D1F5CC28B15', '8030009501101', '    3-6 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06103C42-6159-40BB-9DC3-0DF6621A0B06', 'D448A8D5-1C1C-4DE0-837B-E292A3E472AF', '8030009501118', '    6+ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA65A0C6-C54D-48A7-AD17-04DC0965AC18', '54BEAFC4-B452-48F5-8392-AA5474195F02', '8030009501187', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7B86DB1-583C-4441-8E21-8147127AE571', '0EC80EEE-9FAC-4123-B218-70094B0E23C7', '8030009501194', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('992B944E-1FE6-4E85-83AC-0D23852101C4', 'F0FD493D-F58C-4CF6-A690-FCC82F137418', '8030009501200', '  /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBD71871-0CCB-4E80-94D1-C3F26FF214C0', 'D783C4C6-35E2-42E5-A6E9-95D2B4A541F0', '8030009501958', ' /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21EDDACD-1857-4752-9D2F-04A36DF9B52B', '52517432-9C31-4C3C-B091-26F4CF581F20', '8030009502009', '   / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00EDCEDB-194A-4F8C-8965-8494D0707159', '57B7D085-0CBF-49E4-88FE-7288B79E07C3', '8030009502047', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59878AA9-3306-472C-9643-2E7517D642F0', '30BF4EFB-D8C9-49B8-8ABF-5B8343592C2D', '8030009502092', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D37F9205-866F-492D-8418-8310C426086F', '663A740D-7B06-4592-925E-D41B07629C90', '8030009502252', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A314190-0811-410E-BFC0-A3AB6541B453', '869EC32A-E75A-43D5-A982-68933F4FCDDD', '8030009502306', '    0-3 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61F89914-280C-4F8B-9064-F53FDB6C5307', '9FA57211-09D1-420D-8EF8-8060531AEA94', '8030009502313', '    3-6 /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CE57F10-0D71-4BBE-A8FE-5C1A37F95079', '246940F5-EFA3-42EA-912C-294297118006', '8030009502320', '  3-6    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4638F401-9DD1-440C-8949-9EBB08C133C1', '36C18A9C-C5F4-4870-84E1-A66E923F6175', '8030009502337', '  -   6    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC97B50D-F40D-4F38-B504-0FE442D7D7AD', 'C4EF88C3-4EA4-4B44-816B-FA0CBD5BFDED', '8030009551090', ' smokers  /    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA18FE44-9D9D-4772-B840-DD7D229593B2', '86ACC140-9709-4C18-9CAE-BCFB8FB17479', '8030009570053', '- //    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE6C07B0-D232-4D73-B3AC-48319864BF99', '7508AF03-E664-4D33-B4E6-624D81FE2E36', '8030009570473', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E983E76-D088-49B1-98F7-C68855F88AE6', '5B3146B2-8C51-4ECA-9CA7-B21B60AA4974', '8030009570497', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D872BA5B-A02A-43B0-9B20-937FC6DD2364', '6AABC6EC-9577-4D11-8163-C4CF3FA5923C', '8030009590327', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52F583B9-1838-40B4-A9AC-007A66BF2D4C', '515E6213-CC79-4DED-AC55-906694F342C2', '8030009590730', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D34F7C42-C9B4-4E05-B916-188AB38C46AD', 'E2093F9A-90AC-494D-8B7D-D19C3F2685CB', '8030009590792', '       50+ / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5ACDD281-3C5A-48E4-9B5F-8738FBFFBFCF', 'E28F9732-C811-4559-8020-C360566475B3', '8030009700207', '  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('563C258B-741D-4876-AE8E-E4025D86C10E', 'CC0C2EFA-123D-408E-8B3C-EF486B84158A', '8030009701020', '        35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52ADBA2A-3FB0-47E3-BFC0-9E26990FB34F', '3D29A0C7-F131-4E66-A999-13064509C9B7', '8030009703017', '    s 0,28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F3ECD9A-C0A6-4189-ADDE-0B2F19486E76', '96DE4011-AE07-481A-B0E4-921AD27D4323', '8030009703543', '    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59FE43A9-BB61-42A5-82BD-891DEC0BC887', '0BD94B4F-078E-4F06-978D-051501080241', '8030009706247', '    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B39B1FC5-2EC4-42EB-8E2D-48B795B9A30E', '1B1623B4-D058-4295-9C9A-139B5F0525B1', '8030009719612', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5FA2D66-878D-4092-8BC3-D3195B4F81A5', '2AD28DBB-9449-4240-A255-6CA7417258C1', '8030009749008', '    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('802EFCC0-4275-41D5-A240-43ACD53E7EAF', '3A5B13A7-1327-4A60-8A93-E33864BA61B3', '8030009750929', '   /   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9109DF29-E04D-41E5-B701-6313268E5B41', '1CBEC497-2399-4436-9C64-2074F48D7BD4', '8032568302236', '   . /    spf 30 1 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CE74109-F114-43BB-8C4F-7FEEB6AC40C2', '3601F740-0BBC-4843-AB6C-047D150B23AD', '8032568302366', '     /      1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C1EBE6E-1CE6-4547-B8EB-C7ADA03A75FD', 'E9A74D39-2F3B-4C68-B423-844B26CA8A30', '8032578474152', '  /       10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D27A25F-7FBA-427C-BF88-DE7BB9CA7B6C', '2C2B6B9E-78CC-4BE3-8209-FF9D152E1186', '8032578474640', '  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('024A86E0-0F4A-4C30-A4ED-1CD28E5D707C', 'D95A4463-90AF-49AD-B9E8-7504D0A0E254', '8061841025531', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95A920F3-4524-4ABC-A99E-E992A841B544', 'BC1C5B2C-7647-4E7C-B00B-AE2E06479321', '8225040171547', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D675298-597D-4EE6-B548-F7AE72C9CD4B', 'B535534D-C3F7-4501-B985-BEDCB71E19FD', '8300961015795', 'Relasan      s/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79AA464C-8C94-43F8-95A4-E795EC3AC669', '0553E245-2A60-4F4B-B0E0-5709B161DA27', '8300961020324', '  /  280den s4/nero', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D86D15FC-CAA2-4F97-BCC3-24D9A0EDB814', 'C843EDA2-4537-48C7-8427-0F35F50CC7AA', '8300961028535', ' 15-21 mmhg 4   -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F51B281-55CB-4241-B97A-4913A3EF7901', '9D3A05CA-5DF0-4E36-B4BC-59578323A54A', '8300961752218', '  70den 12-17mmhg   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53529D5C-459A-4EB2-A306-F0816571528F', 'E7E6A88B-F243-49C9-9B27-8EC6FE1B6993', '8300961754991', '  / gambaletto 70den s4/nero', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E3FA045-3D8E-461F-8D5D-F751EC88A474', '39372005-8FB7-4CB8-A8D6-CC2070C54E51', '8300961772216', '  70  2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D18611A-361F-448C-9562-0E2AF230069A', 'F7424E94-025F-4B8C-8691-FAE3C37D9CEC', '8300961773213', '  stay-up   70 .3 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA39F631-9812-4BC2-A31E-AD1438D944DF', 'D4856F59-5F0F-478E-9F68-8C4DC3513B24', '8300961853212', '  140  18-22 mmhg  .3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A8B431E-A1B6-4E29-94E4-61D708642322', 'A6FBEF14-FEFA-4A1F-825E-26E59AFE57A8', '8300961872213', '  140den - 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B27DE36D-5A0B-42C2-BFD5-11E6496568DD', '27EC8AB0-42A7-4885-A146-EB59D40D6D61', '8300961873210', ' stay up    140  i  . .3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BB9C76C-56C4-4FF0-8F31-6900241AF9AB', 'A6340E57-6A6F-4BD8-81F0-FDCD6E433ED7', '8300961875214', '  140 .5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('787EFDB3-00B8-437B-9327-D89B763461DC', 'E2FC065E-2AFB-4C04-9AD1-49575DBFD02A', '8300961875993', '  140 .5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1953583-365E-471B-9615-A8DCD9980086', '4607B285-6CBD-46B1-85D2-4B004FCD6D31', '8300961887217', '  140den 3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A19EA8E9-8B80-4514-AFC1-4EC26EB73839', '5F49B8DD-36D0-43F6-9E9A-7096DBBC2818', '8426181972141', '    /    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A28A1FE3-2730-4F37-8F41-67E5B5152574', '6AC78D1F-FE3F-4BF0-A1E5-4312235E9216', '8426181972486', '        6,25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('334F1CAC-125A-4194-9247-E33EDF6A4228', '82FEB1DD-E5FA-4EFF-A794-ED805B32BEE5', '8427030003320', '      370', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3688AF0-60FF-49A7-9F4C-F4789D2785DB', '5EB6BC0B-ABD8-4CFA-8482-59B23CBC1208', '8427030004419', '  -1 0-6  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FEF3F2E-14BB-4432-9B97-32E76E0A1CCD', '1B438D7B-06CA-49DE-9770-A995DCC5FB12', '8427030004426', '   1    /900', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A8CF3B2-EBEC-4E88-B701-7B3AE21B1159', '48BD369B-FEBA-4F2F-82C5-4937C69CA26C', '8427030004433', '   3    /400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8FE2BAB-8823-40F9-BBED-1251727E2596', '55D85D3F-ECC2-4B54-82E7-21D25797CFDF', '8427030004440', '  2 /6-12/ . 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9A0F1C6-5DDC-4575-A228-C2DCEDC9D204', 'DB407766-7334-433C-97B7-1171EF72A57A', '8427030004457', '  2  900', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3533392D-0396-4B37-A219-79055817E91B', '54F65FCB-332B-41E0-8AEA-9BA0107D6C75', '8427030004839', '   1  0-6  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F687DF6-7D2E-410C-826A-8AB370CC9193', '66744A8C-A919-4690-8C31-AA84B0AC7DEC', '8427030004846', '-2 . 6-12  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE80B318-B87C-4F10-90CA-382206CD7A8A', 'FD553AFF-F07C-4A19-9ED6-B7DE48AD3FD5', '8427030004945', '    375', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2F201A1-D2B6-40DC-870A-62500C8EADFB', 'FDED0D97-AA86-48B1-A1F8-C943A62CF29B', '8427030004952', '    375', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BC227D3-9315-49B4-8287-BF27860D137F', '4539CD30-B6A6-470A-80C1-21F875984677', '8427030005812', ' 1     375', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B61381D-6FF4-4668-A86C-A3271503CA62', 'F42B1A75-D35F-4243-BDA1-5CB091432B5E', '8427324833275', ' 2 0,3% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98B16751-89B1-4E0A-B738-A5E443EB067A', 'F22D0F9A-2FB7-454B-B971-757D77E8F0CD', '8427324862961', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BF618BF-29E4-4D33-9C39-98239DE9817A', 'A5D85CC8-B966-434F-9907-7B474DF53D2A', '8427324883775', '  10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD9750B1-0C89-4854-B568-C6D1EA79F00B', 'D49AD7AE-7D13-4A84-BE22-7AA59381C695', '8427324890346', '   15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1450BF29-D31B-4854-8FFE-22CB5D14285A', '36E8EE84-5293-4673-AA14-CB2E12B7F751', '8427324890353', ' 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38FFF84D-A592-40AA-9639-CA912D401305', 'D5C50B84-3182-4573-9700-33C3B9159650', '8427324890445', '  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C5D9DC9-2DF0-46BC-8BBD-D62FE946D248', 'B4184491-3EFE-4D13-9890-9E87863BDAB6', '8427324894450', '   10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4EC5638-7A54-4C40-B149-39F5743BB5F8', 'EDE7972B-8B74-491C-8F1B-A82859C4C838', '8428235017815', ' 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4EBAF8B-E16C-4348-87D1-E323E35C7437', '46EEC922-0879-4BF1-B04D-35517371919F', '8430134000782', '- 45 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('265764E4-9689-4EBA-B2AE-4F9A08C434F4', '63064789-DB1C-409E-AD50-6805FD46364E', '8430308024217', '  20  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF39D423-80C9-40FE-85E3-8C29A54EE63E', '62E26D98-C32D-4FE0-B4FE-E01D274A523E', '8430308065647', ' 20  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24678B12-CBAF-4D8A-956A-B21646B8DA00', 'E25BF6F4-CDC1-4804-989C-6240B112698E', '8430308577492', ' 10  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49E5AD4B-2406-4895-884B-47D2149873E5', 'DEE3A8E8-36FD-44DF-963F-C14A60B476AB', '8430308587491', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27C92D69-5D07-41A6-BAAA-C4F245CDFFC4', '4ECCF658-0B41-4F97-BCD1-D0811306D8BB', '8431306002719', '     /.  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23E36864-3096-4F38-8C10-F0C6B7395E16', 'C10D6873-DD51-4B80-A1E1-F63048E41F9B', '8431306002740', '   /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('508F1AD6-B012-49CD-84F5-4C3CF19BEC8B', '7E578742-ED30-4A03-8CFE-7D05DE2AC43E', '8431306067909', ' unica    /  .    350 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DAC2C03-94ED-4F19-A7A3-DE521C315459', 'DEC2444B-0A85-4652-BE5F-60AFB65DAD81', '8433042001391', ' 1000 4  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B21067D-35DC-4607-8162-319E8E33ABC9', '26EA4265-9256-4882-B4B9-14330FFEE2FB', '8433042001407', ' 500 4 / / -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1A40843-4BDA-46D3-A756-503424F91039', 'CA20035A-BAFB-4A44-A268-4014A65D272E', '8433042001414', ' 100 30 // - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B67D00D-3878-4C65-B489-BE95F0D87C56', '36EB8051-AA3C-4531-803D-A5301232CA1B', '8433042007126', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C72367E-8FF8-44D9-91AD-727EFE607E84', '8462FFC5-011E-4B73-8911-C810B703533F', '8433042007133', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA9543B0-7580-4676-9860-C0FA50E48982', 'C4CEC4C1-A1E4-4B45-B622-F77F7DACBAD5', '8433042008628', ' 20 +10 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92BF12E8-E335-42FF-9F0F-BEB03CC44BD8', '231ABF90-781A-49C1-BF5B-52A9B79958E1', '8433042010546', ' 1000 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18635487-8ABA-400D-9FE6-E5AF5CF15F61', 'D7C7BC2C-506F-4419-9EF0-C9323A21B1E4', '8436043011062', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5E52411-FBDC-43B3-8DE1-57B9AE257BEC', '4838EB54-F942-44D4-9535-2222FB7424A8', '8436530800032', '  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70DC5432-5103-4C07-B7A1-8AC7E61007AE', '50C6BF15-56FE-4F0F-A8FE-E2042BF77CB4', '8437008498010', ' 50    -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F45A211A-5833-43C8-9335-AFDF5871C9E2', '60328EF7-3EFE-4D26-BEB0-6C8362E0F42D', '8437009433218', ' 2+0,03  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62542B90-580F-42D3-B45D-1F31CC1BE93B', 'C18A9055-3BDF-4571-BE31-0BB7106F69C2', '8437009433225', ' 2+0,03  / 63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79E95BF3-F766-4AC0-9E31-34B41CE675C6', '37A2C273-1DBE-473A-98AC-434D5B350E97', '8437009433232', ' 3+0,03  / 21+7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F85A188-8B7E-4F22-98BB-74919BF6D737', '472F5EC3-07B1-4860-B8B1-311CB4D3997C', '8437009433249', '  0,003+0,02  21+7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DCAD6B0-0F19-4E6D-9473-F22363C4A7EF', 'EB19879E-4795-4AE4-AB82-33753B3C88B7', '8437013563031', ' 100  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B306C2C7-29C5-4FDE-AECC-8819E2C795CA', 'A497CC1C-B75B-47B2-8A8D-430501DCDE13', '8437013563048', ' 200  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4115650-4242-4AFE-A962-B37D3A7CF454', '849D00A9-B958-4FD1-96F5-4C7C493C0D8A', '8470000124280', '-  0,2% 35 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB071326-0498-431A-83FA-B7DCBCCAD8C8', 'E1A4D31A-4EC2-47FF-9BD7-EB0A0087530C', '8470000478864', '  0,1% 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EF7ABFB-B61B-42B4-8F98-4B4A00D73822', 'AE777024-3B28-4330-A77A-32FF65DE12E6', '8470000478895', '  0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70CD8EF2-44FB-44E5-98D9-FC53BB9B828A', '57DB8C81-E9CE-40F9-9E2B-688D045FC050', '8470000478949', '-  1% 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E80B3156-C727-4CAA-9EF0-AD46A75538A8', '619037B3-8F0B-4D04-98E4-E4DC24C99C5B', '8470000487781', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6B65458-C11A-46B3-8058-E0A160DD0DCD', '45BD1CE9-7F06-4E7A-8F97-A68328EEA966', '8470000639159', ' -  0,2% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DECA8782-C1AA-4C3D-AC45-C58656DACF8B', 'C35CB572-4A0D-4427-9783-FA72FE40E0BA', '8470000639586', ' - 0,2% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1363093-BA45-41B4-8F1D-A1B77A20A2FE', 'E9CACBBE-03DA-41E0-A1BC-11B590D09813', '8470006648216', ' 5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEAB6DE0-090B-4069-824D-5B0640FBFB7E', 'CE5638A3-50B4-4C5F-B12B-0145B31AA652', '8584005010346', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2689174B-A79E-4702-9685-04D024A579EB', 'CC81A2CC-69B9-4BC7-8E58-B5906FE2659F', '8584005033444', ' 0,1 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20850EE7-C689-47FC-886F-E4CB4962150B', '59F0AC20-90A9-4E75-BB45-1034FF1AED21', '8584005033499', ' 100 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('990A62D1-A7AE-4ED0-8FB6-9208DB5E0B50', '1B1E5845-A34F-470C-A3E6-FDF0122939BB', '8584005033505', ' 12,5 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF2CDCA2-140D-4DC5-9EDE-1D2BE4BA8605', '00893808-DADD-4070-831E-47D5F7581A7C', '8584005033543', ' 0,05 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB1DF4CC-3E96-4598-B895-757DEABBED1E', '7C532662-470F-4303-8FA8-F349A1DBDBA9', '8584005040978', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D04EA5A4-065E-4F6E-9BA2-CB6C4C569DEA', 'F3362C72-FEDE-4359-B8A4-306585E1E19C', '8584005053992', '  / / 400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B6F5DF0-1952-4426-B340-B5F7E06223F0', 'AF8CB946-FB52-4406-8B6C-4E1824519462', '8584005101303', ' 5 //  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC415D50-0ADA-4FB8-857B-B6A8202321CF', 'A4D0DA46-ED91-4F10-A6EA-96F96AA9EC3C', '8584005101402', ' 10  / 30', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('768D7B1C-C2B1-420B-ABE4-511632F6E052', 'A8088E08-1986-4BBF-A363-2786FDD6BCF4', '8584005101501', ' 10  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A7F5B93-7100-4E36-A0A1-DCDC21688028', 'C6D4AE94-91BC-4565-BB85-93BAF01BDB45', '8584005101600', ' 10 //  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('238E0E85-4D50-4D16-93B9-30CE40F1C65B', '9D77D51F-582B-41FE-9199-DCB04DC412B9', '8584005703637', ' 500 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9F315DD-62FD-4B5E-A33A-763563D69BD6', 'FBCD1B38-6F47-4F68-AD5E-EE276BD7FFAA', '8584005703668', ' 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1706106-E73D-44B2-964A-E0603CAF6A4C', 'B454FC44-252C-4EC8-899B-2E589D6C7064', '8584005703682', ' 1000  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA3BD4A1-0ACE-4908-A312-CE045365D68D', 'FF2A6465-C1B1-4DE1-AC5D-B96BC6DDD816', '8584005703699', ' 1000  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('202E0B30-FDD6-43B5-9D8F-72650CEC7014', '02C7E005-7950-499D-8EB8-7222B1B08EE9', '8584005704313', ' 12,5 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55393C37-AA83-4065-97AF-B44804A884D9', '36F44BD8-DCEA-4FE9-B808-F3BF28BDE494', '8584005704320', '  50  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4B63B23-82BD-47B5-95B0-F5916B30DC3E', '76DE6B98-1908-418B-B682-F8461C1871B2', '8584005704337', ' 100 //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86A5337E-70A1-4EF9-A313-3D7B2BA7BD84', 'C2158D2E-E3C4-48DB-93ED-70AD40ACA9AA', '8584005716934', ' 100 60  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D274E24E-37AD-439F-AC6F-EAB3BE052D98', '8494E9BB-D381-4334-966C-C6AA6B89DD62', '8584005716941', '  400  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A67158F-27FE-41BF-9830-F53B0B170D02', '0CA118D8-9114-4302-B1AC-2CBDFFE17AB0', '8584005717054', ' 100  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9EFEBF8-48B7-4DD7-85B8-809CEDA73138', 'C29B51B6-FAF9-4CC3-B8FF-C183927B10E9', '8585000204907', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4A449F0-0810-456B-8EB3-46C2C04E2264', 'CAC59135-1766-4AB3-AD53-0575026277E2', '8585000204914', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('826C3BB0-FF2B-48C7-A2D5-4FEB81E45D2A', 'E9CA74E8-59DE-4BD2-84D6-85603BFBAED1', '8585000204921', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A583BF67-E7E4-4496-8792-815FBFDFFDE1', '105067A6-60CD-4C30-B3CC-30665B18FCAC', '8585000209377', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D30B423D-3B4F-4F7D-BAEC-ED0BF75A4E48', 'CAC59135-1766-4AB3-AD53-0575026277E2', '8585000209490', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3061977D-463A-4C0D-894D-0DFB7A358950', 'C29B51B6-FAF9-4CC3-B8FF-C183927B10E9', '8585000209506', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9BB3E29-2002-485A-8FC9-78704387D3A5', 'E9CA74E8-59DE-4BD2-84D6-85603BFBAED1', '8585000209513', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA132631-BBA5-4ACD-8B2E-3E14C6D6A93A', '73A8FBBD-8F3F-4C4F-90D3-23D16CE4BE98', '8585000209520', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AEA3339-7800-41B7-91D7-4E5BAFDC8951', 'F04E2C1D-7733-4803-A5EB-51308AF9C3B5', '8585004500418', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3AE892C-DEE6-40A0-8227-79C748B8DF5A', 'D4C1A78C-61DE-44D9-8A0E-4B0FA49E5A6C', '8585004500432', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B29B548-07BF-419F-B242-938BE323EA7C', 'A4D1FA1C-A2F0-4C02-BF08-6E03E41273A3', '8585004500449', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FC1624B-96F3-4309-9808-AF3A2D5B7721', '1985C61E-4FAE-4B24-BA6D-F4E4CD5E9CDE', '8585004500456', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39F3AD0B-BF9A-4053-ADF3-8161B6C9040D', 'B327FDB8-8530-497F-AA18-CE6422823EB5', '8588000133925', '  .    -. 1,25 .@', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4623298C-D400-4955-8114-1520935CD7F9', '24A27EF2-F451-405D-9113-32929F2923CB', '8588000227853', '- 5 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6F2BF85-7485-4D41-B975-3F514C04D322', '80BF52D0-D4D9-4CDE-BE28-7F180CB72996', '8588001193881', '  ola silk sense 100//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E14B384-74EC-472E-8687-92FEE5853145', '20CD27BC-9287-4864-BC40-12CB7F9D94E4', '8588001193898', '   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('461AAEF2-3654-4A5A-976E-F4B12053C3CC', 'E939C554-E859-4E56-B302-C27DA65FF0EE', '8588001193928', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D250C6C5-D377-481F-9656-AA323D3EA547', '7AB8F3F2-6C98-434C-899B-7E39F66C9780', '8588001981402', '    10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('495A98D9-7392-4147-987A-93D2BA89D060', '8FADFBF3-E969-4E9E-917E-03F0621773CE', '8590232000050', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98B87F86-228A-4161-9265-8F092E4CD7D1', 'D9888577-B1FA-4086-9638-91892540DA3D', '8590232000067', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E91D3B0E-C11A-4308-8CB4-F927F5400E0A', 'D2D32E07-2D06-4C9A-8F5E-7C7D7103BE1B', '8590335004719', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A72758D-1DB8-4893-8AE2-AA1A99D8E9E7', 'FE48EA2C-B2CC-4943-A239-137AEE716512', '8594004692672', '  //  420', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53C2BBAE-9979-443C-B262-E8F584EAEF39', 'ED70D14A-1B4F-4B36-8467-34D3EE55D479', '8594737175817', '  10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5767B801-C3C6-4A65-834F-3B91E5D0111C', '5495E750-14B4-4EBD-B3E5-5973702386BD', '8594737181511', ' 0,0025  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A65A4AD-2195-4D29-A3F7-3DB68C41C469', '5276A9EF-DCBB-4301-9BE2-9CB7D380FBCA', '8594737184314', ' 50/ 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EFC9544-DDAE-4EA1-8E32-593A3286BEAD', 'F5572A08-D563-4BD4-BFA7-7A64029749AE', '8594737192517', ' 0,1% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B2FFEF6-EDF8-49A6-BA09-CC2FD4CAE9FD', '3571138B-CBC0-482A-A80F-8063165C5DFB', '8594737200113', ' 50  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DE01BC8-3A5C-4275-B5F4-A53289C02E69', '2408CFFD-062C-4578-87B0-9DEE1DD45F19', '8594737204616', ' 50 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53024597-7F20-47A4-97E8-92A8237C3896', '597B7873-AB5E-468E-B317-1C603BB21F9E', '8594737206917', '- 200 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ABE8C07-A84C-48D5-88FE-D2289792736D', '8C4A44C5-A709-4C51-8C8D-68E72D86B7F9', '8594737209819', '  50/ 120  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA81EFC3-3CD1-44A7-871E-7971D95811E1', '6B117A43-904A-4465-9404-4EE922636E10', '8594737211713', '-  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B53304FC-9821-4257-AFB2-496782B4FBAD', '40B19699-ADD2-4AA8-9390-347517BB7DCE', '8594737212116', '  10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07240F27-E5E8-4786-894B-86629C16C9A9', 'B85603B5-F08E-4FD2-951E-E164BD095C9E', '8594737212215', ' 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8627B56C-0B8B-42B7-A30A-241E995B605F', '448E71B1-FDE1-4D0B-A2F0-24A04ABB5A6E', '8594737218910', '  0,2% 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EE8827F-50CF-4016-A48B-72C14C8DDB53', '2D80E791-C9DD-41DA-ACFE-B7DFBB4BF272', '8594737219610', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E882506C-4B92-4B18-A944-DECD1ABD6D16', '0600A36C-282F-4B64-A1F7-069D60C67904', '8594737219818', ' 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E2CF1C3-1DAC-4A1F-97E9-D67ABF3E1427', '08B7BF10-FA76-4A07-9FDE-A131E014EC0F', '8594737220012', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2286A8BA-E2B3-4271-A117-727A88342FC9', '5495E750-14B4-4EBD-B3E5-5973702386BD', '8594737221811', ' 0,0025  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A730D083-9C7D-4309-9DA0-A6E932AC4EE7', '016FC2A7-05B8-4010-B8B7-CF1A8FCA8A03', '8594737222016', ' 5    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FFFB820-C304-4656-958E-F4A5D32CD19A', 'C6F3E729-7BDE-4638-B406-6FF2171C6FF0', '8594737231018', '  0,2% 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('254481EF-AEB7-4E04-AAF6-483C056FD185', '469EFD74-4C2F-4AB2-9F58-C525F28E2626', '8594737231711', ' 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B4FEEC1-AE14-4359-B937-987576B7DB23', 'EF8BF7EF-37AA-4BCE-B222-E8BB7BABF8C6', '8594737233012', '- 200 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA3214F9-74DC-4FF5-ACAA-4B6FB44F24F7', 'F3F4C512-A182-48D4-A014-22B559DDF069', '8594737233715', '- /1+1/  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEEA88C6-89AB-45BF-80E0-ABE88F3E6503', 'D0EA99BA-2DCA-475F-AFB7-0553515E07FA', '8594737233913', '- 0,2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BD45B60-15F5-4560-84D5-1D729237BF42', '8E0B2CF9-A396-441C-8DF7-F7E0985B4935', '8594737234613', ' 7,5/  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC941563-1B39-4286-8B02-69827724CADE', 'ABB7AAA7-C137-4809-A391-8FC61D8653A4', '8594737234811', ' 7,5/1 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51E2B3A7-0694-4E66-9350-5C3EF6D1EB4D', '788B9653-55F8-4B03-9D93-0F69F51A7852', '8594737235016', ' 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD7BF185-C392-47D9-B79D-BEF346640C3A', '8DBEB559-0C99-4C8D-A807-101D8AD704A2', '8594737236914', '- 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AAC9F5E-099E-47DC-839A-5DFD994EEC63', '9711D582-77E7-4A54-89C0-B91FE9468EE8', '8594737237119', '-  200 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD3107E2-1FEC-4C6E-BF1A-3A5915FD1492', 'CEBBA4B4-FB45-49BF-AF69-E9519EAF212B', '8594737237911', '  50/  140   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A6EECAC-A653-4B99-804E-C512C8FC4774', 'E7593465-06B8-4E84-868F-64692A0FB9C7', '8594739012318', ' 6,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B182CBEC-4DE7-4BCF-80C4-21E4E5D07AB0', 'FE0999A5-2DA3-4AF0-8B4C-7EFBCAEC1968', '8594739012325', ' 12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCB51B77-8AC6-4567-8295-CB4FCF5085E2', 'E6ADB4FE-F7CE-4BCC-91EF-EDA0E6A6FABA', '8594739012332', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E09C674-FE11-4188-BD08-E5FEF9FA7836', '177A29B3-6396-4B9E-BF5D-9F291AA87BCD', '8594739032859', ' 2,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D72714E9-147F-461F-962F-7B293568CD29', 'F3FD1B78-0515-4872-A28E-4E8EB87AED33', '8594739032866', ' 2,5  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73E8E793-7DF2-4D4C-9985-C8728BA24EDC', 'FE268D57-7365-4CBF-B4CE-8B4A90B5CFD6', '8594739035423', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF0DA4D6-ADF5-48BD-ADBF-8A343B3609D2', '8D982637-7CE4-4BB8-B715-D127323B279F', '8594739035737', ' 150   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10B27542-F902-4814-936E-46C518F47A9E', '8AAC8418-C405-4062-8550-49C61830F31F', '8594739040007', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B0330DA-5BB9-4774-A22D-05FDC4E0AC9B', 'AA0E41C8-7719-491C-AB27-173D0446B5A6', '8594739041608', ' 0,005 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AD5A5C4-BCCA-4D33-BBB7-CE2D559BAFDD', 'EFDA77EB-B1A4-4157-B604-360F78FAB730', '8594739044968', ' 35  / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B51C233-50BB-4867-84A2-E7CC6426237C', '0C4C464F-E4B1-4590-A3EE-89DF3EAA41DF', '8594739044975', ' 0,035  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('850B853A-39E3-4652-810E-240971C7C7D8', 'CC42B471-70A3-4953-80B8-296D6FBEDE03', '8594739049369', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80AF8C66-071D-43C2-97BE-E8A125AA8C51', 'E1FAE4B7-6B8F-40F1-B540-BBC19FBE4347', '8594739049376', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15931F9D-5F80-4B9E-9209-E9902611D496', 'CC88B98B-1263-4487-876F-F1CAC6ED7086', '8594739049413', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86DA17A2-BA67-4045-A52F-94BB1B579472', '90944EE6-04E1-4B6B-BBFE-447B85DF9690', '8594739049451', ' 10  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5277B863-49C4-4340-BBEE-659E957FD195', '70A872CD-D19F-4B0A-B5B1-091482732395', '8594739049482', ' 20  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62527AE2-6341-4D8B-B24D-70BF4DEA6673', '920A327E-32B3-45F9-A8D3-A7D0EE33869E', '8594739049567', ' 0,04 //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFF8F2AB-8563-4F56-8F78-4D8FE8E38884', 'FEA1CDCA-1168-4D51-96C4-8D06CFFB7FD8', '8594739055421', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8B23D7B-B733-484E-A773-96464CED273B', 'CBE1E4B5-B8AF-4C6A-87F6-389ED52FDDB3', '8594739201897', ' 1  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AE26FB9-DB14-41A8-9A06-A1F0F4C862CD', 'C3562C49-B678-40DC-8946-AEDAFAD63B7A', '8594739201910', ' 2  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9F77C54-5478-407C-BA8B-FB0B8C9988B2', 'E4D98EC5-A189-4F63-B12D-2DDFB15ADBFA', '8594739202887', ' 5 //.  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D9E2B03-9DF3-46B3-8DBB-195B2B1B86D0', 'A8FD7827-A45A-4377-BE53-FE1F573A1B87', '8594739203167', '  / 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEDC4BA6-6DA0-4FE6-B23F-5689BF8A9512', '6FF1B621-AF59-4944-9192-EDA12EBC2863', '8594739203174', '  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D02659E2-1807-4F35-91D0-61224F6A4781', 'C3E27556-7F65-4576-A60B-CAAB568665CE', '8594739203686', ' 300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CB39E89-FE0F-48B5-B92D-CABC75BAAD07', '600B9E12-6FF0-45BD-ACB0-99906F6487D0', '8594739205291', ' 75+20  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0716F99-8BF6-464F-994D-6D201CD1D3A2', 'A3BB1987-2140-4592-854D-446F3206AB9A', '8594739205314', ' 75+20  / 63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E227768-8FE2-4182-9C2D-FA3256A04CA0', 'BAF4CAD9-9AEA-48B8-B6A5-EE9BE6AD5B7D', '8594739205390', ' 0,01 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('163E9FE4-3CEE-47D0-8BAA-214C4F401F56', '06C01332-57BA-401F-8D5E-64B5EC252F48', '8594739205413', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36162248-824B-4389-BC9C-67355C3CB11F', '39337CD1-C0EE-476B-BF9F-588410F86CE9', '8594739205512', ' 10  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7913142-9196-4475-8708-CF607EA7C552', '110F8FC3-2E7C-4D19-97EC-4615E4A0275C', '8594739205536', ' 20  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3456DEA-0636-45C2-86DA-18E6FD62BDC2', '8D38E05E-39A1-4121-96D8-4FEA387FCF82', '8594739205987', ' 80  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC7562B0-C794-4E67-8001-D9BE93D704B4', 'CAEBDF07-99A9-44CD-9D28-D5DA78B2CD43', '8594739206021', ' 160  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A2E6F4F-7A64-4A5D-B618-AA21DBF31010', '84BAFB54-F289-49DF-9D49-ED98A7186163', '8594739213128', ' 0,002+0,00003 213 // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E9D95A3-0085-4C2B-B4B9-E71F038DE8D8', '073ED9CA-91C1-4B5B-8639-7DFCAC954223', '8594739213135', ' 2+0,03  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48F22538-7288-46E4-8804-147EA31D1648', '48AD3EDA-2589-4ED1-B1AC-B1FE9338E05B', '8594739217591', ' 250  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C310967-E6F5-4A85-8AE4-1F93627CD79E', 'BC5CF39F-6951-4B8F-8FB3-852CC62F4DBF', '8594739217751', ' 200  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6988505-20FC-40C5-BF8F-9FC3F4965F5A', '34EFDF1C-E5CA-4F6F-B79D-214F2803C1BA', '8594739217898', ' 15  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78E6A61C-BAF7-4935-98CF-6FD26C414587', '738B1241-4B6D-4270-A086-AF85BF686D3D', '8594739217904', ' 0,05 //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF388CDE-72A5-4813-A7E9-ED710C08F2B6', 'F1D08AE4-C715-48BF-A034-13A758B551B9', '8594739218017', ' 300  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1EF1B4C-EC5D-4A26-8852-F88A28CB4885', '6440DEDF-924C-42D6-BC19-36CDBDEE3166', '8594739218024', ' 300  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D24C731E-68DF-4704-A98A-1D51D70C0E64', '16416A7D-9CE3-4364-AAF7-63EDD68D3EEF', '8594739221482', ' 10  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50B32322-CDD9-478E-AD17-A30DA6C485D4', '7C0301A2-EF04-447A-9066-D78794237DA9', '8594739221499', ' 20  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('833ACFCE-65BD-4B33-B1E9-EAD01BD78C5E', '8F98C97E-ABE1-42BD-9017-3875CEAE676F', '8594739222229', '  50+12,5 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8ED76A2-8E0F-46BF-938E-0AB92DF0ABC9', 'CDD37FDF-591E-4489-B61F-44F54562DAA0', '8594739222236', '  0,05+0,0125 //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('886BDB96-F87C-4E4F-B8B4-1D16DA2533D5', 'FEA1CDCA-1168-4D51-96C4-8D06CFFB7FD8', '8594739224612', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7725225D-B4C7-46D8-840B-879EA2D1EB51', '8F98C97E-ABE1-42BD-9017-3875CEAE676F', '8594739224681', '  50+12,5 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('189115A0-3FAC-4F53-B3A2-95B310FEAA6B', 'F29F88C5-F05A-4F6D-BC2B-A2758FF2583A', '8594739224698', '  50+12,5 //  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('916B2266-BB94-4E1E-807F-733DAD4562F6', '2CB651D8-ABB5-4248-8EF7-D68C93B48BDB', '8594739224704', '  50+12,5  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88093737-BBAC-416F-AB8D-73BE83D8A470', '9387B3F6-9400-42F3-A38A-AFB2FF6E6793', '8594739224735', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E86F2D1-13D4-499B-ADAF-B4CF9CD1F9CC', '75D04110-0D51-480D-9398-05341C67288C', '8594739706392', ' 0,4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B12D747-0A3F-49B6-B3C6-4FF8E295881E', '025D7AAE-3FB5-4BCC-BBEB-E4304F563441', '8594739706408', ' 0,0004  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62B68D76-1DBD-497C-8886-1FC149B489A9', 'E075CA22-351F-431D-9FED-436480622DAF', '8595026402331', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA34536A-6DCE-481B-B04C-A029BF54EACE', '8176F60B-7E3E-4166-B20C-6CC577A9FCD1', '8595026403338', ' 0,04  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C1DF883-1248-4A85-B1FB-66F63507DA9F', '7CA5FB34-BE1F-4C6C-A1A6-4A89AD22AEBD', '8595026405332', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44FE7270-CAEB-4560-9CD2-560A4527996D', '18A72508-84C9-4B3D-B794-168346DE6FD0', '8595026406339', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFED1548-3378-4961-A435-15FE19EE3A90', '8F4CCBEF-42A7-4C38-93F7-14B5563F2BDA', '8595026420229', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A865C830-F384-4A45-A9C1-2BFB7FE1FE7E', '0C709A23-503A-4B12-826A-4F0D374F6516', '8595026420250', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EA0B11E-BE64-4118-8E53-2B41D8C9F86E', '0C17D6A0-3C05-4111-8187-97F0800D377C', '8595026435001', ' 0,05  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87F4557E-9CEA-400B-B273-DC76BD82AE5E', '6F0F2573-C7EC-4A07-887B-D48D41828E80', '8595026435018', ' 0,05  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0745A12D-BD19-45C4-97A7-B336154C57B8', 'D324F8A7-5815-4EFC-8AA3-C926C2A92CBE', '8595026436336', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D739F92C-DED3-426D-827F-01CDDF5BBCE1', 'B8AD72BF-00F7-4898-A947-306FF0094D14', '8595026442351', ' 300  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F9FB144-8097-42ED-9C08-325D442274E9', '0E968934-2432-487E-9608-D987746D6F41', '8595026450004', ' // 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1B18ED0-14A8-4F00-9335-ECEDBF5E4EC1', 'BAD20D0A-055F-44B7-B01B-AA1D9D374FDF', '8595026463110', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44136171-E6A4-4193-811C-9A88F5B5579E', 'EF250041-1C92-4AE8-8AB3-32FA9CBCE98A', '8595026463127', ' 500  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73BD783B-7F91-47F2-80A1-78106304B950', '38B71646-6D40-4B08-A412-9EF594B5BF18', '8595026463134', ' 500  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5ACA02B6-EAF3-48FB-ACBB-82D4965CC81C', '2293F722-2EB4-459F-9777-AB6D249BF487', '8595026463318', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE17C851-7E13-401C-BCE1-1559BFB6B315', '23A5306B-E3B1-4E03-AD1C-AD19062B4A8E', '8600064422019', '  10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3C9F343-9C1C-467F-893A-D2AAC77A87A7', 'FCECF861-5209-452F-AC58-600B64604AE3', '8600064422026', '  10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47F0FD79-AA4F-47B1-B527-AD5E3BFA92C2', '7C2B7CED-19F6-411B-8CC6-ECD2F5F878B0', '8600097000994', ' 50  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A69F624-B8CE-4174-A137-58FD23832504', '927DACB6-4786-4BF8-989F-BE9407BC0F56', '8600097001007', ' 0,8  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29D0BF6B-2B31-406B-9BDB-30051663F732', 'F39C3B7A-B416-4255-A7D4-895EE5472DCA', '8600097001021', '  20   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29821732-993F-4AEB-90E2-96AD718DA13A', 'A1B6E11E-580B-4AC3-A59E-0ADDED2D7608', '8600097300100', ' 30000  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1B716A3-FD86-45AE-9CF6-4F72F0D98C33', '8529DF22-7B01-4DE1-98AF-E17C9AA53BC2', '8600097300247', ' 30000  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31A6BE77-9172-48F3-BAEB-08FF1196EEF4', '807106AB-A7BF-4282-B18B-E8C58D69DC28', '8600097300322', ' 0,5  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FDB1B23-C463-49C4-B1BB-AF2AA68A7382', 'E4AE84F7-3DFA-4489-85D8-832EF9A23CD6', '8600097300391', ' 250  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51958C9D-F945-4577-9B58-7EA9604E92A0', 'C463CFCE-CA7C-413D-A8DE-A1FF28BD1591', '8600097300667', '  1% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6200E1F0-8E1D-4684-B080-16F0DC644211', '846D94A4-6DED-41D1-9F8C-87010F679365', '8600097300742', ' 150  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADA79962-29DC-4488-A0C2-6E38BBF0F09F', 'CFD78093-093F-4BEF-8695-2613A9D42A77', '8600097301039', ' 50000  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22E34DE3-12F7-47DA-9872-C57F03C76302', 'CFD78093-093F-4BEF-8695-2613A9D42A77', '8600097301046', ' 50000  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8029AD54-08D7-4BC5-A030-B9D65FE0B207', '6EA82FBF-DA37-4096-A1B1-2E8030FC8843', '8600097301091', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E6BAEEE-A755-4765-B407-D48E0AA16411', '84E11A66-15A4-4566-8D71-CE39F968E06A', '8600097301107', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7344C98-B915-496A-AB96-A7ED5D3C25A3', 'AA5CAE57-1EF9-4C0C-BF7E-6DCE31EB9B04', '8600097301541', ' 250 5  / /.  /100/ 40  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88D2089C-043F-42B5-A5CB-5BCED70D4748', '299A6005-2607-48FD-8D93-0E4C5AA9AF2F', '8600097301572', ' 250  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('127537E6-7B87-40BE-A7C7-4FAE5246AB33', 'E1512E54-6A2F-4A75-997F-5A412CA26E18', '8600097302371', '- 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('726F5F5A-7383-4CC3-BF36-72AABEFBF180', '153B3F35-80C1-41BC-8587-8F6E98BBEF99', '8600097303262', ' 200/5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E082B3AD-023A-4312-8FC1-B1EE28A6E8A7', 'BF2C0017-AC70-47CA-B87C-42B1081F1D40', '8600097303415', ' 15/5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E44AA144-FF3C-4E80-8CAB-09827EA507F1', 'F66B2FB0-3038-46E9-A413-9740A04ECCD8', '8600097304054', ' 500 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EDD228C-53EA-41FB-A5B5-3C843B667526', '90F840CD-35D5-4C1F-BE7A-39B60D6332B3', '8600097304092', ' 500+125  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('961665BD-6BCD-4681-9F7E-14FAF94B7B3D', '6EDFB3C9-1DB0-4F79-95E5-9142DB6B59C4', '8600097304207', ' 0,05% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B36740DA-A309-46BD-95DF-180D3AF2FAEE', '1B7EFE9D-906C-4CF7-989B-CE0585E4C0C1', '8600097306065', ' 500  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F4CA432-45BB-4030-8566-04AA78B53298', '04EB4C24-CAD1-408A-B09D-CA62FC51A103', '8600097306072', ' 100/5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9C34D88-4A95-4D36-8FAA-6DA9C9CB03BE', '152A8AD1-6D35-4C85-A77F-7BF61E69AB2E', '8600097306546', ' 20  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('972B9367-847A-4590-89F3-872079FDFDC7', 'D7BA583E-DF3D-4B7B-9B51-CE623923A007', '8600097306706', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44BB98EB-6323-44D2-90CE-1287811C0EDB', 'E8DF49C0-C7B9-4BE7-AB54-384E84FC8CF9', '8600097306713', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('694A0D2B-4709-4183-8453-1A882E81A051', 'D7D71C35-861D-453B-88B6-4C6D34E360AB', '8600097307581', ' 1,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB8D092D-6626-472D-AA62-D50AA6082179', 'A4144BF8-61A5-4F35-8DC3-0457CEB56F7F', '8600097406482', '- 500  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26A720DC-0B9B-4878-9328-8147A37E4A1F', '476E0A4D-0312-4B73-BEAC-BC84829F70E6', '8600097414319', ' 2 875+125  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED19B849-F9BC-4392-8F5A-EAB8FD86FFF0', 'E33069B5-53D1-47B1-AFD4-FBD744CC983E', '8600097415439', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36EDB05E-35EC-4961-98DD-0E6519FCA7A4', 'C4E3F12B-EEC7-4F93-BB90-3CCF8BFF6593', '8600097423113', '  900   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34A023D2-CA7B-41C2-8D8D-EB4B2B3E573A', 'C7F8DFCE-6BEA-4F12-8CE9-44918183B17E', '8606013060028', '  250   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51413A49-1CAF-4FEE-B041-7586986CAEB9', 'B3F9315C-BFE8-4C82-9CA3-3E84BDF9E0D1', '8606106356687', '         4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBCE38DD-4CAF-4EC3-A3DF-563D9D0A67B0', '9CD79BBD-6679-4A93-8DD6-73FA4272E300', '8606107942575', ' 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6D6B6F3-3D8A-44A3-8248-10C5FE4F9499', 'FDA1A571-FD98-4E79-A713-FD53ED4940B0', '8608808120795', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DF075EC-2FE5-4044-928C-A82F5DECC055', '04155C8C-024C-4388-AE3A-CF4386026D6E', '8680585003430', ' 2//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0096577-3925-44A1-B728-C10969FCA62A', 'B6EF1A3B-C8F2-419F-8ECE-34C032F4981B', '8695860003425', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('560C6122-8B7A-4436-8F6F-86915FDB9FC6', 'E4F855C2-3024-4730-8EF3-AF5869B8CDD8', '8695860003432', '  /    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B48A8262-CBB2-4123-85B5-09D8606EDEF7', 'FAD1669F-9F53-48D0-A2E4-F6284E70E00B', '8695860003463', ' achromin classique  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('532B947F-6C5C-45E4-ACD8-6A5F7D5D4E0E', '2B66F097-48A3-4ECA-AB6B-2CA6DF4368D5', '8699502091597', ' 500  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FB197CA-0CF4-49F4-A5A4-3FB7AA674BBB', 'F027829D-B271-411A-A42F-B120BA9316F0', '8699516017750', '  80  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FC95DF1-35B6-432D-B093-96E389B55E8A', '35BEDB4B-ECEE-4FA2-A618-021F222A8C3B', '8699516038816', ' //  80 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00EFCB6E-1341-4F28-BF07-276D77581334', '028B2937-9976-4DC9-8800-7DC6D2DC1AE5', '8699516039172', ' //  80 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('609B7297-6966-42C3-9980-B55691F79DA9', 'E2323239-C384-45F2-A0B7-D3D68B8312F5', '8699516089832', '  4 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('029E3C8D-45D9-4100-B03B-F433C29D87C9', '4517C89A-355A-458A-A4CB-8568C5F3C11C', '8699516089856', ' 5   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7D925E4-F239-41D7-B8EB-A9D3D6859C6E', 'C5590254-52EF-4F16-9547-DFFB95E36CE7', '8699516099862', ' 10  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18DE5FC5-4856-4A4F-93A4-A6411CF03FF4', 'CEFF1393-EA68-43DA-988A-3D9CA25AD4BB', '8699516099879', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03BA6035-8CE2-4109-8EC2-371C3818C922', '95AB9CEC-902F-44D3-9D58-0FDC23D66878', '8699516574895', '  50/5 100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C27A3C37-0EF9-4ECE-A3D0-ADB31D88B030', '273BDF34-70F8-4547-9A11-B7796DA42B18', '8699516575335', ' 2/  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27ABFD47-C7A5-4AF0-87E4-EBF0FE4E03D0', '2B2C3213-7E81-43C4-B14F-228F9709356B', '8699516707491', ' 5/5 120   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA52040F-049D-42DC-8AB1-78F1BB80F382', 'CED1DBD0-2180-4167-8D50-BE75D38E3907', '8699516893163', ' 100  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('822E95A5-ED7B-41A4-B200-D56174B2D2E3', '1197A13F-749E-4B1D-A68F-84CADF636715', '8699525094681', ' 0,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E68A05A-3D0E-467B-A252-7015C4CB8DFE', '31A93571-E47A-4BB6-A4A4-E1BEDF93B0C4', '8699540015081', ' 7,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB7B37A2-CB45-4387-A5B9-987974A752F7', '5509F5DF-BEF0-4DC1-A3BB-11317107237E', '8699540040151', ' 0,04 //  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CD13CC6-CC41-4523-8F1F-450092127906', '7AA4E0C3-8896-49CB-BA1F-60BE4B764F82', '8699540090064', ' 500  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B6634DA-F6BD-4562-8CAA-3D215E218F23', 'BB51EF0B-CA73-4835-87C3-C01FA4C0E90D', '8699540091054', ' 0,5 //  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C764FB16-C6A0-44B9-ABF4-3C4C8C9C1C75', '9884AB08-4F13-49A5-A6BE-3647D77A061A', '8699540091139', ' 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12961BE4-EDE9-43F1-B3FE-9C3A4576D7C0', '089363BF-D24A-4673-AA77-5A2A312E4182', '8699540180215', ' 100  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D63D009-FFB9-4108-8459-FD990E98B014', '5776440B-F5FB-406F-8F75-4D938F4F6AE7', '8699540754003', ' 0,015/1,5 / -  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A262989-91D5-49CB-98E8-5C274BDF169E', '64F7E77C-15C2-4205-8135-20C9B879EA45', '8699541090407', ' 200  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2658F41-46E9-4FD9-B10A-1F8A7E179D0A', '3A33D491-2ABF-48BA-B58D-32F31DF621F5', '8699541092906', ' 400  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64582BC2-58DB-47AD-AC9E-F2A46E86CB40', '36EAE7A2-A609-42C7-B46D-68D7BFF83C5E', '8699580240016', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68B38C78-6331-42CB-89BD-74EE8D2E0AC7', '46B0C5C0-C660-4825-8387-DBE63A24F064', '8699584900220', '-     7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('649E9DED-23C9-404F-B3F9-349F292390EC', 'EC089378-300E-42CC-AA32-AF1061C32CE1', '8699584900237', '-    7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C33220BF-AC31-4531-BFCA-FF8BC13F1375', 'E9364D69-8E8A-4A24-9635-3A3AD97C4104', '8699584900749', '   150 +100  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9D5395F-3D8F-463D-9905-663193F72477', '1327E79D-B3D6-49C8-BF4A-4DEB168E3950', '8710103494478', '  / /86030/ 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C86A159-462D-45B6-A04A-3177BFE7C515', 'C24557FD-EBA3-4BD4-A8AA-919805C6743E', '8710103496526', '  / /86050/ 260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8B0DA50-CADD-4BDF-95AD-FE3BDED43FA8', 'B85EE17F-F20B-4882-B9AB-1584FED60D2B', '8710103496731', '  / /80590/ 260 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F12F50D1-027C-4472-8D7F-8B5BA2646165', '1A6B1A90-76C0-4D9C-B4B2-A8C8017645C1', '8710103498056', '  0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D2FAAC9-E0C7-4C68-8A80-85894B5F6023', '3DBE13DD-A0DB-4D8F-9D2A-0DBD704293F4', '8710103498117', '   freeflow 6-18 2 /86190/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D65A02AA-B344-4C1D-9852-122FCF688518', 'B1B6C9F7-DE88-430F-8826-7F62D790E874', '8710103498384', '  6-18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1381F67C-B03F-4FD1-ABC3-D7426DB6A7BB', 'DB955F7B-C4A1-4857-B070-4B50C730F66D', '8710103526933', '    6 / 65630/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('988B0B07-3653-459B-8522-9336382CB564', 'A85951B5-6BC3-4EA4-B10B-E7F728F96820', '8710103528814', '  /80031/86070  330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EB664BC-DC49-4F70-9C26-95FEA8002558', 'E5DA6103-1772-4730-BC01-08BD0B4A31AE', '8710103543336', ' -  0-6  2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA8099CA-E008-42CC-897A-227EDC6FD997', '82D7ECC9-CB92-4E7F-AC30-577686F76375', '8710103543381', '    0-6 2/bra-free scf176/18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F85BBE30-79EF-4EA9-8102-FF57EE280B7E', 'A01301E9-E67A-4149-AAA4-F7FDC66B684E', '8710103561538', '  /  /86015/ 260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F019BB9-433A-468A-BB7D-DB3AC836FAB7', '57E6491C-8E07-4C87-91F0-D5F815880101', '8710103561811', '   / /86025/ 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5390822-BBCD-4CB7-B229-38678370ACC8', '7E026070-85C9-4261-9DA2-6FEC71B93437', '8710103561903', ' Natural  125 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE53B2BA-599A-4445-ACAC-93D3E714B419', 'E60361BB-9854-42BB-A024-22A68AEA4186', '8710103565765', ' Natural  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF8AD760-B77E-4DD1-94DD-E851048A9C60', '8547CDA0-F855-4423-BF78-3096646DA1CD', '8710103568148', '   / /80510/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BD69484-9380-4315-A7EC-7C0F2C622D9D', '69DFDA0C-402D-4B34-8B2B-C717788B2986', '8710103568162', ' Natural  . 3+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5238FB7-FBAE-4401-81F3-B75E7E75DCA5', 'E01BD96D-FCF3-4BE8-94F7-97602094060A', '8710103568179', '       6  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC692E08-95A3-4162-AE36-305E2788D952', 'B1D877E2-BA62-40AB-ADB1-A0072C65C52A', '8710103574491', '    /  6+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D719FCF-8FAF-4A13-85F3-4115E9656927', '8C6C3D33-7661-4054-B864-FE29754D4D8F', '8710103579106', '   /natural/scf332/01', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('678B7FBE-7BA4-41D5-9B2B-B50DEDC425DA', 'A1A199F8-915A-47AB-B178-BC81CDDCE303', '8710103580935', '     2 82820', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D4BD592-01AE-4C76-BED8-D6004091F19F', '5421B43C-FF6B-405D-9114-099B76D984E7', '8710103580959', '     /8284/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77A0A618-330F-4FE8-86F3-6DD3BB724DC4', 'D1A77F60-2D30-456F-8BF4-A8186367E390', '8710103629405', '    /. 0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A7F26B8-6AEA-4AD1-8A17-AADC96E2C558', 'BE18F2C4-7A4C-4380-80C4-FAF912C38471', '8710103629429', '   0-6 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D197A4F-7B1F-417F-840F-C2F8529C8A11', '21A59107-04F5-427B-9ACC-4193091FDA4B', '8710103629467', ' -   6  18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E70107F0-B04C-4176-81B3-E2825CA697A2', '292173F3-0927-4137-8F5E-DF60C4C0BDDF', '8710103637363', '  /  180 25 SCF603/25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('091C7A2C-B442-4F62-999B-11C4C3D955B4', '75EA5B6A-BD09-429F-9DDD-7C382E025ABF', '8710103645757', '  6+ 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51D0D429-B9A0-423D-B18A-B15CD05183EB', 'A9AA8265-B84F-4AD7-A5FC-B29B0D3407EC', '8710103662372', ' standard  . 6+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B26380C-5648-414C-A90A-F5FB7AD3F0EA', '3D021103-736C-4D75-BE56-4F7B8A8EFD30', '8710103662402', ' standard  6+ 330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7DAA5E9-4D6B-4E4D-A6F3-0B8EABF78ED7', 'DCE45B48-62FD-4904-9D58-ABAE50CAF206', '8710103667049', '  12+ 260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99D7C9F9-205D-4B43-877F-862C638510E1', '9A28C995-16E6-457E-9C17-3F170F03A1FA', '8710103695158', '  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCBFF648-332F-426E-9505-8544F11CCA68', '5480620F-A806-4359-B0BA-70BE4A257C54', '8710103695615', ' Classic  0+ 125 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('130DA71B-6CF8-4A62-B140-AA31FFA4C100', 'F521787D-221A-4972-A1F3-EE8DCD6E85F8', '8710103695752', '  / /ba /scf563/17 0% 260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB7BE340-AEA7-4B19-8D51-ECF73726799B', '2B8C3AF9-D904-45EC-9CDC-D10B7C19DDC2', '8710103696193', ' Classic  260 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6320F78C-A20E-471F-916B-741AB4231FC1', '3A05F6FB-2D66-47E3-8DF9-B8C0691F1B5A', '8710103697312', '  / 125n2+260n2++ scd371/00', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81A53B86-3C8D-4E6D-99F2-04B220322CE9', '662CA173-DAD7-4143-B587-99AB4B2307F8', '8710103759966', '  sonicare cleancare+h3212/03/1 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB031811-1C90-479D-8547-1306F4AC82B2', '11CA382C-3ABA-4E77-9C2F-F8F1BC58E657', '8710103787310', ' -  6-18 2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13987590-087F-48A1-BC79-92F8318F59AD', '9D417649-9149-4198-94C8-041774959614', '8710103789291', ' -  free flow  / 0-6  2 scf180/25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A4DB9C8-4EAE-4799-8DFD-C4C35F24928E', 'F787DDB7-CF96-4C97-8C07-5C2591775F94', '8710103789352', ' -  6-18 2 scf180/27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('430F5354-0365-42CB-B1C3-E0A8039FC86D', '9BEAA1C8-9C79-4A6D-A698-D363E42813B8', '8710103791850', '   free flow0-6n2// /scf178/26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF86C772-D078-4F94-B4FA-4E8DA2690221', 'A52A5B8A-EC74-4CDE-B2F4-09B4307C9AE6', '8710428004574', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CDEA58A-0CEB-4560-8D7B-960088A77BA6', 'B7529BE0-A09C-440F-A4F0-A420570898EC', '8710428004611', '  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9AF1C51-F43A-4ED2-9C07-172D7C3CF643', '11EE3DDB-0757-43E2-994E-D249F1BE0AFB', '8710428007452', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C021B56A-FD47-44FC-9C68-4EF203D5D129', '0457E9B7-5EB1-4253-A661-0A4DD07671F5', '8710428007476', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F61E235-CDA7-43CB-89D5-A37ADA353DEC', 'DFE9CAF0-9F85-4A03-BAB2-9AA405F843C6', '8710428007797', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42E3A4CA-BFF8-4D16-93B3-AE41CB019ECC', '59724BB3-A940-44A2-A3A0-E10F3CEFC650', '8710428601803', ' 1   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFEB113C-6DED-497F-A679-BA2E5B599BFA', 'BDA0D24E-E963-4E8D-B737-E7A31FA4A63D', '8710537000108', ' /  35 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEDBE789-9312-4E84-8F8E-B1BE15E66EE9', '83598D34-9296-474B-A45A-DDAD37E30440', '8711141285820', '- 20+12,5 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B95F477-BE25-440C-B9EF-DC8BDC7AD0D3', 'F4B432BA-12F8-4EDD-9144-B5D96E1B5B5F', '8711141426087', ' 5   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE7F56AD-010F-4CCC-8BA2-FB2F8679848A', '4F6470E8-AFFA-4216-B2CD-F847FBBA7C81', '8711141518430', ' 50  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B2BCC7F-C527-48D4-BCE5-E0DA43972741', '28A357B4-DCA4-43B7-BDFC-A3BB82B67CF9', '8711141808739', '  100/12,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FEBB965-D296-419D-B1F8-284BF9308BEA', 'B474F59F-562A-44BC-89C4-36F73EFFFD7B', '8711141811180', ' 100  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A27346E-C0EB-433D-BADC-89CD90189C92', 'BCFE6A44-12A5-4FB1-B461-86B67883937E', '8711141828539', ' 60  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('755AC344-9B7F-49D2-9D45-8DE974B40E78', 'B7ED6EF5-1803-46AF-AF75-A21B0066BCBE', '8711141828546', ' 0,09 //  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8796668-AF94-486E-A22E-ECAD504988D5', '7923B710-C210-4156-808D-4BA42AA3FA76', '8711141828553', ' 90  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A02C0859-B415-4419-BE09-76C2DCA3A262', 'A7D97F3F-96AF-4D88-ABB0-D08B10377100', '8711141828560', ' 120  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('107E1ECF-DC32-48BC-83C7-1BF40E86BD30', '854A67C1-5C9A-4FAA-9DFB-EEFC82C87D74', '8711141910937', ' 70  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE8CC750-84EA-4C0E-95CB-F1160E8C9CB2', '72E10F10-38F5-4430-A589-FFF11C3BD48B', '8711141911958', ' 20+10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('330FAADC-AEA4-4827-AEF5-7B821BD6BB18', '8D3EECC8-4B72-4016-B79C-A378D20151AD', '8711141912429', ' 30  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCB179A2-CFDB-4C6E-82BD-ED76A2B7E658', 'DB2F3BA3-2270-4DC5-8940-55A13AF840D9', '8711218100537', ' 0,0025 / 2 - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('535F4282-CCCE-4E17-BFA4-783B7DC8104F', '0263E625-3088-4E8E-BBE3-4C5E33CA74F3', '8711218100544', '- 25 50 2 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC3F3C68-1C71-4855-84AF-83B6338D6857', '92FC1CAF-8291-41B4-B93D-C71D231E3433', '8712400160964', '      1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F530F432-B820-45C5-BCA2-3B809510D555', '61C20EA2-7974-41B7-86FF-15256E039DF5', '8712400360210', '     1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B10FC0B8-2BE0-4ECB-A990-F74882B3776B', '6AC985ED-9AC7-430B-A6BD-2E5E70E55113', '8712400715232', '-1    900 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F6618E4-4EA4-418E-B612-F2DD8CBAD450', 'D4ADDCAD-6B01-4D24-818D-E3CA530F93AC', '8712400737258', '  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3736B304-EA07-4811-AD52-23635C6A8545', 'B2498B2C-560F-4230-B29E-FE0C38721E68', '8712400737265', '-2  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B70A75F-F3AB-43A3-BB94-1C677AD48A4A', '34EB6D0C-B6D9-4D0B-B8AE-2027151E7FEE', '8712400748520', ' -  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('956C02AB-48AA-4C58-BA3E-013E41A09D3E', 'D41D418B-FBB6-47E4-B4E3-F14613128F73', '8712400748766', '     450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('710BE817-48EF-4B08-8F2D-B39128429D34', '3E6F3FD9-1974-4D70-913A-8B4C405191DA', '8712400762748', '  0    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17AFDB61-688B-4388-B76D-9B4D40BC3FAB', 'A86C859F-1DAD-496C-9F96-AB97AB31F115', '8712400764278', '   1 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAF20E40-F4FA-485E-B4C2-9516ADFF8FD0', '2D448DA5-4AC3-4EDB-99CC-9B6785E0A792', '8712400806275', '     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E585F0DA-76D6-41BA-BDB9-A31989EF0918', 'A0067E3C-FC8E-4536-BD01-485E92742840', '8714100703526', ' /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37597A4B-3BEE-4C10-9810-0C53B4942FFD', 'DBB37161-D8E4-4066-ACFF-771C0FFB0121', '8714100703670', '.   /   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96965AE7-E1C7-4286-8AFD-91D0604E138D', '44C6FB9A-8069-44F7-9215-4217AEA4A848', '8714100710456', '. - / sos- 45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0D40EFC-F9F5-4182-A008-0841C241717A', 'D0E34DD9-D480-4A05-9826-22EEA3659877', '8714100714065', '  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51BEF3EB-B4D8-402B-977A-B8A5A1292D0A', '6793C693-DE9A-4E29-B426-C424C69BA357', '8714100714126', '       .   /248/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFA60DDD-5D51-4026-89E6-3AF7C13C5CE6', '86D193B5-19AA-4271-BFF0-631EE1B13F02', '8714100716335', '    : .   75 +  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEAAE50F-80E5-4D4D-8B3B-30F6E4118D38', 'FC13058F-225E-4BF0-B83E-BC884879C6B5', '8714100716540', '    75+  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95F3FE5B-D153-47AD-86B1-6A8B82500F26', '7CE74ACA-75BD-46A6-953C-63648C3CEE6C', '8714100716700', ' 100 ..  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB742691-9703-4FDC-8BA8-127CFC315AB9', 'C9155689-B01C-4E99-9A0E-D1E48BBB18D4', '8714100718049', '        8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9EDD2B2-2C5F-47D6-B76C-08C63DF008A1', '333154BE-0F8F-462D-B870-D7B18089DE1B', '8714100921555', '   /     250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E00BAE41-1100-4A3E-8D6A-08C53DA4BFAA', 'CB835986-7A4F-40CC-AD93-B56EEB4B1C31', '8714100921579', '   /   - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05F7D7DC-B3A6-4081-B25C-3E81C00DEA20', 'FB8E1DDC-FC95-4562-A703-0F4DEFC203C3', '8714100921616', '  :  - / 250+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFECB593-BC65-4129-8C2F-EB22598572E9', '8716542C-CAC4-4F51-8140-7460B565EABC', '8714354150138', '  /    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3C69170-9211-4D2F-8352-62A98A3C848E', 'D8771173-DD8E-43DB-A356-900CD43E8F00', '8715239090051', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12DC2F18-49DA-45C2-8C63-6204177AB84E', 'AA7FC3F6-1782-457C-84F2-576BCEE3FB42', '8715554000049', ' 2 /2/10/  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2AA4B17-C077-4099-8CCB-3288F5D39992', 'CEDB6EDE-2DA9-4CA6-AD69-E20154396B26', '8715554000070', ' // 500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6405370-EF9F-4B26-B00D-38137365E4DB', '7FE27F06-31C1-4086-95D8-9822D04740BF', '8715554000575', ' 1/5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AA822A3-75E6-4D15-842D-91A45C6E5227', 'A43D0D65-8EB6-48BD-B7AE-2FD5AF6F5074', '8715554001220', ' 1 1+10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CB1E772-1282-45EE-990A-86EA235A9EB9', '372214D9-A6D6-4E38-925D-3730AC995BC4', '8715554001411', '  15 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F3630D9-5C73-443F-A87D-416DBF9CC248', 'F5DBA9E4-DF0E-4BBB-B288-9D11B97F4D13', '8715554002258', '  1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('291A6CF4-44D9-42E4-AF5B-24C4A5ADC83B', 'CCF2FAAC-F4D9-4046-A892-3B2E6FC7CB03', '8716677005256', 'Kabrita 1 gold     800', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2435CE85-46DC-4AC0-B551-B408BF848909', '14267D56-F6D9-45E7-85B0-73CFE75E1572', '8716677005263', ' 2 gold     800', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85F696D9-FDAC-4065-97F1-F96A3C03548F', 'E04BDF0B-9348-49AF-AC93-F52393853DEA', '8716677005317', 'Kabrita 1 gold     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF1E3566-5A07-4844-A1DE-6887AC8855C1', '5428D94B-344E-48C8-A527-51A5DD3AE5D5', '8716677006345', '     4+180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FEEF61A-673A-406B-916A-4A1F8E0679F9', '0CD2A754-673F-48D9-921B-2100B340FC9A', '8716677006369', '     4+180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09C666CF-A32D-4822-B23A-6FB8804D623C', '42A3D339-9AEE-4FCE-B7C9-97414D56552B', '8716677006376', '    7   6+180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('028405C3-A701-4D71-80F7-762306553500', '9C0DDEB1-CF6F-4D95-9772-D47F91E44F6B', '8716677006864', '         100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B56BDAAE-0F7B-4196-902B-DA330F28D621', '45721FB7-5E9F-4780-B016-DF41F9D2C37E', '8716677006871', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4445399-ACA5-4273-B38A-D5AFAF286DC2', 'A30184B9-E832-4933-9D38-51A3DA620758', '8716677006888', '         100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD9D7E58-6C11-4906-8540-73D177F1589E', 'D9E53B5C-EC20-4653-BF19-59F4647BB754', '8716900553905', '     125n4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1190A506-BBDC-4D37-97A6-6E89E173867D', 'E7870D82-A362-4CC4-BAD5-9EF9A12B6EB6', '8716900553967', '     125 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75ED1009-A2B3-488D-8820-9F7D4D4A89C6', '44AD8DC4-EA2F-4BC7-879F-39C5ADF9BF66', '8716900554049', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA50A551-D49F-40EB-BB0A-4C6818714F02', '27F5A1AE-7F59-4CA2-9D1C-50EF9F55B842', '8716900554698', '  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF5BBF21-015C-42B3-A03F-B0489FC4B703', 'A861481D-B38A-400C-AC8F-F763069CB558', '8716900554711', '   // 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F81F4EB-3436-4678-AF96-975BA5FE6B10', '3F70F32C-8F45-4CE3-9B9E-397902472B0F', '8716900554773', '   // 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB3EEC0E-F4E1-423E-B209-76D8C6B6D1B7', 'EF5F996B-B71E-4D23-8E09-0913319C2EAE', '8716900554797', '   // 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEAC359A-823C-45CE-BC6F-954479F1AA9E', 'E56AB743-4B18-4FDB-8D98-D74461078961', '8716900559631', '   / / 500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('375905FA-6DDD-4B52-971B-531C035B572B', '7F6E407B-484D-40FA-B7A4-31DE7DE727C3', '8716900560132', '   /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99D28E12-A1E2-420B-BCEC-1A87E5850856', '4101DDDE-B072-4D05-A624-A94FB2863D06', '8716900561436', '     /  1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3791B6AA-36E5-4F56-9E5A-EDFB5D785B17', '421C9AC8-21DD-4086-880A-D28CF8BB44AF', '8717185941470', ' /  /   360', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('051F288A-A9E9-4491-A440-F4CF34039D19', '9F7E38E1-3788-43AB-81E5-0523586A5D2F', '8717185941807', ' /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30EFCBA3-4D3A-47AE-9BBE-A0BD8A4EE17E', 'A200CB2A-39CD-4C37-B005-53B1624B8A07', '8717185947250', ' /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C5D12B3-E7C4-48FA-BCD9-17596FBC8C58', '7D4292F5-3599-4590-AF97-E2A12C85A8D4', '8717472292100', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5542BB94-70F3-4B93-AC21-EC61B8F5287F', 'B8158676-9BB4-44AC-8E52-DE018489DB40', '8717627102797', ' /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('068FE5A0-4449-4D30-A45C-81E4DA8939A6', '5183DB4C-FD24-46A0-817B-78348C211D02', '8717627102810', '  .   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C012012-FD22-49E0-A431-F8293816F2F7', 'E6DD00EF-FD17-43F4-8498-C2FFE00E533F', '8717627102827', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A44EEE0-FCDA-40F9-A196-7C8213E86148', 'B8C267D1-517F-4A66-9135-A257FB4008C3', '8717627103060', ' // 1   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5A92464-9FC8-44C8-B872-914373798BAD', 'A2586977-A0EA-4F79-81E6-D99472980AC1', '8717627103077', '  1   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B7D8832-472D-4204-8B10-77190DF5214D', 'BF3C7D91-6500-492F-8EAA-D72F3D4F6C45', '8717627103190', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16B15583-E007-417C-95A0-D05FD0374AD6', 'A999ECB4-2620-4378-81F1-C34CEAFAD1FD', '8717627103206', '  //   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C201A924-5DF4-4977-88F1-E717896EDCB0', '6307453F-BA72-44A8-9F73-E350006A36E0', '8717627103220', ' 500+10+200 //   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40D61EF6-9217-418E-A4F6-4C1168E8F533', '5CB1FDB7-72D1-40B2-9480-FAC15DA34400', '8717627103404', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48B6359F-0803-4E17-A62A-CD173F2FD8DD', '54525BEC-0A40-4B86-98B9-E2D5062E1F35', '8717627104173', '-  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7223969-1FD2-40F1-87CA-C354C267246F', 'D4C38A54-FCA0-41FD-B2F2-82A1C2EF7050', '8717627107006', '  //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4582D2AE-FC3E-4DB8-97D6-6FC4F3503F3A', 'E1C0A457-18DD-45EA-86B8-C45EB2CCE8F7', '8717627107013', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CB6E894-6BC6-4A4A-AEFF-31D26C192AE6', '55663EE4-34A5-44DD-A945-5B6F43EF6D74', '8717627108430', ' /   / 36,4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A35CB08F-C94F-4E43-8E55-296B8DBDF132', 'FD654927-9BFC-448E-AB93-F13FD68810A5', '8717627108447', ' /   / 36,4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C17108F-4537-448E-823B-E76EC81D7EB9', '2C9EF440-D229-4A15-8C3C-B5A5A7B81A1F', '8717627108461', ' /   / 36,4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF07FFA7-E774-487D-A61C-610C4902ACD5', '3525DE9B-5A8A-43A7-BE1E-BB70B4B76F4A', '8717627108485', ' /   / 36,4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C218742A-53C4-4255-B540-55E50DBBFE08', '2833F9B3-6733-42AA-90E8-C514914426F7', '8717627108508', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D09F3665-AF20-42EF-843E-AA5905ECBF1E', '20D090D7-B406-4779-AAE0-F21FE36DD158', '8717627108683', '     17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EA9B167-ACBB-4C45-81E4-674132B1987C', 'A7EF17DF-C0CF-4F91-AA68-C877529E6FFA', '8717627109178', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A5F4B17-CD64-4C43-AC3C-822F76C105EB', '9A8A4B15-32C4-4A78-AB08-7C79C214D156', '8717627109185', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80C9877F-B77D-4941-9E9B-6DB4101F5500', '2592C828-98BE-4D30-91B4-A4CFC7E71B42', '8717627109208', '   / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E657494A-6A37-4201-8D97-24DD7F697D9C', '396785C4-0D1A-466D-88ED-D05FB840CA28', '8717627109840', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0333A6F2-A259-4BBE-9EA5-5597F542309A', '2260E8F9-22D1-471D-9E04-09E2BAD819B4', '8717627109857', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7A8B336-FFD2-4190-8E7A-0500B32AE09D', '0B222B1E-B49C-495E-8939-EE708928120C', '8717627110259', ' /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7D69428-D8B4-4AD9-977A-55EB6193E5EC', '41E2D1FC-15DE-4352-83FE-6F6C93CEBEFA', '8717627110266', ' /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC83474D-A5D3-43FE-9E16-CC58A1C2AD2C', 'DBCB0A33-1054-4411-A7DC-6BB3C50D1995', '8717627110273', ' /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE223830-253B-4114-A196-D5AE6CDADDAF', 'E2FD0E7C-EBB9-4BB5-8E06-4A7667466781', '8717627110280', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('762AE2CA-BFED-4ADF-B4C0-31D3C3C95093', 'ED9F0150-DB05-4E48-AB95-09005C6564C1', '8717627110297', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9849269C-419C-43A2-AE92-070C371A5ED5', '4489D9B1-EC8F-475C-B966-14B5FE81D71F', '8717627110310', '  .-30 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('761F0FF6-7B2D-465D-8204-23BCCB025CAF', '5FD34616-3B6E-4D8E-AC1E-27C58FEEC9ED', '8717627110327', ' /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72731A35-501A-4A66-A1CF-083ABDED37B6', 'B8158676-9BB4-44AC-8E52-DE018489DB40', '8717627110433', ' /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FC9DF9F-6891-4A31-8A8B-2914B52CFF05', '8237286B-76CB-44FF-8811-853BA2172284', '8717627110440', ' /  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46779A19-E256-4E3E-A749-8058E729A108', 'B4A7D4A1-59F9-4AD6-B44A-E3EB0D08EDA8', '8717627110525', '     3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9953DE9E-D8E3-4007-A6DB-0ED365D036B4', 'C748332C-A36C-4E73-B5DB-017F3C5B97C9', '8717775823216', ' /   1-2  //  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79B65A0D-5A9C-49AD-89DE-D0EF629A93EC', '3304395A-5632-4D03-9EE0-30006BE37AEF', '8717775823223', ' 1-2 / / 12// m ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B9655EF-C6D6-4905-894F-E4CEBD6699CF', '00805E79-C109-4CF2-BABC-E93F6C5EB9E4', '8718053570556', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5166ABBF-40BF-418E-8691-8A7348B6D4AB', '027A8BE5-57B2-4292-9FF9-69DE2712E9EB', '8718117600373', '  /   12 . 450 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00F9BBEF-6CAE-461F-938B-24BFF0179A88', 'BDED7255-2606-4101-8887-B47CDBA584C0', '8718164960321', '  2- . -18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82B6335C-1C78-468D-9D1E-4A43229DD845', 'EA70DCC4-FC0A-44ED-A806-B7C7DFE9737D', '8718164960338', '  2- . -20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCFA3C6A-5CF4-45AD-9F83-469ED04250AA', 'BB9663C3-FF82-405C-BDB0-A6C949F3054B', '8718164960345', '  2- . -22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9AB9F23-6954-4667-8968-13C5792E0871', 'D3DC7915-0450-4D91-B809-824CD7A0C548', '8718164960352', '  2- . -24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0604BFE-8A3B-41B9-BF7C-F2BA05D8D873', '1FC8C8DF-C352-4311-8078-54BAA0ABA921', '8718164960369', '  2- . -26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8CB162C-8BAA-4C0E-BF5D-93D049C042CA', 'BB4DF74F-494B-4065-836A-6F5B8837E020', '8718164962684', '  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D632094-46FD-4BA0-8EA4-5C3F133168E6', '402241A9-2D80-40A5-BF1D-F93D263FFDB9', '8718164965692', '   /0304-01-76/ 750 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F67F294-A5DB-4C28-87A3-C64A06694706', '10B76474-0819-425C-8A0C-33311E7BCC39', '8718309700218', '  /    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51C4A1A6-0F2F-42C1-9AC8-72564639E4B1', '7A24CB06-1BBC-4014-A9D7-0545D544F997', '8718309700874', ' - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C57FA9A3-2811-41E5-8652-6A820ED6F2F9', '3DAF0303-F7E1-4AAD-A6FD-079BF4FE71E3', '8718421340095', '-  /.. 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('254B41DA-43AF-4493-AA08-A08A5DBD6CA8', 'FD56656E-B2D4-4CB6-A9D3-BC639F9CC2ED', '8718951149922', '     /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9C0F6CB-D700-412C-ADF0-492227628D97', '60225965-BA14-435C-BAB9-F34340C81A56', '8805178111839', ' luplast  1,25c500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('912CE1EA-5680-4C94-8B5A-CC1D2A19402C', '39B58CB7-73D2-463E-8A6B-5697CA6F0AEB', '8805178111846', ' luplast  2,5c500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E8E60C8-2912-4F5C-8BF6-AE6AF3D06923', 'F031D74E-0A66-49FA-A888-83F77D5BC8D8', '8805178111884', ' luplast  1,25c500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B97926E-E6CE-4FE6-96CD-C621ABB7634C', 'B1EB54A0-CD35-4E8B-B7A5-A70A1BB4197F', '8805178111938', '  /. . 1972 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('581BEF08-1ADA-4E86-AC86-13B2748A7893', 'DC28A0C0-43BF-4D8F-A1E2-05F8EBC9E73E', '8805178111945', '  .... 19*72 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF2B033A-601F-4E31-A137-55CAE3F6D4A8', '6B27562C-CE9A-4519-8573-242AC7A3088B', '8805178111952', ' luplast  1972 10//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE2DD53E-5461-40C4-B24D-2929DFB97246', '9CEEE5A7-3062-449B-B7BF-324AFE3416C9', '8805178111969', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ABF6AC1-4723-4D5C-94C9-DBD264C880DE', 'DD5043F9-DFFF-493D-BDC1-9A1CB50183EB', '8805178111976', ' luplast   ,  1972 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9FDDAAD-D50C-4DA1-B7FA-40F4EA80EDC4', '9782D59E-6940-4412-85AC-4010B7078BC4', '8805178112003', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BD80607-CD4F-4871-913B-1C3329082A83', '8383BD24-DC3B-42E5-9E17-BE6C01137481', '8805178112034', '    1972 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74462895-62C3-4629-9BC7-2480F418D10A', '4555AD8D-3FC5-4A41-A30F-F719AFBBC19D', '8805178112126', '  /luplast/    7325  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAE35020-D31C-49B7-8923-9EF0B53188F5', 'B28CC0B1-0035-42FF-AAF4-3F47AAB29E91', '8805178113154', '     1972 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43008B58-91A3-47CC-88A6-8DCAC5A61042', '439E6B00-4040-45DC-B824-CD43FC25F49D', '8806037004989', '     /2 812/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09B62ED0-C7AE-4DBB-8205-F917FD1DEBA7', 'E332D93C-FD66-48CC-A265-4CF9346B518F', '8806037005023', '     /3 512/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9800E68-26DB-45D1-8DD0-2B67127833B0', 'D15E0451-BB79-42EB-B88C-9A735D27BBAB', '8809033597653', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FCC185D-C01E-41E0-82DD-08B228E51E5E', '56BCDFB8-BB11-4CEF-B9BF-E66F9B0CCEC4', '8809052585013', '  /    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE77BAAD-EA5A-4C87-90FF-9A22D12FCB71', 'A7BB6FED-D4EC-4978-B147-2250EA8626BC', '8809052585273', 'Skinlite   /   23', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55CA399B-3E42-4DAB-A08C-8CA16D81FCBB', '07EB8211-464F-4551-9760-BE08A8A4ACED', '8809052585419', 'Skinlite -  q10 19', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('389823A5-1883-458C-921B-4D58FD8517B1', '4DD16D86-1B94-49C6-986A-C7561B1D45F5', '8809052585655', 'Skinlite     18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('440061FA-E04C-4E0B-A248-73D0F124AC34', 'C0CB140F-55D9-4084-A2E7-F5F5F5D77A3B', '8809052585693', ' skinlite     18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('699986B1-DEEE-41EA-9CBA-45A8BE5A220B', 'AEDBD555-27BB-44F3-980D-7F889BE0F001', '8809052585747', 'Skinlite    7 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FF1648F-459C-46A5-93AD-BE7DC52C5326', 'DA9BDD35-249C-4A49-83D7-29F23AA7D988', '8809052585754', 'Skinlite - /   7 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00AD6BE2-B6D5-4247-939D-F3EE2B982933', '7C552D31-DF11-4BE0-9389-DA0C8D86C2CE', '8809052585808', '   /    4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4819266-FF07-4AEB-B58D-C5052FB74515', '8DDEB4A7-FDFE-4C09-A475-43738DA344BF', '8809052585815', 'Skinlite   /  n4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70DFDD81-9ADA-4FBB-8E8E-80A2EFB3607D', 'F2DA9527-DE48-45CD-A8FF-D368744FBB35', '8809052585884', 'Skinlite   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FA25AD2-6189-46B2-9FE6-535B6DBA9CC7', '91A340F2-E75A-4AAD-9301-826BB6CC727A', '8809052585891', 'Skinlite   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DCB44AA-7983-4D60-827D-BA9201660430', 'F7D98A4A-E819-49DE-84E5-5BE9A68DAAFD', '8809052588366', 'Skinlite     / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8502389B-D4C9-46EB-AE4A-B541677DB4D3', 'FD88ECA0-01F3-4654-B3BE-416E8CB68E8F', '8809052588427', 'Skinlite -  // 35-40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A737287-6435-42D9-B3EA-0B89CDF030DE', 'CDDF0F17-64B8-4782-A3DF-49DDB889ABB6', '8809052590505', 'Skinlite      18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CCC06F3-C8BC-49A1-8A06-5E4E86D6CE64', '4DD16D86-1B94-49C6-986A-C7561B1D45F5', '8809052590512', 'Skinlite     18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F5BB3E6-A6E9-4C99-BB0B-AED260275FFE', 'F514F6FA-1C1E-46D2-BA1D-D9F9BB473BE8', '8809270620923', '//  /  3  - 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C1C4323-0715-4D80-A370-AAEC80F04C2A', '15C0CB84-628F-4A2F-8E01-5508C22D3C19', '8809270621012', ' - foot spa ritual   /    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83154AE0-C6D3-4565-B427-47CE3F4DCE64', 'C4DD3CFA-6A29-4593-BDC5-DB2CC99D5ADA', '8809270621616', '   24 / - shary 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4295990A-CDE1-4E40-939A-C2231187F00D', 'F370900E-13DF-4C7E-A0C2-5A15B5C00D89', '8809270621623', ' /   shary 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D31CE36-B139-4454-A4A4-26FBE5DD4BD7', 'F514F6FA-1C1E-46D2-BA1D-D9F9BB473BE8', '8809270621821', '//  /  3  - 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04F1E987-70D5-4D74-801F-ED11AB527ACB', 'F514F6FA-1C1E-46D2-BA1D-D9F9BB473BE8', '8809270623689', '//  /  3  - 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84EDDC5B-7176-44B3-AE9A-B4C35AF07A88', '8E8EEE64-0D29-46A7-A073-5B1D64A408D7', '8809270623863', ' /   / shary 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('288AE3A7-202F-42FC-BCCE-89055BD0B077', '65E825AF-2826-42C3-80F3-CB8018342626', '8809270623870', ' /  / shary 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F45BB728-BE54-4046-9F26-DC8DD41A8A1D', '3D6FA6CF-B05B-462C-A14D-89989B1AF771', '8809270626833', 'Institute estelare korea  - // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9ADCB60-3083-4009-ACC7-55A814DBB976', '18FF791E-63C1-4EBE-9F8C-CDFD117A8BE5', '8809270626857', '- - // 2  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F854BDCE-4E3F-4B67-9828-FB8BA8149BAE', '5FB2556E-FD3E-4A41-928E-DA22D7744AB3', '8809371142614', '    / 28 shary', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EE8CC58-638E-44BB-BB3C-46723E5E3CA3', '7CCC2BCE-297B-43C6-B023-0A8E91052B04', '8809411185007', 'Skinlite    2 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DE07E72-1BD6-4E9A-BF29-B4275DF1B41E', 'A09200DE-8EB1-44DE-B0B6-1ECEE49D2B0E', '8809411187919', 'Skinlite      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A185ACE2-9A2A-4CF4-821D-F37C20BD2F59', 'C4E81552-7C33-45C6-AF9E-90885CA18F63', '8809411189807', 'Skinlite      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F6BC42E-4A74-4F4C-A36F-3E0B593CEA8F', '94E5EDD5-3174-43FF-870B-DAAEFB440ED5', '8809411189814', 'Skinlite      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7A75B3A-D9E6-497D-8723-EC0AD7BAF6E3', '8387F30D-69F6-4D5A-B14E-0764E36B6F40', '8850006305850', ' pla   /  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8299F251-2A0E-4166-923E-1A0E92C911A5', 'BE9957C7-3708-44FE-ADA6-491DF374478B', '8850006327869', '    - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DD162D0-7448-4C25-BEA7-C0F9B02F0B84', 'C203A190-B062-4990-8EE5-73FE51C9FC42', '8850006330449', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2B23B00-888D-4C65-8315-1CC35278A762', 'A1ED6C76-C688-40B1-AC05-1B725A78AC94', '8850567106323', 'Deoice    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DDB1772-6392-47BF-A263-4FEF0EF65E76', '0AB19340-C0EB-48FC-8E8E-E417822D6B66', '8850769006827', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E79D7B79-AA07-4EA7-923A-2CEE891A6F28', '9A5A9938-9EDD-4E05-86AE-245C1292B577', '8858573001014', ' 0,1  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2481E2D-647A-4E16-BA4E-D4B69C6B1C39', 'A497CC1C-B75B-47B2-8A8D-430501DCDE13', '8858573001021', ' 200  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CC3CADE-8CB2-4B29-A916-9699B124FDF8', 'A39ACBBD-D7A3-48C0-A7C5-8D705AF4C4C8', '8886386388558', '   8% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14533DED-F76E-485A-90D1-A5DF6C4813BB', '07357ED3-D604-4CF1-B980-D32CF8B6528A', '8887786100054', '- ld-303 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6F5C967-3A5F-4350-90F1-4E501B3CA84B', '3E1694F3-F742-44DC-AF3E-62C82CA112B7', '8887786600004', '   aquajet ld-a7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C19B79C-E961-4D87-AEF4-8BF1AC2CD8A8', '1CE54CFD-D4DF-4084-AB46-D879AFE8CBF0', '8887786600028', '   aquajet ld-a8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF3633D7-49A4-471F-8CF7-813A450AE537', '1F47D57D-4CD5-45D1-BA75-871D32191B90', '8888826016588', '  - 3-  40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26301B4E-32BB-452E-99F9-7C2EA06EC4AE', '96C32B31-EE39-4EC3-8DD5-A54F3C5140EF', '8901043000335', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A166DB8-CC30-49C4-8FFD-289B3A7B6264', '7E849382-B0CE-464F-BA56-E2C452839F85', '8901043000427', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE49FD57-21C9-491C-85AC-1CEC76160728', '9ED99866-495D-49A0-AD3C-1B7B82B5F7DA', '8901043000441', ' //  2% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10EF2950-71A2-4509-8737-6FBB0B5BDB3B', '6391F781-3CBF-4D8A-B4E9-3E00ABE20703', '8901043000588', '  1% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AF6DD2C-42E8-4559-A948-1D9112485900', 'F5C526FC-EA53-4CF1-BFD8-8CBFF159FBFA', '8901043000618', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FABA1A55-E703-44A1-82F4-9F27A9879F0D', '2110D225-3C5C-4369-85FE-1CFB933811C1', '8901043000892', '  /  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6706572C-9F15-4463-AFDE-B250CF068A0F', 'B0BD33BE-BC3C-4301-9B74-441AF22F4007', '8901043001509', '     12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CE8D27A-CE56-4687-BC38-C833A657767D', '79857D00-CC21-48BF-965A-9C25F21A349F', '8901043006870', ' 30 1 3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD1907BA-86B5-4AEC-A56A-10F524B7E876', 'E191E7BB-1C3B-4FBE-8C82-F5D13D330610', '8901067045879', '  400+5+0,1  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAA76BED-D27F-4EA4-A627-EC1E96E6DA88', '6ED9B828-7B06-46CA-AD71-ABB7FD3E50B8', '8901079001269', ' // 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3859691E-8ACB-444C-A9BA-E1A3C6D1B34C', 'D71D61AE-1D64-4EDA-9A1F-5DCE71506B65', '8901079002525', ' 400  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67B04649-8E83-412E-96F2-017FFA9EEA22', '38964F32-EDA2-40BC-B77B-BAC0F9CAD432', '8901079004468', ' 100/5 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF151C5A-FA85-4852-A645-9362C16CF6F6', '54278E62-AA63-4062-BFE5-ABBCF7B4BF39', '8901079004482', ' 50   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CFF70BB-6E0A-4950-A66F-0B5E3467CB99', '436B5431-C2BD-4A60-9C65-1625704BAB1B', '8901079004505', ' 100   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED568B7B-F330-4867-AB76-8F0F25525F08', '1E519972-74A6-4433-A5B5-0B484CFE428B', '8901079004703', '  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F6DA1E6-778D-45FD-BD9C-13E452DFC2CA', 'CC1BB51E-E8C9-4C59-A114-20AC806B68E2', '8901079004758', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78E09204-217F-4EA6-967A-1C3331D09C21', 'CEBC7735-F5CE-46B5-823B-56CB653CE900', '8901079005014', ' 500+125  / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('479F431F-FDA7-419D-87A2-661FB385ECD0', 'F645EC24-9DCB-4D16-9F0E-10101A850056', '8901079005151', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('744406C8-FCEA-4D85-99BE-AAA35D1B3EA5', '1E600B8E-6406-42CB-83B5-38300B59948C', '8901079005397', ' 0,2  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E773106-9634-4FEE-AF25-9486824622D6', '5337CCEA-F4D2-475D-B6FB-2617143BB62C', '8901079005663', '  12,5+50 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D8FC3B0-512E-42B7-8243-1B72AC9412A9', '52BFC4B1-F8B8-441B-923B-CAE90E640EE8', '8901079005960', ' 400  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2042A621-A8F9-453B-8629-0B221864D563', '7C5B3714-9334-49FF-8D56-5C98C866A752', '8901079006035', ' 400   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A597D1CF-D393-4696-B258-C38F32AD93EB', '7C5B3714-9334-49FF-8D56-5C98C866A752', '8901079006042', ' 400   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D60C6BEF-EBE4-45F7-83CD-6F70A6D1EC6D', 'BA6CDFEB-0F8E-4655-A404-5C3DFAB1664A', '8901079008725', ' // 1 100  -  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D194E56C-3989-4614-A596-839228C7AFE5', 'C3809A7E-D6E6-4F8F-95DC-23EAED247740', '8901079015839', ' 400  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA9C31E0-02BC-4353-9803-39120843C784', '3DFC5C4F-F711-4B44-B63B-2AC08620BE55', '8901079016027', '   10,2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1071220A-EB8C-4BD5-9DED-67D3A0CAF1A4', 'E96A8E9E-8A57-4EB0-AC91-A826F94AB5CF', '8901083020140', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38F9E4CA-8AEE-4FD2-8457-C2E3DCA79F8E', '29A7ECD7-50C2-4E90-8BDB-2225650A2DBE', '8901083020317', '  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('829EA636-0B98-46B6-A89A-B9E3E958465F', '2AF556DB-145C-4AE0-8C7A-73EBD1720264', '8901083160136', '  500   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16623B25-A01E-477E-86C2-E4E168FD3A71', 'AA09B117-B218-4E1A-BB27-D4174D028974', '8901083160143', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('690A541A-72C3-49ED-88EB-224903865E3B', 'ACE48B83-AC25-40D5-9098-93C3CCE1D646', '8901083200238', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1A6268B-C55E-4A93-ACE2-A6AA1F4289D0', '733F16C4-8B27-4352-AC57-8B3FB1D933BC', '8901086040190', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C8A6AED-6FC9-49E8-A501-DE0DA4C318B9', 'C0FC94B8-DC83-46CD-B83F-B1EC2FF3DDE1', '8901086040770', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66771C2E-AA6A-4F9A-98DD-DA2A731466E8', 'DE44AC13-B018-4EE9-9E0B-37B5CF87F7D3', '8901086041081', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C253DE9B-BB86-45BE-9A63-CB544FA68154', '105170EE-DBBE-4FE2-BB99-4938C5417042', '8901086041098', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F311553-5694-485B-A46F-E06CE3BC9564', 'E8B37C7A-3631-44FA-B300-26B3A2F8883C', '8901086050014', '  1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2435E1CA-E049-4E33-B756-3EF47FADDEA8', '7D317777-B081-420D-B849-F7943CE348DF', '8901086080189', '   /./   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57F2A08F-D698-4CA4-B66E-22277FDD3E90', 'E08DD435-4EB8-4BEC-9409-A597D6F09166', '8901086080196', '  //   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D74B875-CDD2-48FD-BBEE-921041BF2A60', 'F281E5DC-7104-489F-A377-77846C31B71D', '8901086080202', '   .  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7081CD96-4D1B-4B99-83E3-601C7E9133DB', '361B6436-4A01-444F-B803-086FFE5948A0', '8901086080219', '  -    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDC6DBB4-B6FA-44E4-8E0B-55527B0680B0', '58AC238D-A9AF-4A2F-9A08-CA4369185007', '8901086100030', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E842D52A-B439-47A0-AB1A-F5253DE9BD81', 'D76C5CCB-E5FA-4220-8B3C-9D1609CEFDF5', '8901086100115', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('340EE758-6BB1-4FEC-877B-1B4EA94ED9C8', '3679E004-A6A3-498F-96EF-816D8B922092', '8901086130105', '  10/ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('879CA89A-D72A-4D91-BBC0-D085C4AC191D', 'EDAB73CD-498B-4683-8A5C-11043CA60B6B', '8901086131294', ' 1% 10/   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AB734D6-D2CE-42E8-9978-7D28381556ED', 'D4C2C911-E849-45AD-90B3-10C67A9C9FA6', '8901086131638', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49EE4D93-E24D-4F85-8F7C-3A5C1F267A02', 'B13B812E-D824-412C-9529-2AC9EA7A319F', '8901086131645', '    50   1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1917AC48-B35B-48F9-993B-13E76EE9B6E0', '50282F83-D83B-4D73-983B-C9A4D17C44BF', '8901086181183', '   5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AC06CB6-ACEC-4652-9FC5-8560F99AF738', '1D26A15E-279F-4828-8719-7063F98BBCEB', '8901086181190', ' / -     5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3A4C8E9-DDEC-4F88-A1FA-2C77FDB9969F', '93DA901E-E795-4D50-B07B-F1FF42E70EE2', '8901086181206', ' / -       5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB8847DE-81E4-4183-BDBF-5BB35F1FB395', 'BF05F90A-1E32-4FBE-934B-CA5836E5AA55', '8901086181213', '  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A194823-18DE-4AA6-9F64-43A2A769F0EE', 'E675F268-5F63-4926-ADC5-9C477332224F', '8901086181220', ' /+./  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D56B72C-5080-4446-84F6-9938004B94AA', '8887113B-02EF-476F-A896-9F777B794DB3', '8901086181237', '       5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12AE57B9-DF24-4B3D-9792-797682ADB6EA', '07D55559-630D-4E1E-86E9-173C6C08C156', '8901086183224', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0351F3EC-D234-4D60-A455-DC7F0EE81CEE', 'CD82BE35-C55A-4FE1-99BA-02162012885A', '8901086210470', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B49BB69-75B3-496E-B833-07F963E38EDB', '4EDEACC8-7105-4A2C-BE81-6B69B37E0FE5', '8901086261120', '    /./   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45261CC5-DE97-4856-8AAE-B5BD492D9DCB', 'BD67C0DE-AFF1-4CC9-9CC5-4FF3003439A2', '8901087676756', ' 100  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C18C03D-673B-47DE-97D3-A33AD0E97BD9', 'C938F248-27AB-4A26-8998-7EE678534B61', '8901091000011', ' 1%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B640F0A1-79D9-4FD8-BBD0-503DD176F605', 'AD75A8FC-C73D-4DD2-9062-1604CAEDE9E5', '8901091000066', ' 1% - / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F3953D2-E891-4D1B-B9BD-8A8A1693360A', '9F4FD6CE-BDAE-4EBA-BA1B-D776A10754E2', '8901109217592', ' 0,05%  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43EBE5C7-F93C-4D5E-AD2B-38B9457A426F', 'E27BFB72-0DC7-4EE7-9D70-54F7583A4609', '8901109325037', ' 100  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E79A7ADE-8513-46FE-B24C-D03711B3C0FA', '52675D8C-460B-4B29-B5B5-BBDA68BB9381', '8901127001098', ' 400 /./  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5290A88-EBFB-464F-9D1A-A8EF8B40DFDF', 'D2436B9C-4532-4873-9084-BA078C9A60DC', '8901127003863', '/ /  500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20639A60-4BF8-4F8A-B953-9FC566DF6A64', '105F3B7E-AD1C-47AD-ADEC-54FCBEFC9990', '8901127014586', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E421657-EEE5-4EEF-9461-BB6F16DC7123', '313A1F1B-A785-47D1-871C-5B2A802514BA', '8901127015453', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17645E82-AB7C-4A60-B939-CFFAD4BBE419', '4C77E97E-FD1E-406D-8802-EA8E63E263EA', '8901127015460', ' 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('897EAF7C-E130-4A7A-BF35-9C6C0CF53A21', '273B41B6-EDCD-4605-827D-0A57C947112F', '8901127017419', ' 0,3  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74416321-06CE-4FAD-8D43-F494A499BC82', '3E527BAE-2AB5-4FDB-ACE2-2813873040D1', '8901127017426', ' 0,3  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C69C92F6-BBCC-43AC-8DD0-D4FB5FC4092E', '9F30A1FE-CCCC-4061-9AF7-DC8D5FFDF5BD', '8901135000731', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C60AA18-1620-4521-9CA8-BDA602B88B19', 'C1C760AC-1C71-4CB5-B087-7DF0FEEA33F2', '8901138110710', '-52  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBDE9975-B6F9-4BDF-8F26-446703A45AA6', '1CA6BBCA-9A4B-419C-8432-2A12E7F6A18D', '8901138160647', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('154C6857-765B-4A5B-A639-27E0231042A1', 'EB87089D-2417-4F1C-A5CA-E6A38EFB10F7', '8901138509231', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8449AFAF-39C3-47D5-A7F0-598686E169A7', 'FB30B3F1-630C-4362-BFBD-EFACC4207A85', '8901138713874', '  /  /71387/  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C6D0EE9-0615-4FA5-B030-395F2EF0C897', '21451161-E406-46B0-9188-B78E1EB5A5A6', '8901138825799', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F50FD8A-A77B-45E9-B1BE-A05E9E031873', '8F0A5C48-D877-4E37-9A0B-5E94D0EB7BC8', '8901138834760', '   / / / ./ /83476/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('672B9771-3080-4D7E-A2AB-B67AD55264F6', '756F77AD-7EED-4D85-BFA6-09FE962BDDAC', '8901148009011', ' 250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDE88392-2A7C-4B71-B3A1-80EDA7400AFB', '9E716E34-17B4-4900-9266-C8D2F39E8B84', '8901148024014', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('480E7D6F-81B4-409C-9C13-70156CB21163', 'FFF1D6B2-F291-4820-9AD7-2465B2EE9EE3', '8901148026049', ' 250  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56A3CD19-C534-42F8-ADA0-0DE54D620548', 'FFF1D6B2-F291-4820-9AD7-2465B2EE9EE3', '8901148026155', ' 250  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77F88485-A877-4DD8-A545-5793483CCE9C', 'DBC3315F-5AF9-4C9D-B0C4-6F043498AC8F', '8901148028029', ' 1%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E106657-79F5-45D3-A4B1-3880F630D849', '6D66FA2A-3AA6-4415-AF73-752A83B193FA', '8901148030077', '  100+125  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3128A35-1303-475E-A876-F677AFA92E8A', '97FAAF3B-D8B7-4D9B-8DDA-F719B7D28DBC', '8901148094017', ' 5  / N30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('500A7660-9425-4FCE-B2F7-CA128E109B40', '578653BB-18F9-4016-AF64-1E17A4963487', '8901148203662', ' 150  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75C9F104-376E-41AF-A732-C45B2A3932A8', '38E86D64-ED71-4D4A-B67F-3882BEC346AF', '8901148206489', ' 2/ - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B65C98A-98A8-4A71-8E3A-81565882BE9B', 'C86D438B-B18D-4B5A-821D-6B2AD4FE2A0F', '8901148210745', '  100 125  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BD912F7-3974-44BC-8C2A-AB8AFE1F12A6', 'DBC3315F-5AF9-4C9D-B0C4-6F043498AC8F', '8901148212213', ' 1%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8768362-63F0-4404-A912-B2541E62A4E6', 'D73EEB17-123A-4AD0-8DC8-6ABD8D470C7F', '8901148213043', '  1% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B32C3F7A-4223-4361-89AE-E50B1487F198', '5E2ACB04-1107-4E8F-A77F-E55FBB04A650', '8901148213494', ' 40  / - / ', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43566006-8903-4FC8-8610-6A4374E3449D', '267F6750-7200-4D5C-AE66-F22EBDD56AFF', '8901148214651', '  250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F2D05AF-8B47-4DDE-A5BE-3E928D217935', 'C3E6761D-01B4-4B58-9C07-0FBDE5CECF8D', '8901148214675', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7140A9EE-7F0F-4EE6-BC35-5D9A120D48CE', '4B2A3290-4B8E-47EF-8242-209B9E50E4A3', '8901148223691', ' 2%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53E997FA-DF5E-4C13-97E7-0B9C283664A2', 'A2DFDE64-7D89-445C-859C-AD126496AF47', '8901148223776', ' 40  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35424E90-6FDD-43AB-8C32-D56EE5A77D74', 'D7DF22EE-96A0-4213-9899-B8E4A7AB49CA', '8901148223820', ' 600  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('235BFAC8-0A46-44AE-97FC-8E66051B730A', 'AA3D6D96-A071-480A-99AC-31367972B5E1', '8901148225640', '   20   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB368A91-F941-4E60-B548-62F736C2EC15', '611D6F74-3EBD-495E-9C04-F830B2DB6221', '8901148229532', '  1% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F489910-856C-4669-A6B2-D1E4633D94E1', 'D3CE223A-F397-42A8-BDA7-3CEFF2CBFA45', '8901148230507', ' 30/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB697FAC-B77A-4415-BF8C-CC398E071213', '27038915-F347-4706-B693-C8417A2952D0', '8901148232174', ' 400   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F24A8603-5C61-4D52-9AF8-412D25E73207', '6946AFA9-8881-406C-A063-92EE342B27DB', '8901148233461', ' 0,01  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18C33E1C-6EA2-40B4-A349-361BF9678B5F', '8DCD6A7D-07B1-410E-89C2-F9A1F94A3381', '8901148233904', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50331189-AE9B-4171-BC59-371C367BD06E', '9914BAB8-4A24-4815-8C93-6F0180EF4812', '8901148233911', ' () 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('480177B7-8CAC-4AA8-AFB9-95F55FD013D7', 'A49C0FEE-032B-482F-A857-75C7AE0069E6', '8901148235250', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E95C5381-055E-4FAA-BD57-F63A5C978D04', 'FFF1D6B2-F291-4820-9AD7-2465B2EE9EE3', '8901148235434', ' 250  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DC95029-2033-4211-ACCF-1DBCB4F1BD53', 'EC06B974-110C-4D9D-981D-EFEEEDD2A716', '8901148235533', '  750  // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43A2F47C-4103-473A-8095-455D41C83B26', '99B997C2-3FCC-4C77-8305-88037B2F782C', '8901148236615', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82839DB9-E1BA-43F2-A8F0-5CC1CB1275B9', 'CC14F2A5-E8A2-45B1-B39E-AC667E878B13', '8901148236646', '  0,075+0,075     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4077748D-9717-4C88-9DAB-F6F15ACFB5A2', '6886DA7F-6351-48F1-9CD0-C01ED44A8780', '8901148239418', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2E40E8B-4F8A-4FD1-9A2B-DA746A6CCF97', 'FA5D7347-3647-486B-B843-FDDC1B74D705', '8901148239470', '  0,03+0,02     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87F76E2E-09D8-4F1C-B8EF-88F39F293B59', '34323A3C-F350-4A4C-AEB4-EBECD54A7CDF', '8901148239487', ' 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E3663B3-C561-4953-81D2-1049FD348387', 'D2882AFD-BE15-446D-9443-0172323BD874', '8901148239494', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C657C3B0-7FA6-4BF4-ADF6-F6A92357AE99', 'BC958200-2C18-474C-9E2D-C95B9C91E019', '8901148239845', ' 2%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('427EF318-8F6A-4161-A7A1-80A35F9AD805', '277432AD-18EF-487E-9B29-F4F7D56F6171', '8901148239852', '  1% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60D70756-AA9C-4436-A9AC-6235EC598F71', 'D10A8CD1-F3E7-404C-A144-B89DF8F7398C', '8901148239968', ' 80  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BA79E06-053E-4C16-8A2F-2E9737BCC4A4', '23A62A0B-EE0C-4B29-8956-9C1363550CF0', '8901149000352', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41944BAA-E727-46F5-B6E2-DD52FB31D8F8', 'CDD130EA-5C56-4D3D-B18A-BC53D65B44CC', '8901149003308', ' 100  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0890C3F1-3D90-4C4A-9F6E-796E593B2903', '47693DA0-1343-4A96-A19B-090FD3DAB57C', '8901149006484', ' 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5387D95F-DB32-4962-A0BB-27991A2146C0', '9A1180BC-DF4C-479D-A270-2F23C8D3D546', '8901149007238', ' // 30 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66A679C1-9D04-4E1E-AE8B-ADB408649ECD', '7511400F-8289-42E8-B54E-AEDE209F9EF7', '8901149009720', '  0,25% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DA217C8-52A6-4530-B310-BE1DEB515902', '93FD6658-4403-4F53-AF9D-6ADBD756BFBB', '8901149019897', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('955FB43B-67A3-46F2-B259-807C62366B24', '2832891B-2CEB-4770-991A-64310E2EB0A1', '8901151560318', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4307061F-764C-4D06-A53E-FE57A91A5CFF', '3C5495A8-67CA-47F9-8A90-40693D638B2C', '8901152331023', '    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('613BAE3D-B655-4961-BA0A-00D62681FCEF', '63568AEE-AEF2-46F1-8047-B67F19795CBE', '8901168012015', ' 100   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68465FE6-36C3-4A83-BED6-6028D1BEAAFB', '9DDC2332-0A25-489F-A6A3-7535238C6341', '8901168012022', ' 100   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92D7C987-1FCD-4747-A7A4-D827D1153418', '9DDC2332-0A25-489F-A6A3-7535238C6341', '8901168038022', ' 100   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEC30404-3D3F-4C45-8C9D-0069C9CFFBF7', '843DC865-7C2A-4F58-A406-CA755FF7B7D2', '8901168038039', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADCABBF5-35F6-41AC-8C33-7622B65373D0', '9204EE69-78DC-4979-8B3A-D81244009B49', '8901168415021', '  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B3F75A2-E7EB-4781-BB2C-49343B1E963E', 'F1E92A19-7192-4E59-A4B5-B1B34BF29E20', '8901168415038', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D353A56-39A7-4863-BA83-12371461051A', 'E18D594C-7ADB-4A87-B011-C39BEA9C042F', '8901168583027', ' 0,05/5  60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C94386E4-5233-453D-819A-277BC3FB62CD', '61CE4807-DC86-4033-B2D7-66B7B87C1125', '8901168601073', ' 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04994332-2C7E-49FF-AD7E-D37660560026', '61CE4807-DC86-4033-B2D7-66B7B87C1125', '8901168605071', ' 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEF5D9FE-B1B1-48DE-9303-59EEA8214777', '5AED83A9-A157-4F7E-8E86-B6F1A8CC8773', '8901168958030', '-C  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A58E9C4-AD45-41F9-95E6-9DD3BFB1EAB7', '55A7E656-21CA-421A-A61C-9A6AA37C6F89', '8901207005244', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E12F518-E788-4A61-9148-82C8F7ADA1F7', '93811FFF-AC3F-4FED-A008-5B405E395F6B', '8901207005251', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F77D7E9D-599A-4E1A-88C6-7FBB5D711EA2', '1F8BEF7B-3FFE-43B6-8F91-1CB134C1BD88', '8901210000663', '  // 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F760793-D27F-4EF7-B0CB-E6915FF529BF', '28765344-A546-436D-8C2F-C2790116F2BB', '8901236003402', ' 0,4% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34B4CBBC-3E6F-4C44-921E-C3657AAB4656', 'B7E7A929-6A56-4DA1-BC82-64AC0F42CBF7', '8901236004706', ' 0,25% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFE44351-CB88-41BA-B62D-BD5B76813649', '1E800902-3164-428C-9028-60FF214D1AC3', '8901236004805', ' 0,5% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0604AC10-CE19-449A-9115-2DB6EC45D47D', '36E1D3A9-6420-4B6F-8023-3125A054865D', '8901236004812', ' 0,5% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A93A60D-AAAC-408B-A146-4863ECD452B3', 'F96A7F37-0787-4B96-A759-84F2BB8A1256', '8901236009121', ' /. . //  48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ABCC798-685F-443B-90DC-871970106225', '9BB86575-2213-4E0D-A0B6-154B733A2763', '8901236010714', ' 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4972716D-1D02-4FA9-9A36-45A4940E11C7', 'A248E045-E37F-4532-B023-58B3028A3764', '8901236012107', ' 5    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CBB2703-F025-462A-9EF0-145F4A350250', '41AE79EE-3901-4A83-9990-3F95F35DD222', '8901236012206', ' 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30D505A0-9779-4FFC-9F1C-71DB54C42A0E', 'CA4EDE95-2C14-43BF-8C85-4FCE9047F1FC', '8901236012305', '  // 0,3% 5   - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C29003C6-901B-4A22-BFD3-0E2267A0C451', 'CF7A62A2-7618-4DA9-A6C8-4471DBAE07FB', '8901236013005', ' 0,5% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECB54931-9DB1-46EE-924A-DBC3A8D62F57', '1FA2F8B6-F356-42B2-BA82-04BB7FCF0031', '8901236014002', '  2,5% 0,4 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51EB72DE-E3F4-4722-8F6B-6C02788C2BE6', '6A4C0372-3D4B-4079-82CE-503FAFDAF3D0', '8901236014705', ' 0,3% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F4E7BBE-2F3A-421E-A3B2-EFFC16187837', '255F9F57-0CAC-41A2-8347-F6C22ABFA21F', '8901236016112', '  100 / 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A70207F-ACBF-4CFB-A272-86E7DB4408E4', 'F165D342-692A-4BF8-A446-DBE576364BC4', '8901236016709', ' 0,3% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAAEA941-C0B7-438E-9204-53EDE85B2507', 'BCD5642F-3486-4414-BD6B-D1C2A1B4D7E5', '8901236017942', ' 0,09% 1,7   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC1A6F8D-C0A3-4A25-AC5D-2BF6B240760B', 'D4BA3098-37AB-4473-B717-D428B3671409', '8901236017959', ' 0,005% 2,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA6357FF-4EA7-42DD-B230-0C6F7AF31CF1', '82355A7F-6582-4F97-BE64-5A774A0045D8', '8901236018383', '   -. 0,4   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B05CCF00-961E-4601-9424-92033CAD118A', '814685FB-FEBA-4149-B406-1B8C1C872979', '8901236020065', ' // 0,5% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8FACF61-D97B-4230-8A43-6E857B4C2806', '41AE79EE-3901-4A83-9990-3F95F35DD222', '8901236020089', ' 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90E9927C-33F8-4E2D-9C06-3F2562E9F436', 'CBAD1C2D-5CB5-417C-BB8E-16B3A12D3590', '8901236020102', ' 0,2%    2,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16483AF9-963E-45ED-9C7A-424C5BF2144C', '858239F7-D098-4D1C-A0AA-04637166D5E1', '8901248333047', '   () 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8816FF1C-387C-4A21-84C1-FDACD1AB3D60', 'F582C822-7197-4145-B43F-37DB41FC9445', '8901248333061', '    /     25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C370EBE-0F3C-4630-8272-26EACE34A835', '1B8ED25E-1BC6-4E6F-8398-119F3B0CA456', '8901248333078', '   skin  regular 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD0C912D-A3D7-409B-92F0-06C9B5380D86', '9E9C6CAF-3DC3-43E8-BB20-E973E66C663F', '8901248333085', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DE60A09-45C8-471A-BDB0-00D3BC59AD09', 'C5841DC6-4FD5-44DD-99A9-0DDE1F748388', '8901248333092', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64B77EC2-048F-4DF2-9A73-6FC0CFA479FF', 'D466248A-88B9-499E-832B-8F4121FE80D6', '8901252950032', ' 5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C06B2C1A-7715-4500-B8EC-6FE674FBBA7B', 'EE6E57E9-A8CD-4450-BC2F-B4A7E22E3645', '8901252950568', ' // 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F73001E-D2FC-422B-93F0-CB3D2EF41415', '8944FEDF-62FD-4046-85D0-92C2BB81C3CA', '8901252950582', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78CB2F67-BF29-4A27-9064-81E9EC904031', 'D0759BE5-D28D-47FC-B944-B346071C67C1', '8901252951107', ' . 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30C9FAFA-5E24-48A4-90F1-0455F3E0088A', '6DEEF9CA-465B-4090-880D-DA7A03F877BC', '8901252951275', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('212F65C7-1ED3-4DF7-9DED-EC6E56F6AF0A', '012FBEC8-12B5-47A6-AA54-9D6C59A59EF2', '8901252951282', ' 50  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9894BBC6-7FB5-4E4F-A514-0E057F5DFEF6', 'C75DD4F5-5EDF-4DE5-9285-9A5EAAC86EFF', '8901252951367', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C593D12-6C5D-4DFD-9BB6-B417E0A18A62', '88479FD9-B3A3-4076-925E-E6D050AB209F', '8901252952050', ' 0,01  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3FA4CD5-55B5-4736-9000-890062C6C48A', 'EE6E57E9-A8CD-4450-BC2F-B4A7E22E3645', '8901252953934', ' // 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B8B0C01-0B98-4C37-ACCA-0E09A65EAB86', 'BD920FBD-E9F6-4264-9B07-99397074BE35', '8901252953941', ' 0,004  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5A0A1F8-8394-469F-9130-0A4A6FAF7AEE', '4250FA4F-F79B-400E-B2E1-755E75C345C6', '8901278000025', '  2% 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB402FFD-E2FC-4526-B0D1-1A01A9F1A0A6', 'EC114D82-439B-4A7D-B958-6940669D719B', '8901278000032', '  2% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28242A32-1837-43D0-8F2A-5E9E4D1DDC8F', 'D88598C5-56C9-45E2-8522-F7D5255024E1', '8901278000049', '  1% 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9E4B89B-F0DA-4F77-B77D-DB97C51DBAF3', 'E88CABBE-7783-434C-806A-52B4915393DD', '8901278000056', ' 1% 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02D454C3-F966-479E-A23D-02186AEAE568', '3FD3CE48-460C-4C5E-95EB-44F628D1C57C', '8901278000063', ' 2%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('778096F9-795B-43F6-AD30-786A9F0A06F4', '37987EDA-2D93-48FB-B1FE-7AE2E5A32905', '8901278000186', '  1% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04645EF9-0EC7-43EE-B6F0-D4BD2F18863E', 'DE63E060-F714-4B8D-BD96-D0CF46ECC795', '8901278000193', '  2% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC80765B-C2D3-41F9-B066-2A8CD12B0AFE', '7A074847-30D4-4A6B-8033-FDFF87C79940', '8901278001169', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2519290D-3C2D-4E08-931A-2AB43A7FA0C4', '9599BDE5-1BAD-445A-94AD-D8CCF291ED57', '8901278003026', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83EDE2B3-B99A-4B5B-BE9F-EA2B9B799D52', 'A4F81D3C-2229-405B-88C0-A48DB01EE68C', '8901278003033', ' - 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AC23AC8-DE86-46E7-8A83-84F6D77987CB', '157D54FA-00E6-4BE7-BB87-E8CECF519BD5', '8901278003040', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AFE31EE-7F9C-42A0-B2B3-C265D5CDE76C', '1FBCC8F9-9DBC-483B-938A-EEAE7645E589', '8901278004016', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A53ABCEC-8D05-463B-9775-0316CC9D4A64', 'A3E01034-0874-4500-8CEC-E66CB6EDACCE', '8901278004023', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9100229F-EC83-4A81-B75C-067CA0C6DDD6', '74CCA99B-036E-4257-9480-D4CB74ED83B8', '8901278004030', ' -  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87546A69-E1E8-4725-ADB4-DB6C5A317E7C', 'BD5CA576-B650-4BA6-8FB8-6F15AE8AFE57', '8901278004047', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C5300AF-AE1F-44D4-A7A2-436F17B65445', '238386A4-1C44-46F8-8328-C9F32F638661', '8901278005044', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F46EFD5E-32D6-4BEE-8C55-52D14451B134', 'BD5CA576-B650-4BA6-8FB8-6F15AE8AFE57', '8901278005068', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6939B12A-B123-426F-95DE-9801249B0DEB', '59BB3EC0-4E4B-4434-B06C-30027541ADB1', '8901278005075', '  -   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A65482D9-A241-47B8-9922-E4746BD1AAF5', 'DA914706-2E4B-4702-90F6-DDAF5FB8DDE5', '8901278010031', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F02FC6C1-3025-4209-963C-AFD1A2F37269', '5502775C-FD45-4C14-BE09-04328BFA43C9', '8901278010055', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F2AFB35-8341-4E1B-AA8A-0F106FE57FFD', '4EC948BD-4790-47C1-B2D6-7BC85075DB40', '8901296042021', ' 250   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF985AF0-61B4-43F9-8571-CB1714DB6846', 'BC3F76CD-C6D9-442E-8CB6-859BB579398A', '8901296042038', ' 500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CB2BEAC-C3C5-465D-B29C-6E436F3F01A6', '49E3F765-DC74-4786-8C53-17DBF074EC70', '8901296043998', ' 100  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4690FC0-FFAB-40F8-B45F-892F56C6B1D0', '77DA5B7E-D8E8-450D-BF7A-7BD6569653E4', '8901302051153', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A6D455C-3316-466C-BDE1-96132EC91DD0', '46523090-BA38-4557-A691-96ADAD6CE44A', '8901302057278', ' // 0,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53D1F208-68E4-4DE0-8E13-AD777E01FA4C', 'D1EA8B53-E518-4F22-B035-5B2F834EECC2', '8901302060391', '  5% 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94DAD247-F88C-4B40-B74B-CE9093DC2C7A', '449B9796-C1A9-4533-AB79-28BEA6613E7B', '8901302060551', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('922EF513-866F-41D6-85CA-84FBE88DB0B2', 'B288D4A5-7E85-47BD-BBEC-9FB2BA6CE3D0', '8901302092125', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF67C1E1-4785-4341-89D5-BB7501D306A9', '69EDEA23-8196-42FB-9478-9BCCA4503AC0', '8901302093504', '  / 0,5+0,2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0043C775-CDD6-49E3-8669-A44155573E97', 'BA815E64-1F5C-4761-9B6C-923F19A9CA63', '8901302093511', ' 500+200  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D945550-8CF6-43DD-B86D-BBB7634A6AA3', 'C705C91E-86FC-46FE-BC73-2F166E818FCF', '8901302096956', '   5+10 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('464B8DEA-981A-4F79-87F1-D65EE2F49134', 'C705C91E-86FC-46FE-BC73-2F166E818FCF', '8901302096994', '   5+10 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ABADDAE-F30E-45E2-83AB-7C614B8CEBA6', '22744545-E223-409F-B40C-68A19971C4FE', '8901302118115', ' 50  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C89D6852-3A43-4C7C-9C3A-C0FA2F7973BD', '5C994A68-CC31-4A68-B22D-3AB8795F3C7A', '8901302123898', '- 75  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF4D8A71-36B5-40B4-840B-E846B2FF101A', '17118918-5BE8-4180-B670-03D083F13CB1', '8901302123959', '- 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('464BEACF-DD3D-453D-949E-AA47E7EBB82B', '1527D1AD-14EC-4AAF-926A-54AD8FADAE0A', '8901302123973', '- 500  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B616A831-16BB-4174-8381-4D3FA04818BF', '9C9BB25A-3B79-4312-9C84-5426E69AAE24', '8901302125021', ' 500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('060669E0-07A4-4EEB-83CB-1ACC75E94190', 'F11406EC-96DE-4D10-BC60-2D0CE30AF731', '8901315200135', '    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('357C1AFA-9A3D-4EB6-B3BE-335D873C20C6', '539807CC-8B6F-471B-8F50-DCA853A541FC', '8901315201217', ' 500  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C740806F-5618-430B-A045-1A93237F17E9', '06289525-8BC1-4F4B-BC81-4D7FD0DB7C8B', '8901315201231', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8D74B40-8F52-4C1D-B1EF-375FF8361CA4', 'DC5ED4A3-6A68-4DBE-A788-BCA7FBC10960', '8901315227316', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44A7608A-11E6-465B-9A86-7358460F7F6F', 'F96D2D96-8195-4E8E-9345-27680CFD8488', '8901315227415', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D580541-831C-49C6-BB97-D6690A08ABC7', '818515EE-5668-465C-AA8D-3D46D08DBCD2', '8901327000204', ' 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EC8B29D-9030-427E-9479-E4417D3D9C0F', '907FA261-C7D0-49A7-B4BC-F4E9207B9A2F', '8901387007861', '  /  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B786002B-F15B-47C6-8861-8C4CE70D6F73', '3D6F43A5-CB95-4F1F-B273-FACC69DBB7A1', '8901387007878', ' //   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C497F916-02FC-4D3D-B3BC-BEA5017FB8EB', 'AE175704-854D-4EE1-A706-1E8DD0AD7554', '8901387007885', ' /   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB7B85BB-A3F1-4B64-88D9-9C9446DCBD9D', '16A507D7-3D2A-42F2-9A80-A94DDEBA7C7F', '8901387007892', '  /  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A3D2057-FEDB-4CA0-AD96-1C8050204904', '907FA261-C7D0-49A7-B4BC-F4E9207B9A2F', '8901387007908', '  /  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C17DE16E-D114-48B8-B0B8-24B24582B3C4', 'C8B4081A-154F-494E-954A-FF6F52BA0B0E', '8901387007915', '  /  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB469544-F77B-408E-97EB-14C53B1C9993', '5E2CC2CE-7760-4810-87CB-FC81FAFEB372', '8901387007977', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89A1A76D-5D99-468F-9DDA-4E671DE6F1F8', '36800224-013E-491C-8AB8-CC92CDDE575B', '8901387030210', ' 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E119C2B1-434A-456C-AF1A-38CD901EE204', '288F31B5-3839-4A0A-A1EA-F90E6C3FE03B', '8901387050379', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D0BBE36-7426-4771-B8D5-855BB0F18225', '970CDFFD-56DA-404C-BE3F-51CCD3F19FE7', '8901397012923', ' 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF88F16F-9E17-4976-9A43-E527B8A06F91', 'B2817922-7FB2-42FB-9362-365404612065', '8901397012930', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('553D3D93-F94D-4209-989A-429234F00EDC', '71D8568D-966F-47B9-9507-45512062EBA8', '8901397012947', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73EF239C-3A2A-4DA3-AAEE-734941AD7930', '38084BDD-B136-469C-B574-35D6C037F161', '8901428000028', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DE71FAE-4682-485B-841F-9750D7DCAE09', 'F60667BE-ED02-4801-9D52-F7DCDFB493A1', '8901428000035', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17021A1B-673B-4DC7-A497-0563CC4D326C', 'E47C2252-4A2F-4229-B95E-DCC82A7CFA91', '8901428000059', '   /.  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06BDF840-691B-466E-AD3E-876BE01C81EB', 'FBE9A8D5-3120-462C-A12A-D942003431CE', '8901767223904', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1B878A7-7C25-4C20-A627-2F6A42D1F075', '9D427376-BDFF-4519-BD37-FC4E8A1F611D', '8901767223928', ' 0,02  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('325267B1-81C1-4121-9FC8-3D870BE05344', 'AD9B06E7-8A80-4D98-92DE-8FBDFEDFFFFE', '8901783000206', ' 400   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A69842B6-3D30-4370-B3AB-CA2C95D3CE61', '727547C4-1AFE-42A3-B724-45116C5DF974', '8901783008196', '- 0,2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F1A8302-12DC-4ABA-9DB1-72CC3DC67A6A', 'C1BB1C64-CCE2-45AD-83B1-788172D45E74', '8901783008202', '- 0,2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96CA0410-0296-4B5F-9FA5-B928A9914C70', 'F5272511-5194-49FC-9A39-3AC85C7BD37C', '8901783010090', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20E6FE25-5298-43EF-A06A-A42F64037EEC', '3029B95F-73C9-483F-9782-D634CE7C8EF6', '8902034101239', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1108AE9-D114-4BD0-AED5-6A86594E9231', '0F6A2EB4-3C77-4E7D-9D1C-8DDFF1547B95', '8902034102052', ' 250  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BC6D8CF-518B-4705-A8FA-DEE66947DC45', '1F7E62CB-E428-4F29-BD3D-D5591F0DFF52', '8902034102861', ' 0,075 28  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B894307F-69B1-425A-9764-17F5F664B4FE', '0EB713F5-F9BC-4334-855B-68A681EFCDC7', '8902034104063', '- //  0,1% 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0AD7E1B-7B72-48E5-B7D7-65BD9492C762', 'AE873604-B838-4B40-90EA-3334F1ABAA73', '8902319010591', '  2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A928A55-EDCA-4412-BB64-4154E3933C6B', '678A394A-1EE2-40F4-9B50-3AF8FBFB69EE', '8902319010607', '  5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('169E34CD-976C-4D63-A702-014DC05EA6CA', 'DD699933-C252-430A-BD57-B700B4D2CD0D', '8902502117410', ' 500  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9D9D6C8-AAD4-49CC-9822-FF295C8694D3', '14623BFA-B294-4DE7-A3FC-5A397E99E33D', '8904004821239', '   () 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7972662A-6F24-4D2F-9576-8C68553A1A44', 'FF964E7A-9423-41C3-8718-C7654F2DF65D', '8904004821338', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D839BEE7-05A9-4B7F-90EC-569F8BE0ACA9', 'AF4EB51A-72F6-4129-9FB6-0F35424FCB7F', '8904006304273', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D956EAE-D9AF-446B-8C2C-CE6CB42B780B', 'FD8805C3-F1DE-43EF-B458-11F0C75142D3', '8904019600409', '     100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A7231F9-7270-4220-BC64-5FD107A5F1EC', 'C938F248-27AB-4A26-8998-7EE678534B61', '8904091100118', ' 1%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10F4F460-3623-40F2-85C0-F30D2F7A4005', '51315B65-05E9-45BD-9EDF-D26F6FF2D304', '8904091100217', '   1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A84928CA-44F1-4455-890B-45DAF32E1DD9', 'EF33D04A-13F0-417E-9CEB-1A8696CCF09A', '8904091100316', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B166CBA-F318-4894-9EFC-22D7F5C124B2', '85F6E340-56FE-40D5-9523-3C7E4E6104D1', '8904091100347', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F9D7AC7-3D65-4B8D-AF37-A2CB5AAF35F0', '2244AB79-EDD6-40E1-B2C3-9C52E3C8F328', '8904091100613', ' 2%   30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6096E9DC-7285-42C7-9035-74A0A00A5900', '03663802-FC70-4A8F-9E1E-E045AF79C1D6', '8904091101610', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8404409-5A67-4B9E-8770-4424316E3BF6', '0FFDE3B4-2CC2-42E6-8500-29BF5302A2B2', '8904091101719', '   0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51FC6F11-5FDB-41FC-A518-1FF9E0361421', '18BB5DDF-8C3D-4DDA-BC65-1CFAC10FBE45', '8904091101801', '  0,05% 15,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E563D5B-904C-4A88-BB1C-F16411BADD52', '6F669CF9-18DD-4470-8A2C-507988B7F133', '8904091102211', '   2% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93BD2D8A-DCCD-4FBB-8812-2280C7FB64C5', 'CA209805-636C-47B1-8D39-90E4687C1729', '8904091103102', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('173DBA19-7381-47A3-92B4-59F0FC561343', 'DDB87C95-3A91-46D0-A3A0-C4C9B3795FB4', '8904091103119', '  0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FC379BD-0CF0-4D4E-A2E5-C815915F2FCE', '6E3600DD-7C89-4CB7-AFBD-FC4F87D1AA0F', '8904091105908', ' 500    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFA3A646-FA8D-447B-970D-34DD8128ABCF', 'E50AEA5D-277D-4293-9F43-A2CD440C9EE6', '8904091106400', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79E0D221-54B3-4CC2-8346-DA8E7B7693B4', '67229FF9-99AF-40EA-9A24-63623A11D4D5', '8904091106431', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21FBB925-57B2-445E-B80E-7199D580C979', '16921D58-BE9D-42FF-B3BB-945155D510AA', '8904091107360', '   50/ 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50AC09B1-0358-4144-AA26-3235835ADA12', '49DF3B78-2728-4DC6-997B-CA3F67F3F565', '8904091109715', ' 5%  / 2,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C395D38-E83A-4322-BC27-C5932AEC9326', '41C83C43-635D-4275-9167-D042EF1E3158', '8904091111305', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('586859C2-F036-441B-8C3D-0A69558DDF1F', '12F16DDA-8600-46EF-A8AE-F308B7E67C97', '8904091111312', ' / / 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E8CAABD-9F7A-432A-AF8C-031C10259AFA', '4962FD0E-BDDB-486C-8338-B3B42A1D1BFF', '8904091111343', ' 500  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBAAD52C-892C-4185-B161-C6296C0EE328', '919AD8B1-83F6-4DFF-A7D0-1A1CA71FBA8C', '8904091112012', ' 1% -  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFC1A6FB-0FBD-431F-ACA0-6FB861807CA6', '7C53FD9C-1D30-47C8-81E7-2ED5C54AC14F', '8904091112500', ' // / 1% 15 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E195AFC-CFCD-4DED-ABF2-623088164A70', 'ECE21218-D485-4CFB-BCD8-C7A3E792261B', '8904091113606', '  1%  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2251F6E-8497-49D6-8273-E4EA53AF2281', '56CE5B38-BDDD-4D25-B6E2-D85CE378EA1E', '8904091113910', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A584C0F7-504F-46F2-8693-1FA655C7E6AD', 'C8B6960A-E17E-4121-B57F-1575D78179C9', '8904091113965', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1ACF2BD-2E10-4DD6-9435-108377A94545', 'F9B9B924-13E3-49D2-A081-7C965DFB4539', '8904091117703', ' 180  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('822949B1-8275-4D60-B32A-6DCFD53F1B25', '12EC19C5-5C98-46EF-8EF2-E33A356254FB', '8904091118311', '  2% 15 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C11E387E-DB8C-4BFE-9464-F0352AC5B847', 'A387EA68-02F8-4902-AACE-5459B0278253', '8904091118328', 'C   2% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9137D66-CE68-45D4-BE3B-EC1B6899E9A7', '4EB75C8E-A747-4C40-896A-25A562E1DA67', '8904091127177', '  / 18 /  140+50/ 150    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE8F5B54-C1D8-4089-B5D0-6F4CF134CD6C', 'B2D8EF92-765E-4EA3-A7DF-1577EB5484FC', '8904091143801', '-  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F62D36C4-A4DB-4D2B-B479-D9ECAEB5FBA3', 'BF2E442C-72C6-4FFA-9B34-C36356E30939', '8904091143818', ' c  0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('628A1628-D2CE-4DB2-BAEB-76289FF9E3DC', '0328B36E-3B0A-41BB-BCA2-1EF3633CCBCF', '8904091146017', '-  0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('654632C0-1AEF-4C2C-A31D-F505A70E0477', 'D943BA9C-142E-445F-8C42-22A736B3E886', '8904091149018', ' 5 //.  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB282443-6A73-4759-BFEE-A3A5D0413720', '5207AEE3-C39F-4AD9-ADCE-ACE1BB80D130', '8904091149025', ' 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F8C8531-B37D-4CF5-AD74-69FA82ADE0B8', 'A5A1E1B6-847B-4CBF-9042-B3D3CF0CF025', '8904091149032', ' 5 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4B744DC-6B50-46B3-8E59-A436B43C8E48', '0F96408D-9A41-462D-808A-CAD99A910B48', '8904091150502', '-  /. . 15 2% 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC658FC5-3EA6-445F-837C-71FA6790E672', 'FA7E8D06-37B4-451C-A949-366AA3982F0A', '8904102203920', ' 400+32510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03C4F649-3E8C-4F89-8B20-557040854699', 'BBAF5FF8-91B7-4E40-A468-368D13FE91EB', '8904172101737', ' slim  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEA5487A-0335-478A-9ABA-9FF41CB7E5A1', 'ACCB8D0B-FC3B-4554-B586-04C8D769C677', '8906000570418', '  400  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFFBDC91-1DFE-4C27-B4C9-6602772FBD7F', 'E985E088-8344-4EB1-B042-B97ED84DECAB', '8906000570531', ' -.  80 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6093469C-E817-4089-B618-1256E8792BE0', '27F57626-B3F6-4390-8F77-D7D966A0CF29', '8906000570661', '-   / 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DD1A7A8-AA22-488C-AB69-1562B6C664F1', '714FFAC9-0202-4EF7-AA9A-4FC1D1235EA5', '8906000570685', '-   / 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBCF0B30-ED22-46D7-B765-52516B7B1F6F', '27F57626-B3F6-4390-8F77-D7D966A0CF29', '8906000570708', '-   / 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D152DC4E-1FCC-4FED-A53A-26CDDD104588', '6A187AEF-D254-4450-ADA5-BB1A5C3BDD22', '8906000570791', ' 10  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9519A352-36D6-44AD-A94B-1D2A8C7816A0', 'FE319B6B-7496-4895-97D4-BD7DE799CD84', '8906000570883', '-    / 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEA7A1F7-D951-4C00-A698-13100EE10392', '7B8C1692-0DDD-475D-9A85-65AC9097E39E', '8906000570906', '- //  / 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92A656FB-8FF7-4530-B9F7-996A298B659C', '3DD615EA-9EFA-42FD-9705-95D109702409', '8906000571170', '-    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B39009C-2D37-43A5-962A-507DD7FD913E', '757FD6A5-23F3-46CC-87C9-06FBA0F0C027', '8906000571194', '- //  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB33680B-5EC9-40EF-A577-5DC851CEAACF', 'F743049F-A66A-41E2-B308-F254F40F9270', '8906000571217', '-  /  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4524267-2BD1-4D16-B591-C721FFD38912', 'D2FBDB9B-97B8-4862-95D9-1DD1CB470CBA', '8906000571262', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8F5B3C4-F8E0-4C47-9AD8-856E7775A92D', '3B38A5C4-3683-4303-B973-791BCA76D776', '8906000571774', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D4B2838-CC5C-4FF8-A33F-871012E36CFB', '34A46BFF-6CFE-404C-928E-3B2685F0CE15', '8906000571859', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('321B4632-80BD-46F8-A017-368BA93BD872', 'F8EA6D4F-8794-474E-ACDF-E6641E645F6C', '8906000573044', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCBDB1F8-E576-4DF1-AA52-858AFB3E7774', '72FC653C-D788-4819-B750-16433ABED92D', '8906000573051', ' 250  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1727D80F-B3AF-4344-A87A-96716E6CA950', '58907FE3-3C7C-45A9-B01A-4AE1BE2C9A0B', '8906000573280', ' 500  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4792C276-46C9-44A8-B03B-7AF0A8168DB1', '71A4A99F-576B-425F-997D-2390D5AC8EE9', '8906000573556', '  1/ 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB395251-CD13-4B19-8B6B-A84351C41851', '18875DD2-4377-4EFE-840F-BE5B643D3933', '8906000573600', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9601AAE2-EB28-496C-AE75-CA3AE008C8CB', '97EAF711-CE86-4E37-B6A2-5B9453F43A00', '8906000574058', ' 1%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1A9F506-C366-4369-B481-8D7646F007D3', 'A0A5D559-1E57-49F0-9D1B-2AEBD1603E78', '8906000574072', '-   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45864317-F5F4-42BB-BFF0-D497E1DE199B', 'C1DA4934-F53D-4358-9C95-C80DAF1C14A1', '8906000574089', '  1% 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A53855E7-F108-48D3-9DD9-A9EC98E89C00', 'FE24D19E-BA69-4E45-A77E-BEC87A5E420C', '8906000574577', '-  0,05% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C98831E-E4BC-4A58-B64A-9948DA2CCF56', '25D65FD3-1B4A-498D-B3F1-0D6B324B2A84', '8906000574591', '- 0,1% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E6CCAF1-54F6-4320-BA66-41C54A38373C', '3941866F-ADFC-4047-A914-CA7CC268454F', '8906000574638', '   5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C994D747-3C01-4F6C-99A6-7D5E7F6444A3', 'D726FCE5-5D2F-4074-8778-2C1965DCFC8B', '8906000574645', '  //  5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('054BAD02-3936-4D6C-AB27-A4F91077095B', 'F54F6ED9-3D9C-4D77-9E2F-F80CE7B313B0', '8906000574652', '    5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('887311BD-B937-4D54-9E0A-01DA475FFEC4', '19F87744-288F-48CE-A9BC-3C4844826ECC', '8906000574669', '    5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F94D9D18-502D-4275-B5C7-29063D8D951F', '7DFDC19E-3626-43EF-AE8D-5C130B7C1316', '8906000574676', '     5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F82AB5F-4E15-47C2-BD3B-3ADA4E246F89', 'C9775849-BEDE-49D1-8395-A8CC31E36155', '8906014100878', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9975E745-E089-4E70-9D5F-A18F3FBCF46E', '1E4F4821-9D2D-4B50-AAB3-CEC82D591EB8', '8906021625357', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AB0AE02-08C4-4885-88D8-1CE261F9B1C0', '4A9541A3-8305-45AF-B96C-71FD539A0BE7', '8906029381224', ' 500 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAE18991-CE8F-4D9E-9C2D-61C482094496', 'FED4696F-82AC-4085-BEC5-0F6B841C90FC', '8906046112702', '   18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75428977-4439-4F21-A243-9D6823AD35E0', '0D7EAAEC-68C5-469D-8AE8-C0433A284D8F', '8906060500462', '- 250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6157FCD2-1EAE-44CA-9487-3F4C154230BF', 'FA179DEF-95BC-4633-B70E-F8B28CF13E49', '8906060500486', '- 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D9DC944-40BE-43F8-8392-E941190E0202', 'A898F04B-AFF6-4413-A387-E45CA5DB6288', '8906060500493', '- 750  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1020AEEB-506E-4FEC-8927-28B225478543', '4E133C0D-849C-43A0-8603-06A6F22AD22E', '8908005685173', '-  18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C458438E-EFD6-4E0F-AD31-7BDAB8A59A6B', '4DD549D4-DA08-4205-A212-6DEDFB781700', '8934574011426', '  200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E080A17-F9A7-479A-BA7E-C79790F8F687', '01D05E88-9B00-481E-955E-2B716CB3C8FE', '8934574060288', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9B5AE12-7988-4D5B-ABA9-2C12FC417FB6', '7F8E740E-7F84-4BA5-8B79-CB0A95ECC882', '8934574082105', '   360 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B47110AE-318C-43EF-8D40-A380353C3959', '05A8C293-E26C-44A9-A830-3544693D0745', '8934574220118', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F547FD09-9D95-4FFB-9954-C92983419927', 'FDD5D8C2-0E51-4C9D-829C-17C39C4E88B5', '8934901310062', '  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E24E899F-B029-4B82-8D8B-48A35B893CEB', '879E6519-545E-4180-AA79-766C958470A0', '8934901310079', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('229EBF0D-5B24-4954-B797-65E0BAF9BBAD', 'DBA9B18A-9654-488C-94EE-0F212971264A', '8934901320085', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE97EA9E-B48F-4277-86A2-0A92FC8BB1E0', '3447B539-A77E-419F-AF36-459BF095E510', '8934901500104', '    /- 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('813FBFEC-BA10-42FD-82AB-1B1CA6D05D46', '791BCEA7-F702-44B4-B773-BA7B1BC7B2E4', '8934901500111', '  / - //    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A96A113-2510-40CD-8531-65D2181FF1F7', 'A620DBF3-7D56-4EF7-A2F3-988D99069AD3', '8934901500135', '    / -    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('571896E3-D748-4DF1-9228-51603308B3AA', '3AF032AC-6F69-4823-BEC5-D059A90520FD', '8934901500142', '  // / - /./.  15 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F2C54E6-258C-411D-89F7-FF93DD8B437A', 'D3FE23B9-432D-49CD-A40F-5D28A4B67697', '8934901500159', '  / -     15  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F95AB620-F012-435C-97C6-D64370F3C1E2', '6E6CA978-7508-403D-9C1C-0B83E5695F35', '8934901710176', '  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA0773E7-4F1A-4ABE-BBB2-4E5AEE81FDAB', '4393EF25-70B4-408C-A8FD-C329D11202F1', '8934901810265', '  0,05% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6BDE7F2-02DF-4D6E-BD4B-37A0A7B8F2E2', '48BDCEDA-B227-4146-91C0-53098FA913CA', '8934901810272', '  0,1% 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3469F134-E1EC-477B-A0CB-7D8E62FA8CBD', '8BE498E2-EB6C-4F7E-A85E-2BB6655CCAC3', '8934901810289', '    0,1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26F4638F-DEF6-43F7-A2E4-F1134E45E655', 'C3901A1E-7847-4316-826A-20EE283A65F2', '8934901840118', '   0.15% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53B69CD8-3525-4500-9A20-92156CC5B6DC', '783B78CA-6777-4368-BDC1-C30D4AC86497', '8935070816270', ' -- /1440/48/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9310707-4165-47C8-867C-F4373FE459AC', 'B50D0048-4AEB-4273-8376-997075CBBF06', '8992781120058', ' 225  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E12284D-1FF4-428D-9829-394C7FD6255C', '0E19FA8E-4301-43B7-8AEA-8AA16F4E6EAF', '8992781120928', '  -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('949F64BD-FB9C-447F-9000-A346E1BA55A4', '75D98EF7-A1B6-43EF-B60C-673229E92FA5', '8992781250366', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4381D89-AA93-4276-B600-BA6AFAFC49D5', '73E58CA1-E916-4D5C-A897-F55B1414AB4D', '8992781250519', ' 550  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E271F637-2663-4A3B-8A6B-C8FBA94DE18F', 'ADC01A73-3415-468C-A5D1-319697585D03', '8992781250922', ' 0,55  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18699AB4-2E00-4F61-BE4C-6B5C523ACF95', '5D3E5A9A-A841-4CCB-A926-0F634E8129AE', '8993149623709', ' 500  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD4FC7CB-F603-4D0D-8A1E-FCF1CE2211E6', '51509FD1-14D7-4844-96F7-CC1D8612CD10', '8995151160227', '  750  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3F26988-1953-4F5C-991D-21F47FC2CFC4', '770A693D-DC7F-4786-8E06-7F3D9A631295', '8995152900396', '- 600  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C96C604-F35C-4CA6-8CE8-8C09B5902827', '5A06D47B-74E5-43E2-A840-778ADBB0FEAA', '9001505000015', '  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C1EC414-3D4F-494F-9E18-BF273B100E4E', 'A812D187-433B-4EE4-AE17-5C28002EF639', '9001505001470', '   12,5  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E94C2B52-8F26-4B48-86D2-9F844DC16DB4', 'DA2AFF75-F133-412F-B49D-4A1C4F430D8F', '9001505001821', '     12,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99E113BB-5973-401D-B003-6B579B66EBF4', 'E7A340AA-16E4-4D7A-B563-22C39E7423B5', '9001505004020', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9D18D03-B4BF-4308-8761-968342DB66FE', '9C068C45-273A-4F71-B9B8-33F7BB478613', '9001505004075', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39A6D0CC-94E7-474E-8E37-81D42854BF88', 'DBFC14EB-87B5-4BAC-B591-D18A01CDFDFA', '9002260001019', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4309FB5-04D4-4669-92EE-521702CF6DFA', '1512B0F3-53D6-48A5-A064-EC8ED8760823', '9002260012107', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3F66A6D-83A2-42C3-BF28-CC9A537C1336', 'A37CEB55-890D-40BB-8D2A-4A48AAC04277', '9002260019250', ' 1  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDE2DF21-4FA0-422D-8B9E-3838ADA80BCD', 'A37CEB55-890D-40BB-8D2A-4A48AAC04277', '9002260019267', ' 1  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('008B905A-54B9-4137-9B4B-9500E551579D', 'CFD67B77-C4B8-470A-96FF-0D3133D4483F', '9002260021284', '-  500   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D64C7E7-25C1-4D83-82CD-79B2B8D01E64', 'DBFC14EB-87B5-4BAC-B591-D18A01CDFDFA', '9002260021444', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E1FCF0F-B31B-4EF1-80F0-F03288C1D306', '575204A0-95FD-4F48-BB98-480D2287AE9A', '9002260021529', ' 1% 30 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('461592E6-1C41-45A7-9557-75D9CFCD254B', 'E2197C19-1839-476E-8B7C-80B897EB9F18', '9002260021857', '   1000   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('197E13E7-62C4-4694-AC23-F788918482F7', '7FB9A303-F4DF-40D3-95BC-11AAD09A49A2', '9002260022823', ' 1% 20 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E283D1C0-BB03-4D2E-A2C8-99AE18AF1252', 'A820283C-E96D-4048-BBD5-88CFD47D3A56', '9002260025107', '  510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8F9213C-AF67-44CC-BA74-183C6659260E', '9BB793CF-41B4-48FD-9231-85CC2B151049', '9002260025138', ' 250/5 60   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3309C319-AA9E-4CC9-940A-D7EA55861ED3', 'CCC0C364-A86E-4057-9869-D251036FED55', '9003576001885', ' 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CD4D494-8D78-4249-BB9D-35E143633135', 'A4D4F123-A077-46C8-821B-E77DC45624FF', '9003638023855', ' 40/ 10  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C31970F5-03ED-4166-9A8E-1CFAE1A63B46', '5F7249A1-0C01-4A32-A5C8-2C9C4BBDCCF4', '9003638023862', ' 40 2  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('254BFAF2-AB9C-4928-9AD0-1F4DDF2DF145', '42AC4AD7-2F67-4755-81EC-0FEBA0B7F019', '9003638024418', ' 200  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCB2A2BE-9A60-48DF-91A5-BB9144E338C2', '50BDF386-B050-4E53-9A08-8467462B8D32', '9003638058055', ' 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85B6AC1A-3B91-44F5-89F4-9E73DF26DB10', '89FB5EBC-185A-4E50-B783-2AC15A9B3A6A', '9003638058109', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B91F094A-0273-4BD8-8792-693C860B60D2', '6E6FCB4B-A62A-4300-BCAF-A16F1948DAED', '9003638301724', '  8  / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54C05F2E-899A-4C07-A9C7-9A22E3608CD5', 'FD85479D-EF14-4096-A894-6C981CAA22D6', '9005441075014', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35B07D9E-5ECD-46D8-BF62-A4154C0BA439', 'E0C163F1-96B9-4798-ABDC-2B7724EEB9C2', '9005441075137', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0617A02A-C5BD-430B-AFCE-1A5C7FF9E68F', 'D00B2AB2-F8A3-4BB8-9533-8251B8875CAB', '9005441075212', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DD40509-B0E7-4536-84A4-F1FCB96BA8A5', '83E4AE6E-0F80-4BED-941A-77F44683A2B0', '9005441075298', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4FE444C-EBF3-4224-A5D6-B3C5D9AC8793', '254CBC3F-2AA4-49D9-8690-5A1C89AEA4EA', '9005441075304', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5004582D-937E-40E0-A729-9B0208417790', '6FE18B80-93EB-4EB6-9FD0-91B86565D30D', '9005441700503', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF8B3FBA-750B-447A-B58F-FA24891A1984', '9F808C99-F99C-4034-9475-390AB60A560F', '9005441701005', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EF9493E-1697-468A-85B1-84AE28C80D88', 'C18EBFC1-0610-48C4-89F7-3BD11E96E279', '9005441701210', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE2CEFB0-D273-4A69-B0E6-415783D3986F', '27B82955-4AAB-4990-AA01-5BAD1C7C9189', '9005441701258', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB413FB5-0732-4715-BE9B-5A3719BBF848', 'C78ABF49-3873-442A-A359-2D6BFC67DA61', '9005441702415', ' /   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E83A509-10AD-4CF9-9455-C365A8BD8C89', '78CC89BF-4F63-481E-8721-FF6FDAE6D3BF', '9005441702507', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0352265B-91B4-4DF2-ADB3-A131E266BD50', '2F76A7AE-5A6A-4E89-8F37-AC0264832B34', '9005441703658', '   36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D067D022-05A2-41B0-A49E-8EEFBDBE0F72', 'F85071A7-8890-498A-BC1B-E7A05A4FC45E', '9005441704006', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60F94160-4434-4FCD-AA4B-9A1ACD7D6A6A', '35882C1E-5E40-42CE-9F73-5E644501D123', '9005441704815', '  48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('883294B5-943C-4A59-B2CE-AEE8119D4924', 'CED8E7CA-24A6-4896-862E-A6F8D7FAF40F', '9006968000565', ' 30  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F40FDB39-A614-45D9-BB1A-71CD5905F7ED', 'A3D1F6D9-5F95-43F2-9A5F-4BD4098B2A9D', '9006968001692', ' 10   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4B1978D-E09A-498A-9469-F166CF835E78', '1DA28608-8459-4ADC-A71A-585366777DC6', '9006968001890', ' 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76080D47-6175-4314-9317-4F783ACC4C8A', 'E1F1CADA-5A60-4CC0-9D31-22A56659E1C9', '9006968002286', ' 1,5/1,5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD5C989C-8017-482F-B193-8B74F5DA65B0', 'F0E912DB-384E-4AF9-B2C3-9EA291B2BAF9', '9006968002965', ' 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32702775-A32C-40F3-ADC7-EF18DA8CF0AE', '2EBC77FD-6956-4C76-9C98-E8535478907E', '9006968003115', '  200 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6FEDEA2-4C54-4D34-B546-BA94D3F5A39E', 'CB7F3387-751A-4E03-8952-092C9373E90A', '9006968003139', ' 18  30+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1374913B-B3F7-4ABC-8C9E-CB7AACA2177C', '74F0A4FE-3B1C-420B-9883-9F7C38554434', '9006968003160', '  100 / 200 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E8F6FF3-AD93-497A-9559-D6915494344C', '7E26F1F8-4186-401C-8A5A-4B04F02B5431', '9006968003184', ' 15  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF1C34A1-FE30-47B2-AB15-33A96FDB24E3', '81755F9E-477E-45DA-AAE0-FE950B222829', '9006968003276', ' 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD737A71-CA95-42AF-B9BB-F114E222978A', '6EEE9B52-13CC-40C0-9271-F2D7B558CAE7', '9006968003924', ' 0,005 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94C601DC-96C7-4492-9C44-E4765C11BCEE', 'C7A5CC98-85FB-4EDC-98B6-99011C093120', '9006968004013', ' 0,1% 20 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0484057-D55E-4C15-B3D7-CDD7B6DB9253', '7BCE881A-3AA8-4C08-83C4-A6B918498559', '9006968004020', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D2E937E-2BD0-483D-9F21-D36FA64A0C12', '02B34ECD-F98D-4F27-87D6-DF36CA2F6FEE', '9006968004037', ' 10  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B07C72E7-6A3B-423F-A535-E4CA4184BD53', '971AEAD6-B004-4457-9B83-8D47DF26E7D4', '9006968004532', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BB55F76-8C3B-422B-BE89-D2A72476FA25', '396E3D7F-75B3-4AC2-B3A7-22F2AD29AD48', '9006968005102', ' 75  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D76CC1DF-510B-4A19-8BD1-6D7F21026A6E', 'EB79A209-892A-43E3-B746-93192E623E48', '9006968005119', ' 110  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34BAFD55-C911-42BC-BE0D-887EBFE19D83', '9B03F5D4-44A5-4F58-81E6-6447B6A4E518', '9006968005126', ' 110  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48D8B8BE-2A31-42FC-8D37-7FAC6D4ED1D2', '23997BFC-19B0-419A-B84F-522C604FA24F', '9006968005157', ' 110  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9C8E118-5ADC-470E-B3E4-2D39DE6CAF9C', 'DDC3CEAB-7144-487B-B610-B1C68EAE02D9', '9006968005638', '  2,5/ 4 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D6058EB-2491-4413-8A6E-C294D36FA6EA', 'DD454C7C-2BB4-4409-81CA-762DE068DE59', '9006968006178', '  15 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66191760-4FF7-4844-9C2C-5B125948BF63', 'D6B7DC54-9B69-4BB5-875E-03341295AE94', '9006968007038', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A455184A-F9A0-4DBE-94BB-4386914D8156', '696DD7F5-B539-403E-837B-561ECE6583B1', '9006968007120', ' 7,5 5 100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADF88EE5-865F-4269-8847-0E16800219BB', '541112E1-B7E4-4B0A-8BF2-F97E51693F92', '9006968007182', ' 0,015  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('635A7F87-E0C5-4886-B501-AA0923F76CC4', '7E26F1F8-4186-401C-8A5A-4B04F02B5431', '9006968007199', ' 15  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72B9ABBD-6E98-4D76-AE8F-29E9CDB8478F', '40953A5C-4D40-4305-B83A-EAE97A3A73C4', '9006968007205', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FC19AC8-D34C-43F2-AB8F-2E3DB8629B2F', '6AA1353D-5842-4DF2-A060-7D6A2BF0296E', '9006968007359', '  0,375  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CC559F7-E030-4D68-9833-29F0C3379FAE', '0EAE1586-D2BB-4492-AD1B-29E5C3F8F658', '9006968007373', '  1,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDF6DD9D-D5F4-4D35-821B-0386AC291A17', 'F96AE9F6-8829-4940-931F-577EACFC691C', '9006968008066', ' 0,005  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D091264-97BA-4479-936D-7167099EB1D6', 'EB152876-B5F1-41F5-B032-477B5C456572', '9006968008073', ' 0,005  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('404B4D99-D7FD-42BE-82DC-911D78F6A9CF', 'A444A996-C0ED-4D12-B3AC-34B1F2402DDE', '9006968008165', ' 150  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B8C67B9-2851-432D-A4CA-7A7A6390C404', '0110943F-9B8F-441F-8868-3EAA40E6AD7F', '9006968008172', ' 150  180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E05E0E5-8585-4AA7-A3D5-6CC2801C5913', '76E58240-02F0-4628-A505-8E9842FC9A85', '9006968008202', ' 150  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9ADD93F8-F065-4C6B-A838-393441839A4A', 'ECD580EE-E6B9-4394-A201-E67CE9EEF9E4', '9006968008387', ' 10+80  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBEE2C68-380F-4184-9FAA-848A1B58E5E6', '0108EC8B-EE9C-4832-B4DA-FFBE808E9B73', '9006968009636', ' 0,005 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62555F67-E978-4B9C-B97E-A8DD4AA3AC6D', '4EF396E0-8344-4056-8EF1-A993D16AFF7E', '9006968010342', ' 40  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36C196F1-F780-48FB-8432-D0E4154FBCD5', '47BAAB0F-B066-4A9B-9086-950847227D0B', '9006968010359', ' 80  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F5B848D-3400-4B26-ADF5-BEF3FA3F5773', '66CD930C-1963-4219-A9E8-8ECDA5D37DE3', '9006968010793', '  0,75    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB34B90D-3F7E-4933-811E-DE232C042C8B', 'AE193E77-270C-4428-A352-45A8ABB5EED7', '9006968011462', ' 110  180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FB94FF0-B88E-4C36-BF53-7A07595B06CF', 'F16F4B6D-1656-4E6C-AB32-9087E83F45A9', '9006968011523', ' 0,025 /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64D48316-0F8E-48E5-8AF2-8A030435D915', '7212ACC4-1F9F-4EB3-BBC9-EE00BE755B95', '9006968011639', '  12,5+80  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42AE2498-824B-486F-AC3A-65802440BB2A', 'BA8F953F-BFC1-4066-89E4-0265F12E2532', '9006968011912', ' 10 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FD508FC-D355-4C7F-A345-856FAD04BF26', '12A89735-FEA4-40BB-9A0B-5179D5E1BB7D', '9006968012254', ' 0,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78ACF4D0-C26E-4DE1-84D1-25C292037691', '221B8805-C3A8-4284-956B-36928B81D479', '9006968012261', ' 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88CD82F2-6108-4E00-8410-335B90D5D8FD', '16AF1D59-78D3-4562-BA92-AC0C101F3D3A', '9006968012537', '   2,5+2,5 30   - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01A24B93-720C-404B-91F1-5A7976B53F7B', '8F4825EA-79FF-4586-ACBB-D701E004703D', '9007253102513', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7E8459C-DC67-429A-9D85-95F7D01964C8', '09AD01E9-6FE0-4099-BCA6-6B88A253017C', '9008732004533', '   /.. 600  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7C0B551-FDBE-4F40-90C1-357DB1F8D6C0', 'D59CF21A-643E-49EB-9324-44E1C6BBFFD3', '9008732004540', '  90   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA93D2F2-B38D-480D-8E0A-21E872500EB3', '22C19DEC-94DF-447F-99CF-FE231A927D35', '9008732004557', ' 180   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD4232AD-7EEE-4CFA-B1A9-5324579FBCFA', '4D599714-ECF3-4CDB-BAB3-A49080F6E7B4', '9008732004670', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E05B081-244A-4391-B90B-44F95B7A7809', '9EF4DD36-015F-48B1-AB8E-95EE7983DD75', '9008732004687', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0D73216-8CA4-4F9C-91E2-93738CDA2E0C', '681D0181-5021-4FAC-8D55-DA05F19926C9', '9008732004700', ' 50/   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E71FE56-F4EF-4317-9FF3-9626F9EF30C2', '37C9DCFB-16B1-4944-ADEC-1F2F7986FB63', '9008732004724', ' 300  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8210A907-1F81-4030-B56C-771D921850B7', '15420681-8B1B-4BF3-97C6-AF4816B9627C', '9008732004755', ' 300  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A68D61EE-EF08-417C-AA56-1B2BC48482A9', 'B8163074-AB55-4176-9E4D-2117CB3FA42D', '9008732004779', ' 500  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11571C3B-B58C-4987-9EA2-FFB75ADE353C', 'F970DF27-0431-40B8-ABE3-0557479CB6A5', '9008732004809', ' 300/ 100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6AC1870-3A5B-4333-AA24-3C2F7F5CF002', 'EFAE5AC4-B124-4695-9151-C5D5748AB1F7', '9008732005172', ' /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB517992-E84D-4DCC-B355-4EC9EC7054DE', '3D9651D8-A800-4257-864E-9B0B72E0711C', '9008732006896', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEB98646-DDB9-4898-B8A4-E137F74C1440', 'B6328CF5-7E7F-4363-9956-DBA573C276BA', '9011111516145', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1D58D76-4265-4150-B119-AF6790FA39AC', 'FBF24259-4EC7-4059-8C22-6A172D81FA8B', '9062300107811', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75A56D7B-0097-4648-A32C-00C0ACDDFE0E', 'AA2E47A2-835F-4E9A-81CD-801F674B0F7E', '9088880087886', ' 10 - /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CD1C063-C7A2-4837-A403-E7718CB6BE94', 'E128B97A-3420-4B9C-8C09-E80AA3A48D2D', '9088880553695', '  5 - / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFF02554-05A0-47A7-9784-7DAFEABCA233', 'FB72BC96-38DD-4F0E-B800-1FBD5916990C', '9088880727546', ' 0,01 / 5 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA45DE45-676F-4C36-9022-05BCC1AE637A', '558925AE-3ABC-4DFA-A0AC-0D1350444090', '9088880738078', '  20% 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24106803-E7D0-4D4B-A272-E6105677B3E8', 'BF7140AE-B2E2-49D3-AAD4-C4C0DF0BFEAD', '9088880781852', ' 10/2 2 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('273823E8-449B-4712-BE40-D182CDFCA4E0', 'D2EEC78F-6358-4268-80F5-E8C12736A057', '9088881253150', ' . ..  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A0122E7-E2AB-4899-94C6-0662A9CDAD1E', '5ABE1A47-3878-44FD-9D0B-61B9F5E3BFF4', '9088881256212', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C28163E-8316-4333-A17E-583B6BF14E68', '1CCC4EAC-220B-4CAA-B4B2-39C41691E585', '9088881286196', '  10/ 5 -  1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAB00953-9888-4C44-9DF4-E2A31181E0A2', 'BA378D1D-1B75-4E33-B502-70D027CFB921', '9088881314783', ' 2,5  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D92CAC43-A5C8-4C7F-B411-9860EB69D4F2', 'B8DAC5FD-A5E1-4738-8BC4-A7DF0A5A606E', '9088881315629', ' 5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3D0377B-E539-4EBE-A0A3-C89E771303EC', '82FB176C-AEF1-48F4-9A2D-97E1415B4A4A', '9088881321514', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF4D6BB5-B7AB-45D4-943F-C9FD005D8C2B', 'B3C5C25F-0597-4ADC-8DA3-63A1A9364752', '9088882444274', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D11F7860-0B76-4DC6-8D13-74585AEAE913', '853971F9-DDB8-4458-B2F4-14FCF34316A2', '9088883510114', ' 250+100 200  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F25084F-2328-4CDB-8A3A-14ACEEA77D7A', '540047CB-CD62-4FB6-929D-7C9C19DAAEF3', '9088883520236', ' 20 10/  2 / - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2003E5B-E547-403C-B63D-AEF8A0A21475', '29E8DA36-B606-411D-A8C7-7D253B22B1AF', '9088884222580', ' 7,5 10/  0,75 / - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD4E36D8-7470-4FBC-A805-1C89FB0523A0', 'A99998EE-2258-4C8D-9A35-88470FE33BF2', '9088884222597', ' 0,01 1,0   / - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C96B677A-A91A-4AAE-8446-912379334441', '63D6ACC0-F751-412F-BA2A-DE63E6BFAC32', '9088884222603', ' 15 10/  1,5 / - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF9120AC-34E3-4BEE-B439-DCAB3540EEB5', '0BDCB00F-4746-4631-8D45-AAB190A0D7D8', '9120008841373', '- 500  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC76BFE1-19C3-486E-96EB-081575EFFDDF', '340D4ADF-8036-4A89-9F3D-2072597318AC', '9120029750180', ' manual ..  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D2CD68F-4F75-426F-81C5-35AEA4EC721B', 'CFEBD534-F9A7-44E5-9F65-2BC51594DBD9', '9120029750272', ' .  -  manual 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CABE8AD8-6C70-4AEB-862E-5160F308F84E', '7E4494E7-CB1C-45E5-9607-810702824B43', '9120029750388', ' manual   -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73A74D2C-8F7F-48E5-9548-AE6BE5CC1FD4', '8A2E52A1-BA20-459C-B6B8-F1C357DAB41F', '9120029750395', ' sv609 ..50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C930CE20-D245-4596-AA52-7D158BDCB6E7', '2792E368-C82E-4C52-BE45-40712DBCA963', '9120033950019', ' 80,5/5 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('047AE195-F259-40B9-9377-5F940936A445', '8375BD3A-D3E8-4CE7-B5E2-3C209463171E', '9120036091856', '        / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF303194-A06C-4F0B-95D8-E59BA54E82EE', 'D188B329-551D-41C9-A9FE-E28B4BF863BC', '9120036091986', '   / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EFAD8FB-498C-414B-9DED-2988105A141F', '4439DE22-A0C1-411B-91B9-C40499BD9D1B', '9120036091993', '   /,     2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8689C73F-90F0-43B2-B043-9777108D78E3', 'F3767E51-09DC-48BD-9103-F4EB017EEE56', '9318637042319', '    235', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69F3E5D3-533D-44C2-BA90-F86C0CDFCDCC', 'D0EC7470-897C-4E5E-8435-378DC7EB8596', '9556807311128', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AB9EF18-7E22-456A-B12C-945FC71CDFF2', '634B1B10-B925-4C79-87E3-B76AAD415F73', '9556807311173', '-   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A8EC46F-4796-4A7E-B39D-06866AE10057', 'E76E5367-E4FC-483C-AABD-3BC0EBD14D75', '9556807316123', '-   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AAA1137-C455-44E9-87F3-20DB623096E1', '7F2A8EB3-07CF-4554-A9CF-1A9971BD1A88', '9556807316178', '-   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0808A382-AA9C-4A65-B05A-AE3A56034FA7', 'C1FA5242-6EDF-4E3B-9736-E745AF27AC59', '9556807331133', '  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E927E23-A8E1-43B9-B5C2-386314BF4CBA', '6C44643B-EE6B-47F2-BA0A-85709E56573E', '9556807412122', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C20C6C6-6337-4365-9835-7EA341DB1E69', '3F9EE316-F1E6-4E2B-92D0-A0A612F316D4', '9556807413129', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30FE3682-96C7-4D36-B1CA-6B13588364CD', '6E706C30-AF2F-45DE-945C-86BCB6CA7571', '9556807413174', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E68FAC7C-24A8-4BF4-B933-C290339F9B0F', '3887B675-B924-4E22-B066-185CF5917BDB', '9557955001435', ' high risk  - L 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23AF5196-57FA-4E78-8AE4-68B8E1278E8F', 'B092B610-1A52-489D-A07A-1A5D720F6BDA', '9557955015906', '   .     nitrile .  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34E35997-EE34-4D1B-BF09-9F52D2D224B3', '974B494F-5CA2-4822-9DA0-5C15DF23D38A', '9557955015913', '    ls /   l 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABE96AAA-ED69-4A08-9BCA-0B8B4DB1B09B', 'CAEED210-6EA7-4181-9FC2-C4BED9AA32E7', '9557955016637', '  s 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FCB4917-679E-47B1-975D-B4553F8CB137', 'F269A75F-72AC-4834-B5A4-62ABD3DBA092', '9557955016644', '      1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F7B04B1-5137-4012-8C1A-D20652C44FB6', '7F832EBC-F403-4187-90C3-57D1D7430580', '9557955016651', '    l 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('155123CC-ED8A-4CB0-922A-051A4DA90874', '78735E9C-EBB0-4691-9C96-DB2385C6E2D1', '9608450003209', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('112C45E2-EAE8-41C3-893A-CAA5F901A0DC', '923079AD-7EBF-47C5-A297-14DBAD4F4BF8', '9780201379624', '    60100 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EFEA35B-0566-48FA-80D2-CA8477801A75', 'B4B7C4A7-C702-45ED-B259-E16E4B57A832', '9785040890668', ' 1000    .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03CB2A9F-EAE0-46B1-ABB2-4CE091BCE09D', '1834F53E-E641-42D4-BFC9-AC4C3F691DF7', '9785040903078', ' 100    .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D27BF07-0A78-4015-A273-C2006606AB3F', '5B76AD20-FD9C-48E3-B2B9-CD3C4C51DC1A', '9785496022965', '   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83330DBE-3F39-40F9-9145-4EDCCE185854', 'F5400613-2DD1-4ECA-B966-647ED8E95236', '9785699868247', '   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE121E10-2DF7-4C37-9F90-FA6F3AD210A3', '8BAB3CEF-BBAD-4E8C-B9FA-ADD998021E76', '9785699994861', '   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3C5F81E-B0B6-44D3-AB13-DF18A9BC40FD', '9A3205FF-DF87-4616-AC1F-2B30246C35E8', '9785957332541', '     .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B695C557-15B6-4766-BD3A-1B7AE3BDAD18', '661090FC-2841-495A-80E3-035B2DAD6DEF', '5900516096823', '   Panty soft classic ''20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('092B5D88-D4B5-4BB4-8702-EE29FE84120B', '68AFF716-F2C3-4C3C-8E4C-D5B648860E00', '5900516124281', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B49A9789-965D-4AEB-94AC-90DCCEA1CD58', '8D5F2B32-2FAF-40F9-8C4D-1E2B55EE2F04', '5900516291273', '   seni  : ,  /,   e  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B9AB7F2-C558-4796-9BF9-D21DC98CA516', 'E808A54C-D835-43A9-AF3C-8923D669136C', '5900516300692', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56F52071-0F90-46CC-9468-4779C72E6969', '7FDE59BE-71B8-4078-8507-22B8BA7C4324', '5900516300920', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F3804C9-48EC-4DB5-9BA8-2EB64757B2E7', '6CC1E4FE-E02A-4918-93CA-BD3040B2F755', '5900516302344', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B77E6EF-8318-4759-9252-B10BC1D4D0F9', '92E80C02-512E-420D-8449-D19CFEA63311', '5900516302375', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A24B8FDF-F2F1-4056-80CB-E67C229E240A', '4E7959F8-F911-4F88-B666-496350700AA3', '5900516302405', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4F2BCCD-997A-4CAC-8D1E-A32CD6F28B1E', '5C75D9D3-AE25-4AA5-9B90-6DB6E00D6CE9', '5900516302900', '     10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E11D2E44-362B-4F08-90A6-D8D965A3423C', '0442F9E9-67AF-4279-B5D1-E945A8E7444B', '5900516302931', '     10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04CDAB1D-B6E4-465C-942A-C50D718A37E9', '1EDAA9AF-4FCA-435E-ABF4-A85977C90BF0', '5900516302948', '      10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26CD3058-C958-428D-AC19-729E32CF2079', '0DE1225C-F687-4109-BDC8-705926DD682F', '5900516302955', '       10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58FEF319-646B-4DBB-BB4C-F516D5BD8EEC', '204E08EF-E222-43CB-8F44-BEBB86EE1DBF', '5900516303037', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7606AA9D-4F4B-4B77-90AF-0057473A613D', '2401636B-8C88-4DA9-AF26-41E6AA1B473F', '5900516303044', '          10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB5F9E5B-0EAA-453B-8A05-CC055B0DD48F', 'D6D27C7C-C6CD-4C01-92F1-2DF8496ACD6B', '5900516303051', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4AF10DF-68CA-4BE9-BBD5-D2E5F8EFA210', '6EC3E36D-119C-4C89-8DC8-D96C69372FC2', '5900516303068', '  Nova  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C52563F7-331F-4C62-9C71-3DDB38A1D067', '883F1977-099B-427E-BD64-5FF05B9FEF34', '5900516303082', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3F20620-A6B9-46D2-9887-AAEBFAD01D00', 'D07A5A78-825D-41B1-AAF6-B9111D08F127', '5900516303105', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD7B16CD-E92E-4962-A4F2-EEBFC6B5A7CC', '3DD28DFD-BBDB-4B47-992B-3E18C5B1F25B', '5900516303167', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1C8205D-A6D7-47F6-AD92-B03B560B1003', '4D29EEE4-641E-4E1F-8B0E-71D1475DC855', '5900516303174', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8391E2C9-C338-4BC7-9558-6DAD0B16B202', '251F3997-6D3B-4EC1-B52D-016A0554B809', '5900516303341', '    /. 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C7743C4-C807-4E04-A0E7-0D0A13AC58A7', '6D66D4D5-2A3C-4A38-AAE1-170A36D655B2', '5900516303501', '     7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D41B64A-37BF-4059-8E56-CBE1C656A84C', 'CFF4883C-F36D-4964-B11A-90985E3CAE5E', '5900516303518', '      10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74035854-0928-4A8A-9E6E-03F14D11EDEE', 'DF8D620F-2217-469F-A425-19FDEC887B00', '5900516303525', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD9DFB12-5A65-4CCE-843D-D9645CEB3537', 'CC84ADCA-455C-4F8B-8AD4-84D28617FF18', '5900516304348', '        10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F382C509-F022-4359-AD92-9B9C54E561FC', 'A591D2DB-FC51-45BD-8640-7D9B308B786B', '5900516304355', '        10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3DDF523-DD97-4176-BAED-880F130DEB2E', '73992938-DA65-4A00-8DA0-08EBE85DADB3', '5900516304591', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8A4A953-E0EF-464C-BD01-E03ADEFB4A97', '71AD33DB-091A-4AE5-8B37-3E5DF6E75E9F', '5900516304607', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEDFA31D-0FAA-4109-8503-566E17F8B10C', '8173BD46-B3D8-4BD1-A134-97FE2C8F5ACB', '5900516304836', '  ideale ultra normal 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FD8F928-CC06-40A8-9030-13F03B990C8C', '694659F6-658B-464B-A4DB-2C8F4BBD2ED0', '5900516304843', '       7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A37EF4C2-3CFB-4E13-B7BA-F30E7508181F', '62DC2437-D7DD-4E43-B886-474A3C4B3F85', '5900516310479', '   - 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8738FAA-2B9F-4022-97B3-94885D80FD76', '5F009E90-2ED3-4435-A521-A16E742EC317', '5900516311407', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F4E926C-AA36-4355-993D-BE2C42808630', 'EE3429CD-8291-428F-B077-D796EF5F4259', '5900516311414', '      20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E9858AF-4F26-4779-BD9F-BB76C7EE8C8C', '1A572EA0-AA57-43B0-8400-4C3E86B11011', '5900516311438', '   . "bella" "Panty aroma fresh"  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7225116D-3919-4627-850F-2992576E907A', '4F10F313-5B1B-4FEE-B7A9-181D9FE61ACE', '5900516311445', '  energy   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64518D5C-09A6-4C15-8A51-C1B8CC82F403', 'B8B218C5-FB83-481C-A793-B070C9479034', '5900516311469', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C39DC9EC-A03C-4A16-B583-5B417B256DD8', '7658CD34-846E-4629-8D09-EE339BC75D5A', '5900516311483', '   "Panty sensitive" 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBA5B499-27AB-42D4-8AD2-FE37BC853761', '0211A7D0-901E-4B7A-B96D-81E2A7D00B29', '5900516311520', '   PANTY aroma fresh 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F6B52EB-52A5-410D-BB57-9D07E2033A25', '06B67311-8CEC-4C8C-A86B-4B1EEDCEFDD5', '5900516311544', '   "aroma energy"  50+10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2953D61-72B9-4160-81D7-69642647125C', 'C66BA782-6004-4755-AF4B-26DA80F63EC2', '5900516311575', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C69B733-CC8A-49C2-89F1-7C21DFE2ACA2', 'A61E5DE8-3BE3-44E4-A598-EBE16C2215A3', '5900516311605', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BBDDDC0-38B9-4333-A43A-BBEEE4C42C4D', 'EE1A1B8A-D105-4328-936F-A6B4C2ACFE9F', '5900516311636', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB2BEE29-341D-4207-9881-CFF242C12915', '285B23C1-AC4D-4A63-8C39-AB7FE74FD989', '5900516311926', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A98C368-6082-40F4-9A7D-158FDA858A41', 'B717EE02-9EDF-45D0-BC12-DD53B91AE9E1', '5900516311933', '        30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4FFFCA2-D102-4F30-B915-CF677BC0BBB9', 'AA71FE2E-BB9A-491B-980C-4C499A6E0336', '5900516311957', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A68DF385-BD99-4FDF-B411-D0035D8DF3B7', '785E5157-BCEC-4A98-AB67-F0A1680D1BA2', '5900516311995', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E934828-7145-4CE7-B484-EA4DDA9471E0', '2C5744E9-FDA5-4A0C-88E8-AFC29784E307', '5900516312008', '       60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('873FF9CA-376A-46DA-B1C1-0DF974296400', 'B2D97C1C-5A5F-4DFA-B0C9-8392C69B7559', '5900516312022', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FB503A7-D480-4A81-8359-2359B6B876A6', '2FC52C71-28ED-4E13-8901-F351832E4685', '5900516312084', '   Panty Soft  60 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8E18FF4-7CF5-4CA7-BF24-523ACDA3E3FB', '5C5BEB33-2546-4316-8E8C-A7B30E84725A', '5900516312091', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0FA68CE-F943-4E83-ABA4-B0DD040971BD', 'A9CD5751-310D-4BEC-B22A-3BAE54117421', '5900516312107', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2832C343-7630-4FA1-868E-58C1C45D24D2', 'C6907D08-E924-405F-8139-381AD8E37A23', '5900516312114', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E53DB02-65CD-4E59-8305-67FA802ED9B9', '2E16EC98-27F8-4F60-AFFB-727E2B0D44A7', '5900516312121', '    60   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2A86EDC-FED7-44C6-8BF3-96A2D328F1AA', 'CBFB18BE-A193-4D63-A4E5-8B750E19E998', '5900516312183', '   "Panty soft" 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE33DEDE-352E-48E6-BC5E-20E0DC204659', '86354ADE-BF0B-407B-A35C-DFC9353D7A88', '5900516312480', '      "bella" Panty soft classic a''20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98E00695-DD14-4B5C-9B03-59D5E623CD18', '6B0E6F8C-5A83-4E63-93F0-BFA52E92FA26', '5900516602949', '    classic  "bella baby Happy" 60 x 60 a''10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE6F4049-01BD-41B4-8AB0-85061DB9EB8E', '7361D105-C3F0-404E-9442-3A90D66EDB4A', '5900516650391', '   "Seni Care"    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1730B73-ABF0-4053-AD84-D1141789FDEE', 'EA71CFDC-46F3-44F7-8143-094CC76C5BAA', '5900516650407', '        200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA992DA0-30E0-4158-80FB-311FC8ACBC07', '6EF60DE3-7AFF-4744-BD0C-0C3174333162', '5900516650421', '   /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0BE80E2-CF5D-4287-AA0C-4ECFB1F52E91', 'FD926144-1C91-459D-848B-D7683C7902E0', '5900516650599', 'Seni   //   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EF34750-9E78-4BFE-957B-36BD7EA36150', 'B45D3758-AED0-409B-9CB8-B2F554F7FA87', '5900516650605', ' /  /  "Seni Care" 500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F4EF0E2-E5B4-46C6-B72E-C2B1288E9B8F', '3F93B141-B1C5-46D4-B9C6-B17B62E5A071', '5900516650773', '      "Seni Care"', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00350DE4-917C-4EEC-A520-8113653D4609', '58F8E080-F391-40B1-B81E-2818EC423855', '5900516650988', '      150  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C01CF6DE-2504-4E4A-ACC9-1296315D886A', 'B670002C-6CCA-4750-964B-A257348AD5A3', '5900516651053', '       100 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('478A5596-F38A-4B06-96A9-DE83CE75176A', '192DB0D6-B000-41F8-A7AD-4F5DE1C323B8', '5900516651107', '    31 / 1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B057913A-BDB7-4768-99B3-46C229D2D911', '6B1DD091-F00B-4C66-A47A-D2F407200CF5', '5900516651121', '  31 Seni Care 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB947C92-42B8-4AB9-813C-18A6CB09BE7E', 'E3BE0BA7-04B7-483C-B8E7-AA633F2FDADF', '5900516651251', '- SENI CARE 200 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E31FA7DC-4BDB-4D9C-958B-EB27BD896801', '831245C2-CC25-4EFE-A5F6-0DDED9FD1EEC', '5900516690304', '   4060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EFCD36E-DB5C-4719-B3D1-DE91ADE6F10D', '17E31AAF-B242-4951-9A9D-34BA52EE6B68', '5900516690311', '   6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CF49F3F-3986-4B4B-B4B5-A6720A30A40D', 'C9C23693-782F-4368-9D79-DE7BAA8F5CC1', '5900516690328', '   6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9213D281-1818-4B16-981F-60B77B6E7690', 'A8F0CA5D-A2BC-45A0-B104-A81FCC9FFAC5', '5900516690403', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F54A9A61-BCA6-4831-A3D7-DAB6169E8BEC', 'D66FFC3F-8187-439F-A2A9-F247B646E5A0', '5900516690410', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A16FBD6A-464F-4C84-A262-6CB47ED950B7', 'CD150B29-D86D-4C27-8EBC-F18224708768', '5900516690427', '   /. //  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8439E3B-0DE1-46B3-946D-9130FD3433C9', 'EF7E7C3A-ECCC-4B2A-B9CC-FECCB544ED01', '5900516690434', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E69822EC-A712-4627-B0EE-4DD183A45588', 'BEC87FB5-711B-49EF-8FC8-404C912A351C', '5900516690847', '   /  //  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFA867D3-07B6-4CDA-96FD-984568E91C90', 'BE246676-ACE8-4D14-9EDD-D7CF7576E8A6', '5900516690908', '     2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF389499-1A23-47C9-8F36-FF0A7E16C8C8', 'C9308E04-7AC0-4036-BF52-7FCF6AAEA529', '5900516690915', 'Seni      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D8D8237-63B3-4050-8DF2-B78299769395', '51679123-1AE0-49D5-8BB2-782DD3DCA735', '5900516691059', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48A034FE-B1D9-4E29-85AB-4D544B4BD193', '15A68F32-8D71-4155-8046-F417AD4943E3', '5900516691165', '   0 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DF36964-CF1E-493D-84D5-1E3155BBA658', '68C9443D-1017-4CA2-A32C-7B7535D8FC6C', '5900516691172', '    S  1 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC900DB4-C6FF-44AB-8116-43EF5B96D69E', '574A3ACF-774E-417A-872F-21A3142F2B31', '5900516691189', '    M  2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5853BE80-46FE-4EC2-9296-B3F77758969A', '8387E679-0978-4204-BABA-A3CDF2A036A5', '5900516691196', '   L  3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAE07CA7-1BB8-4BFD-B378-0EB8F86B4E01', '53FA7292-1959-4604-97CA-91B48ECCF4F9', '5900516691202', '    4 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CBE58B9-52A5-42AB-8703-21EF3A25FC10', '6B73B90D-338D-4DF6-869A-2B94D028418D', '5900516691226', '     /.(1) (S) .10 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A78489F6-C3F0-4DF4-B3B4-E31390FDCFD1', '0FD949AA-1CBC-4E9A-939B-2D3F05B3A0C8', '5900516691233', '     M  2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAB64301-6159-4DDF-BEDC-7D529C6EBE34', '5B4905EE-0B30-4DFD-BFDB-2F4088D31FE3', '5900516691240', '    L  3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9A12F4F-542B-4DFB-A2FB-0EEDA5A97E8B', 'C6525550-22DA-4483-9126-4D0254CE14F6', '5900516691257', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92468EE3-72BB-4F38-8742-DD0E56CDFB2F', '426A3B73-320D-45C6-97C7-A7D16F8BD8CF', '5900516691271', '   4060 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7902E474-4EE7-4777-9B96-D3A8FC54913C', 'EFDE98A0-2562-4FB2-B86A-B29AABA22C22', '5900516691288', '  6060  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99A41950-AC8C-483B-A0F6-6F6BEA4B9D3B', 'E0D267F8-CA41-45C3-B885-50EF41ABA4D0', '5900516691295', '   9060 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('816156BA-04BC-43E7-89EC-B42550489356', '5E9C84E1-5753-40B1-BB36-AECD3FD8CBF1', '5900516691363', ' -  san seni .L 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B444B57-B3D8-4A78-87A1-F0BA99DD6861', '6D7802C0-A46D-4D59-BBB5-57D8C13846F1', '5900516691370', '  SAN SENI xtra Large 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B88E6185-83BC-4E9B-AD30-01C4561A6710', '5FE696E9-407D-4445-B314-D90EAA6426E7', '5900516691394', '    (1) 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFDE9A94-DEEC-41BC-A057-BD50CB5E8FF4', 'C605909F-D230-4F91-89AD-1E5B8FDE3840', '5900516691400', '     2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C922D5C4-D854-4B87-A784-821DADCD414B', '9C5571BE-1CCF-479B-A3DA-C187D8023225', '5900516691417', '    3 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8D6BDFF-21C5-42DD-AAD0-7B84E19A13C4', '2949D9A9-F98F-40B9-8F59-679DA5898931', '5900516691424', '      large 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86887299-13A5-4554-9571-53671E613DCE', 'C9F607A4-72C1-47C4-B9F4-53AF172B96D9', '5900516691431', '    seni: SUPER SENI Medium  1 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50C767F8-32A0-4A19-987F-2637478D101A', 'F6EFDF18-1516-4F8B-B907-14DE40A56633', '5900516691448', '  SUPER SENI Large  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1124CD86-7DBB-45D8-93B2-6E20C0778013', 'ECE2AD85-9FF6-4F10-9653-9857BBDA0F5E', '5900516691455', '  SUPER SENI Extra Large    1 ', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E44A8350-77FF-4760-B80F-2D75BC615E36', 'C4174F07-1A37-48D1-B696-1DA104BCA5A7', '5900516691462', '      (2) 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D5B3962-B1A4-4837-BD60-DDD4C56C1727', 'B9762CCE-B5DD-4718-854F-21221A323D35', '5900516691486', '        1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBE5BFC6-0AC6-490B-A645-3A89557B1149', '482327A6-4110-487E-825B-6E786CC8527A', '5900516691653', '     S 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BD07D47-589E-4CF3-8379-929D752D52B5', '54A86F02-2734-492E-A874-FA1488A635E1', '5900516691660', '      2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFD3C2ED-025F-431C-822A-921F49D6DCC0', '402176D0-FF8C-4EFA-8863-013B7B8E0A24', '5900516691677', '    PLUS Large 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EB36919-800B-4F2E-9FC0-0A71A3B386A6', 'CD1BF36A-2961-4338-A981-FED0C8E55386', '5900516691684', '     XL (4) 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A5C780B-110F-41B8-8B82-FAE193A28809', 'FD99323A-90ED-4523-8771-3E2C2B8018C5', '5900516691691', '    S  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B56E4B1-3174-447F-85E0-107D507B28FE', '138C935D-4DC6-47A5-8139-F9D659DB4EB1', '5900516691707', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A13503DE-5274-46C9-A9C8-4023B82896BB', 'F76CA730-5C34-4E4C-A16B-298130E2D3C0', '5900516691714', '     3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5755F82-2BA6-45A1-B5C1-DD3EE79F810F', 'DADAE7E3-EBCB-4553-9F44-3C7C736931B9', '5900516691844', '   L (4) 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A0CEC70-9C56-48B8-B28A-71F7CDD84A8A', '516DE587-3862-4355-9D70-1BDB47749C3E', '5900516691998', '   90170 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18F1512F-6B52-4C43-962E-FEF03B1DC558', '768E0CB4-C419-4F8D-AD37-695CFD4E5BBF', '5900516692308', '   6060 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F2CFA0E-29AA-4BAD-B442-1D5EBCC18EC0', '13E5D9E8-7E54-4DAC-88C3-927738BC3EAD', '5900516692315', '     6090 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DCCC137-24A3-4F07-B8B6-AE496EBBFEF3', '79D540A9-A98B-438D-AA13-A9181015B28C', '5900516692377', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A819EDE4-82B9-4AA2-83D4-5F1875A7C01C', '88A72C25-1051-476B-9D60-73D92DACA4F3', '5900516692445', '    4060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F449ED62-5004-4E96-9436-8DCDF090EA45', '430423ED-4A58-47DB-9DD2-44B004D26B50', '5900516692452', '      6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C488CAE2-C91C-4558-B16D-136BCE579266', '72C72144-E5D7-4450-A507-E675E31C9A75', '5900516692469', '     6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3008368A-C2C0-4014-9DC5-620C4BEBA089', 'A688C017-261A-40B7-8BCE-BF6F1F5EEB2A', '5900516692575', 'Seni    9060 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA1925A7-4F65-49BD-A91A-9A6AEA887327', '95C986A0-46DE-4B25-A033-C7668CAEEB89', '5900516693039', '      .s /./ // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4E1C6F1-C590-4708-87E0-EAB631772792', 'F3CC8C07-15F4-4EE8-8398-9C2D0A677BDE', '5900516693046', '     2 10 (80-110)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33BBF567-CEF2-4760-827B-412EA9A4D00D', '81A5786E-B701-4078-9FEA-18E757572181', '5900516693053', '      .l // / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C33F3AF-148E-4651-B3B1-C536A4492E87', 'C75A8514-2F6E-48A7-85B8-2198BE154172', '5900516693060', '      .l /../ // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('941B6F4A-07DF-4EA4-9080-613F5C36E6D4', '8CD74E65-4A3F-44FD-A2CB-6CB47C091FA7', '5900516693077', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B989E387-C0E7-42C5-AF5E-68E855579E59', '73B72EB0-C9F1-4D11-8AD7-D77514A8C454', '5900516693114', '        100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B85893CC-29AD-438F-A7D8-BF51105C198A', 'F468EB94-4EFD-4FFE-AD7D-A2D4A69F7055', '5900516693121', '       10 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('782FD5B7-441C-4105-92EB-CF02AC429FC0', '9840ADFB-C1A8-4CF6-8F86-DC25EA419168', '5900516693145', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5225D498-D15B-41B4-AEF5-787457273647', '3AB693CA-4D96-4243-AC6E-CDBA886BECBF', '5900516693152', '   /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('101FD54A-8F1E-4A85-B39E-16039AB0018F', 'E1986679-7B02-4B11-9A2A-8BDCD50C942A', '5900516693190', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('229D12D5-E019-45F1-BE7E-31E73F2B5E5F', 'C29D102F-781E-4B12-9FE8-F5F61C206758', '5900516693305', 'Seni   //   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7A321F2-5350-476C-9001-E8FB0E74996D', 'FEF4FA91-B045-4F04-B116-3B1C167561E6', '5900516693978', '   90170  5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10811AD1-849F-4227-B3A1-067ABC0063F2', '3FA4B573-F48A-4979-A5C1-DE3C3B19A60F', '5900516694029', '  Seni Soft Normal 60 x 60 c  10 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2CF5798-D834-44B0-AF29-595BF7D62289', '559C1F03-9896-48ED-B18D-B6D192315E9C', '5900516694036', '     6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77D53255-6CDC-4641-AEC6-6FF62AF82284', 'D452128B-1BB3-4D42-8DEC-96483E992561', '5900516694043', '   SAN SENI    large  1 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40A81D83-7B7E-40F8-9EF3-E983880719AF', '7B7DDBF0-B0C6-4846-AC26-20D63909B606', '5900516694050', '   SAN SENI    xtra Large  1 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA071F1F-639F-4C71-AAC2-BF74F4E9A241', '80B67015-68DE-4FDA-BEE4-8A64D9FCFC77', '5900516694166', '   /   . // 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62AB9CED-8511-4AAC-973D-AA26D6B39A5A', 'E4FBC8ED-23DD-4BEF-9462-FF6777B869D2', '5900516694784', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('338024E9-5D1A-4654-8D64-AED6D8755296', '0293D3B2-8C7F-4716-9879-1E644DBCF485', '5900516695187', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F80420A-0854-493D-9892-D0A332F07C1B', '4333B5E7-5295-469E-8B9F-7631AD4794AF', '5900516700133', ' .   "" MATOCOMP : 5  5, 16., 17.,  a''3 . blister', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DCF9D6E-C521-4D80-9D86-B66CD89D4321', 'FFA12F64-7608-4448-B04F-24D35F35BC8D', '5900516700546', ' .   "" MATOCOMP : 5cm x 5cm, 8. 17-. a''5 . blister', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A602E634-C285-4937-B7A1-A9E893A8B1EC', '8C4F7015-A4F8-4885-889E-BC43BE5C64EA', '5900516700768', '    7,5/7,5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C246048F-EC90-4CE1-9318-59F1F0800265', '5B2B0C84-37BD-4C05-B53D-D1AA2947791F', '5900516701062', ' .   "" MATOCOMP : 5cm x 5cm, 8. 17-. a''3 . blister', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A3B35F5-F8B2-47BD-A768-7F5EA5FF8260', '352A0810-994B-4BF8-9129-222AFE0B655B', '5900516702144', ' .   "" MATOCOMP : 9cm x 9cm, 12. 17-. a''5 . flow-pack', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B2EAA4E-5F20-4AAB-A6C4-967DDBD2DF97', '82E6517E-E19C-44BF-BF0A-A5B2C9A2C1A2', '5900516720469', '   .5  7.2c ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('936DF2B7-414B-4471-B140-75BAA5B49C83', '2F0B6045-F734-42D0-93A0-238BD8C2CF58', '5900516720513', '  "" Fixopore S10  25c 25.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('046337A6-8CD1-4D00-83FA-F7A78E9EFB12', '4616988C-DE32-4EC3-A420-04075BFC7656', '5900516722265', '   s 57,2  /  5/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EA788F5-D433-48C5-A778-63FD1565CE53', '28FDF933-74F4-4563-A556-C69238ABD9F6', '5900516722272', '    8  15c ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA75CDA9-A2F8-4E4D-8547-9606A5BDCE66', '8BC5C150-6674-4DD5-920F-49582E910FBD', '5900516722289', '   s 106  /  5/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1580DB6D-72B5-406E-ABDC-64F4C69946E9', '4CF4BA09-E0C6-4E0F-B693-36230F8AF674', '5900516722296', '  "" Fixopore S       :10  8c  1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BBD106E-45A1-4CBA-B806-61FEFF3FF9A1', '14940118-5392-4551-9FC7-78EBC31AD391', '5900516722319', '    10  25c', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3788E82E-C826-49A3-B944-6426013892A9', 'B24C3380-BBD2-4DF8-A06D-E3D9DC9EF09C', '5900516830007', '  matopat 5  4 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07B4C0E9-C9D4-42D6-B135-2F36E78E070C', '044F0DFB-0471-4DE0-8179-5BFD2A7C7BA5', '5900516830014', '  Matovis  10  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1D90E4E-54CD-4C59-8352-F2E0ECB917F6', '04016D03-59C0-4CEC-B698-CE1CA357B2F4', '5900516830021', '  Matovis  15  4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27855DE9-D920-4070-B8D8-43AC8A4B652E', '6C145137-C03C-49BD-91A9-6CEBBEAF451F', '5900516830137', '     Matoban    matopat 12  5  1.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F330670F-97A5-48C6-A1CC-7489FAFEC8C5', 'C3576C6F-154E-4101-992B-6C084F71D038', '5900516830182', '  / 4  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('580AC2E9-3183-4309-A853-CF4B46634092', '5DB8B523-74CA-462B-8459-A579CE625FA4', '5900516840075', '  /10  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F568ACA-2DC1-405D-96F5-7E44DEA3EEDC', '6ED4FEDB-2AA4-4468-A8F5-4E7E98E18D16', '5900516840389', '  ( ) 10 x12cm  5 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1E246CD-56BA-4539-87A7-CE036A523342', 'FDF32DEC-A36A-4057-B63C-3FACD9FAE170', '5900516842321', '      /1976 / // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B1847FA-5281-4768-B3EB-572E9C1AF93B', 'FFAB41D2-0016-4333-9095-E97218EA1D85', '5900516842338', '-   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87851CEB-A7EA-4A50-8BBC-186C760EEA9E', 'FFAB41D2-0016-4333-9095-E97218EA1D85', '5900516842376', '-   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AD9B71B-685C-49CE-8112-8783781DB387', 'FD3041C0-79CE-4123-9266-3CDD73F0BD5B', '5900516842383', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C242BB43-C892-47D0-9F34-4BA56C2C6642', '124FC8A1-5D6B-4419-8D7B-3A3EE753FD27', '5900516842390', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('052BD96F-D2A0-4064-A14C-181492923B43', 'A60F6458-5498-4FDF-98FC-0652991DC07F', '5900516842406', ' "MATOPAT" : CLASSIC  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('049D2F3B-A741-4E66-999E-F07CCF0F8A7D', '8F367209-7637-4928-8014-F71C34B5734A', '5900516842420', '-   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18F160AB-BCA2-4F53-A458-8168082A1971', '27123366-8439-4AAC-819E-2AF792959EDA', '5900516844295', ' Absorgyn  27 x 7.5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8888930B-CAB9-4F8A-9409-8A49D0F58933', '26B7AB3D-47A3-4C2B-9311-30B7EEAADAC6', '5900516850555', '   .S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EACA1C37-F88B-4C95-AE9D-D21679DB2F47', '5A9A7536-8595-41E6-8B37-725653F7AF8A', '5900516850562', '   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20E7F792-48EE-47DA-A51E-440F06C2ECF2', '9E08D975-37A0-4FA3-9DC3-1A243BEC5847', '5900516850579', '   .L', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('362DE8D3-29AE-46EF-BFB7-A1132DD3061C', '43019369-DB22-4102-8F51-47CFBFA85832', '5900516850753', '     M 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F6825C1-C9DF-49A7-8733-3083E2058883', '33B8BA7A-B729-4E0C-99AA-E49E7C6B31BB', '5900516850760', '           L  10 . 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('616AEBE1-6B3B-49AE-9B63-4FA4AE69F7E7', 'A820283C-E96D-4048-BBD5-88CFD47D3A56', '5900516855093', '  510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3154E701-F61B-4E2E-8C1B-3312C2C3DD2B', '8A7BFD6E-0A49-456C-89EF-8CCB7CF18B9D', '5900516855109', ' 714 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54FC4A10-2041-450F-9426-6B2A3FFA896A', '77AEF744-4BD1-4C78-AB89-33FC05ACB85E', '5900516855130', '  16*14.   , . 462 32?2 /2,    10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6030D95-C7F9-4651-93DB-C9D136671F1A', '1F7F277E-1A80-4433-981F-7B9C06A43853', '5900516855147', '  45*29.   , . 462 32?2 /2,   5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('184732DE-4674-474A-BB6D-0C0711D803CF', '58C7AFCC-0A4A-4183-9A5F-EE2AF6C4D154', '5900516860059', ' Matofix COH 6  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99B74DBC-CFAE-4BD2-AB8E-861A9047230A', 'B42FB5CF-4875-470C-91E8-6D4330E2840E', '5900516860073', ' Matofix COH 10  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC1A7FA5-1121-4C22-B07A-343D71378DF2', '6392C748-7A1F-4DE3-A720-BB669A8C5070', '5900516860080', '    12  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B878050-9650-42D1-B6D5-EC19A3FE9664', '861F632D-4E48-456B-87E2-F0DEA67D6EB6', '5900516860738', '    Matolast 4  6. /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('253C2ECD-F46A-4EFA-9778-1A52BDEB00C5', '53E4DB3C-A63C-4EF8-A470-66E8D97A03B1', '5900516890599', '     absorgyn 34 9 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81DD0929-16A9-4C90-8082-6249A317881C', '80DA765C-A025-46B5-8683-09AFAD7B7BE2', '5900516891602', '     "" FIXOVIS :  6  1 a''1 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09F6D297-D94E-4524-B94C-B1F62A2D8E83', '7E3F8C86-9147-4C60-978E-2F1D104F0BB6', '5900516896416', ' "MATOPAT" : Soft 6  10  A''100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('188DCA32-E9F7-4D6C-BAD1-FA35270EA457', '08D53B00-1776-4B94-8E5C-7C417F4BA4BB', '5900516896423', ' "MATOPAT" : Classic 6c  10  A''100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59D2B252-5BB8-408C-96B1-3B12AF720116', '2DBE959F-3999-4A57-BA56-4183903E4692', '0027917101347', '-   40   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E06531C-A286-49E4-B361-ADAE21D60692', 'D027840A-BE72-40A0-A6FC-97DC0780029C', '0300651356496', '-     90+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D3EFD68-EBC8-48CC-A0D8-30402CC08B5F', '1AD5783A-5244-489D-8657-231182421073', '0382900909011', ' 1  u-40 0,308 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6867DE7F-08E4-4688-84EC-F836B87C3F9B', '163EFF77-DEE4-4A27-8CD4-1C3918B17920', '0617015109231', '   -923', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A434305D-548C-4B6C-9BD9-8F830FB8089A', 'A9278B72-9309-4984-A884-B0E09F4EB458', '0664942200111', '   amdt-11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DE2BA5A-9A1F-42C4-91E6-F9BE58855E6B', 'D4F85A2B-0F8A-4D93-AD85-94706C0F44B8', '1214960801068', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8899FA0-40C3-4891-BECC-8722DD9ABA0F', 'C5E6A330-1FE3-4EAF-A4AA-419CBD6A2020', '1661242007593', '    2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF21EB50-5891-4358-92B3-9D01E8ECB0C9', '1197086D-AF5F-40BA-8A68-3B69EFFF798A', '1705770151189', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1C063A1-4388-41A9-8637-3D877DB1F4D5', 'AEA7147C-BF32-4728-9190-876573293A45', '1916190463008', '    /.44-46/   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8740D1D-7603-4548-9936-3AA4E31D620F', 'FE2A2CA6-180B-4CEE-9B00-B865A3E4EB8F', '1916190463015', '    /.48-50/   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA3D94E5-8099-49CE-83A7-746DD2A94E62', '4E6A0747-E3B2-4CFB-A1D7-A8D249BB4AFD', '1916190463084', '     50-52 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B187D98-85FC-4D97-9ED0-E93BDFA342F3', 'B847610A-6D41-4081-A077-EAAB81DE5FF7', '1950112580077', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12803DF6-149C-481C-B980-4461F34A158A', 'C9D52F0C-54B0-4D83-BE12-B4A3BD82B75B', '2000103610883', '-   0-6/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9ACEEED7-E9DC-4827-967E-200BB444B2D2', '0606C626-A9A1-4312-BE0B-098E7536C0A9', '2000103611736', '-  animals 6-18/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('677F2B70-E80E-4EB6-A46C-38F90016B2FB', '4BC59AEE-1871-4316-8E56-51059BBAA3B1', '2000103612627', ' 13/109/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AABEFD7E-AA7D-4301-831A-625F6ACE763F', 'AFF2D396-1156-4DDF-BB07-EFC7A4FC1E29', '2000103612870', ' 2/207 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BE8C392-27E2-440C-B41D-C87EBD9AC14E', '5BD516A7-0352-47D4-8096-B6EFEBB222F7', '2000270050314', '      /F-227/ - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B534BF57-DBA0-4D80-8421-8D69ED76FD08', 'AECBA436-111A-4955-9560-982BD366FB04', '2000949785523', '  .52-54', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D535AB2F-BDFC-4F54-9078-D7024706F120', 'E54B3808-19CC-4C03-83E9-48835BA871A2', '2000949812687', '    /   /,    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57FCB998-097B-40E6-8F40-1BED66E58827', '04BE8D5B-AEAE-4514-8A22-32948492BF7E', '2000949867021', '   /610/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13CA4652-BD99-4C00-936D-2915473035E0', 'C60BA0BA-063C-4E5B-9E98-6896ED36924F', '2000949870021', '   . .0,75 / 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('368E60B3-3999-4BD2-8DFC-9C3C64B41ACC', 'CE13ECC7-FB63-4CF5-B9FE-F6AB31FFE6AD', '2000949882871', '  .   2. 3 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2E38EA0-A2AC-4242-A6CF-F6C4A2692BC9', '833D8D96-254C-4BF5-A013-0C94B56FE5FE', '2000949888194', '     ( 1)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E7442BB-CEB1-4EEC-89C1-FC0796617EF1', '3F2EC8CE-58E7-4B5F-A09B-EE1F5F128E86', '2000949934075', '  .   2.. 3 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EDD4763-AF10-453F-B0FC-3BF44BCBDFA4', 'F054CD80-4D4A-415F-9C9B-B575325C2F8F', '2099426627661', '-  0,1 //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F90FCFDC-C33B-4EFA-B15B-06D8DCE14F13', 'E9AF890F-0BF6-4F41-A902-F0AFD45103EF', '2110788874361', ' 250   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('452FA5F0-EE69-45E5-AFE9-8F9F2657726C', 'CC816477-9800-47DD-B8ED-48D3F76A5560', '2400004717818', '  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AC16792-05F8-433B-A4E7-FF34874AE8AF', '6D94A77E-2CD5-4FC7-9CD5-83315E5D28C9', '2400006310796', '-5 1,5  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0260E37C-B248-4F30-81FD-7BB4A1E68706', 'C168624B-41D8-4971-AFFA-B3C403557790', '2400006370226', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47162B77-51D0-4B9B-8660-119F5D88EAC4', '84075C1E-74AB-4ADD-BEFA-3AD0E406DC45', '2400006370530', '   /   . 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D064D557-A9B5-4450-B46D-DFBBE96664DF', 'C3220E12-A7BE-47F9-A293-565056C42B77', '2400006376693', '-103 / /   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0D7EE11-5345-41D5-AA8C-8C14DD2E0288', 'E5B11229-3989-4584-98B9-A1F9E18A429A', '2400006379816', '  2% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E6772E3-27C8-4BAF-83D8-8329EFB18737', '2587638F-A79B-4412-B198-A746FB907661', '2400006396547', '  /  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAAD54E1-2C15-4C2E-808E-F94C638CD17A', 'F22C0226-AB9F-4958-90D9-B990D4332D0D', '2400006396691', '5     / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41452B58-9471-4E4C-97A1-094F10B3460A', '6724F278-5924-481E-B577-9FA86C64E022', '2400006421522', '  . 0,05+5  10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9F7234D-9DE6-4E1A-8176-F210296D3BBD', '267448D5-52D8-4F8D-904F-D9253C54EAA9', '2448695863445', ' - kineib pro       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC8E67DB-6E37-4A8C-9806-F9211AA5D6F3', '20FDDE33-470B-4501-9526-49E56882722D', '3014260007232', '  - pro-epert clinic line pro-fle 38  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D874ECD-FEE0-4954-A665-04B7DAAFB92B', 'B961F62C-1FEF-41A9-9398-3F7E7CDA0C96', '3014260282684', ' 2  /    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A8860BA-B020-44B1-B126-4EC5AB8411E0', '9D7016D6-8E25-41E3-99A8-60C838528334', '3014260732042', '  - proepert pulsar ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A19E5F8-9BED-429F-9E7A-0AB8E2E320AA', '3774B48A-9F17-4A95-9067-A62BA9F6CDB9', '3014260782818', '  - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA9C030D-632E-4C44-B5DE-0DC9174882E7', '0911C3FF-22D3-4771-A0CA-41DCA7612718', '3248140756679', '  /. 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('387331FC-B664-4AEE-BB88-D2B1DCB79DAC', 'DBB9AE0B-B501-4273-A03A-E2B9EA5129B3', '3282770037678', 'Avene   /40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2AFA8B3-6ECA-4833-83DF-B78C63460265', 'FF2355A4-026A-4ACA-B9C5-20C1C72B62FC', '3282770049336', ' /avene/    30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51EE8378-D1FD-498F-BB9B-34CADBAC2254', '286E425C-5505-46B8-AD08-0E12ED14A34F', '3282770049350', ' /avene/      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A09871E-698C-4FAF-9613-399C0378937A', '4C8472D0-58A3-42C7-AEDA-68051A966617', '3282770049381', ' /avene/   /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9773AC4-53C6-4A5F-9C2E-F54528721941', '8E60686D-C190-4F18-ACB7-948DE009C4CE', '3282770053111', ' /avene/      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43E218A3-AF1B-44AB-B10E-686EE17CE99E', '815B3744-3931-4BA1-83AC-71791EE8B5D8', '3282770075533', '  +   ,   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C7EE351-2258-4409-B913-940A1AA565B5', '4EF6774F-E732-4DF4-9E5E-87DE9CBFC6E8', '3282779242080', ' ducray neoptide    3/30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9DFEFCD-9868-4187-9203-4DB877221B79', '19B182B4-B84C-4240-9E71-02CA6DBAABF9', '3352712005772', ' /  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28DF1796-4D2E-4280-A2C6-CC9F6CE2623C', '3FC23B86-003C-46D2-AD7D-A8000AABF953', '3352712007462', '  /. .  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A543FF89-034E-4455-8FF1-CCAC15B085AA', '1CCB1A71-B5BA-4AE1-8121-2ABEAD6EBAE5', '3400935438188', '   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CEA0F49-5839-4844-BB08-B1761BDFF5AD', '4AAE4A0C-E06C-43C9-9E15-EAA936877352', '3401560141122', ' 378  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31BBA9BE-F56F-4BBC-9C02-9288B176A644', 'EF6014A4-766E-44BC-A27B-D29CE3FE6924', '3499320005982', '   /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E9B60B7-B845-44B3-833F-B93679D48BE9', 'C53DFFD0-30DC-41D8-A5F4-CD8DE813331C', '3504105024390', ' /mustela/        spf50+100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC86893C-6A1B-4A94-8CF7-3B85039B5A7C', '58C22CBA-1ED3-4F96-9FAB-83925110EEA1', '3504105028954', '  / stelatopia / -/ 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BB6B38C-8E49-4405-81A2-DD4E37BC347B', '0A5C748E-19BF-48D7-9851-1B135287AA50', '3504105030360', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A091993-209A-43D2-8F60-26E56D242064', 'B31496C8-B154-477E-BB43-24B5241F6DE0', '3518646042645', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A924FF9-9A60-4261-8BBF-789ADEB34F2A', '935A63C2-0E24-4B64-B136-B6A935C1CDBE', '3518646670121', ' 100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('528E2865-2338-4DD2-BBA8-ADEF36D76BA1', '2A04DA7C-DFCF-4FEE-80B1-673D786E7B9F', '3518646671869', ' 5   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32D4A179-DBAC-4DB8-A750-EA834444196E', '30705BB4-3733-4B3A-BABB-1030D9C65A1A', '3573991467109', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('114360F1-9B65-4B4E-A28E-0A3A1C78A58C', 'E6613F41-FA27-42DA-A16B-4267C4E44CB3', '3574660149807', ' Clean&clear     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0E35079-A294-4C92-8456-113CE7497707', '49C76B84-07D8-4D3D-A4CB-CD4993599BF5', '3574660388879', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58B335DA-61F3-4F9D-A12F-A4BE0B8D5F88', '7D2870FF-10E3-4363-845D-427E7FA96D21', '3574660617283', '       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9821FB93-D8FC-4D22-85DD-8615F9D3F198', 'C472C165-90A9-4044-B71E-BD1B19F6BD13', '3574660709254', '     6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('304B2EEB-56A7-44C2-9E20-1FFBD16B415B', '126B465B-6F07-48B5-AF27-2C6144CAA040', '3574661017808', '  /../   32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4389A3D9-AF83-49E8-A8F1-AEE7390BB640', 'BA5EFE4B-0F19-44B8-A1DE-25C53C67C050', '3574661044965', 'Listerine    1+1 // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14E7D022-04EF-4F22-8E84-AF301E761E4D', 'B58B7D08-5C09-4A85-B296-FF573A482358', '3574661047317', '  0,05% 4   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9FE9E5D-2505-4302-83F2-D5F9E15A42C4', '6734D93F-A3FC-415A-8D1F-E41689F7B739', '3574661064314', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C89F7D5B-40A5-48E9-B291-923B42A47618', '4352BC5C-A204-401F-8203-945CCCD9AB5E', '3574661133942', '    /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B29709E-E054-431F-AFC6-AB8E99D3C6B0', '239EAD2F-CBC0-4D24-8EA2-325DEAEFDA0D', '3574661212708', '     12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00CFE33E-4E00-4F24-B03A-04DB5C0467BE', '2D23CE14-6EA0-40A8-B96D-0EF2BCF83C3F', '3574661335513', '         56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55E2B8E4-55A3-4AE5-B9DB-8C3283E509D1', '9243601F-79EE-4A56-8B9D-CC2BB8EBCCCE', '3582910005308', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E98B5CF1-23FE-477E-9528-9D704FF6F1F3', 'D9E7F8F1-1AB4-4F15-99CA-B38C6F48D2EA', '3582910019589', ' 0,005  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA2EC353-DE70-4947-BC7C-37CDFABDB196', '45A2E08B-D5E0-4A97-A4A6-88C76F9B2368', '3582910028970', ' 250  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9327FB3-C8CC-4DD7-8767-2A3CF8E9C65A', 'EE37757C-5DEC-4319-9279-CCE39FC712E9', '3582910069713', ' 180 //.  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49FD3B9E-7B52-4E3B-87B4-D6101D3D1F5A', '4EB00FE4-9494-4F02-8117-FC17B15BD62B', '3582910075950', ' 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB0316CB-591A-4ADE-A839-25A202B72821', 'A2121E36-E4D3-4517-B8E2-E45E0FF8781C', '3582910076292', '   - 5 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD4F5130-31BE-4309-84C8-418520DD19D0', '27640F2F-2526-4891-A523-AD837D14E3D8', '3594450800329', ' 10+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28023DB1-B4E2-4100-B5AB-B554BD1E7377', '11B3A5E3-5FDD-48EC-925B-B06B5A615FDA', '3596540040042', ' 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFEC64D7-CC6A-4497-A03B-F1F9E8931E47', 'DDA48007-7B1C-4618-ADBD-3184673C581D', '3596540050010', ' 1000  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3096404-5B0D-47B0-B26B-15C42B354209', '02CE4BED-4024-4CA1-8527-0E9B6B72C1F3', '3600540042927', ' /garnier/    /  //  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('210CCB19-1ADB-413F-8ECE-12AD887CC2C6', '7DBE4FA3-FD8D-4C35-9883-0CE603171F24', '3600540791917', ' -     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C883DC0-9383-4099-A5A1-5C3FD74AB8DB', '47D40E11-F9BD-497D-B006-D13E64337D2E', '3600541448148', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F472007-05B3-4F2E-BFE2-D7B097EA2967', '2A4A083A-8252-4045-88D1-4A59BE862A5E', '3629002716060', ' + 3  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('759297BC-0BD4-4064-A36E-F72AF01F02AE', '56371EA0-39C3-42F7-BDFD-D108E99C459B', '3629002754062', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('069B9BF4-3C89-439A-A7F4-E5EB7C4D0152', 'C168624B-41D8-4971-AFFA-B3C403557790', '3629002790060', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C926C4B-6984-44F0-9E8D-61310508B8C7', 'F1405DD6-E2A9-4E12-A626-EDC57B9E7F45', '3629004135302', '    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7E3786E-7302-46C1-8E92-3474B3DD2B69', '4A7B860D-E9D1-49E6-8B84-960FFCEF0CD7', '3629004192039', '    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05334E3D-82D7-46BB-AE2F-98708F8E2841', '9BEA3EEC-35C3-47E3-9EB4-57432477C1F4', '3629006016302', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6DC2869-F435-48F8-829B-5E7AA22B0EBE', '4C9EAD0B-307C-44F4-A5B0-2BEA632FEA92', '3629007016035', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A1F8C9D-61E5-4B88-B481-BA795B3F415C', '30B6008F-4EEF-4A56-A36D-CE1D500C4662', '3629007016066', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC2E5A6E-690C-4C0F-8AE0-D00E30869D10', '0668C564-AD37-4558-B5FB-74F97E8856DE', '3700281702316', ' ur-10  /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4F6174B-1597-4EFC-89D5-DA5E30CA4F36', 'F6BEB7E2-477F-4CEE-B403-3D6431AF96FB', '3760001050127', '  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3298E1FF-EB15-4A7B-8F6E-9CDA991F3F7B', '65FAB483-FD17-4387-A886-0B3DD4326A56', '3760102850244', '  /   spf 20 4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D6ED729-D25B-484B-98E2-674EF510C6A7', '7BC160DC-D4F7-4D03-AF7A-555F51648B74', '3760102850350', '  /    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8FE217A-9DC6-4485-ADD0-BEE4155A4C3B', '2946D08F-7680-48E2-8336-C76AC3EE55B2', '3760102850923', '  /   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A86584C-27F5-444A-9374-A9F7A23528C3', '184A47D0-7A67-4C93-AA8B-204D37DADCEF', '3800002302020', '   / 21 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6443D8A2-27A8-4341-B51F-04C4E3DB30C0', 'A0016CA5-C9EE-4370-AC6A-49AC1528D9F2', '3800002303065', '   /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C007E044-BDF4-4798-AD00-1CEF92288C62', 'A4DB6655-A7D9-4315-9D5C-660E319E12BE', '3800002303317', '    220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53574473-EF75-4352-9FAC-6E295E63A433', '0B0DBA53-4F15-4D50-BD7A-B907DF2D3490', '3800010643115', ' 0,25  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A11E00DB-C1D3-47AC-976F-FA22A62AECC4', 'FA5322A1-2E99-405B-BA72-D58D87249E93', '3800010644686', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('941ED596-D2F2-45BD-86DC-C3CB2891B34D', 'A9F1E7C2-B367-403C-8551-B47001AB47EF', '3800021100157', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCFD6CB4-7CCC-4CAE-B5DB-0BFA76FC6F09', '54FDCE56-000F-435D-9124-04B1A4E4371A', '3800021100805', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9DFD328-A037-4C2E-984C-EFE5FE55FA65', '5C77AC94-2272-47B6-9B15-E0339677B9A8', '3800021150053', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48F615BF-27FD-4C82-8E60-CF679BA3017E', '0B1F2549-C9FE-4933-A015-BE06AE2D02F5', '3800089801027', 'L-  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('344964EF-0687-4A9F-8F3C-93101966BF97', 'D9E33892-8D31-4020-BD9B-DA81EF693938', '3800200962798', '    25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06E07523-68F0-4F92-8F63-E9B18EC4A5D3', '63EFA83F-1680-4900-B232-3A984598E525', '3800212710332', ' 340  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A34BD2EA-0311-4332-AE2E-ABABF3F9F50D', '0CC5470B-2572-4F20-8AE0-CDC3E8C32A38', '3800212712602', '- - /  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E8B3B09-6CF2-4D7F-A5C0-9B84F09CFC0A', '08C148AC-0579-4532-A269-AE2A591C0A43', '3830029294794', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94B30617-F5EA-44DC-94C7-E0D4D98B618F', 'A66D9795-8D89-4524-BDBD-014E24BAD9E9', '3830029295104', '   epert soft', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D59169A-8208-4810-992E-1F41E4D7CF89', 'D9C702A9-F845-4734-8512-317BC772EB93', '3830029295500', '  /.  . 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('659C8876-308A-455F-8621-61D23B70F77C', '64F81C21-A93E-4717-923F-9A07D1612346', '3837300905974', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B965E435-FBD1-4F67-BAFD-08792D9FDC82', 'C0D3F855-A5FF-435C-B1BE-06FEA6D96A1A', '3838471024389', '   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71029780-56FC-4A8A-AAFA-BADD9DEADC27', '982ECFBC-00D8-46A5-A56D-B011846BC60A', '3838957005154', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7AF736A-4B70-414D-A87A-0471226DE22A', '460647B6-CF52-4AE8-8222-11D74FE40C66', '3838957030286', '   5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59117643-92D0-40D1-8BC4-5C187DC433D7', 'EB0D07B0-723A-417B-ABF0-8F6B228014C4', '3838957044979', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('790F781C-DA34-414D-95F9-273D09F2DF5F', '97F96FF3-66CD-4BAC-BE77-6924D0BD8EF3', '3838957076741', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A588962-430B-4CD7-A7FE-A9E2AC9EA9A8', '0570A8D1-341F-48E6-B18E-6678C97C4F3D', '3838957871025', ' 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1FED205-324E-4BD4-857D-A21E787A23CC', 'DCEFC57C-9114-48F5-87E9-13C15BB2F418', '3838989516376', ' 10  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A184B505-CFDD-4289-8AF5-5ABA62B34CB8', 'EF3321C3-0C33-449B-9D9F-283C4BA8C6B7', '3838989559120', '    54', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD26B1F2-7F22-4720-AE3C-7FF70B944954', '608100F6-3172-4037-8603-561AA20CC9D2', '3838989559540', ' 10000  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDC2A111-AB0E-4863-A077-F156441BE500', '63DDFDC7-A902-4580-8DDF-ADA1AD2E80DA', '3838989562434', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('891EE986-A2C7-4E3C-8B02-09D639608C6E', 'EB8482B1-2047-40C0-9CE2-A8C09F77FA36', '3838989633202', ' /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D39C976-8711-465A-92A3-5359CE11D2B8', 'C71C3C8C-071C-4A9C-B5E0-4A4FBA5ECEE4', '3850114213271', ' 75  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC681230-B57B-46B4-9CCB-A891A4D2DF42', '54929198-4DAC-4107-BFA8-8A9E9D09AE17', '3850114218580', ' 25  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('091C4B7B-168E-45E8-8A48-C5D13DA34A59', 'E109B544-08F8-4613-BB79-2D2BA0FDA6AC', '3850343028936', '  /. . 5% 60  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F6EADDA-816E-49D7-B1FB-FC7F65D641B8', 'FAEADBA2-7ACE-402D-BB07-068657BF24E7', '3850343028967', '  2% 60 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('962908B4-7AA3-4C02-907C-93E55A905756', 'BA564DC0-47D0-4C29-ABF9-6833D587ACDA', '3850343031097', ' 20  70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BD3AF51-E0E0-4FE9-8645-FB043F3473AA', '97ABC7DD-4957-4708-8582-5FFDB3A7CCA6', '3850343035446', '  0,05% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3831E0F0-356C-466F-9DC5-5C8601BB0A62', '0E3E8F2A-7553-4031-BEB8-630D52F5B169', '3856013207021', '   /  +      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E722C84-C6D7-4E3F-ADCF-4CE57D5DE5D9', '9C499EB8-C891-41E6-8759-CEF2A1725D73', '3856013209353', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02E9CBAD-B1FC-493E-8EB9-40E43C04A062', '4551CA59-B5FE-4DDD-80A9-96DA7A216955', '3856013220167', '    /  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('788F1FDC-7322-4D2C-B711-F197A5884401', '15E8E5E7-69A1-4B7C-A508-673A968A612E', '3856016807013', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E7DBA9A-66A6-45DE-AA50-FD5CA109AAFD', 'CF77F825-E108-4FD8-944E-507B78F00EE0', '4002857002721', '      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED8671EE-07F6-42FE-B1B7-0A720D2A746E', '01B49921-F30F-4E39-9AB7-A4053D947D51', '4002857002776', '  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C805000D-157C-49CD-89D7-03DD342C5E9E', '39D7A40E-257F-4E34-8834-C7374F6D1C2A', '4002857009386', '   /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CC0F838-E6C5-4DB3-B69E-70A86401E2CB', '9EA88361-AEB9-4377-A7EE-0E26235A65E3', '4003583063475', '   /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6690D790-3810-4EEB-9F74-99D00B96676C', '7B55ADAF-1F56-4615-A026-494CFD32A554', '4003583121083', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F462142-343C-4A26-9636-E78E3E144713', '2BE48BEA-87C9-4B2E-81E1-F928E6AC4877', '4008233104003', 'Kneipp  /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E16772F-BCDA-4E76-B800-1A462027B5A6', '5DF968EA-6E3B-4151-9C78-3BB970209258', '4008491309783', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B385A521-AE13-4F3E-A162-37C25FC9F6E8', '6B36E4F1-6B86-4F3A-AF5E-3EA13F5718CB', '4008500127162', '   10 + 15+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D1EA3A0-819A-4709-8F4E-FCB4B5DC9D6A', '184C6520-6714-4F12-8DA9-8C720611D561', '4008600047186', 'C   / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1282D85D-EA03-4929-84B2-6FE9B652A464', '10B0A992-2BEE-4433-AD85-E189255BC417', '4008600047537', '  /  0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D60353C-8B0B-4BC1-B0C4-A9E543B72EE6', '0F519669-7B16-41AC-9574-6A325F557C9B', '4008600047575', '     /   6-18  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52DD2C53-FEEA-4A57-8BD0-B66593D28F4C', '768B6541-3ED1-4217-920B-ACA99F16A005', '4008600090205', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D987567F-FA50-4A2E-95D6-6BE6CA316834', 'C4BBC893-F39A-4C1E-AB9F-010B30A83C3D', '4008600100638', '     0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14FEB1C5-5165-4810-ACD0-F4EBF4B10F6C', 'E4B19A44-81BC-4577-BAE8-8D1393A714FE', '4008600162667', '-  night  day   0-6  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98C5ABD1-4A48-4A69-AEB3-20AD499CA025', 'AC1B7121-AE70-4D6F-A789-EDA657F662D0', '4008600162933', '-  night  day   6-18  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50BF2152-0F5F-4D29-A5B2-EF5EC8D941F5', '0CE4549B-9054-4706-9E4E-E3A054C03426', '4008600194880', ' Freestyle   / 0+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74B1990E-0BD8-4BF0-8F9F-BFEEAFF00B5B', 'F514F6FA-1C1E-46D2-BA1D-D9F9BB473BE8', '4009800001206', '//  /  3  - 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E418C417-91C7-4247-8405-C22AF4CFEE59', 'D17B6990-A62F-493B-9C23-0167914697AF', '4009932529265', '      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69929AF8-F59A-4CA5-B276-D45665E467EF', '7703B9C9-2F4B-4C9B-89C1-69DF58B6A81F', '4009932554748', '   + 6+12++  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08374865-E835-40DC-B3BB-47D3DB3E8DEF', 'CAE336E1-AAA8-4F9B-9991-B014392F7577', '4009932557404', '  -3+q10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3AC9E1D-942F-4286-B8E2-5B8E61DCFFB1', '3075EB6B-6A16-4DA9-8D24-F9045370EEEC', '4009932557411', '   / ++  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10A2F7F1-DD61-40AF-8090-3AB96D434EA2', '80193A0C-1B09-4995-9585-1BD95AB0851D', '4009932557596', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8556BBB9-3DF9-46F0-9080-2B7ACAE984A7', '8C01440C-4F71-41BA-942B-7BD7D999C4B2', '4009932557954', '  -  /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E0D577F-570D-4206-9EE9-B5228226A5AD', '22A9D551-2F3F-49DB-81CF-2E25AB4B846E', '4009932558463', '  +   /-/   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58AADF31-316F-4843-9BDB-7B6E7E560605', '798D2EB5-D823-4F5A-B1F9-87A0B26E2B1C', '4009932559040', '  - /. ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AED7F31-B754-44E6-BA7A-18456AD20813', 'BE63F72C-BC3F-49AD-B477-6AE594B238BF', '4009932559071', '  // vip  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D44068C-FD75-4056-803E-5BEAAC1AC293', '0D370A38-037C-453D-9B45-0B3758F5B470', '4011548016039', '  spf25 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DEB300C-6BA9-48A5-89F4-F34A9B3E8EF8', '09D81FDA-F12C-494C-861C-3F73B454024C', '4013006092203', '-    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('274DC69B-CC3A-4DE2-9028-2955C5E55BCB', '3C0B687D-5307-4803-AB50-A85616D923C3', '4013054001288', ' 40 5 100 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA6A72DB-B599-48E1-ACC1-841DCB44FFCD', '6567396A-7822-4CEC-9C59-46739E643AE3', '4013054002537', '  320  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD208023-F001-42AB-BB5A-0BE50F83FF8D', 'F049273F-A762-483E-B17E-0B9230115FCD', '4013054013915', ' 1000/  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2794C61A-4F01-4460-88C0-3027585DEDA7', 'E07D3F85-031A-4EEA-82D7-4603214207B6', '4015400041597', '    7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35E14B13-CAE4-4D69-B97E-B1114C6FD8B1', 'B1C24CFE-4EBD-468A-A018-415F7C7D9DF7', '4015400080817', '   ..   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B5D021D-F961-46D1-811D-BCD9D07D7A35', 'B655BAED-700B-4277-B636-88C95B1C1FB3', '4015400125082', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47E3AC6F-7E38-48B2-8BCC-821E09614F9B', '9A7D0F76-FD61-4A1B-AA53-1D0FF9FA019F', '4015400165774', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('899352D6-5801-478B-B65C-E9DCB0AF8957', 'F982BD9E-E534-4B20-96F6-82257D3F090D', '4015400197546', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('888169F7-6BB1-4C80-AA2E-1BF35C7B9189', 'DE68662E-5845-4079-B356-CA85341EF4DC', '4015400219507', '      16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7CA1852-D01F-4842-A5BA-94CA88ECFB2F', 'DE68662E-5845-4079-B356-CA85341EF4DC', '4015400220015', '      16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFEE9F60-0755-4675-8D0A-3C091E5296DC', '092C57AD-EF46-40C4-B12B-1835BEF647D3', '4015400453277', '  platinum duo    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B56B469C-F845-4FEF-93AC-3D245E666C16', 'A268AD58-8A35-414D-ADE0-D75315B3198B', '4015400481164', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89AA0B76-4884-4DAC-B694-FC22A84484A5', '465A63C2-C530-4F0F-97A6-BBAA743099B1', '4015400686361', '      20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C509A1B-486C-4E5D-ACC5-BDD7E9D1D607', '3C7B5E21-D064-41EB-B4A0-48E7B253C916', '4015400687689', '    /- 1/ 2-5 22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0555C907-A947-4B63-AB92-68B44444A2B2', 'E27B86A6-0478-436A-92F0-851D95A5E82C', '4015600002886', '     /9-16/ 18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F3B6946-138D-44FF-9BD0-A839AAC0FE67', '9A12D081-FC13-4E82-BC6E-EC5F1FFDEFA5', '4015630006724', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4C0CC1A-1FDD-41FB-96C7-4A036E486889', '84DB309C-7CB9-4CC0-8390-765266ABF12F', '4015630058518', '  fastcli / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D7D1D98-A63B-454E-911A-74DE33606A34', '6B0389B5-B870-4FFB-84ED-B996FBA13540', '4016369355084', ' -   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60F97A93-B401-4C4D-8B54-75E036941A8D', '7CAEE5F8-E866-479F-AD9E-7CED18C9A5E6', '4016369355268', '   /  13', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E8F160B-DE9D-418B-9122-30196928A644', '78C34B72-FF18-4AA4-BE36-2C4AB5B2219A', '4016369546536', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54234C4D-DAE0-42D6-837B-15F3398AE18D', '57A5273F-8B36-4E06-8515-FD91256F81AF', '4016369661352', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5452B31D-BC4D-4822-81BB-0CF13E469881', 'BB61999F-F507-42A3-B810-5503A50CE579', '4016369661789', '         /178/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('983EE755-B335-4543-A621-71F0539327C1', '8DD822EC-0FF0-4EAA-ABCA-8F49C87CF7B3', '4016369669105', ' .    +  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E32F390-CEC1-49B4-B4A2-9AFAF513A717', '301F8358-D48C-458C-BD94-B0CC8F3BB289', '4016369669341', '     24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0FA0D5B-8867-47FF-8973-BA9BA4369A3D', '52CA0418-D3C2-4ABC-93C2-7192BBFDA362', '4022495112262', ' .   18g', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9ADE129-4645-48B9-AC24-232B95C1F7AF', '177635F3-40A4-4654-8841-CCB5E04D2349', '4025612667089', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABB8FB4F-56A8-4B91-8FC9-A8A225704FE7', '61B2229D-BB77-4F1F-AA98-EC36D71A9F77', '4025883616380', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('668D0AAE-0C14-4147-AC26-2702A25C4530', 'A7E3E4B7-1961-48B5-99D7-CA842262B4F9', '4029916000016', ' 40  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F23BA1D2-CD6F-4CC6-8814-C6E5E9796D5E', 'FEE9749A-4FDC-434C-B9C8-978DE5460C68', '4029916000023', ' 320  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43BB9C31-9249-4910-9151-93296899170A', '349A22F2-AE31-471B-AB20-66F92420E601', '4029916001174', ' 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F7EFF02-A391-42FC-85E8-A253FBE43DC0', '1BD6A791-08C8-45F8-B821-8F6439483AAE', '4029917000718', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E403F8C6-E1FF-4104-8B8F-A5E0DD709C40', '2BF62848-D297-4313-9A5B-D922A0A7A4C4', '4030031898341', '-  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('590D0D90-98D8-4D7B-98E1-467AEB732ED5', 'DD511C63-83D2-4175-AD71-8FCC305EDF79', '4030113647164', '   130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84676150-8BB6-4B61-B46A-CB0B0D97A417', '5E9E8178-F484-4886-9688-734C613F9721', '4030142148137', ' /.  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8BE2BFD-16A1-4FA5-A758-014EEEAB36FF', '4B707E06-AF0A-4FA7-8B29-BFD714B2BBE6', '4030539030762', '- -20 1% - / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5998E3CB-AEA9-4125-987B-D494FC0DBF64', 'D1FC27C3-D900-46E4-AB41-3068BEE70F7C', '4030729001602', ' 20  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40441AAB-2A32-4BFA-B321-B8F8A42D62D9', '9B61B356-505D-4C6F-9ED9-CEE90F93CF5E', '4030841003737', ' one touch delica /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA5E9F5C-9153-4D8C-9855-926E50DEE653', '216A2815-AB76-478C-A671-8ED8FFF05FB2', '4030841006219', ' onetouch verio iq', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5B73A9F-5868-4EC4-B09E-800BB922D227', '28CA9331-7E72-4A6E-9429-627A8915AC4F', '4030855502486', ' , 20  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA634192-C66F-433C-8FA5-E38CA856BAFD', '65B08E1A-2312-4D2D-8880-97A1306E79EE', '4030855511211', ' 200 3  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('531CF1A2-B0D9-4E27-863D-3531EC342D49', 'BAEF0E5A-7C18-4C84-B3BD-8DE7C7FB6039', '4031626710529', '  0,2% 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF448B68-0FF3-4989-803A-891084C19C03', '4021CB1A-7FBC-411A-92C0-3AE898D97310', '4032717000062', ' 500  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFC93BCB-5BB2-4E8A-A6CE-172F2464A45A', 'AD1AA063-1F4C-421A-8BC4-C097AD0E11C0', '4032717000147', '  2/ 30  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A855937-B5C5-4B33-9F8B-0AA0AA0385B2', 'FB611A5D-956F-4927-80CB-8339BDDB77A5', '4034541006319', ' 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B687EFDE-1E81-4FA4-821C-45C948C3C44A', 'F2EE9644-9EAB-40E9-A326-E582ABDEE2B0', '4036534254189', ' 1    u-40 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C66B402-A1A3-48B4-B67D-4155DBF0A892', '6A370591-A551-472C-B40C-3060EBFC1845', '4046222754105', '  -  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73B8A837-02A4-48B0-84F6-C53F040703D1', '1C600F95-546F-40CA-BC63-CD468DE89E89', '4046871000141', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C5FF21C-975A-44ED-88AF-4CB41415BA68', 'CFCFD7E0-A401-414F-A19A-E42FBDE98F5A', '4049500025140', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('682971D5-3C5F-446B-866B-F5A2F7CBA633', 'BCC67022-06F2-48FF-AC9E-20318F449F09', '4049500047609', '      14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CD6745E-A41B-4985-B760-02A88A73C692', '77303807-DD2F-464A-A0A3-FCF17510844F', '4049500187619', '     /  160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9803E2C-F5C5-4354-93E1-6F3EFB88E294', 'C733391F-4E90-4398-91F4-E1D33B99AB88', '4049500204354', '  ria   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A893548-A6F4-4C82-B270-E01BE2612B3A', 'C7AE87EA-BC69-4C8C-89F8-CAE4998F98BF', '4049500245227', '   510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DDB8EE3-5293-4E17-BDBD-6C4FDDE5C4E6', 'EFFDA5D0-020F-4271-BA42-004E233A5012', '4049500271356', '     () 10  10 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15BD21CF-3BC7-4632-9950-FCE888BDB86B', '6FB23F3C-682E-441C-886C-2C1A50AB9D29', '4049500302449', '   pagasling   /4 / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D35BDAE-0EDF-463C-A468-F6B8F8436FA4', '1CFCA7F8-AFE2-4BE9-B8A1-82FECA737830', '4049500551397', '   2,55 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BEDBA6E-0D44-4A56-A1B0-F3BF908F9127', 'F775F335-71F3-4784-BA2D-96CC9A5F54A1', '4049500609401', '      L 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDD17FBA-0C72-4104-B1A6-273813C9BB1C', '903FCD0A-2A39-4663-A1E3-1B27A3814E28', '4049500744089', '     10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD238784-55D8-410C-8D6F-CBF61BC07DBF', '9C7DBA61-0B20-480F-ACA7-B8F319D63EEC', '4049500812481', ' -  44  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C9D14C0-C330-4B80-9D47-F882A5D9B7D2', 'DBCB5007-70BA-451C-BE8A-E6C70AA5208C', '4049500835459', '  (Tensoval)    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96A28F38-4369-4E1D-A76A-7D40EC020F94', '5852507D-A9C8-4311-AE0E-773037B3701A', '4049500857932', '      l 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D819903-4FEE-4949-BC93-458F1F8B62DC', '8C7FCA72-0996-44F3-9CF3-A8E9FB1BF5C1', '4049500881593', '    /  2010', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82AADA97-8270-4627-98F3-7FAF0B0BF404', '0DAA35C8-C624-4558-BDC5-0079BE525DB7', '4049500900225', '   . 1,259,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C71F93D9-DCAC-42B0-9815-C583FE631CE4', '76DFE62F-8FDF-4BE3-BC0C-F1E7136E71B6', '4049500900317', '   /. 1,255/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6048BA50-6C2A-4460-991F-3C052D45F43C', 'CF8B20C3-37B1-4B7C-9D1A-357BD4862977', '4049500952170', '  -   4x6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AC4E6C6-C058-4770-8987-0ECE27E20B18', 'B72CAA3B-49D3-4A57-84A2-D3B7B84D10DD', '4049500967754', '    102', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA18F3D3-B27B-432F-A1B9-441AEDE34EA2', 'E0A9C1C4-93D5-4ED3-A455-60CB5D50C352', '4052199235646', ' menalind  prof.   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4079C449-2D95-40ED-9CE4-DD5E5D37566D', '888A1FCA-A5D0-4267-ACCD-B0C9E06348C9', '4052199241203', '  2,55  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EE11637-44B8-41EB-85BD-89D5A8BA5456', '5F7CB945-9A4F-4EEE-BD61-2670B849DFF0', '4210201043508', '  -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17DBA51F-5795-4DBE-B4D2-208A0BA59F56', '520B3165-93CF-4040-806B-FC15D09FD489', '4210201187899', '  - vitality crossact/+ precision clean 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB43FD5A-FA45-4030-BBCF-03797001DF03', 'EB9F3EB4-5AAD-46D6-937F-AF664E8458A0', '4210201822448', '  - . pro-epert', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3377689D-2D57-4660-9870-895CC623ABF9', '8A09CB55-BB5E-41EF-9428-EF1768ACF188', '4250360110130', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB2E2523-B5FC-4CEB-9BB8-45A72E14AE47', 'F8BCF3C0-957F-4BAE-AD32-5BDB2892612B', '4250369504343', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4035A3F8-E2D0-4119-A1CF-11C048ADB2B2', 'BB086A39-CFF1-4531-9037-320013D91E8C', '4250369504978', '      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54DA8F10-60D0-484D-9D18-5377FE906C39', '377C30A6-7FB4-48C9-ADAB-A26694968136', '4250369505593', '    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA1B984D-E3D2-46F8-A064-619E78ED3E67', 'FE8C1170-EBB5-4314-AF72-FCDD5184608C', '4250369506590', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB424324-7389-4F0A-BD6A-EDCEF62DF40E', '88CC56F3-A17A-486E-90A7-F64D4269B298', '4250369507382', '   /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('788A1840-6E0B-4CF5-8A4A-768CBB114EF5', '77AE3F2C-CCA0-40CF-B99D-5E64B50C0A86', '4250369507641', '     3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('989D9011-B861-4A90-8F61-675BA25B36C8', 'F84AAAAA-0E91-496E-8D02-1389D5D7249F', '4260068590011', '  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B6ECEAC-832D-4A98-84F5-C4E379F1524E', 'A6FD47D4-F23A-430E-B5C7-9FBFC8D9A5A3', '4260085521654', ' 1%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F95EA9D-6DFE-48A0-B367-D9EEB3A7E5EB', 'E162135C-8751-4DB1-854B-5E759C537D8B', '4260107479901', '- / miiu 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D96A5A0-1F97-4196-A225-59DB540CD60D', '814EF303-F07F-4792-8F10-960F74DEED61', '4260108399093', ' / /    fabrik cosmetology snail etract mask 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BE5BC85-BA77-4286-AF17-0167F8987250', 'C62ED435-C623-4D93-9A0D-E2E197C753DC', '4260108899098', '-    6 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78524283-429F-431D-B4E4-2E1204713DF7', 'AE2C58E5-253F-4D3E-A72D-DD5C71595FF3', '4260142420388', ' 36.  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('089A4C2F-587E-4D0E-8C81-941120926DD1', 'EF2AF330-93A1-49B4-AB75-5416BD9DF261', '4260329740292', ' 5 3  c  0,740 100/pakromedical/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A3223C1-C40B-49F7-B6F7-DBF0F9D88FAF', 'B78D0909-60AF-4E66-AAF1-385548ADE0A5', '4260532450773', '   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D60A618F-2A34-44A1-812B-6E41C59777B4', '93914E06-49D0-4E4C-A2CE-69BDF378CBE1', '4260532453378', '  /  l - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96939998-04EC-4CB0-8460-57C812EAF8B8', 'D8CDEF3E-8D72-40D8-9CCE-0EA9AAE87658', '4600053020220', '   2% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F60D1DD-8021-4F70-A36E-1CC80E812449', '928DA138-6383-41A2-8A9D-B43D31D45FAF', '4600104023057', 'Picnic     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07149F43-3FD4-4990-81FE-1211DF971EEB', 'A19DC2CE-C4BE-4379-85A5-165984F169B9', '4600104023194', 'Picnic    150 3 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84A5CD3F-8BB1-4CEF-AEEC-7D093763004B', 'BA45E43F-FDE1-4807-8472-4B5B284AA193', '4600104032165', 'Picnic  -   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3AD5A0B-9031-4C7C-B5ED-5EECF430FFE2', '19635509-1E13-47E4-ADB1-52DE5B54D1BD', '4600104033537', '     150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDCF79DD-7DF9-42BD-9BA9-9670DD42E266', '5A6238D2-4692-4ADF-BA4B-C3B1BB0C37C7', '4600171025633', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB285503-FB5D-4275-8CBF-290EFD402078', '74B82C0E-B5BF-48EC-B316-DCB5CAEFCF35', '4600171529032', '    51 /906/ 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32262F52-1551-4747-A74C-91C68F55B8BE', '77249B52-F0AF-4F89-BEFB-C9F5500DCB9B', '4600209009239', '-3   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('216E33F9-5284-4555-B770-4E60DCA1EE1F', '868E41B3-F53F-4F9E-A3EC-CAE8C331A18E', '4600338000411', '    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('901DB6B6-D59C-401C-8D33-AE3598EF2331', 'D2912CFA-807E-45B6-B479-9BE444C6E883', '4600338001999', '       .200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C7541D0-5BC2-4A7A-9568-AF2FDD512719', '2EABA95F-14D4-4E98-8D76-574E5F77BD6C', '4600338004310', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('245E324F-BAAF-4677-B0B3-BE44A280F95D', '2E6D447A-AEE6-45D2-8385-FF396DABA3B7', '4600338004501', '     6 . 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('737D4D12-27CA-48AB-BA1D-1CA8A46DD4A2', '659D6547-68B2-47B2-A311-51E4ED4CB43D', '4600338004860', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33F77D85-A19D-4F49-A1AB-7112898D78B3', '0DC0E9EB-481E-4003-8190-C669385CD999', '4600338005195', '       8 .250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0E6D90C-5425-4C10-93FD-6C0DBF08FE0A', '2EB612EA-7F62-4762-927B-3104CEF438D3', '4600338006567', '   /   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E04E6C95-66DF-4060-B426-9762F91680BB', 'DB3A9CD5-68E2-4258-9623-00AE7D98B6B1', '4600338006833', '     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B67C4A79-8F71-41B4-B608-827DE0807126', '0C2137D3-C42B-4D9C-A73D-46645D4CBE41', '4600338007199', '   0,33   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('207FCC10-4D53-4146-A407-52394119E405', '22059E2B-2C38-4F88-B2E8-EA736F6968ED', '4600338007830', '   /   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8524E4CD-05D8-4BB2-BA70-327C99CBCF37', '3F61026C-ABD7-4148-B2D4-76B6BDC8FDC3', '4600338008455', '  /  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0547664-9994-43CB-9027-754409E45881', 'E687C0E0-67A0-4562-9F3D-BDD51C5E37CB', '4600416011865', '-   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A6F3339-217A-45E4-BCCF-AB78495469B6', 'C90220A2-2065-48AF-9CA6-13C39F2AC71C', '4600488003355', ' 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BD00791-EF24-4C65-A535-F102BCE1ACA8', 'B1CD2A1A-0E56-4089-951D-3ABD159B79FD', '4600490620236', ' nutrilak   0-12  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24670B3F-A69A-43C1-8A50-6DDC5D65DF80', 'E6C8568C-CB43-4777-993D-6FC60C84CCB7', '4600561021122', ' 5    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('935A81B7-A4B8-4750-A51B-C96B05F06372', '9B0D7ADA-6502-4C91-B771-8BC44865195D', '4600689601978', '   -   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E47165A3-01A2-4628-8A6F-5F41507EEE9B', 'E8F2294E-DFD3-49B9-8DA1-96E894460F84', '4600689601985', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43D41F08-E843-42DF-9E9C-10215FE20C2E', '9DCED567-2257-4B62-8CBA-90159162C7D1', '4600697101927', '  4*100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('525F33BA-C221-4DDB-A59C-7A0221181118', '3B9E449E-F8A7-41CD-8934-1E0512778005', '4600697101972', '  -  . . 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EBB391E-E590-490F-97B5-F35C0B58738D', 'F6FADB8B-AA4F-4884-A367-43CE1E5E02FC', '4600697122090', '   -  / 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29A72300-9619-4069-9D42-51337B8262D5', '99F950B9-AD5A-4C5E-AE0A-FF26B8150E3B', '4600697171043', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98902247-9512-427C-B518-AB04688F4AB8', '85AD3496-A72E-4E86-A2C5-CBCE234A845D', '4600697171128', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F810CB4E-0FD6-4332-8D93-3BB1BC5D10C2', 'AFA3F189-4E26-4004-86B9-BF6DACE91FAA', '4600697174242', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4EEC778-0023-4361-9B57-8945AB5AB548', 'EC1FFCC4-8DE1-46BC-8DF1-A9E0C0FD3571', '4600697174273', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D87C6B85-F41D-46CD-8619-788842FDC30C', '1F3445CF-F4CF-49BB-A3AD-116A2EC4A926', '4600697192598', '  /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('786A4A3C-B139-48B9-BF76-BE9354500BE1', 'A44E3E5E-F275-4EDA-9581-D703BA8599D6', '4600697192628', '  - /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61FCEBE6-B4B9-42B6-82DF-6563DE4759D3', '6DDFFA69-A78D-4ED9-B760-676A260AE825', '4600702082371', ' . beautology /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9D3CCFE-00D7-4C6D-B596-464CB9D6CCE0', '49A54DEE-51D4-4CEF-95F8-EDDB7ACA1210', '4600702082395', ' . beautology /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB2FB010-C043-4768-8CA6-486D3932FCA3', '3EBC7B47-D198-4140-AB36-30B92B3BFF71', '4600702088250', '    forest balm     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6F260EC-BB95-49BD-9FDD-C3854CB949EC', '362A2C18-DEBB-4521-BD3B-A15BA7BCE225', '4600702091830', '     / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32FD8B82-EE09-441E-89AB-BE8FD664D44F', 'D6AF2CDD-5C15-4CE5-845E-10E6E5B2E363', '4600702093575', '        1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90D53825-C82D-4D79-9AE5-53E2AAD54515', 'E5C134A5-CA88-4BE2-A667-3190EDC26024', '4600702093803', '    - 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E272535-E828-4FA7-862D-ADF338124674', '59F4450A-9304-4EAC-9E90-1B69673713C1', '4600702094930', '      2  1   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF82F96D-09CD-4142-80CB-F0F667CB684B', 'EC4427EE-5324-4CA6-98FC-9D3CC4501287', '4600702095531', ' 100 ..  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EED2880-5809-4DF0-9B87-A8F98882257F', '398BB1CF-D7C5-42A9-A683-DD613EF22CF3', '4600728002896', ' ..    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7744C938-5732-4AD5-A2A0-E685B85BCCF0', 'E92C065D-45B8-4FCC-8869-88C28061852C', '4600728009260', '        90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F998890F-DB4C-486C-B28D-C132F7BC2F3B', 'A59AEB41-F01D-42D1-BD50-2ADABA01E9D2', '4600828000327', ' 4  / 5  5  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('776A4F7D-0017-4055-8B74-987C2EBC2F53', '84FBF3C9-4BFD-4018-A740-EB0872619140', '4600828000990', ' 300 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63B41F3F-684B-4E81-9CE7-2948AACE5016', '19BC8709-6589-46C6-B59F-841A4654A08E', '4600828003878', ' 1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88EA7ECA-6B5E-44CF-B46E-11C972D74EFE', 'C0730F25-0E45-4A6F-AA69-DAA6BDDE3E98', '4600908020719', '-111 //   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCCE7A8C-03AD-4CE2-B175-AAA26E0F37CB', '461DB779-1798-4A61-A72C-F011C99A5398', '4600908020818', '-121  / / 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28F6A282-6675-4485-A366-A25AFF1AA9CD', 'F4843659-CCA1-43DF-8E17-C53E93CD03E8', '4600908021655', '-307 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62147503-345A-4AEE-B514-74924BCCD27C', '473216EC-EAEA-4BBD-B2DE-69727E46ADC8', '4600908021938', '-307   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('730BB28A-0491-439E-8E22-46CBC331729C', '895CF435-DA0B-4471-BA17-6133E6400228', '4600936241230', '     124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87E00E8C-2412-4974-9E0E-3172D25F8C27', 'A1F0FC2D-68E0-4759-B99D-338973740C89', '4600936252045', '  - /    // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78495C33-F671-48CA-A348-CE9E34282107', '1FA50088-8E78-4FF3-899C-0B707C47E14B', '4600936312121', '   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('577604F4-2A7E-46C6-811B-1A37EA19B90B', '03B15018-761F-4617-A78C-742445921A74', '4600951000126', '  /  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4789472F-820F-4A01-B8A2-2B8220A1C547', '1150487C-BEBA-49D2-8300-3D73205E2476', '4600951000966', '  1 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B476B432-93B7-470B-ABFD-D39F043D5BC0', '302CF21F-CDEE-40E6-BBD4-D6945DE319F7', '4600999011306', '   25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88F868A5-5047-4E67-A7C2-2ADA1605B358', '56E19AE2-0F7B-4C78-BD16-8EC1F5D69641', '4600999011894', ' aura  ultr comf +  /n100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0954D40-2B35-44B8-801C-D2D816C6E539', '45B9D42A-0D7D-426C-9F09-DA03C1D3CDAC', '4601026307089', '  350  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C66DE94-FD03-4427-B55C-634A2090D122', 'ABAF51E2-DBFF-40FE-AEA2-19661DE70041', '4601061101093', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52934668-34DB-4135-BC83-EE75A459B527', '19911170-918F-4514-A007-5710CDBDCB3D', '4601061101260', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71505F37-4599-46A3-852D-A0BE880274ED', '34EBC430-949F-46D9-9488-B7CBFD95C1AB', '4601061101291', '      22 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F422B25C-0B1C-4459-BCD3-375E3ED8CAD6', 'FBF6AC98-CC73-43C4-B2CD-E505FA0089DE', '4601061103608', '  meed -10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5495AA1F-3170-48DF-A8EB-100F5A299061', 'D731030D-EA70-4A04-84A2-A6E412350B52', '4601164001382', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BADD710-D093-41DB-B767-A2F80225C22C', '482F95DA-3947-4E89-B7E7-18C9441C0B7D', '4601164001498', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('703359BF-8FD8-4EFB-9252-2F90583F237A', 'C65C270A-B86C-48E0-8F81-8D8730FBABE9', '4601164001993', ' -  55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F46CC6E8-3538-4DE5-95BD-1E17B713C2E6', '9D5A949A-EBF0-410F-A9A7-E6A13A4816C7', '4601164002433', ' 0,4  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE3D70F8-BD04-4352-A7B3-ABA70EF04EF1', '0625ACB0-C29D-4F43-92D2-93435AAFEF30', '4601201011039', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('026594D5-4362-4BD1-A10D-7B075F88F4F7', 'FD1F9052-B926-4CE2-9D71-4D561037ADEC', '4601214000037', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D7F6F83-E78B-43F4-8842-D729F39A7BCF', 'C923DCC0-F8AC-449E-A946-09929741D1C4', '4601214000044', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDBBA64A-585F-4725-9BE6-E14677E4F663', 'FFB79E56-8CDF-4160-B87A-0E4969F9D804', '4601214000051', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F92E85F-98B3-4367-A1CE-A1DC33FDF14B', 'C73F6A15-8DCA-4E7E-8254-0BF629CD1737', '4601214000174', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('075FAE2D-810C-4606-B85D-64366A7BFE35', '48631F28-3618-45F9-90BA-4B3D439839E1', '4601214000259', '  / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9ED0DAE1-9B85-4E5E-822F-821E4F95F176', 'A55093B4-7AF1-4010-B2B9-CD7B653D288F', '4601214000303', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A2842D3-8632-4EDD-BF96-DBAF5B09E7B0', 'E1A6880A-04B0-4891-8F92-206AB17C7C24', '4601214000860', '  // 3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E091C99-8D7C-48C7-BD2A-1137CB950B38', 'D4C8E1F9-FAD7-48BC-ACE1-D48BCCECE427', '4601214001065', '   . 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C531271-7B5B-4A95-B6A2-C8F4D62A6FE3', 'F4FE025F-15F4-408C-993D-B599C38E460B', '4601214001737', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D1C4FF9-DC5B-4CCC-9422-DCC315A1D610', 'D3267CE4-0067-4AAA-B7C2-76B1BA7CBF68', '4601214002772', '  /// 2 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C867D95-60ED-4F29-8559-9AC1EB0F59D3', 'ADF4BEF2-90B7-4ED0-8510-2909F4843156', '4601214002857', '  / / / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3C3B37C-F0E6-4F10-9DB1-FC13E61A3C4F', '0D9E8A84-580F-452F-B8DA-03B2A5B1EDC9', '4601214003090', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9785979-F12B-498C-BB8B-F8935D3790C8', 'F2F3C922-1687-49B8-8BFC-60B51081ABAB', '4601214003366', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D170722-2FE6-4E11-AFFE-D15CDF957EB9', '35798508-2F72-4A8D-B49F-CD839E78280F', '4601214004820', '      / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93388995-4C49-400E-9E23-F497AA5DB380', 'D141900D-FF41-4E3B-9979-E922F45AADB6', '4601214004851', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28A22F18-E6FB-4931-A46C-C575BB8BFA1C', '7BDE8363-0143-4036-A773-AD12B2E31F94', '4601214005018', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0A4330C-1F72-473A-A276-4FAB67367879', 'ABB9052E-F1F6-45E8-8EBB-3AD60777ABCC', '4601214005056', '   /  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45B74F2B-1612-43A6-B162-D9EE591336D6', '441F10DC-905F-498C-8C37-11F9E592ABD8', '4601214005339', '  // 1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7374BAD7-10A8-4788-894F-13D2E2DEEDD2', '1CFBBDCC-732B-4A45-9E04-95637A3C34DD', '4601214005643', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38DB488C-285D-43F1-8F0C-B7B8091C7D3F', 'C21DE544-A30C-4854-8794-5B0C2B8E2274', '4601214005797', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E6DBD73-3E05-4B4D-8E66-4EB88AFA2D9F', '24BF20B1-F87A-4DE0-874E-0A846465B6CB', '4601313011538', '   / 280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8B28860-FC08-42B0-8BEE-5A4699823187', '657422A1-BFE8-4B87-AABF-8C8E2249AC42', '4601420002092', '   znse  1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFEAF93B-1E3B-41AA-B5E4-E4249F552513', '112CDEE9-F19B-426F-8F46-8840F41EABA0', '4601429000884', '  20% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94E87C93-63B8-40E2-8FC1-618718B59612', '7E8439CA-69AB-418D-B0B0-41BA3BE65286', '4601437053735', '  /  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33FDE3F9-BD11-4666-BC11-A4EFDF4A5756', 'C6B916CC-B39A-4821-8380-62E038FF1E14', '4601437053759', '  . /  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDC13B68-EEB8-4A56-901B-A9194C030053', 'A20CF88A-D7F1-4FA9-97C3-3287E2D44F4C', '4601498003885', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19CCE4FF-3387-4C1A-AEF5-39A12D3A1A89', 'A0E326B8-A409-419F-9F4F-BD7722AB2188', '4601498005469', '     1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC457392-9B98-4CF3-9D1A-AE2ECEAFC86E', 'EE8E8D45-091D-480E-BB9B-55AEED8D1C64', '4601499000456', '    160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBAA090D-29C5-49A6-B3F9-AD8E90F7B0A6', '283252AA-A77D-4C3D-A78C-72AE9F6649FE', '4601499001835', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('962BF431-8BA5-4EE7-BD13-C133F9C50855', '7A1FB02D-51F1-4BCB-8F1B-BF446259DE61', '4601499003235', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98062667-6640-4B25-AE75-2DCC1D5122AF', '765BA803-5355-45DB-8931-0AB5F3C00598', '4601607000149', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C8E7E3F-EEB0-443F-912F-C220586A6C24', '8997C703-6DA4-49B2-828B-E1F45EB99CC5', '4601654000048', ' 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98F9C929-F2DF-4085-B01D-604B582235A1', '9D5243E8-4E97-44F8-BFD6-86D278DF7760', '4601654000239', '-  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE414F38-0EE1-47FA-863F-0F5FCA42FA5C', '106226CB-06A2-446D-A23B-D26B5A6245A3', '4601654000536', '- 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E7D23BA-614D-4173-9CC5-5865C761B03A', '0142F1BF-571F-40DD-9C7C-81A65FAE5A57', '4601654002981', '     650', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A38FFF9C-2D43-4E15-BE3A-EEA85D745E08', '68641EFC-A90F-4001-9A34-EC78B6B1265D', '4601669000620', '  0,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A668461C-D164-4C44-B310-373E2651B0AF', '8C0C11A0-7E60-4C4D-9A16-CBF34EC4AC97', '4601669012272', '  150+30,39  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73032987-5520-4506-BBA8-8E1FE7923B52', '697A32BF-2EDF-47E6-B868-9783CFA221E7', '4601687000121', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62C94CFD-6133-46DB-BA7A-7453070D0D0C', 'DA591EAA-8B6C-4A59-A913-8B1EC90AA9AF', '4601764001379', ' .  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC88DF1B-0021-4469-94BE-EC6E87873EC6', '55CDBB0F-2A3C-4D37-98B6-D1EAD8595F78', '4601764002024', '  400   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAF96809-D72A-4E13-AD36-F96098184809', 'F3DFF94C-AEF0-45D9-904D-3ADFFDD39C55', '4601764003243', ' 2  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('961C1957-F11B-4584-B2CA-39761BFC79FB', '5F857DA0-283D-4B27-8B9A-4E68FDE10ABB', '4601764003977', '  /  0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EFB7DBB-D649-4399-9C3B-8AFD53E89A0A', '7F7F68DF-215A-46E7-825E-03D4C42C566A', '4601764006060', '- 20%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9803DDE-B087-4233-AD93-CAC89B6C53B8', 'AA477272-45B8-49FF-AA42-26A897E536CA', '4601774005671', ' -  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE798279-3145-4C53-B26B-D6642A656AB1', 'DC09C34F-FBEB-4C74-853F-B18351BCE9C4', '4601774005909', '    1,510   -305', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31B286D4-9C0A-4082-BDB3-B98046785E15', '8604B8F0-D2E2-4C57-A3F3-1E72A7610E67', '4601774006166', '-    210 / 306/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58DAE48C-7C26-4838-8F36-B0E21059B5B0', '7B566CE7-6A77-49DB-8E5B-F93EC56D1843', '4601774006241', '  -. 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03CFF241-9243-4D95-82D8-AB4231BFF646', '2E6BC582-CAF4-4657-B39B-362AB4F767AF', '4601808005042', '  100/  3 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B037E1AC-1051-4C17-AAA6-04ED847A74F8', '11C53A7F-3583-4E71-9DE5-D2BD594DC7C5', '4601808006995', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E443B0A-0C51-419C-BBE0-251BF18337D9', '046BEFD9-50CB-4A7A-B90D-7789383B4053', '4601808010459', ' 1  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68BBFE7C-4C00-46A7-98D9-FBE3508E9D57', '1EAB7AFC-C621-4D94-BD23-2093D47B0CCF', '4601811005466', '  -     3,7-4 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F60C6902-EF1F-4E2E-B0F8-DBB88510741E', '1D435B8D-3192-47F2-B1ED-C3839AEAA7A8', '4601834000264', '  hi-tech Sensitive // 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2C0C07B-E95A-4E65-A265-342675DF5F07', '61EFD809-8876-4F5A-82C8-EFE3C744833B', '4601834001599', '  large / / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C107DE1-9F1F-43B4-BE53-90016A309681', '4A28AD93-7ED3-48B4-96CE-8C3101F81F22', '4601834002626', '  hi-tech  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F973A33-563B-4680-9900-9931C77FBADA', 'FD9D565D-FF8B-413B-A501-0972427CD3A1', '4601834002725', '  elite  light 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CD706B5-85D4-4164-B437-7C8B5681C270', '95A04AB6-5FCE-451C-9C7C-E3DECFE72313', '4601834003524', '       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A315A203-D1AD-4DC6-AC48-F93798CFFFAA', '4855CD8C-5448-4FF2-BC9C-2DAF64007D7B', '4601834003562', '     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A38D69F5-C031-4C8F-97E2-F55576BF9A5C', 'E43DC00C-E69C-4AC5-904D-EED0CE70E1FE', '4601834003715', '   7  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1E437DE-F233-4975-8EE1-99719554CEBF', '453EED07-75EF-42C9-AC61-54B45FB736F4', '4601834003944', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFE18088-E716-45A5-AB18-50F6F79CBF7E', 'E88531BC-848F-412F-9443-127EC42F3F8E', '4601834004644', '  hi-tech  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE099D48-942F-49D3-8480-3927B4F94BA4', 'CE1BB009-C1C7-4A9C-AB24-9D24BF31C6F9', '4601835000010', '  1 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE0043F8-5256-4CB0-A78E-8737AA2C196E', 'DC13F46A-7203-4156-9E4E-E4C11E800DAB', '4601835000270', '   1 - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('638E1BA6-FB5C-49E8-895C-7314F23E01AC', 'A5D286D0-34D1-4B1C-A29B-9BE8E5E1E473', '4601835001116', '  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDF6E694-2164-4F43-B54A-EE5F15E86465', '95A53EDB-E718-441F-A5A0-54FD922C9D01', '4601909000045', ' 1/   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B027BCE-D59F-4226-9CFF-2B318B3D7DFF', '128F525C-257C-40AF-8AA7-9453E523E49F', '4601909000052', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6664BB8F-2CB4-478B-A5A0-9B8EEC2E728A', '059B2705-0025-45D9-A47F-E8A8095F08FC', '4601910000072', ' 213', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('791D9F59-91A3-46B9-AA34-C2EE35638B6D', 'ECD7D291-0A25-4C1C-A8D1-A8074E5BBB84', '4601910000461', ' 75  / 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C72F3AEF-D269-46C2-AF61-0BA10997F7FE', '19063DA8-9E91-4740-A398-0339540B09EC', '4601951000628', ' 2500/0,2  - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4614E9B0-005B-4C96-A1D9-CD70E030051B', '94883830-D40F-4D0E-A458-E4EE128119CF', '4601955000389', ' 25  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04B8311A-04AF-43E8-87BE-209BF95FEE51', '52CC8615-67D8-41F0-BBA3-489481DF42FC', '4601969003567', ' 25  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ED03FA2-8DE3-408F-958F-998C92C20B7A', '08CC73A9-F254-4C79-9753-267798D7A471', '4601969005455', ' 6,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFE2BC6F-5B91-42F6-B36B-6D7EB96E7500', 'B21B10E9-D209-4A42-BABF-9527CC97DE3D', '4601969006766', ' 5 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A53015C1-827E-4B77-9381-1E5F3771B2FA', 'E98EA880-187E-4CD0-9775-261D52C28D75', '4601969007459', ' - 0,1  //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F4D36AF-6512-44EF-B5EF-0FFC3041CD8F', '5045BDB8-498C-4B0A-9F31-D1ED5BAFE898', '4601969007695', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D0021EC-AD7F-4366-937C-695B1B562345', 'D91D44EA-1B26-4823-AA8F-722DA24EE010', '4601969007824', '- 0,12 //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9E130E5-496B-4843-8841-4D2EFD9CC9E3', '51CB1432-8240-4DC4-8C05-491BDE5F4955', '4601969008036', ' 750  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8498C1F-216E-41BB-8390-A2B3E1D8F72D', 'FBCD1B38-6F47-4F68-AD5E-EE276BD7FFAA', '4601969008302', ' 850  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DC456FC-2384-4238-9DEC-9115A2F8E98D', '77C63829-A861-4F28-9A9F-1634EDA85F99', '4602009360107', ' -  superoide dismutase  40+50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B06A2D1D-8B0A-403D-BBE5-C8E12981C68B', '2126801E-6A36-446C-ABF7-455850230D6F', '4602122000140', ' "" (-01 )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('041646F0-8BCF-46A4-8CA1-547B03FDE56F', 'E4A20B40-3E82-417E-B6B3-AEB9E550E403', '4602159016565', '      4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43ECC762-4853-426E-95EF-397977692DD9', 'BF4422D8-E436-440D-B9E0-5AA3CBAF0C28', '4602193009981', '9   /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECB9138C-9EAF-44A1-968C-CB264BC2CA8E', '21EB5580-7BDF-43C9-84A6-CBBA60BD1F3D', '4602193011502', ' 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A695FE7-0FEB-4A6E-AEDF-1F4AB530D3E5', '9C9BB25A-3B79-4312-9C84-5426E69AAE24', '4602196004105', ' 500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('081A8F64-6D50-414A-B65C-85B1247B1079', '8E3C0AD0-B5C6-40B0-BA69-26D834DDEBCD', '4602196004358', '  / 250 30 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBE4DB88-B002-41B9-B8C7-D4EAA99C9138', '92FDFC20-6E61-47B1-A9FD-4C63F6C1F3ED', '4602210002988', ' 2,5+1,5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26F1B24B-5AC2-4E96-81A2-1B9DC5B35E3E', '1BF3BCD8-E822-43EE-B9D1-1E4E1C6E1FF8', '4602212003532', ' 5/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('447F7200-B500-4788-BF5A-562448B0ED26', 'DC2B429B-90FA-449A-A4BB-279A847D72C1', '4602212007028', '  4% 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6852C4F9-1516-4A03-A52F-FAD4E0B83523', 'E21DC91A-2B1D-4DFD-B6B9-63FC03382C74', '4602212007448', '  1018  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B264688-98ED-46EF-B347-ACB82D7C3E95', '2280557C-E7CB-4D02-A307-334CEACECDF9', '4602212008506', '       72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22115ACC-CB99-4363-83E0-B15E7AD4185E', '8D419AEE-6227-448A-BD37-569BFF760F91', '4602228000372', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99BB37F6-AB95-4011-B003-B8BA05750B8C', '46907EAC-757C-4DD6-BD26-148A26908A40', '4602228001744', '- dure play  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('225FFAE7-C944-4929-AE0C-106ACFDEE6DF', '5FF7896B-F605-4C02-B0EC-28CF666B112A', '4602228004691', '     6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44296DE6-F62E-49D3-8440-C453D9795046', 'B431AA01-D8B1-43E1-950A-60C4BCE65AF7', '4602242002468', ' 0,4  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A60BEBD-E56D-49E1-B0A6-81413962F94F', 'E5701352-4707-48F5-BFB5-7845471B9D59', '4602242002840', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('516B8EF0-5C7E-48E1-8865-EA13C468EB1B', 'C5F2087F-77AE-4F04-A64E-26CFB8ED4084', '4602242004981', '  / 45+- 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF121A86-A39D-438B-8CF8-DBD2ACA4810B', '47234BBA-C72C-4C05-91C9-EAF7177BDF11', '4602242005407', ' - /      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('906B8B34-C220-45F8-8EC7-052FEB260F92', '9B8B6B7E-0B4E-405B-8268-CDDD466A6C3E', '4602242008460', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FD129ED-1FA1-4C32-A85C-585A2C00815E', '73FC3A1B-0279-41DA-BD03-FE2E8CDC2CB2', '4602424005027', ' 10% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0470C925-6AC8-459B-B0D8-8F4A78E596F2', 'F048FD91-863D-42DF-BC6A-0DCB408A1F6F', '4602424006703', ' 250  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC072B07-F143-45B7-BA4A-DFF46BBE0A4E', 'F048FD91-863D-42DF-BC6A-0DCB408A1F6F', '4602448007212', ' 250  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82E2A37A-EF85-4D04-9459-D35732812B92', '2FAA537B-C5DE-4284-AAA0-BE98A3AD98D4', '4602505008930', '   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE86A6D8-A102-46A7-BEAC-01F6191CFEF6', '7633A999-E46B-4BEE-879E-849620EBA87B', '4602509000336', ' 10% 400 - / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('961F181E-DEE0-4C1F-B789-060A670E2F57', 'A4EA0CA2-540F-4CFD-A3FF-09C55B192A9C', '4602509011417', '  100 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF1D97B1-258D-4FAC-8095-195459D57E16', '1B849F36-7F8D-439B-B4EE-993F105BF09E', '4602509019376', ' 50/ 2  10', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('438712AC-FDA3-4D1B-B605-5539515CB798', '9E8BB9D0-1E3C-4979-9B8A-24309BA40B02', '4602521006811', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('501B3C8C-8FFC-49F6-A588-CAB1639DF187', 'B9C17363-740C-4D02-8B86-23BC405857D5', '4602565005665', ' 1 %   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA23C8DA-AF7D-4776-9760-2CF72EA094D6', '1BF26EAF-189A-4F87-B6B6-24817779D9E2', '4602565011291', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1922D59-4707-4F9F-A306-380362F351AC', '34A9CD97-7167-434C-9228-4D6C9A60A424', '4602565013097', ' 500+125  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96118969-3634-4DD4-9A53-BAFFEA62CAFA', '1ED6F060-6066-4AD0-B247-A37388853988', '4602565013660', ' 100  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90649BBA-E0B8-4785-913F-087CB31D163E', 'CFD7F58D-5185-4572-9630-7082F94BB9E8', '4602565018726', '  / / 0,1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC0B2F24-730D-47D4-94DA-C359EE9790C5', '2A884531-B62A-4A84-A9AC-D841F9DCA6B7', '4602565020132', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F409C7A8-BBF1-469D-867C-51692738A9EB', '55617B1E-8AF6-42C4-BEF7-0BAA8DD98423', '4602666701800', '    - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC7E8BEF-4256-4A1E-BFF6-AF28A23024E9', '4557A5EA-55DA-47FB-8DE9-0C513B627F59', '4602779004027', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D61DFE4-A3A6-42BA-B45F-9D1DBE95932C', 'D51C9BF4-DC21-4038-9786-BA83FCD73FF8', '4602824000257', ' 25% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58B72737-7DC0-467B-9936-7EB976655D3C', '110AFB7B-FC1C-48B7-A844-D416C53FE435', '4602824002657', ' 24% 1 - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB614C76-5105-4D40-96E5-E108B7277726', '466776DA-EA0D-44D2-9D4C-5C1EB367C092', '4602824002664', '  0,1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8E13A9C-6A11-4E78-9633-FD1573038035', '8F4650EA-08CE-46DD-81BF-1B5D71CC27C4', '4602824006549', '  5% 100 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EC25FAC-CD30-4944-9584-DA16F56AE942', 'EA39C43F-E726-4874-8EE3-A7EA4D16D3DC', '4602832000249', '   / / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6B4035D-3CF6-4396-B4E0-83DC2BD4216A', '59F79894-DAF6-4FF4-A89B-8BE53D00DD6B', '4602866064750', '      -8518 XL', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24866E9D-C5D7-463F-B260-28A76EFA6393', 'D5416C87-1AF1-4324-800C-7B3535322852', '4602884001799', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F252FB02-0C04-4BB8-AF1C-B412E339DF5D', '187841E3-F949-4297-BD01-475112CCFEB8', '4602902000780', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F980137F-6955-456D-BDEC-CC56CEA9D9EB', '116F19EF-B45D-440C-AA44-2037F39CE457', '4602902002043', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F72E23E3-8090-460A-82B2-C303A056070D', 'BD36A783-7012-42B1-8252-8FF0489FD28F', '4603014000149', '  0,31  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('216A5DCE-9B01-4458-97A7-7E72BA0597F3', 'A89D3B1A-508D-4042-847B-DC115256FF27', '4603014000996', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30A96DC2-F076-424E-90F2-82E268C21240', 'FEC732A1-F266-49D3-8CF7-9CB7E3616B5F', '4603014001788', '     / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACDD7898-3E40-4BD4-B6CA-CD8009520860', '7B98F3A3-0617-47B2-99EC-D9BC3476D8EE', '4603014002006', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C7D430C-777F-4FB1-AD5A-CC85E6BDA125', 'DEF4601A-84D0-4C25-BCCE-5C0B22AE5259', '4603014002570', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10440854-07C6-41B0-BB35-51A6C9FCB136', 'D8CB6A50-41D4-47C6-B29F-3AC9F6A383B8', '4603014004796', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CC99E83-8A6A-4FE5-9F0D-CB0346A106FD', '2F292587-39E6-4DBC-8341-A626AAEA0ECC', '4603014004802', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AC917DF-2F78-4014-AF52-896A723F7A7A', '3204706F-B4F3-4040-8B8F-1B5BCE3A0D34', '4603014004901', '   juicy / 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63651920-6835-4046-BE8D-DBB9FA0DFA3A', '0A4F9B03-1D25-4B42-8D10-9505986384D6', '4603014006271', '    2-6    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05C81B23-B37A-457A-A47A-D60E5A06FA76', '0853D049-8A53-4F99-A43E-3F386955507C', '4603182001023', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3349012C-F30E-4BFC-AA1E-B8A21520BAA7', 'BB9A2C04-541E-4548-90DA-E53BF1A4C73B', '4603182002822', ' 110  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC17A382-8E1A-4102-B8D2-36F5CF8AA686', 'DDBA8738-6D27-49D9-8E2F-EA3DFE34A800', '4603188000358', '    // 1 -5 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8613A273-DA80-4FBA-8CCA-A2A1C363CF29', 'D2E58736-0D3C-4651-871D-5EA5491FF97C', '4603231002339', ' - . 1  . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE0255B9-306E-4D4B-A209-4DD416CCFA5A', 'AAD0356F-F10B-4F36-B29A-E91F52510CDB', '4603276003704', ' 0,005  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37C2E66D-7586-4276-ADC9-56E9EF7FCE37', '6E8178E0-F4AE-4021-B299-F470AABF69B8', '4603276008129', '  0,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0BAA2D3-D9D6-4565-AFCE-E79FC4EFE711', '843B44E3-A70F-4153-8437-7441076E44A7', '4603341000140', '   1/18/25 (12330291)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('177CFFDF-0F07-4731-A20F-93DAC63762A9', 'E60ABA12-F371-4DAA-A1EF-7513D56D03E1', '4603373005021', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('843AF939-F03E-42C1-811A-38186AE6E52B', '8831AA73-EB2C-4481-851E-F510EF96578A', '4603380000538', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B980EB1-1C8E-4C09-A9D8-A330A5C2904E', 'C1432C53-8DC9-49C0-8CAB-5010CD6FE1F4', '4603380005007', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('667CC1D2-985C-4FFD-BF5F-38B8F01D2415', '47E228CF-CD48-44E6-B195-BE280F9335DD', '4603380005212', ' 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('247DB60F-227F-402E-84B5-B8E0C8D1F1DD', 'EB43D32B-AEEF-4F8B-ACCE-9AEE8D8CD5E0', '4603423000174', '     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3340FDB3-2135-4226-A443-ED6724BA5293', '7E9EEA3E-9DA3-4872-A430-1987B27DA009', '4603423002857', ' // /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7FD6FFE-0326-4AD7-A0FB-7F7629AC1290', '80670EF4-0924-4EE5-8B4E-8F52508A9E77', '4603423002963', ' /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05E13390-AC1F-4564-8650-6B2B7F777EA0', 'ED226EEA-BF61-4C72-B312-F49B0872A421', '4603423005582', '   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4562C8D6-A009-4608-BCE4-561E8DBCEE9B', '8AD1D200-E23B-41FA-941D-D4EC990FB62B', '4603423006398', '  / //  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C5EDF8D-DD42-473A-B70C-1ECC1F270A39', 'BC1FFC07-A213-49E3-88EB-E5D9ED5E6279', '4603500180850', '  /./116-120/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25A33C2A-BC5F-4ED7-936D-8A6FBAF6BE45', '9AE16562-B22D-4C94-B528-3C34650D9A28', '4603569540015', '   600 / 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD1EAACF-D3FE-45E9-BF06-A024750BC12F', '05813E28-62BB-4721-8CB6-0A0EB39D403F', '4603583000144', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('867686C7-9528-442D-86D8-A9B823AD648A', '9979AC7C-7793-45B7-B478-5AC4FD118F8E', '4603679000812', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F692B99E-33CB-4158-9C12-AF916B2D4399', '745FE21E-C4E5-4B61-9D96-68610FA00231', '4603679003745', '   1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D774FAC0-025F-4099-A899-63407B281758', 'E7983809-88F4-4DDD-A633-519111F80142', '4603695000490', ' 60/  /  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B293032-0044-426E-AB1D-FA114E4EB536', '19BBCCA5-5D09-466A-A779-4D58C5567247', '4603695000575', ' 600  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C10E08B9-116E-4FB8-B944-00E31343FF8C', 'C4CEC175-CC5C-4A55-BDD5-DC6E2D3111D6', '4603713000891', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('376631D9-90CA-4357-9B1F-20C8C0351762', '0C6E1389-39ED-42A8-96BD-43EA72E7F85C', '4603720177180', '    18    1,5 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CB73F98-30B6-4046-AC2B-D1497FFE86F8', '1F842030-43D8-456F-9BA8-06D94040684D', '4603720177197', ' /..  20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E589E42B-0607-453F-A065-EFDD1D3D9F0E', 'B10A7C11-0B2B-4FCF-8FD1-5ECF44056163', '4603720177234', '    23  1,5 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3781C9B-55C5-4B6C-AC00-4151B7A1C0CF', 'AB954F58-1E51-4353-A9DC-AD68A6161435', '4603720177265', '    26  1,5 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC99364A-2BE0-4F17-84B2-C90C163A29A4', '5148860F-DE72-4255-86A0-EADF36371E68', '4603720177272', ' /..  20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C345E47A-4B2A-4F99-83CC-8CD9AB914761', '614EC3BB-2F42-462F-9337-804D6AE98A93', '4603720251095', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7E4BC04-FDF4-4E60-8687-1F2A2DF00AEF', 'B8999387-6C4D-462D-A18F-7D15ACD26F7D', '4603720937203', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B942E0B1-D635-4908-9637-0DA4E5CDAC8F', '20FBC4FA-4230-4649-82A5-C7007B65209B', '4603725951006', ' - / / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3C8A179-FC1F-40E4-BAD1-2F3C7E076E55', '27AF7CC0-440D-4A9E-AFA8-4FA80CCB4AD1', '4603726763165', ' -  /     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E02FCBA-7DD9-4C19-A6FB-34154DF71A83', '4076019B-2C83-4828-93E9-513FDC030BB9', '4603733078818', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EA8BD73-4D98-4D5D-A453-389FC0E60C5D', '100991B7-E202-4526-85AD-4020C65111D9', '4603742000688', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FAA4A6E-F913-4453-95A0-7B079FD86529', '413F4B36-A759-4399-AC3B-9B231D4A97D8', '4603750000540', '  55  /12 /  . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B84561A-E51B-4D19-8D18-7C0CC934C24E', 'B6C9BC87-96C3-4285-9FAD-01189E81D4D4', '4603762000064', '--  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E3E7720-7B1C-4B0E-8B65-C46B4139C5D7', '60ABB04E-CD32-4514-B5BF-7F7D479AD2FD', '4603762000637', '  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DBFC0C4-E10D-4C91-8D0B-FF9B285712E5', '3F52D550-5944-433F-8BF8-A8AA756EF6FC', '4603762001887', '  /// 3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('117B61F8-E681-4017-A9B9-3B8F16CFB0B6', 'FC54876F-E816-4F61-AD8E-2CE8B373888B', '4603762002822', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E405D8EA-1AD9-45B3-BF9F-58415F1A6029', 'CAC062A1-B333-4F0C-9461-FC19D03AB9F0', '4603907001185', '    250 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA66797A-DF90-4242-B4EA-9A3D03103B27', '1F795550-8ADF-4A3D-9F4A-6C1EBAF31316', '4603907002366', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12FCF62F-58C8-4F29-A1BF-36C8852769F8', 'D71B134B-245B-4404-BB55-713F4401105A', '4603907002632', ' 0,52  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A34B5B65-CF3D-4EAD-9475-F7E7830CFB3E', 'FCC8B698-477A-4D15-971B-BA37F1982388', '4603907003431', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9766688-5B9C-4B19-90A9-36F05720CD60', '8A807352-6139-4C72-99B5-ECB94277E73B', '4603907004117', '  +   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4AE1E07-FB6F-4922-9A4F-28F350B86372', '3D227E36-D5AB-4CA8-9FE1-7230609A5153', '4603907004261', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7FCA927-F1DC-4A34-A18F-09E2E7BAF211', 'CC35EE65-9213-474B-982F-D11BC1DFC62C', '4603907004896', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B0E2948-0B0A-47D8-B63F-F070752BA7A8', 'F260DE2C-EE0F-4DC1-A0A2-3BF121EE93CE', '4603933002552', '  1% - 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3715ABCB-4FFB-495D-BEFB-3BD00861E344', '0A600BEB-9164-46FB-992C-B0E33DA833AD', '4603988010984', ' / / 0,05% 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB72978E-80E8-4F78-B8B7-12ABAB2FED5C', 'A2084D94-EEB3-4D50-9140-426562813B67', '4603988012049', ' - /.  . . 0,05% 10 - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('328D26B9-72A1-4183-8F61-461D04296215', '48452FFC-5D3E-4444-ADBC-A85441A49D16', '4603988013015', ' 0,05% 15   - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C752AB0-C304-4CCB-8383-9472DD0BFF63', 'B8109F2B-4720-4090-ACF0-E7F13F061BA0', '4603988014289', '  500  96 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19C4B447-032B-4069-AB3B-E74402039F9B', '501670FB-258C-46BA-A220-44C73A836C12', '4604060002460', ' 75  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4F04787-4FAF-4481-B88D-56AD1AE269C6', '3CAF0742-782F-4C2D-9709-ED75C27C4C18', '4604060011349', ' 10  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95DA0BB2-620E-4A94-9F29-B9090ABECE4E', 'B141C470-ACBE-4646-89B9-658069B3CE28', '4604060994192', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('347E73B1-C011-4A28-B12B-BCA74185A9D0', 'E323CD74-7814-41F5-82CC-69FDDBBF1833', '4604060996820', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8366A7E6-6F53-4870-81D8-F03BC838FA87', '05936BCD-F9D8-4413-8608-F05ED25468CF', '4605052000990', '      0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('163F12D3-6A65-466E-8351-C1FE9FEB83FD', '42538F91-3B0B-4B80-9491-BC48F89E8327', '4605059009460', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('012D14BA-FCE8-4A1E-9581-9A5D4FA05919', 'B4675C8C-8D66-4F0F-8C4B-AC4794A90504', '4605059012682', ' 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3A22499-524A-4EF1-85D3-7E6E06063A7C', 'F2A4186C-59FE-4B70-9DF2-8AF677601E4B', '4605059016468', '5   /   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F5F4AE5-51A7-4EF3-AFD1-27D8C4B08B53', '60951C43-DCF2-4F90-BBF0-C902261B367A', '4605059019599', ' 3  20000   - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E450E4E8-2112-461A-8CA7-5E3921E4D9BC', 'C86BDC64-1AE8-4C14-A775-87207F272195', '4605059019940', ' 5    /    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1004E083-2F24-4799-B2E9-65B5DA8C83DD', '94232B60-DAD3-408C-8DFC-B09CF7BA27E0', '4605077002610', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B4B0149-FE36-4528-9AD6-4D69D131F6FF', 'BA09B2D3-520D-4870-9C1A-46DB1C78A8D0', '4605086000010', ' 38     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD9E6FA9-360C-4D2B-ACEF-04358F32EECA', '256DE00F-F2CE-4B96-BE21-3D1CD02BF369', '4605086000263', ' 110     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F175421-0790-47DC-9A42-C4A390DF1856', '06CFB2E9-D85F-47A2-9708-16309C0130E9', '4605086002779', ' / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC23AB4E-6C8E-4E89-A555-441E4153C5D5', 'E65C09B0-7652-4232-9374-E7FD768A5085', '4605095011625', ' 0,1%   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FB81498-58DA-46E8-A5F9-DF0B48576EDC', '9C00288B-4410-4086-A904-5E1D9D37E948', '4605108001452', '     0,3  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('838F63E3-C19A-40B6-B299-A703C30E0267', 'AE9F0B90-C047-4609-AF56-8A63D7685702', '4605108002404', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AC020C8-716C-4F5C-AAA2-8408D691F04D', 'C580F153-A15C-4169-A67F-B01F4C7722C6', '4605108002978', '  - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD29E26F-4654-4BE1-9045-37FF95786818', '8223D785-0161-44C9-9D3C-EDA648C51A75', '4605108003395', '   / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB79E213-6EE9-4E86-A0B5-F05BB6B61DDF', '4C9C73D4-24B8-4AAA-B60A-038D17709793', '4605108004231', '   75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E8D3DB6-3232-4D3B-899B-4E117503E8E1', '6F864720-A1FF-4A5B-94A1-1620E8CF69EE', '4605108004248', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6ED4D5A-A67F-4763-BF75-AB9BFA1B66E8', 'B9F8870F-9F8E-4FF7-90A3-388FA529E21E', '4605108004316', ' .  // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D012820A-CF0E-4414-9995-3FF092A60B46', 'E27C8689-BE19-4A62-91D8-F399A7F15292', '4605108004484', '   -d 8   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B52FF7E-3D6B-4F1D-89D2-30610357F671', 'DD1B9079-AB49-40F4-9D8E-3369A557E37C', '4605113000457', '- / /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82CFE7D1-4079-4B58-84A3-639B88E45A0E', '48EF8811-7792-46EF-A7F5-4F26BEC0E244', '4605126000246', ' 50 /-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCBDE144-A186-4E57-977B-A025F2EC4CBC', '1DBF4E14-A8C5-45FE-A537-B34B60AD2EB5', '4605126002080', ' /  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB6472CA-B0ED-4EA5-9B49-E115AF17EB2B', 'D3267CE4-0067-4AAA-B7C2-76B1BA7CBF68', '4605126003179', '  /// 2 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F30E5922-1542-48D0-A5E8-EF1EA286BA62', 'B6DD2FDA-B5C3-4B51-8AA5-E8042F7F06F0', '4605126004237', '  // 50 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3AB2739-382C-4B23-AE0C-BCCEECAE1582', 'F1B51764-529A-4E37-AAF2-8FDEF49B374C', '4605147000157', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F492D50-5DC5-4C5B-9C38-69C89424D82B', 'D0629646-4384-4871-BF0F-98E78DC6B6BE', '4605169211142', '-     55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F60ACB2-5337-4C8A-9110-083D0F4805C1', '9D24B406-C3F0-42B2-90A1-DFC79128638E', '4605176000357', ' +  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E35AFCD-A8DF-4D15-B3AE-77B215F4B2E6', 'E82DF492-A3ED-4A94-B955-50A38CBE5444', '4605185001031', '   - / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36C7A949-0163-4F52-BF1F-7B7A8A827282', '6F85A9ED-E515-4251-B791-94CC2891080C', '4605234002736', '   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('471F2889-1E91-4768-9681-236C040434A4', '817D78BB-9A94-49DC-9705-1FF038CCD158', '4605319001289', '   /   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('538BAAE3-7E38-45FD-805E-D79B8B884DFB', 'E16FE577-CFCC-41DE-9EC9-AD9C7FF4F087', '4605319001524', '115 /    135', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABD00D61-98E2-4B6F-AC89-11E21BE50117', '96983B68-25C5-4A1E-A136-D222FD5BC9A0', '4605319002972', '  / / /215/ 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D1873C4-6EB3-4898-8F2D-77E7AA42B13C', 'E994F808-1CBE-40F1-A744-338E788D0C3D', '4605319004907', '-   /   110', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AE119FF-82C9-418E-92DF-403D7CABF3ED', '29EF0155-C941-49E2-945C-1F6A383DB288', '4605319004969', '    /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28338F34-863B-4E2B-9902-32199F857C5F', '27B7F14C-AB95-4FDD-9B09-860700DB15E4', '4605319006321', '   - / 24  170 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F68A182-4C7A-42F1-87BE-65964FA659C3', '37FDD174-38F4-4E5A-8963-D521CDCB59BA', '4605319006642', ' 98   // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A06B4CD-4148-4CE8-A9B7-5BD184F5D471', 'B37CAE3C-D0AC-46A1-B7FB-3DB768737187', '4605319006826', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('117FA3D7-383D-4826-9B34-2647D4854411', '012CF7DF-4FC7-43FD-984B-238F2B255838', '4605319006932', '   5  /     450 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61288DA3-2A92-4F04-BF11-28FB8068834E', '3AC948AF-AEC6-490C-B859-E2408EE135B0', '4605319007465', '    / spf 45+160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40CBE638-2B99-449B-BE7B-6185216B30E5', '81433635-85F2-4FBA-A213-926F79C958E5', '4605319007496', '   253 /  spf15 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B96E6B3-11CF-440D-BC33-63E82B156431', '33BDF436-D1D0-4C1A-A71C-A05B3E26B997', '4605342001867', 'Dr.aqua  /    +0 / 450 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C66D523-85B3-4473-96C3-1C019F5A0945', 'D9A495FC-7C75-4F5B-B254-D184B31370D7', '4605370003970', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5F772CC-54E4-4DC4-8BC3-4B7D6DD82FB1', '585D793E-210F-42D8-85DC-072F52A9A2FE', '4605370012903', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BDDCD52-30A6-4634-8E3D-7D0C5C9C8845', '964649C8-753C-410E-81F0-BA153A7BA288', '4605446001541', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B259BC80-006B-4B84-95EA-59ED226DFA0B', '0F09EF79-D440-4FD2-9963-A5748AC0C919', '4605446001589', ' - /  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('376DF138-0471-44D5-B8C6-837608CB3B7C', '7FD86755-9152-4736-BBEB-8A19D5BEA8CD', '4605446001596', '    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53BF21BB-93D5-4F98-91F5-6F15FD4943B9', '1857A92F-7274-45A6-8232-447415455DDC', '4605446001794', '  /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C6F8D16-C5AF-44E3-B29C-7639BBF1347B', 'EBD2B977-157D-418B-A988-87E4BFB0CE17', '4605446001817', '          f 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08C4E2C9-FF7C-4C34-900E-46092DD5E3F3', '4A92730A-2CC7-4740-A7CE-E1643BBC653C', '4605446002166', '    //  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34253FE8-E4CE-4751-AA87-3249F5BEEA17', 'CF1E101F-7B48-4D32-A746-FE66FCCFF85E', '4605453000063', ' 400 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E11FF985-E753-44A4-A6CD-D312F18FCC0B', 'DFA745FF-4120-42DD-AA80-A747616C6A3D', '4605632244851', '  - ./. 130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B0EC8D4-A4F3-439F-AB9F-4B2586565931', 'F33FC1DA-FD0B-4833-82C4-4552EEC81BC4', '4605635000379', ' 2,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB54999B-B4A4-411C-9B5D-43F7A07CFAFB', '0596AD35-9794-42ED-A2FD-DF64C1647D71', '4605635005053', '- 3000000   /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58BB917C-E809-47C6-B07E-4E695A21F1BC', 'C39AC602-B4B3-43BE-90E0-D330DB4EA9D9', '4605658013295', '      250 /11139/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9693EBC2-6FB9-4D8C-A219-2912486DB6A3', 'B4815BE7-1C09-4776-8609-88E305BD17EB', '4605658120009', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5138CAC-72E8-4A33-ABF4-09CEC0D42A7A', '8084220B-F138-472D-9B61-4AFA1BF0E70A', '4605658121327', '   . . 6+1 /12132/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC0430DA-1607-410F-BDF3-FCC06AE38C67', 'B72AF616-DF74-4C4A-8D1F-0C2F4759DCF7', '4605658130671', '   /13067/ 6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC8F3A41-2354-4D36-A112-72972E922473', 'B19F89D5-5FC5-4441-9068-46031705998E', '4605658131470', '  0+ /13147/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F43C6E60-95FD-4871-83A6-F4762E9028D8', '1831FA23-D0B2-423F-9B24-CE16EB9361BC', '4605658150273', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35675D3E-E93F-4F51-B014-8C0338297AF6', '05AE2CFC-BEB9-46A4-9498-DF638F86369C', '4605658170202', '-    6+ /17020/ 210', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BB74520-DBBA-4B7F-B5CD-5FA1E2972149', 'DE1C32A6-2277-4AE0-B406-65109822F72D', '4605658170240', '   200 (17024)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CE958E6-1452-4801-A453-453C0AB4AE26', 'C6ECAD6C-8ED3-43F2-A287-33EE8747BC2A', '4605658170448', '  4+ 210 17044', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38AB72E3-3E16-425D-87A5-2C6B98A0EF24', '37EA47DB-C5CD-45F1-AD6B-484B55B79BAB', '4605658173029', '   5+/17302/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F90100B8-7528-426D-8ABC-40C4350F248B', 'EEBB8BE6-3F16-4D69-99EC-66F21E9C5439', '4605658174026', ' /    4+ /17402/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('524D497B-AB2A-444E-BDCD-B2F68B54C7EC', '5929336E-4CF8-4AD9-A08D-C0B74288C2DD', '4605658174071', '   /  4+ 17407', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6387889A-1BFE-468E-A617-209C3D714587', '5784B475-6E00-4F3F-BF35-6EBE670CD67A', '4605658174309', '    17430 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8859DEE3-653A-4313-8BEE-8184B27A656C', '52FAF4D5-3260-4AC1-9041-575FDE8CEA66', '4605658194031', '    /19403/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB8F5D64-985C-41B4-99A5-7389E1C27DBF', 'ADA0B3D4-6D83-4BA0-BCDC-6525015C981B', '4605658195441', '  / 0+ 19544', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E62FB990-4246-4474-B065-047368F22F2A', '56A500FE-20CD-4D15-9745-86396B64251A', '4605658195687', ' /   /19568/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('732FBD9B-0FA4-4E51-B55A-F13E6765E2C4', '70D250B3-0756-4403-96ED-2F37A0D567BB', '4605658195694', '  /   /19569/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F57E594-6175-4B1F-B347-801DDB7FEA55', '37EA8225-9772-4766-85E5-C2345BDAA820', '4605658230289', '    4+ 23028', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('147C5BEB-C954-4872-8469-D6022579EB37', 'D5DF84F2-9963-4A28-9D03-4BB02F1BE353', '4605658230340', ' / /23034/ 4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9BA27D1-72C3-4423-A332-04435EC57530', 'DB62EECD-FB6A-4390-AABA-9A966BFE7210', '4605658230555', '      23055', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F11708E3-F3D4-4EEC-9CD3-B18BDD645050', 'EE7E247C-8123-447E-A06E-C28725CA6EE8', '4605658231040', '   /23104/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('681E16DF-788D-40AC-834A-1C518C6A87F9', '865D4FB4-8EDC-41B6-B08B-43D0513F7669', '4605658251130', '  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06D82E8D-6BE7-46DE-B581-734C2DD2924D', 'C68D8A34-9A56-469B-995C-46F54C1793FE', '4605658251291', '- /  25129', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F1D515F-12BD-4DEB-AEE2-CD1334A47DFD', 'B93E85F3-3D8E-46F3-A298-6031D8245E13', '4605658251314', ' - / /.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D53D13A2-F09A-4A60-BB00-61318D28EC07', 'F7CFA212-6486-4DBF-8FFF-66A78C994996', '4605738000597', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6185D8A-70BA-4849-851B-5228CDC2AFE7', 'D93E70DC-0B2D-44CA-9D69-290DFCF68672', '4605738001747', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6085389C-4A0A-4DDB-AD7D-095FF02979F7', '32AF850F-49BE-42BE-8FAF-C0A1DA79AB0F', '4605738006414', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('996E7CB2-AAEE-4450-979E-788D368E2D93', '78F95F6B-841D-44C1-9054-67243FCF4F5C', '4605738006650', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F670047-3EF7-40F5-A419-CCD5D93E58D5', 'D68773CD-297E-4FA9-99AE-6B1A131FE4D8', '4605781000193', ' 200   / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5B3DF87-1974-4613-89E6-F2635DDAED03', 'E052140C-4C13-44DE-ACAE-00E1A2EACB2C', '4605894001247', '  15% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08414B46-A60F-4790-AFF6-31B53890E077', '40A8DF64-0FB2-4DC6-9628-778908C50982', '4605894006969', ' 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FC2BEFA-C072-4F44-99F1-664936FFDE7E', 'F9D7FC41-A827-491E-8813-637DC63433E9', '4605920000275', '- 500  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('702D5E5B-EDCF-4FDE-BE52-8AA7CBB3AFC9', 'A6FA0CBD-E623-4ED8-AA29-7199ADB335F5', '4605920000480', '  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7DD312F-569E-4D74-838C-86EABB01DD77', 'EC1CA6B3-49C9-4439-9481-943790DA6A9E', '4605920000749', '  50 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFFF4EBD-6EC6-4F56-853D-F5D31265679D', 'F3008A7B-1A65-4D9B-BD8C-9E4527C8F44D', '4605927001534', '  +3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C2D238C-F35F-49AA-AE89-79A7260E323E', '50F119E2-7959-4502-A584-481DA4896411', '4605949001741', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E100647B-6E07-4BCA-9AF9-6BD9D82C2A07', '6C8C7E8E-BAB8-4C1A-B64A-B83AF2FAFCFC', '4605964004604', '   5 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03A82559-83F4-4BE4-8354-2600867274C9', '5C3D8647-B602-4597-BE94-7B5339762ECF', '4605994029165', '         50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FE7BC05-0A8D-4948-B1AA-8B4DF5B7CC98', '4B92AFBB-9D44-4466-9480-89184420DF55', '4605994032066', '  /        60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0FB62C7-0CE2-42C8-8E65-2AFF05D6D14E', 'A892C488-D1AB-49AE-A0BB-76C8BD653D4F', '4606116000574', ' 3% 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FC876A1-AE46-44A5-B951-6AF74C4AC926', 'EA8BC3DC-2C17-4B7A-AD63-BE49C586F11D', '4606249000083', '   // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6543157-1DBC-42A2-BD7A-979EE62C9145', 'E5E45531-82CA-40A5-AA0D-6AA840B1D752', '4606249000670', '    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3F533B2-52CB-48D7-A41C-B095A22C55D3', 'B5345670-BBCD-4CD0-ABB0-1EDAA372FD64', '4606272031306', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DF37549-4847-42BB-9B77-521DFE59836D', '88C7EAD6-AF8A-493C-BD2A-2E7F10A1C029', '4606371000036', '      50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70558361-20E0-4CCF-9BDA-12AC07C351A9', '531E7D0A-9CF8-475D-8A2E-5F86ADBDA20C', '4606371004447', '   35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('608DAC82-16CE-4672-9D69-8DFD4ED14278', 'BC5A9554-0BB9-4540-9CB4-9CDD0F4616AD', '4606486000853', ' 300  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('577260B0-E81E-4E71-8534-BCD437442649', 'A060CD24-11A5-48E8-885C-6DB436A4654D', '4606486001034', ' 24  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EC0FE33-3D46-4374-8DF7-1305B0B8EBA9', 'F7EA6D1F-8751-4C10-8C8A-EB82A3731D22', '4606486003168', ' 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42253D7A-B127-467B-B985-DD3AA35AFDDC', 'FE0999A5-2DA3-4AF0-8B4C-7EFBCAEC1968', '4606486018940', ' 12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D907DAA-6283-42E3-84A7-F65109030D85', 'E6ADB4FE-F7CE-4BCC-91EF-EDA0E6A6FABA', '4606486019053', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B92BB4B-D3ED-4144-8EB0-8543ED753A59', '56D73A37-7339-42BE-AEA9-88558FB8684D', '4606486020479', ' 10  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('177DADD6-A3CB-4777-A528-6E50FBC9FEEA', '41BD8C62-93B6-48C5-8CD8-E4554324FDC8', '4606486023340', '  20  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4C40FEF-78E2-4EC2-9076-6E5B95E7BA57', '7A8F678C-16F4-49F5-88B5-0ED129451ACA', '4606486023739', '- 4  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4E672CA-C26F-48AD-9722-E4F940D4FE47', 'FEA3D727-1D04-43B9-AF1D-DF4D8598098C', '4606486025290', '  600 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('684458F2-D504-4D74-ACB4-68E8EFACA723', 'C753CD73-EC52-499E-AC52-260368EB919E', '4606486027249', '  75  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28A02D8C-F6CD-4885-9AC0-00100ECE21C5', '90E75089-25A8-4D9E-94AE-8D6286058204', '4606492012567', ' 400  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67633CF9-F5F1-47B8-BBFF-5EB091BDD933', '973AB5CB-207B-4710-850B-E5C4E60E42BC', '4606666021494', 'Patricem        2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6ACF13A2-B2A0-4FEC-9842-362ED2C88A8D', '0057EE2A-CFE8-4B62-85BE-B864EE018150', '4606666078115', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB85F172-8248-4708-9B66-CC58C6AF84E8', '981B9AD1-E7FC-4B70-A2ED-B592D940243D', '4606677021995', '  65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E20A6AAB-50E6-448E-A5F5-B117B1F7A78E', '883165C5-F9ED-4AD6-BBE0-B99A77FF2E7B', '4606677091967', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1DC1139-9E9D-4BEC-B28D-12BE9BF7966F', '47444032-124B-46C8-BB50-4B60EB5B2DAE', '4606677108320', '   /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C3BC490-12A7-4746-AF4D-7BDA7CD9C08A', 'C05C5C7C-47D7-46FB-8F17-B3D73EA20EB1', '4606711704419', '  - /    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62BB0F91-A91E-43B6-B47B-F2A2D2BEB3A5', '17E335CA-6A3C-4CCF-AEE1-E01B235DE39E', '4606982000937', '     . 10/48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4281EDD3-1130-4082-8499-6D9BF9EC0AEB', '834899C8-FD97-4C80-8D2B-6197607A18D1', '4606982003143', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C39F8CA-71EA-4ACC-8EF0-9D57FCF3114E', 'C139FEE5-9478-4E1A-98E3-E13E7CE49901', '4606982005611', '      1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB2DC869-F43C-442C-A4A0-4D43FFB2D59A', 'D6456AFF-7C0B-4501-9050-D9F7400C2EAC', '4607001340188', '- 500  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5423355A-2D29-4049-9DD7-5149D8AC0135', '95E23563-FCB7-4131-899D-FCF341FEAAEE', '4607001340270', ' 0,3  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68400FCA-6B80-4546-9D20-C42B0A7DB2C7', '0D08C04D-2538-459D-AEA3-787B540328DD', '4607001500766', ' 20  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A3BE62E-E5E5-4859-8049-8943F7A92996', '29117A21-84D5-4E42-B1CC-6E64D77F98CE', '4607003241650', '  1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B2E4A1A-5D01-4331-AC15-D7505EF0713D', '5C069D54-9A1A-48AD-BC17-EE38C1E6E8AD', '4607003242107', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76FC6124-9B6A-4D2C-AD02-478A7C9E8238', 'C7C95421-239B-45F2-8095-9A8AA16AEC44', '4607003246297', '  / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A94B466F-B106-41DA-898B-7BCBA95D0DCA', '90BE6146-C5F6-4B4B-96BF-0D3FBFD79E59', '4607003246525', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F0FA903-D55B-4A1B-8F6C-0803B402DAE2', '4AFD55CD-94F4-4DC4-A1BE-F47D739AA861', '4607003247782', ' / 250 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E132FA25-08FB-4D76-A424-87B83D0792C7', 'F0A32607-F27A-45F2-913C-1B8A3DD1A841', '4607003247829', ' 50  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A89EB50-289C-4AE8-8D55-F8083ACE1ED0', 'CD55CC74-830D-44C2-BE30-E49E9465A136', '4607003247836', ' 100  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29F03022-4F8D-443B-9BBD-CAED5700B6AA', '835847E3-5A66-4218-A62A-670FB796FCA8', '4607003668396', ' 0,25+0,125  / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76146DCB-CE65-417B-8C45-AC3FF33B4737', 'A1DF9CEC-18D3-4859-BC20-D1B7DBD46390', '4607003668983', ' / 100 5  16,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29B06D74-F9C5-427B-8F6C-1F800138370B', '38CAFBB5-13A2-435B-A872-D4F7A0923389', '4607003668990', ' 200/5  / 16,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D79BBB8-ACE8-4B7C-88F3-C846F38AD0D7', '03F4EFAF-B7A7-40F7-BD01-4C92E5ED901B', '4607004311000', '      25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09B46074-BC4A-418D-A09C-74B964765031', 'D0AF4137-CC89-479B-BAB8-E454F50E6B6E', '4607005280428', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12694CBC-F4EC-4577-9537-82C67992E3CC', '7BD93A59-1A0F-48FD-A5C8-9CBBDCA9B020', '4607005930385', ' 0,05% 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46537F2F-B16A-4BD5-A050-6D79EE15D299', 'B7EB12C8-78F4-45F2-844E-AB4363F5D5A6', '4607006490024', '   4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C6C931B-A19A-4E56-A3FB-83649ABE1486', 'E56C1EF9-9092-46C9-B423-BABFD1B751DA', '4607008131406', '  600+42,9/5 100   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4C50538-9BBA-4CF1-A775-1147795FC625', '6C3A0728-1E36-4BF9-9D7E-946EC7E5E512', '4607008160215', '  dolce   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E22FEDF3-5B4D-4394-A64A-16E029C18109', '7264636D-DCA7-4B2D-9702-55BA170C7252', '4607008160338', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60DB0BED-65DC-4424-A1D1-E84D1A3E8C7D', '0F64544F-806C-4F56-994A-29C90BF9DF85', '4607008960648', ' (   )  / /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D956619-A8ED-42C8-AF52-9E857A240EE6', 'C97BDDE4-3BA1-4DCE-A813-A7F4C73E9F17', '4607009580135', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0C8B3BD-AF26-4367-9849-DAF26C4C5908', 'EFEB6410-F3A7-4854-AA61-392232DEA712', '4607010087012', '  140den - 6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0843351-2832-4A3C-97A0-E607559CA6E8', '2B44AB09-4B19-4434-8B92-422F674954B3', '4607010242879', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04BF50C4-FD5C-43EF-9134-0F198709E245', '04BC5521-4AEA-461F-AFE1-25AC2649B48C', '4607010244668', '     - //n1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDA9ED34-2225-4799-8912-FCB392DFD397', '5D92AEE5-99D1-46B8-85B1-02B420B640FC', '4607010244941', '911    spf 40 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A7CD686-84C5-4F99-BEF0-0FCB1D3AAB4C', '23F94B63-6536-4553-A22D-742FE811B5BE', '4607010245627', ' 1000     /  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA4775EE-455A-4213-9221-07211C093152', '0CDBD86F-1998-4810-A347-D6CB11CFB5F4', '4607010246327', '   . / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1B60444-73D2-4A88-9DAD-9E98FA808320', 'B72716F2-C3B7-485D-8CC1-9D3E7F3A5D5A', '4607010246563', '     . / /  .  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B38F2D7D-11F1-4E00-9721-8C509E29086D', '6E3DFC19-189D-492D-9D30-8AB520B82A97', '4607010247256', '     /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('097CCCDF-96E5-4FEA-A61C-A9422A968DB7', 'D67BB7EF-DF81-4D2D-9C97-C438CE134D91', '4607010247621', '   /    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8F24F28-983B-4EBE-9745-5BB140FF3DE4', '81235C66-209A-4097-B455-2B5EB00B077A', '4607010247874', '     1 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB7AFB7A-9C2E-41D3-B87B-4400617DD867', 'B09C19D8-3100-4665-B508-192BB7632664', '4607010248246', '  - /  - slim-lift    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C17F1B88-8DEC-4862-BF1C-23F6C613891B', 'B7032289-E2F7-4002-A15F-1B8FDEC12CB1', '4607010248536', '      / / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F7759C3-391E-47CF-8EEE-E72A83DBB803', '793D4706-277A-4F4F-9FE2-F02111CCD9B1', '4607010248604', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B81E554D-144D-4DB6-9D73-F305B67F4593', 'CD7ED2A7-44BC-4C78-82A2-025FCFC0C673', '4607010248703', '      / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('055099A9-0E7E-4035-B105-BC46CF577DC6', '17E42413-381E-4B1A-AEF0-25B28F84E021', '4607011632600', ' 0,1 ///  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77B428A5-D38B-405C-BC1F-7DDC76015441', '5BD63EA9-8CA5-45C4-8295-76560B63376C', '4607011662461', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFF6BD38-3E8B-43FF-ADFB-75A1018AD7C8', '69E56BAE-AB09-4743-8477-41F61643F2EE', '4607011662485', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7BFF4C2-D0D0-486A-BB45-F8C5B3E404C2', '0D55AF3F-F3D4-4FA9-BED2-A0C271C5465D', '4607011665349', '  /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F27684C9-BA9E-4BE1-9C61-1AF659BB354F', '9ED9504B-D5C7-4ED7-ACB9-9D6DD60210BD', '4607011666117', '- .  . / 3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E55CF88B-C74E-4A0C-AC27-D9CDD6242199', '14B0ED1A-8577-4233-8C30-47D36CF4986D', '4607011667145', '  /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C48821F2-1451-46A2-B55B-AA8D58C491B4', '69D96511-3CC7-46F9-9690-9A6B9871577F', '4607012580696', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9585E97-7CB4-4506-9261-15D2D1EF3C79', '3D512166-B5B3-4466-AFBB-EE0CC79488A7', '4607012580719', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67EA3D34-2B5D-48AC-A26B-AEAEA42A5892', 'F73946CA-DA9B-495F-BBE5-8E5BF5F51254', '4607013580596', ' 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B02014E9-B604-45A0-AB38-1B4F72F5FEFD', '9350D916-C999-4356-A862-06746580A65B', '4607013589339', '  3  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78C0AD95-01DA-4A21-AE3A-FC4FA67D26E1', 'DE415F8C-2575-4C82-9D9B-63E75CD4C111', '4607013790216', '   0,06  1200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEB30020-B436-4EB6-B1FD-76A47B5332F8', '89FA5522-9C47-4DC4-8001-822465C1516B', '4607015591125', ' - 8    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DE237D2-0829-4AA4-8F66-3A73DF7D1E48', 'A4D39182-6C83-4BD2-B745-CB3FEA827F6F', '4607015591255', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14E51789-E7C8-40D4-9402-0A6DD1562775', '4461AD13-8EC3-4D24-9BCD-47AF2FA01723', '4607015598186', ' 6060 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A9B8651-29C9-4204-9E9A-32ACE5896C6B', '266A3AEB-BA5B-4CD2-8832-9AB87C63FE9A', '4607017268261', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC8423E8-0766-49C7-AA29-C6ADCEA8E36B', '5A891B57-9E21-4B8D-B469-C1A5A34D5F64', '4607017269961', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D13D150-9ABB-4F27-AFA0-5996AB50AFB0', '563F0C79-D5D5-431D-8EF1-585DA28FCE13', '4607017471722', '  350 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('851DB90D-3CAD-4C1F-A767-0B266D25BA7D', 'DD3D903F-E041-4455-A7EA-6A664A36F599', '4607017471876', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C68CA7B-BE99-47F8-91B9-8DA6606F6867', '895958B4-7E44-4294-B0D3-E7C94BAAF4D3', '4607019010370', ' 200  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74BE5677-A042-423B-B05D-7672AFFE1384', 'FB1B5E49-4FCA-4109-A77E-258E8AFDCAFE', '4607019390465', '  202', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FBE3775-3EDA-49AB-A738-27EC48809341', '3EA7410B-FC0A-4F6E-B43F-AE0661A06879', '4607019390472', ' 10 202', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52CEC91F-7421-418E-8998-D83C7B8B49AD', 'CE0E4CBA-DBB9-4603-8E1F-5535EFEE610B', '4607020333598', ' 4  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('972A2777-EC40-4FC3-A76A-BC4FFDFD65F7', 'B3C9C77B-469E-47F2-82FC-D8DC46C6559C', '4607020641303', '    / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D49A17AB-5BD1-4033-93C8-CEFA6560BA4D', '5A89E855-CFE7-49ED-A3C5-222BA3300589', '4607020641327', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E599A361-E53A-401B-A66C-E1DAB3794CD5', 'A423CCA4-B99C-4D3B-B686-BD7DF1F13730', '4607020901544', ' 4    20 / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50CE6F2F-770D-4F8D-96B4-7A818349AD2E', '528D1F51-E3B5-492A-B54A-CB8B3114E252', '4607020901568', '  6  20 / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B99E6BBC-5017-49A7-866F-977B347EB8B2', '557CA3EC-C42D-4381-A326-9C9DE5D9D7EB', '4607020901629', '  12  20 / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9339BF6-81D3-47ED-AAA6-BA0796B2D3AE', 'E54E6CCB-32DB-4F04-AA32-266CBD747A43', '4607020902367', '  3 / 2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EAA7867-EBC6-4454-8CBE-2C5F5FFB5C96', '227FED5B-741C-4403-A7C4-6BE640F3A000', '4607021272759', '   /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48488077-E0FE-4496-952C-804159C55837', 'A6BCC692-969F-4C29-8D68-06CAD173F333', '4607021930147', '    /   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B16FF7B4-4CE7-4ACC-B8D8-F9BD389AF571', '961F431B-2E93-4824-A5DC-BE300F20E23D', '4607021930352', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91F463CD-1039-4560-B905-88D0BC69D989', 'FAD35F66-B0F1-4AD9-B01B-A68E59124CA2', '4607023601120', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D89CBE6-814D-4A20-82E3-ABE96CFFF7AC', '606ACF31-A52A-4B1E-9DD0-6D458BB88B6E', '4607023601151', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32B5EA33-504E-45B7-BAE5-2CB790E5C395', 'CCF0264C-637B-4CF2-97C7-CE111ACB3207', '4607024591192', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A7BE817-431D-4F3B-961E-A3158513DC65', 'ACA68A4A-9A78-4C56-8957-A02269384C7A', '4607024970850', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DF660AE-5BC3-47E0-BAB0-568F59386CFE', '8C4D65C8-5F95-4F4F-A86E-0BEBBC73DFDF', '4607027210083', '   . 0-6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A310191-B12B-47E2-ABAE-4F1832D13D5A', '2A9CFCF1-DD47-4372-85F8-FA4314F6A3B2', '4607027210175', '   .. 0-6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA1CC115-2E27-490F-B85F-5809D561602C', '85AF98AC-BA03-427A-B4CA-DF325EE533BA', '4607027210410', '      6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4197D499-6B68-47E7-BAFC-52EBE607E863', '9E97A4BE-0B38-467F-A70C-424A0134D241', '4607027210427', '      0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3EC0681-93F2-481D-A967-AFC387418650', '356C9267-FF48-4E99-817B-89DE8A3DFCAD', '4607027210670', '-    /,/ 6-12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBC37E22-3AE8-4D2E-807A-236B2D0BBF8F', '1665FC4E-7785-4472-9288-6A7D14F6A7A5', '4607027210731', '   . /  ... 0-12 12321', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB096E43-8261-4E26-A967-7DB4477E0798', 'FC1CE2DF-F024-4812-8828-7D86271BD79E', '4607027210908', '   / 150 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D43E9128-B804-4E1E-A444-2F0C25D5F2D9', 'B8679E8C-0854-4923-B455-16635A0BBBA5', '4607027211226', '21620   -  /,/ 0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC26EE57-077D-4D47-B096-1D54A7A72FC5', '59634D52-0BA0-463F-826B-848D25C76147', '4607027211875', '    . /  300 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98877FB0-8350-4263-89B9-0AA86A66B20A', '426AFD42-E824-4BB8-82D6-1F6F51999AC5', '4607027215774', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66A1B885-89E3-4D78-BED4-3329AEE5D68E', '0A758B1E-D13F-4FC3-8BE4-2DAE7C2B6C5E', '4607027216603', '  5112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('844CE21B-9FBD-4913-B25B-B51E929A9A3E', 'CD6781D2-C8DB-45D2-8CB5-0406B8DDFF7E', '4607027216788', '  -/5226/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5232FB3D-FE56-4D36-8B56-F52C899C4C5C', '82FC1164-A778-4C8D-8C9D-144E3B1A4CDA', '4607027217235', '    /2171/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('141C72C3-B31A-4FCC-9746-E2B49E3692EC', '997B3E4D-58DC-467A-80E7-6289BDBF3846', '4607027217242', '    0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31BB9625-C86A-43AA-9EC3-7C21357747E3', 'E1EE3C9B-C635-4422-99A0-361019C77EDF', '4607027217716', '2603     / 2./', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEFE736D-B124-47EC-A32D-2B7E8A34951A', 'F992C3C4-B310-4EFF-988C-4499309B048A', '4607027217907', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E65CA13-4987-4268-8E8D-4BBF325F04BB', 'CA2D346D-3928-45E4-827F-96F6457F3BE7', '4607027217921', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5984686-73C2-4381-BA6D-28647D961146', 'DD20629A-D0EA-4D01-9747-EBE779F1655F', '4607027217938', '    .  2255', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDA5B98B-C4B2-4A1E-A76F-FD314B215796', '6A9FF4A0-1029-41AF-BC88-CDBD5276F416', '4607027218003', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7E11E41-6855-4405-AC28-628C2411F8A4', '741D3037-63D8-4240-B034-6535A6AD394C', '4607027218027', '  ++/2215/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEB0FA9C-B6A4-4270-99F3-0B401E84AA94', '430F81D2-B507-467B-87D8-5F9C31E375B0', '4607027219253', '    . s 6-12. //1217/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83DA4F30-5231-4545-9136-4B5607C21863', '9802771B-1A52-4C4B-B1FC-396248B3CE44', '4607027219543', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('301EB84D-7232-42A7-81E7-E94B03EA906B', '0E418E3A-FEC1-4566-AD5D-0D9C642E1358', '4607027219710', '     130/1132/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('447C82F2-6108-4DDC-847F-9F0082B982D4', '2D0EED7D-5751-4EB3-8431-D98B737749E7', '4607027410186', '     7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29ED1DAB-A97D-410E-ACD5-4DC74EED488E', 'B2306973-A403-4A96-B7F6-3BAD31589A6B', '4607027763244', '- 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EC8A24A-067F-4E37-B1AA-6954B19D214D', 'BB8C05BB-3573-46C6-88EF-1A05DF4EC965', '4607027763251', '-  100 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD5E9C04-66CC-4895-B7FE-B47140081579', 'B4F9A642-B072-44A3-B29E-C36D7C15FAE6', '4607027764944', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A36A4E7-29FD-41E8-8EB2-CE4F994960FE', '7C2B1D3A-E379-41CF-9D48-4BC66C78AC6C', '4607027765064', '  250   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F77844F-7DE7-4A4E-94B4-895053FDE514', 'EF9AF96F-6CEE-42A8-97B4-B71FD6E99F0B', '4607027765613', ' 150  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B52E3EB0-14F0-4F9D-AA4F-376151964D0B', '010DB499-E1BE-428B-BD5A-464991689AE4', '4607027765644', ' 1  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('977FE6A4-9B73-4194-950F-90FE4F65B9D5', '97BDD679-037D-42E6-8ECC-C3755A1EFB03', '4607027766689', '  0,5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0A156E3-A7B6-4921-AAD9-EA673F4C1D34', '598017F2-6F42-4244-B6D8-9C43DDCDA2D4', '4607027767365', '  0,01+0,004  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DCBC409-7E05-43CE-8BBC-6CA0A845C7C1', '8B2346D4-E165-439A-8EF3-205ECA2AEA54', '4607027767464', ' 0,16+0,025  //1+1 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5605E3F1-8CF6-42ED-A4C5-25CA87230F90', 'D48313AB-F339-4B9C-BF8F-62EE988BE1C2', '4607027768799', '  10% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57684F6B-7189-409A-B4AD-56C1D7B30E53', '74217E76-6AE7-47F1-8762-48D6FED598EE', '4607027769116', ' 50 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89139126-17BB-44F6-BDE8-F02062F96DA5', 'EF9EBE8F-8834-40A4-8251-91DB419A461A', '4607027769536', ' 1,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78AE66E2-1D36-4526-A59E-516FE87DCB0C', '4BE2499F-D87D-4937-8ED7-DC1C3735DF57', '4607028010026', '  /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60F24C6E-43B9-436D-9758-B1DFDDA534DC', '4AB8319E-212A-445C-8E05-A58A4205F813', '4607029290717', '   1,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2CB9598-E9DB-4B78-B85E-3CDECD3B50DF', 'FC1C9E32-3709-4D74-B79B-34AB429573A4', '4607029291561', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D048AC90-C8E4-4417-9D7A-2762E74B25BA', '9A24820C-D423-4289-A4F5-88B38D095C8B', '4607029296115', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('725D4363-BB6D-41A7-AF65-EC53335E2778', '395E4C02-BBF3-4416-B11B-B340571E6996', '4607029580153', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C68C94CB-F2C6-4235-9FB6-B9DFE9EBF85F', '669E38B5-BEDF-403A-9F84-C07BB774F8C8', '4607032904250', '  90*60  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F79C955B-D443-410A-972C-E2FDE86D4F1F', '9E022E00-923A-4464-A888-B4A9736A432C', '4607033350025', '       30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('319A264D-4975-4F6E-8C2C-F4F9564840E5', '7744BEE1-9F47-432B-AC3E-01ED8F929724', '4607033350407', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D20DAB39-6BF0-4E32-B662-E7AA9B479F31', '90A4ECC1-A7F1-4138-B154-464E5309C1C7', '4607034470708', '   /  / 74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86954614-FAE0-44AC-9CEA-5CF1DBD38658', '49433D51-14F3-4D67-8430-AFD6787DFA9E', '4607034470906', '    // 74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5930FDF3-5EEB-4F02-A19A-9512A42C92C6', '90A4ECC1-A7F1-4138-B154-464E5309C1C7', '4607034471675', '   /  / 74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EECF57D9-984A-41E7-A9A0-9F90A81307BD', '9AB3E83E-54D7-4DE7-9B5B-20E67A4BFA33', '4607034472122', '   teens   74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('803DFC4D-A745-4140-905B-08EB4B98ACC0', 'E6328EE4-4C3D-4A2D-A5C5-6F889136EFEC', '4607034472597', ' - baby / + +', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78D686AB-7F3A-440D-9B49-C9E3EAD391D3', '6A521525-B513-4291-AEDA-3EFD89A07229', '4607034473747', '  /.    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1753FFE4-4095-4DFB-B05D-CF303CDA0A9F', 'C7817115-7641-42E1-A253-A8912F43326A', '4607034473754', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3815E830-E6AD-4C4B-A1F9-49FF8FB4A586', 'E12E3CD7-F79B-425C-A686-0FCCB41B566E', '4607034473860', '     &  135', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EAD275F-17BB-4B29-96EE-8E029E9A0C92', '73B82C49-FD11-4F29-8A31-3B433B74FEDF', '4607034473952', '      74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FAA2FCA-F54E-4474-A930-E7B93E07FD25', '57F30DBC-0191-4A0E-B48C-B8F21D8B7290', '4607034473983', '    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F55D6EA3-D214-4979-AA48-09F3162AE697', 'D773E46A-8761-4DEB-B902-F64FAC5E99A7', '4607034474355', '      74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CFF1807-6725-437B-AF2A-FBF0B0460DFA', '8AD44A48-CC19-47E7-8644-BB0E3BDD01B2', '4607034940157', ' . /./  ./ 1 .16 /527/  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('235B3864-0AE8-45A4-9733-CA8F38F5F3F3', 'E133FE82-D3CA-45FD-B56D-724D31B5EDB4', '4607034941697', ' /   19 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95A2EB28-714E-45E5-B08F-8079B1EB21AB', 'E61197F2-EDFD-4E82-A817-796FCC8BD772', '4607034941758', ' /   24 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A1B12BD-B221-4990-8292-D1C80680A60A', 'BF7C16B2-B918-4294-9FBD-8A6303B26503', '4607035392276', ' 6   / 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('111876DC-9124-462D-8D2E-1113B6F45CE7', '8CD40A8C-7A1A-46D8-9742-542ACC61CAFD', '4607035440045', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20A971F8-4D01-4338-9EB4-CA0213FDB616', '9AE7B86E-9081-45F0-A22F-BABB02682B84', '4607038730037', '     5 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B77BF54B-43FF-46CA-8AEA-FCB8BADA410E', '99A6C672-07BF-4164-B713-EB0CBE64F85A', '4607038730082', '  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9731257D-8ED4-4368-9463-3A3C12389982', 'F3C5D6DC-CF41-482E-806F-AC29F40FA007', '4607039773576', ' 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3D3D803-0E16-4267-A30B-FB0EFAA3A137', '573F5A11-7938-4C26-A436-56AFCC769453', '4607039970067', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E089370-58CB-4A6A-9CC9-B39E4F62D9AF', 'CFB360D4-6A97-4AAF-B8D7-49C4CC0504A9', '4607039971149', '  /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2C596B8-C423-47F6-A5A8-87CC496BF9E0', 'F0A32F40-7DB4-4C05-8F0A-A732D2620E70', '4607039972702', ' 0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0BECD4A-0785-42CD-B6E1-1B54E8DAF85B', '115CA8E6-6250-4539-81E1-82B16D0F6B6C', '4607039974041', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37AF25CE-8596-408A-B56D-13262B0645DF', '3AEBD923-7FFE-4BFF-B9BE-3D10116ED3AF', '4607039975185', '  -  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4B1A366-35E0-4F42-A242-C141127399B6', '55D76853-5AFC-4E63-B586-B2003F551AAA', '4607039975192', '  - 0,4  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBC8E5BE-3D6D-4250-9F0A-8C0051A922CF', '4AC9B640-AA35-4690-A267-6C5018B58E4E', '4607039975208', '  - 400  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1538F65-0DA4-4F0D-888A-D2E44351DAA0', 'E6752FF5-42CF-4C02-85E3-5A36853FCD15', '4607039975406', ' 360  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59F37F75-B6E3-416B-9638-A1143DB6F38C', '7DA89F4A-A164-4F42-82A4-2E8BA9587DDC', '4607039975475', '    48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B8768F1-FF46-4A42-B18F-2B871B2F7977', '268ADF87-86B5-469A-A181-978218835DBB', '4607039975598', ' 0,3  36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5FC7807-F6FB-4785-A5B7-99DE9EC2F27C', 'AAB616C4-08E1-4497-94A5-03D70FF512BC', '4607039975642', '  0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2641C621-67F8-4983-ABF0-EDE54EFF732D', 'CA247F34-B9F7-4D13-9AA9-AD4580FE1FB3', '4607039975857', ' , ,   .  90 0,3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D11A081-80DA-4940-B8BC-18FF0F4F3E57', '50B959A9-A132-4007-8F03-8D5B7969D537', '4607039975895', '   // 2,5  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B9D7570-7A91-48D1-B53C-29146664D1BF', 'A21D8114-23C1-4A34-A0CC-B53D80C6798F', '4607040313921', '   /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F01A89A-5540-4ED6-ADDD-D1F7546318BF', 'E27AE5C2-3F60-4ADF-8023-411C35AC8A79', '4607040317912', '   /    600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EE946C2-DDD5-42BC-A14E-767B4844E643', 'F05B6AB0-D111-410E-A5AB-3A0BF201B148', '4607040317929', '   /    600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31DA968E-D88D-432E-AB68-BDCDD85EAE5D', '5342B103-BEC0-4F78-A776-609EA387CBA2', '4607040647644', '    /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7E4A9F0-FCDD-4E24-B3B8-E21A7D132443', 'DC002BFB-5A51-472C-9E15-E17AB6646502', '4607040649709', '     3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61262063-C817-4721-B070-683F2E6F83DE', '53854F81-C47F-47C9-A1D4-17AEA00F1EAD', '4607041020095', ' -  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA55308B-890D-4EE5-873D-101696EF1914', '896DB879-0647-4457-86BF-46EF5694354A', '4607041024048', '   /   330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90BD07D2-14BB-4AB0-A838-3E0B07C71620', '83A03831-15EE-4BE1-A6B7-2712115D32F2', '4607041024086', '     . . 330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28270D24-4111-4A6C-9DEF-20BD5501D44F', '97CB1E57-93DB-4924-96C5-FB0572EE223A', '4607041024222', '  - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B521A16C-30C7-47E3-ADE0-58E0FF59BF45', '2EC4C783-2AAC-45EF-94ED-2203755BCAA1', '4607041069506', '    2     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('655DC0B7-0E45-4E2B-849D-B0C643ABB19A', '932B190F-9018-4CEB-B4B9-F1FA1849878C', '4607041069711', '   20 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9FF0B48-C463-461B-B85E-560974C83DCA', '3F0EC1A9-0A69-4E37-B4FC-E7F5C990A2F9', '4607041292072', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA74D43B-C1D0-4B99-888D-171B99DF8CA0', 'A6AF6921-38EC-48AE-AAFB-AB631A042EF1', '4607045192422', ' 300  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C6A4633-6BD1-4327-B210-B4DD7047C2FA', 'E1CC5041-01B2-429F-937A-DB0BE75BCADF', '4607046740387', ' 3  . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50102485-CFCE-407C-A973-50538DE8EA02', '913B9052-AC20-4318-9CA7-D6168A03AE95', '4607046740967', '   / 3+7+-+ /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7871DEB-BA71-412A-867D-891C3221C102', 'B58DF87D-45D9-4512-B51E-AA8C5AD8DBDD', '4607046740974', '  1-1  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D39F428-90BD-47EF-88EB-4D0E6564B5BC', 'F1DDE6AA-31EC-4A25-BDAC-2F8377AE0C1C', '4607048350492', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A982542-7B2E-4CB8-B649-58532CB19005', '622A6958-3263-43A1-9EE1-E04CBB82B322', '4607048760215', '-  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39ADFC9B-5A6D-4633-BCDB-5B96D239F039', '95986D59-2EA7-4718-9487-38A6ECFEF54F', '4607051430044', '  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A14A856-AE8A-48BF-A5CA-554B14B55CB4', '2E1B6CBA-CD9F-4E2C-9899-092B6A2FA0D6', '4607051790308', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F844B3C-493A-45A8-BA52-CD91CA864A18', '580A62D5-A90E-4631-BD66-D5F21CC30EAF', '4607051791657', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B93322B8-D5B5-4AA0-8061-14AA359035B1', '209E7E30-8F3F-4A56-B14F-3E46DA0218D5', '4607051793538', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FFCF004-4154-4E0A-AEEC-CFB5581EA128', '66F312B6-5D60-437F-96E3-E96A946A99DD', '4607051794023', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D575B566-ABD5-47F8-BCFA-5CBCBCA884C7', 'A6877938-F2A7-4D7F-9232-95D47391F61B', '4607051796102', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3AFF746-681C-4DDF-BD22-6DF0C6ECC30B', '2DAB58BE-E56A-436F-B0B6-3B872A4E1F82', '4607051796843', ' /  / / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37A2006F-330D-47A4-96A3-3ADDD82609B8', 'D643CDD9-0685-412D-84A4-2F084C52AA9D', '4607051797116', '-     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8037BF9F-0818-410B-9DBB-95ADBABAEB29', 'F16E767A-46EE-4009-B76C-3B4D9FC6BA69', '4607051797178', '-  .    / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14FB553D-5011-43A8-AA67-BA2C08E54ED6', '99E29146-B090-43A7-B1DD-6C2E0C54DCA0', '4607051797352', '   /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F600FBDF-87D0-4C35-B8A6-06A09FAC034D', 'FE3CEA26-C21E-4150-9F83-9901DB2CEEA3', '4607051798090', '   / / / 30 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76AE2E1F-069A-4235-AE6E-397255B2E81A', 'CC4E4C22-B3AE-4FDB-BCA7-7F936E509D14', '4607051798106', '   / / / 30 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A743BD5-EE76-4E99-9377-8269483A1A4B', '5FF2066E-8B10-4DC4-ABE3-2C67513CAABA', '4607051798533', '   / /./ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90AA8E85-D8B9-408C-917C-2AD759948F7E', '5CE65606-6406-4551-83E6-3303C9A2F644', '4607051798571', '   / / / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3407E36-9A7F-48CD-8B17-2AE4C17AB354', '21C70F84-83A6-43A1-834D-CD9D27B96148', '4607053660043', '   200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0B3A86F-91D8-4BC8-A1A2-7F9F91F48334', 'F9949B86-06A8-4266-9535-FE47011920A8', '4607055134962', '  10 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46421F59-01E3-4CA3-BE67-5C455E07CC89', 'E41440E7-41F6-4BFC-913C-C2CA7B9453CC', '4607055135280', ' 120  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52B4FAF9-8C0C-481E-B32E-74B654A0F433', '526D9BA3-C744-4FB1-BABC-BDD4EE85E9B7', '4607055563243', '  // 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8F04D60-5476-42A6-925E-C156A452F2B6', 'F9B405D9-D4A3-4279-BDC4-DFEAA5EA6BD3', '4607055563779', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E6A6A7E-B23D-4BA7-963E-B157B17F9755', 'A2C4573F-84D5-42FC-9383-C67B45B08164', '4607055565612', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6E836F8-AAFE-43EE-B349-E52CE839DB7A', 'CF5AE13D-39EE-4458-A195-07BDD8999BE2', '4607055565803', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25C149AD-6BD7-44E8-81BE-F7F5DABE1EFA', 'BC6C1E6A-DD4F-4974-969E-4978E662C99D', '4607055566237', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ED7A0DA-46AE-4311-B867-8607D04E5EFF', 'BBB46BD4-5850-4B07-8904-86B887388A95', '4607056260462', '   / ./ 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55DD3F7A-E67D-482C-97C5-FA110EA96CE7', '767DB364-BB4A-4F3D-AFB1-80B74A08A169', '4607056261049', '    170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61B8D73A-1CB1-40AD-914F-7213D553AF3F', 'D899C29E-0598-4789-B46B-CD956791926A', '4607056263562', '   170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB2589C7-1563-464E-AAFB-DE4D5EDAE2DA', 'A15BA473-446D-4D7F-9D02-D8BCB197B575', '4607056266334', '     170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0608AAF9-ADD0-4796-8C83-66B8D9B8FDDB', 'CA7F5468-33AD-4A34-83A1-3AED932C5673', '4607056266389', '   // 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5CEA922-84C2-43B0-87C7-2B98ED1618AA', '9F30DB05-57AC-40A6-AEF2-77A8D20527B8', '4607056267256', '    55+280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31AE2A1F-522D-4D6B-9F13-19E70708C8A5', 'B5F9C1DC-6A5D-4B9E-BFF8-5063CA134F9F', '4607056268925', '        170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85CE5D2D-E4B5-4A8B-A182-D7D67BB6FA65', 'DD4CD46A-431F-4306-892A-57E3C37223B8', '4607064291175', ' -      900', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01380FFD-045E-44E4-9B2D-3CC560F73E7F', '425EF40F-7CB1-458E-B9CB-77FE376BE307', '4607064299201', ' /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D98A04F-255A-4476-B102-B69D7C530D86', '0946EF40-C664-4AD4-9734-9D7B564DF021', '4607064299409', ' /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A259291-E151-4DF1-B802-38B8692F7C9A', '9A6B5410-1C94-4A55-9DB1-B7846369DA22', '4607066260681', '   1.5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6976E076-FD89-42EA-ADAD-C9333D1382E0', 'F2F3C922-1687-49B8-8BFC-60B51081ABAB', '4607066260759', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3494677-E89B-490C-87D7-489EF63EBE62', 'C848E069-D72B-4971-A24A-D472E33D031B', '4607066262012', '  3 / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06B75EEF-6317-44E7-BE5B-85016340CED8', 'F4FE025F-15F4-408C-993D-B599C38E460B', '4607066262302', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2A7DAF8-6D95-465A-AE91-95945EDC44D9', '65400AD5-DBE7-469C-BBC9-F4B7CD8AC356', '4607068620360', '      72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54FE606C-0786-4548-8865-9F3EA771E6CE', '0A9D876A-CF57-4997-8F52-9E7C04D4A2CE', '4607068621220', '   /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96C9851D-9274-40BA-88B9-B3D37DF233E3', '14F0E15C-BBC9-415F-80E5-6D7DEE614585', '4607069270700', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1239EBCB-6DB9-4B6A-A5EC-3994FE4E44FE', 'B7C94A59-CA62-4291-8AA4-2966E7CF63DE', '4607070020899', ' -  spf-10   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('597D317A-7B6D-4E32-841F-5C161BF84251', '977A47DF-47A5-45DC-AC57-F49E657342E9', '4607070020905', ' -  spf-15   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B058FA1F-1928-4E6B-A0DB-0BD1D0657B12', 'FA107283-5C71-496F-9D59-D9FD39F89FA4', '4607070024637', '   . spf-40  /18-833/ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63670E72-BEAE-42AE-AB11-F7A1C86ED330', 'C0BA7299-629B-48AD-9E66-F81216A780FD', '4607070028031', ' - /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA771FE3-3E79-4770-B403-14F86BCE2F90', 'E07583BE-1408-49B2-94EE-7D1060D43A24', '4607077090147', ' /.     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC9825F3-1648-4F57-A0B3-05C6C28464E2', '6A327DE1-317B-406C-9253-04CD8BF29B9B', '4607077091748', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('813CC39E-A76F-41C3-8327-AE297C66E13A', 'E38ED208-BF92-4188-BF23-905C982156F9', '4607078790268', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26D1DE0D-1C4A-4365-8CBF-B4B70F36C446', 'D26FC991-5065-4863-896F-5FC9B0606B10', '4607078970028', '   3 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A29676E-D7D2-4245-824D-C004D17FC1BB', '51C88FB7-F3E9-4208-B63E-6BE713AD6BDB', '4607083728348', '  610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EAB404D-353A-48A9-A9F1-DC9E14E8940D', '7ADF4EB5-CCFE-4CBF-A640-39826AE985B5', '4607083728386', ' 410 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('316DE7B3-C8CD-49FC-9342-44DD192C887E', '79170D94-5C33-4A53-A83C-175A588023C8', '4607085860053', '  /      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9B1E26C-E66B-4C84-97DD-8E874EF428D1', 'CCFBD164-9FDD-41C8-A329-B09509B8FC47', '4607086563021', '    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3ED8867-FF73-4A93-9044-0EB0E041C9B2', '38C18D92-1987-4E1A-B415-99901A5D5000', '4607086563649', ' turbo active  /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('185FCD1D-86FE-414E-8EE0-04486E7C56E4', '9029FC2F-69C7-405B-93BB-B73D2DA85B09', '4607086563885', '      kopeil  + 350 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D050BE54-4A5C-45EF-8436-6BEF1BBCBEC4', '748D92E7-8286-49D5-86E5-341153AFFA1E', '4607086564035', '  pore vacuum    200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6737B01D-847D-42C6-A208-52D5F9D2CEDA', '515A48D8-4B02-4C2F-BAC0-9CF57B59D9B8', '4607086564790', ' - immuno  21 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8107544B-7BF6-4EE9-8DEB-23503B9F0B09', 'A08E8690-73C9-49BD-B303-8AC7D07E78FF', '4607086564875', ' azeloln+zinc -  .. 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('880562B3-DCA9-4970-BFF0-D0528E9F1DE5', 'F3CD34A5-8193-4C97-9812-EA77991FAF2F', '4607086565346', ' volcanic clay     bio /  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BEFC547-6643-425F-A937-86AB7A10D95A', '7613627F-B366-4932-B94B-44A90CAA8577', '4607086566510', '  boltushka   25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EBE6685-81AD-435E-BE31-242E74966B81', '7E5C9ECD-A924-47CF-A570-DA6589623A9B', '4607086566800', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA7F16C8-CCAB-4EC5-B6BC-88A8D812CD27', '5B30AD3A-BD17-4F59-A4DB-6FC2A22D8044', '4607086566824', '   /./ 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C037412-F5FA-4E9B-828E-7F2011021845', '826BA203-4837-4E88-BA72-2CC4A9F74952', '4607086568736', ' turbo active    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56FBE72E-E4C6-4349-AE95-A23C04AB5EDF', 'B76F906E-BA44-43D4-A348-DCC22C64CB9C', '4607086569597', '     / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00372BB1-D5E2-48E1-9B4E-6C3BE230C748', '5F1522D2-EF0E-46E6-B8FF-8A3609FD22A2', '4607086569733', ' -     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EAEBEBF-8225-4EFC-B666-41A69E343AAF', 'FFF7DED9-79D3-4E9F-8363-D1DE0D808A92', '4607086569795', '  /   190', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89F84ED5-1F74-4EF6-8EC1-EA266A9C7D54', '12A558E0-5C72-4B1C-BDEF-D78517BBCBA8', '4607088741571', '     100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FE80F72-EC7D-4FAC-8798-56E499F4983B', 'FEDDFBA0-ECC5-4347-A064-2EEDB78F1B63', '4607088741670', '        70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34B04E11-9A7D-439E-86F5-3E5009DEF307', 'CF5AC6CE-CE77-4481-9101-D85A68FB9EAB', '4607091892987', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F8E395F-C4E1-4024-AB33-F58A81F45013', '42E7EE5D-D9FA-4DB0-AC8B-DD8748FCCE3F', '4607092930053', ' 10% - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14535F41-A5DE-420F-8B40-A59AFE21E7D0', '689DDBED-B041-4223-89D7-3B9EC9716524', '4607093911082', ' /   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76BE0802-C9C8-48B8-99C1-04F7F5F920CD', '488FC594-C6D1-4616-83BD-CAFB1E638721', '4607094170419', '    4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4068DB33-6435-4C8C-89BC-139D8C3E8440', '4D2EBCB7-20FF-4B92-B4DD-62928E832EDB', '4607094170556', '     6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3A43D76-1441-4456-A130-DEDEF1274C47', 'C266FE74-5ECC-45DD-9546-E73D36EA9345', '4607094170686', '   150120 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54B9A96A-77C2-4574-AED0-34A32FE8D7F9', '4080C3C6-2A43-4158-AEA6-B3E76E09FB6D', '4607094170815', '    3+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40C73BD1-55DD-4C3B-9A73-8AA0074C1E72', 'D28BFBC6-E239-49CB-BEB4-9F8DA6507B56', '4607094171379', '    12+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49F85D73-BBCF-4ED9-81DD-34807DE4B0A7', '1BBA32E6-0E2B-409F-A97C-90A5556D4521', '4607094172079', '     12+ 3819', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41482365-4EEE-4E78-A48C-569FA5426B3E', '141F8F03-3442-40D5-B60A-06210942553C', '4607094172642', '     3 12+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D41A390-BB1E-4D74-B2A6-740FA40610A0', '8CC60898-F85B-4AA6-973D-F578ACAFC793', '4607094173809', '  6+ 240/2210/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90084D29-D20E-4BA0-8A2F-96B765673C75', '513CBAF4-F69A-4A74-AA5C-1489245DC5D7', '4607094173816', '       . 1910mi 210', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5254937C-F25D-4558-878D-74547FF8B1D5', '7573FE51-0E1E-4D4B-94F3-AAA8EFC85EB2', '4607094174639', '      4+/. / / 140 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFBC5261-FBDA-4C17-9232-95555674AE7F', 'EA50B6D8-8711-4C61-A18F-1E40E453FE97', '4607094174684', '   12+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82718250-BC3B-4577-ACA2-A29E22A08331', 'F7D1DB93-D292-4094-96A8-E37352998BFA', '4607094174769', '  /  0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D408BDC9-81D1-4A44-A784-B04EA5BBF249', '94918DC5-67AC-4EF8-88FF-7D83EC0A1E58', '4607094175896', '    240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B69006DA-70E5-412A-87FA-BBFB5B6CA8E4', '9E4CB23F-9139-4B25-B86E-065FC3B1A3A3', '4607094176275', '  /  4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CED39D4E-A9BC-4B32-9928-F24A682012E0', '6CA21990-FBDF-43DE-9934-4A25D881FD41', '4607094176572', '    /  0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C478773-6E06-4A33-A530-9FE2DB42FB14', '8484E0C8-4740-4200-BE64-16121BEEAA72', '4607094176992', '   1 30087', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC4C03A2-A8C3-4F52-BD1D-AAA533F786DD', '9F770AAC-B5DC-4F10-B354-3501FF6C7F89', '4607094177678', '    0+/ / 125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21FAA7D2-4D62-4298-A2ED-A5336F18FB8B', '3784F493-1602-4CCB-977A-AFA6D2723566', '4607094290117', '    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B21070F3-B7AC-4138-8885-E959E54CAAE3', '881579FB-C803-406F-9DFE-968BE3C573C8', '4607097011559', '     3 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C62900D-9357-496B-8255-A2142BA67E5A', '5804F244-3AEE-4CF8-8632-4D328DCAF608', '4607097012587', '-    30 /1+1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA65AE4E-DB09-4AD0-92B7-6293619E5FD3', 'C7436757-D4BC-41C2-8D72-ADB7294C5045', '4607097012655', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3265B672-CEED-4ED1-88E5-F6677F0D2077', 'A8EA7D2D-8049-4A13-9539-A75CABA65609', '4607098451392', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D9BE70E-4C40-4175-B23B-48EC134108CE', '7F4DCB33-CE34-44BC-9852-5998CE698DBE', '4607100350149', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B8C495E-98D8-4BDC-9C86-B03EDB0D81E4', 'C272EC2D-A529-49B9-90EB-4A28B0FADF4D', '4607101200924', '-  .   3.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84A69774-CE37-4ED2-82D4-65C8ADBC15CA', 'DF7C1F26-52DC-4938-822C-643D539F48D5', '4607101201723', '  "L".  6 ., ,  , 2.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B16A719B-3CC6-462C-9BF4-419502916191', '5A448BCA-6C75-41CE-975F-90A561C49396', '4607101202836', ' LUBBY ""  4./13798', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D314A936-3984-4D06-9AE1-3FF44251D2EF', '3C3BD925-AC4A-4D15-834D-0B125D177FCA', '4607101202843', ' "".  4 ., , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('675253B6-AFD4-4922-A056-769986C092DC', '25AFF815-B5FC-45CA-AC63-8B19095E10FE', '4607101202966', '4696/144/24   - "". 0 ., ,  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63B5B391-839F-42C6-A424-C32C44BA1876', 'DC25EF84-D5DD-4C12-8CDC-793846E37EBF', '4607101203444', '- "".  6., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2346498-8AA5-4001-8D1F-962ADC44FF33', '6CDC0844-8E3E-468F-BF24-1B07030D1EA8', '4607101205103', '- / /13686', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD5FC11E-2973-41BA-850E-289143745CCA', 'B7A18488-5230-4D64-8935-EDCC7A3EEAAB', '4607101205370', ' -     0 , , ., ,  11402', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D11A12E9-8F80-4CC8-AE2E-D01D2171901B', 'EA04DB65-3535-4EB6-BE8F-814B16151372', '4607101205417', ' LUBBY 250 " "  .  0./11389', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E673FDB4-A983-4504-8365-5D0D64F96DB6', '55274D70-53FB-4612-9A0E-D9C33D7351F8', '4607101205547', '4492/144/12  -    "/".  4 ., , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCFF4ADB-5088-4FD4-B41F-C5E154341949', 'C96925C2-C02C-4AC1-A4D5-95C180EDA2E9', '4607101209262', '   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C038F0F-60F9-46D7-9465-2F72A9B709D6', '13EE1639-E5D1-4AB0-BE4D-C52398C41623', '4607101209507', ' LUBBY     6 ./11854', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD9B84A0-F673-42AA-9453-E0B61FF64EA0', '3EADC56B-8F97-4BAC-9D05-F1BA65FC8195', '4607102010348', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70B2657E-FBF5-411C-8685-FD5E58EBD7DE', '5138FDE4-F7B1-4715-848A-B860C1543BDC', '4607102850555', ' 9  /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('147BA596-4B0A-4FE2-A53F-D6E9654F2264', '6AA1CFF5-A86A-43AA-910C-2EF7DEAEE11B', '4607104090096', '   agcu 150/250  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0481CE5-110D-4EDA-8188-AB2A532C675D', '73C4948A-4E5A-463F-9371-2583FA3E54BE', '4607106001502', ' 410  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6C50FAC-047F-4FAB-A609-4B18DD99EBBB', 'F6CE1110-DC65-42DD-84E4-C58EB0CD3CA0', '4607114290158', '         0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEEBB260-3CAA-487B-945B-B7D776F506E2', 'F2F3C922-1687-49B8-8BFC-60B51081ABAB', '4607117341369', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52CCD99F-F7F6-4985-8176-7DE3B3F55E1A', '2BA051ED-DF84-41C2-ABAB-64168864466A', '4607117341550', '  - 1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6596BE83-8A98-46E7-A7D5-B35237A15CD1', 'E09B1D82-F108-4EB3-A3D1-0543D03DB17F', '4607118050796', '    1% 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46397659-F12C-4861-89A8-1A0F3200D8B8', '0CB52D22-BDF6-4447-9D7F-5B2B8BBD61C4', '4607121694116', ' - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23FA2085-F9DC-4271-9771-C9C4760914C4', '0A316550-BF00-4AE2-A225-3A8A05085B32', '4607122560335', '   6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88B5A897-77E7-44CF-BC5A-BAF42081325A', 'D3BA0712-5D4F-48DD-B121-F2845F16FB48', '4607122560533', '-6     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24C05258-09A3-4556-BE2C-C8A9D85DD3AE', 'B7C0C119-122E-409D-8457-7A281708E599', '4607122567099', '    /  6090  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9289C3E-40BB-443C-A05F-FD32AB83252A', '77DDE8AC-DED1-42D7-B172-D7B3AFE77EAD', '4607128160409', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('883206CF-CC3F-494C-8255-4C907CFB9C5D', 'F0BBC6ED-FAFB-4CF9-BB9F-A2B1610E7C34', '4607131043584', ' 40  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98C910F8-7EF3-4E99-808C-171A422F4546', 'B59020F6-69BF-4556-B051-1C379BC13AF0', '4607131043805', ' 25  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4439A63-7986-429A-BDE4-C2BAD425321B', 'C565D319-855F-4B57-86D2-D432C8B26C90', '4607131043843', ' 50  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6E8F091-D310-413E-904E-ADA2E1EE48A2', '44F30FD2-E39A-44B1-A76B-4B1354B52579', '4607131043911', ' 5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC1159CF-FECD-419C-8163-38AB80C8459F', '5D796025-E06C-494F-8E01-C89CFA843E7D', '4607131421139', '  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC34E5AA-F948-4033-A6AD-358CB13ED194', '1FC5F58F-E27A-4E3A-B21D-2112CE339A7F', '4607131421153', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('014F6701-B75D-4415-AC7D-0CBAC756CC9E', '1A6DD950-2DFD-461B-9812-AA25ABC43C23', '4607136740051', '  300  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F9FBC60-5E69-4D35-AFB2-3A64EB61C483', 'D9714467-5DDD-4377-9E84-C184B815A23D', '4607136740143', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA214C81-2411-4481-855E-ECE377E095E6', 'F88C6750-E032-4EFD-B5A3-29CA87C5E806', '4607136740532', '-3 600  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3D6F6C6-98F4-4E8B-8166-AB1831AB1B3B', '7666C7C0-4342-408C-9DBE-A5C13E832769', '4607136740716', '-3  1,4  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21C6F981-DAF4-4908-812B-D3FD74E570EC', 'E32AED3C-5DCC-4BE6-A85B-C618F63C93C6', '4607138078534', ' /    /116-120/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DB2ECA3-EB1C-40CD-BD7F-BFED07A270AC', 'B32708FB-3AF1-466E-8AD8-C40A69A611C8', '4607141120756', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C023977-DBDB-4679-887B-48F568966595', 'D7819D6B-B8A9-45AD-8CC7-952824AB1182', '4607141120862', '     70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AC3D584-4569-45B0-8FE4-BE2EDB522B85', '617B7CBF-F7C5-4711-A5DB-69A069617A7A', '4607146760940', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('528E4CEA-48F0-4E0B-AB8F-E7A6FBFD88C3', 'BCDEBB4E-42CC-4E93-A513-5F2FD0E7088B', '4607146821993', '   /  / . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E67126A-8DAF-420C-8785-D58398DF82C5', 'C3BA5A91-2145-4364-BDC3-4A141F3D8EF4', '4607151710121', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('381C05D6-B5D7-4B19-A6C0-94C2DB77E47F', 'CAFC2581-15C7-4771-BE29-8767309BF8FB', '4607152730159', '    ', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7382A84C-28A7-47D5-B54C-A374BD83BC32', '7A7B08E7-5BCC-4E54-BB6E-91CB59BB0899', '4607154693339', ' little fo       300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48811311-1B49-49CE-AE4A-61B9174F5028', '6243F2E2-8396-49B8-8EAF-E0E42BD2C1DD', '4607157730499', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A2DBF5F-B72A-4B01-BD2E-4092D9FA928D', 'E2951B99-31D4-410A-9C93-56D658F9909F', '4607159860729', ' 5+5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2073DE6E-3F8E-4BD3-884F-711F19274E6F', 'B4A1DECC-D792-4417-961A-E79A63196818', '4607163091638', '      1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CBB4588-E3FC-496E-B52C-2850E54EC2B8', '004D43BE-612A-4876-8029-3250EA79DCEB', '4607163091645', '     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52698E34-BF7B-45AC-B708-01DE8431A7E3', '48F62F54-4646-49F1-98AD-C81D301A702B', '4607172374050', '-     zn  7-14  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('097EE6C3-DDA9-458B-8DC0-5F4AB19F464F', 'CDF404BD-B7BB-48A4-9E7A-FED44A84B746', '4607173030115', '   .  0,25% 10 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9798B318-57AC-4A1B-A33C-E71F1A57A64F', 'BC0EBECB-E056-409E-B9C9-7473A65DC8E2', '4607174140011', ' -1 /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D959F03-A6C4-42D8-AB7D-224D25784B99', '36ADE928-7A6E-4358-9E27-F7FC64706725', '4607174430235', '     /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40392B72-5BAD-4C2D-9D17-E2189E84635C', '3B101986-2B7D-4F76-BD09-D57C99D7A124', '4607174430822', '   / /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4CE5148-3E46-4F71-8461-34C713C1B158', '9A875C44-7C48-4562-8F1B-1B768640A59F', '4607174431300', '   /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39423551-C2C2-4F54-B3C2-F672399B262C', '633F07AA-5747-403A-B99F-6E1977680036', '4607174431348', 'Natura siberica  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8424C2FB-FC6D-483F-8A6C-00D31C6FAA8D', '653252EB-C61A-430C-9FCC-ABCFD0E10409', '4607174434899', ' natura kamchatka /  / /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('866F4DAF-ECA7-463A-9B38-284196E99319', '9B6733F8-5868-4FAB-8602-FF35A217F3E9', '4607174435742', 'Siberica thalasso    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D7B9842-88C4-4F40-9205-51521B29180B', '9D6CE203-A1B7-4A07-BFEE-839B77787782', '4607174435766', 'Siberica thalasso    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CC0BE78-5F6F-45CA-B012-30BF346C3A1B', '614B4DB3-C10B-49C1-9C02-44AD084F3B45', '4607174436114', 'Natura kamchatka  /   //  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('662CD510-7A15-487C-8A6A-5391C03E0B20', 'DDBB4F5B-DE45-44F1-A889-B1B5B8FB58EC', '4607174653665', '   110125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51AB7B07-C385-4379-B8F8-686A421181A3', '81B4490A-55EC-4E83-97B0-C803B46B4B22', '4607174653801', '       ..  /70% / 60100 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44D21D93-071E-47A0-93E2-5F923D1C262C', '92982335-C8CD-440B-A12D-333A4D4FB02E', '4607176000221', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DD5A649-479F-4160-ABE8-609A3854C871', '67535576-B633-447F-9ABE-36FDB7554A94', '4607176000252', '   / // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48943D5C-0CB2-4922-BD06-E1C58C6C33EA', 'B7B9FB2F-DFDF-4E40-AC36-A591146F3988', '4607176000290', '   / // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('490F0528-CEB1-4A18-B4AC-94310EF7A186', '56BAA4ED-CF02-4196-9D38-745E236AC223', '4607176007855', '    / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65BF9FE9-2891-4B70-A8A0-5CF2B0324FFF', 'A728F7C2-B805-4786-98F4-1EDA8FA38BF9', '4610004310928', ' / / 5/ l / 88-98/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('991DED28-077B-4CE8-9F68-FF649B106402', 'DF766885-C511-4CAA-864E-8DF9463B2C55', '4610004311192', '     1 // -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('665C6768-E3FE-4EB6-90B5-FF51C321CBBB', '4355AA73-2382-4BC0-9CAF-44C320930948', '4610005630018', '   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3057963C-2A47-45A0-8846-75781B7D35B5', '8A9B197A-D8EE-4728-B660-EAADBCB1E7A8', '4610007620277', ' 300  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D582B68-AE03-419F-947C-F08B59DB78B1', '27698E0C-8E00-448E-8A5B-7B5B303F87D1', '4610007620482', ' -   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55C1105D-8C90-4848-9258-3F2B8CA390C4', 'E485A9C3-9694-4600-AC0C-583080C6C7FA', '4610008490831', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('453280FE-906C-4294-B26A-DC3728942A25', 'DE5F5551-41CF-4975-BD0B-EE3DD5D22F2E', '4610010011406', ' -   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECC33E0C-2D0D-4BD7-9960-290A2357F322', 'D83ABDC6-67A6-44B5-8601-C8F5BA4AD533', '4610010011413', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2622AFB7-2355-41C9-B63F-52A01D366393', '65F0B9B2-689A-4271-9146-F268D91C8050', '4610010011420', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1522650-E009-4F55-B150-225C954EE7CB', 'BF365079-AE9A-4B13-8061-9FEA1AF3AA4E', '4610010011635', '     45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CFBFF45-3184-4BCB-87A1-8A088D7AE5E5', '055181A9-0149-427D-A810-DA4AD24AA8DF', '4610010011673', '    .  /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('920614C3-11EA-4206-8200-97B24E410BC1', '1053346D-14F7-440B-99C6-A15294D483A1', '4610010011710', '  -  . /.  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDC4B0E7-B570-4FE2-97CB-2200D023F158', '3AA347C8-1B06-4E5C-86E1-863EBF78BBB9', '4610010012465', '     /   /   100% 45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06484417-B7AC-4339-A945-0C6D354B8893', 'BB98E705-2B33-4A95-B323-3957A553DD50', '4610010012922', '-      5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB784BD3-D7A1-4FCB-9DC8-63DA517F4B96', '930C3EB4-0302-4C94-8B8E-EBF3CF7B8BA5', '4610010012953', '  -    /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A418B99C-10ED-4E3F-BC84-E85C75D8C853', 'D5FB132F-57BF-4980-8D11-58600DC46BEB', '4610010013257', '    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05AC7497-9CAC-49A1-941B-A47FECC46D24', '8875E9B2-AA5F-4693-8F84-F9959C409CD1', '4610011894763', '  / 1,5 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75E99D7F-F0F2-4C84-88B7-2C7F5CFDD1F4', '7BDE8363-0143-4036-A773-AD12B2E31F94', '4610011894787', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D734174C-6A1C-43A4-A620-9D6C6E187648', 'CCDEE90A-15E2-451E-89DD-1D7F3F0932EB', '4610011894794', '  /-/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B9CB27E-9361-4672-8894-05DBD26ABAB8', 'B0B58BC2-4827-4387-9D31-EBDC5DAB8E45', '4610011970375', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DC1D2D9-B11C-4A77-9EDB-99DD9AC23082', '66863665-D46D-47A7-ADE5-81EEEC3C0C97', '4610012020109', ' // 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B056FBB-DF61-4CAE-BDAE-B5AC1DC54EFA', 'BF9C3D5C-1FC6-45B7-A633-1214702619E8', '4610012150714', '   / 3 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92EDA29B-5E55-4C93-8488-C04021781618', '4AFA2BF2-964A-4691-BD97-31E29EA4E665', '4610012371850', '   hartmann 6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68F3CF9E-DC46-4125-BC5C-EDCBF8F8A581', '063575ED-5C13-4190-8C41-B90CC988B930', '4610012371874', '   6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('348D601D-8A2B-4678-A894-DC9E26015188', '52B8C904-7A01-45F7-BC0D-F7F328E4AC15', '4610017192160', '    70 2-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6F9ED3E-A73D-4F7C-AAFD-FF0BA07619FE', '5C5A55E8-AB9B-4B7B-9494-074F3E15FCDF', '4610017500361', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('531475C9-6ADD-40DE-9629-CD2B639F8D8A', '3F57B0E5-7DE8-4F3E-9D67-4F27C40B249D', '4610017750063', '   2500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0903A7E4-8E64-42A9-A796-AFF004E9BE00', '8C317096-0B22-47C5-AFEB-143A83B349DE', '4610017750506', '    3/in time aroma', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B7E6E38-0996-4867-B397-3E61E40AC65E', '2D052E75-276D-475C-BAEF-5FFD9E49C26E', '4610017750582', '    12/in time fine', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F28767FE-0D62-43CD-89DC-5B672DAD2803', '39AA4FD6-8C5F-4CF5-8BBF-EC5FC83B9CC8', '4610021170222', '-   //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB44CAF7-EA33-4ADF-A9A1-164B71EE846C', '23862BEC-3B71-41D3-8310-8B2BA8189EC4', '4612613500196', ' -   2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F35BB898-52B0-440D-8336-E1F32455D235', 'EFD7FD3B-C08D-4B03-9D35-CE574328E10E', '4612729880656', 'Pure by presi    /  115', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B329570-AB97-45B2-A57E-1175B8C97232', 'B337F3EE-C31D-4EE9-B072-26E22B230710', '4612730250752', '      0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9258B66C-2EBD-4345-B174-32251F71D3A9', '916B6E6F-7EFA-499A-9016-4B2DCD51CF1A', '4612734850217', ' 6060 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D99933ED-3C81-4ED4-8273-B8790E44D4D0', 'EBC38D4C-5618-4261-BFA9-4F56381FC9B8', '4612734910362', ' 510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCBDEFDA-93D3-44A6-8FB1-E391A3B31EB1', 'DC235C11-9F64-4AC5-BE99-2598F47F5637', '4612738370049', ' 1,58 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DDA5551-15BD-4DA5-B6B1-45A75F723ADB', '59308C6B-26CC-4D63-B4F3-7FEBC609C601', '4612741480285', '   1010 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAA3DF28-7643-4481-9CD6-7E075374972D', '28308178-45E3-45EB-A408-09E27BB6E08E', '4612741480704', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('942AF763-0833-4DE2-9A39-426815806A6C', '3CA7BA49-F13B-4CD9-8780-D41E504F2746', '4614171333414', '  .  .     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB3978E9-5DE2-4413-96D0-7EE8445B6AB2', '2C8353C8-ECDB-48D4-8F3C-3585368131ED', '4620001090334', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F35D109B-29CA-41E8-964F-B9ED7FFD8B20', 'C39A9AF1-99E4-4391-8225-BF1D3D5B3912', '4620001091430', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6B03314-4E59-4C49-A3AE-8F637C00EDFC', '1896F57E-721C-4A93-A59D-AE467045FE07', '4620001091461', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD66F922-DFCC-4291-9844-2EB3A6DCD8C2', 'F0A687BD-9477-4482-9F98-53A8531F4F64', '4620002180423', '   /  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('627B565A-CF8A-47C1-ABB3-757DB13B2E21', 'F0A687BD-9477-4482-9F98-53A8531F4F64', '4620002180812', '   /  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86E87FA7-E0DF-4187-8740-40074C6D4A4D', 'DE97D447-2207-4176-AC6F-E0092D9C46D6', '4620002181444', '  -  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7F8B146-4D76-4346-B79F-93F91B698E63', '4DB53BAB-AC35-462C-91B7-88B0B2E7846C', '4620002181536', '    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3A62042-8676-44E7-BB95-2C88B049C18B', '13BA0625-ED58-40EC-BC60-F7F91F1F664F', '4620002182380', '        3 18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45BF40EF-0BD1-4B6A-B90E-847D0FAC8673', '544FC047-6EF8-46C1-A98D-B6E80D83ED31', '4620002182809', '        250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D4754BE-1A5E-483A-BBEF-2683F5ACF3FF', '7036189D-A30B-4250-AB63-45D43BAAEED5', '4620002183714', '  /    4--1 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D035203-1A81-4035-957B-FB314FDEA067', '9BA839C7-2EEC-41C0-90E5-F940975960D4', '4620002184148', ' / sk .20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0D4762A-6082-4BD1-A5FC-4C1D0DC325B0', 'C972CB64-AD96-4134-84A3-FEBCEE4B94CF', '4620002184162', '   /   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF286966-5920-4AF3-B4FB-604C7175F480', '4770F7C2-046F-4C5D-9CFE-8C60F684D863', '4620002184308', '   - /      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F7F5BA7-14CC-4DE1-AB37-A2BD70769CC4', 'F165771B-FB4E-434D-9498-6791D0C76F2A', '4620002184391', '  /       300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B03E9100-C44A-495C-95A1-934D669FB0E6', 'F2EEFC9D-DA1F-4964-9051-7FCDF8ADC76C', '4620002184490', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('582DE4C5-747B-477C-B2EC-00E92539D6BE', '7BACBA2D-1702-48BA-8B32-573C0CAAB1CE', '4620002184506', ' -    - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06B6CE6D-898A-425E-A7D3-0FD3FD594951', '4778CBEF-A8E7-4A4A-97A0-8A5B23D38DDE', '4620002184599', '  -  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD565E23-5B50-44CF-9FCD-D42F608FF8B8', 'F59BC14D-2757-4606-BBEE-5BE7A7F2AE14', '4620002185053', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CF02D7A-7DA8-4A99-A115-246DD9E92F72', '1FAB242D-656D-41D7-8F5C-38E4364D09EE', '4620002185305', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A6A8E60-2FB9-4D58-A48D-5756119F050C', 'B5728CFB-90BA-428F-8F99-95CB2F634A6E', '4620002185350', '   10 1//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7550FE8C-F928-4874-AC0B-72B2BA2D30C0', '3E90D2AC-C075-4451-A7C3-469AB5E6AA3D', '4620002185466', '          75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01CC9D34-DDDC-4563-AB72-E630BB34B7EC', 'EBFD27B5-757A-45EA-906D-201C01ABEBC9', '4620002185503', '  for men / - spf7 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6888B623-BC15-4EAD-A491-8062A753F562', 'BB41DA16-A911-4486-88B3-675580FB5236', '4620002185527', '       4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('438D3735-0C6A-4F6A-9805-3F14FBC78F7A', '123D89A2-7DF1-466E-88F1-CBD0E71A2A1A', '4620002185619', ' - / miceclean 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EF74399-0E61-4757-850E-9826E2CEB63B', 'A7D4E4E5-8742-4436-9D85-8B949F1698A6', '4620002185756', '   -  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51A0CEB5-92B6-4802-B95C-7D4D86216B07', '907D8980-0038-4657-8049-7E8BF4F74C94', '4620002185763', '       4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDCC77FC-CC23-459C-BD4F-1F0AD4904355', '3E65A6B5-B3B4-449F-BD75-EA53A69A9A33', '4620002185794', '     /      spf15 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8D9F0F7-9B20-40F6-9BA4-32F04A23BF92', '23F8A5E9-74AA-415E-8383-811563B220CA', '4620002186111', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1292100F-6806-4176-B33E-1C6039E0F434', '2566CC5F-73BF-4E5C-A9FD-0B83DCC5F6DE', '4620002186210', ' /- / + +/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34154B65-13BE-4A53-BC6C-DFEBF6F1A85A', 'DE14B24C-5ACB-43A4-B588-194E65F2CB74', '4620002186418', '   3d  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B200170E-C053-4699-BC78-03E23F3C7A34', '2176E05B-ABB2-40E4-BE79-51ACC122E252', '4620002187064', '  /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB3FEAAE-EA89-4EE4-987C-796B0B6B395D', '49A61DE5-D1D9-43CE-B98E-6046570177A5', '4620002187606', '  / +/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AA00FC9-6ACB-4112-9882-56B85B041AFD', '98872085-320C-4727-95AC-BBB35AB32287', '4620002620011', ' 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D427772-AC0E-447E-B319-F0837A1A0742', '929FF0AB-B7ED-49F3-8BD0-5F07B101DD03', '4620002622039', '  .-.. /./ // 130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACD8A607-FAAD-4677-9570-8B9DAC4C8764', 'F7AC1C44-1B3D-4484-8CD4-3982A921EE4C', '4620006110426', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9671DF4-60E4-4403-B438-4250393CEF29', '7D0C0B16-EFD4-44F1-9B20-B876842CCE87', '4620006240888', '  - /-507/ - 3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62EF5083-DF28-4CEE-8663-F5B9E6E714CC', '6E5ADC6C-B2AC-4947-AD82-B288D91508BC', '4620006245487', '    . 4, F-203', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('313CCA2A-B194-4A7E-BAA0-9627759B121E', 'CF9CF0DE-C256-415E-BFE3-16B17D2A4DA0', '4620006245616', '    /F-210/ - 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF8B7D71-5300-4DD9-B51D-CB02360EC095', '2C077621-1B85-4558-BC32-C15FD44F150A', '4620006272995', ' /  /f-320/ 11  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C58EF96-E69C-449C-9449-3C4FC90089E8', '97C1E096-6AEB-4FC2-8D0E-AFD1ED7DEB84', '4620006276412', '    /-190/ - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('450A0A5B-1060-47BA-83E8-D2CA4D5702F4', '1740278D-9027-43B1-AD7B-12A7BD34B5AC', '4620008620251', '  1% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E0DB15A-0452-42BF-8DB7-5A59AA8F64AD', 'FCB76D92-4FFE-4E5E-8480-3928D7EA8537', '4620010796517', ' velvet / 51    /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E40DB2BB-98B1-4577-93CF-E2FA45E3A0D4', '317ED269-8794-4D5F-B9C9-3DC68405EF41', '4620016240083', '   /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A25DC094-4F5A-4F60-8353-AB282069C2E1', 'D0E3D0EC-4F9E-4CE7-A4B2-AC47746C352C', '4620016240250', '  -     500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61795435-99B8-46B8-8EEE-70922A99DC50', '957364DB-671E-4288-B652-219EB68E6204', '4620016303276', '    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69828C6F-30EF-4E29-885A-62B78258570D', '0A3779B3-DA0D-410F-A36D-1BE74B5615AF', '4620017368304', ' / / 200  90 .30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('882A73DF-E9A6-4641-AB1F-8BF6EA4D5C96', 'F79C040E-D685-473F-869C-7F0AC7CBB757', '4620018140145', ' 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39B91F9A-05A2-447E-8335-FD5B23C7D6D6', '432BBD2E-05A2-4BB7-A876-BEED8FE80033', '4620018872916', '  /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('943E644B-7173-4137-B203-C6961813C09A', '35B0D71E-328D-4022-A0F5-723F8891A9BA', '4620021520316', ' clearasept anti-acne / /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B90E7345-D66C-4BB4-95D4-6ADB6375D3B6', '6C3D86E5-EBFA-4453-AA78-4C9A402C9488', '4620755670196', ' /    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62EDBF1B-6132-4CD0-A6F5-7CEB9AF115FE', '854875B9-650E-47EE-ADD7-23044227EFE1', '4620764311608', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38EE9821-DAA8-49AE-AD35-157EBAC9038E', '23C736E9-6A92-4678-B079-4EADD7811ECE', '4620764380093', '  /   1010 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('452804E4-EBAD-4435-94C6-018121141922', '89AE675C-9C85-4809-A75F-B7270884060A', '4620764380178', '  /  510 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FC69E3A-C0B6-409C-979D-F9BE47E3033E', '05A38715-A4E4-4071-88D4-7C2FCCC4A301', '4623721333422', '- 250  1203  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E4C36AC-EFA9-4F2F-B1A1-B7B1599F158C', '7DBE1265-0000-4369-AAEE-35CEF0D2BD07', '4623721427398', '   250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ED6C5F0-C8A5-4423-8C7A-0EB9638EEDA8', 'EEBD7971-7AC0-44EF-B0E4-A0FF75C2CF1E', '4627072882066', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C0EABFE-34DE-46A7-9D8D-F0EF1D7625CC', '1B9C1BFC-5C35-4FE4-AD7E-CB754E87AEE0', '4627074840361', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADFE3FAF-DB32-4A95-8702-118437CCA839', 'AE9F0B90-C047-4609-AF56-8A63D7685702', '4627074840453', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9392304D-FE80-40BF-8696-162DC5824266', 'A3A146CE-613D-4118-8518-FCE9818D7022', '4627074840538', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C25F1D09-C453-4072-803D-E858D72DBADF', 'A6B8CFDC-78B8-4B3D-87DE-AAAB93B0A117', '4627074840743', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49C050CB-8A2A-4DD2-B7BD-6365B668A4F3', '3279197C-E056-4739-BE05-8B0831766A90', '4627074841122', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9BDF1BF-0A0C-4AA2-A649-C24A1DA35030', '7C4B24ED-21BC-4EE8-BE71-00903A3A10D4', '4627074841160', '   .  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75165F3F-5A20-48D0-AE3A-19DA1AD8F271', '6466505E-D6D6-4170-8134-552DFD31A252', '4627074841368', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57F59AB9-B3C5-4643-AEB6-9957AECA010C', 'F72A1F73-98C4-4F77-A7A7-298239BDB831', '4627074841535', ' -     1,3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57628FE8-F261-427A-A8B2-B190A086EECA', 'F9CE2052-F354-45AC-8236-912DC0FFB0FA', '4627074841658', '    1,3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F03A127F-869C-46D0-A8DE-D0B4F5882AAD', 'A588AA81-DA07-411F-B062-F6318B219D3F', '4627074842365', '  450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68114A6C-2C7E-4441-A6EF-990016F4DF3A', 'CEE3C613-6E14-469C-B137-C6055970371F', '4627074843720', '     10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CFFA83C-D868-46BE-ABF5-1FCB2DE8E390', '00EEB5A1-8864-4B36-9C51-591C3D1551B4', '4627078980452', ' / gess-623', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73ACAD28-2081-4A67-917C-1BCBFEA610AC', 'AFDDA385-31A0-4ADA-B4A8-1113943DE851', '4627078983569', ' / -1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBBFD5D9-2F57-47DE-AAFD-BDF19AE09559', '8C25233F-25BF-40D9-863B-ECE5B69DD004', '4627079640089', '         100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6375386-8552-45DA-B9DE-5C1C3C3670E3', '447B1997-F3C7-4AB6-B094-1F42AA416969', '4627079640096', '         100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('901D2267-743A-437F-8A89-66640911F7D9', '81937326-B8DF-40CA-93E0-42D15525E4C2', '4627079831067', '     100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('094D2184-C0F5-4600-A66E-4AB8BD7228B2', 'B8E3206F-6972-4662-B591-9926D95813F1', '4627090498775', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50651D0A-0FF8-44CA-8AA0-EAE5333CFBDB', '1096CA73-051C-4310-8E31-AF5019F24A77', '4627093273010', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8E0689D-ECE4-4967-AB1B-25A5904B0848', '6A3A3A72-EB95-481D-9DE7-47F0019B3824', '4627093273799', '  2- . 22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EEAED87-463B-4777-8FFF-67FDF16E102A', 'D14A4409-A826-4AFB-951F-C94B4C78AC2F', '4627100131975', '    spf15 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA87C224-BBD3-46AD-B57A-4756853C086D', 'C4A6F251-20D7-4752-88B2-06A6B9C9E402', '4627102710147', 'Dryru roll 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A818CE8F-6530-4EE0-B7FD-B7B73C244B4B', 'AF01F230-B76B-478E-B59B-42FBA36530AD', '4627102710178', ' -    20 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B5F42A8-592D-4DB2-991A-CBA2DFEB166D', 'A40C36A6-DC20-4AB8-8BF4-DC987A5BF8B3', '4627110046368', '  fosta /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DC452F9-BC14-4397-AE6F-AFB3329DDBD9', 'C4EB4AC7-C041-4546-A162-A305BE67CBAD', '4627110264335', '   - 3/-608', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93849AEF-14BC-46AD-9CC6-196AAFA50CD3', '75B9D7B0-F9ED-4DE7-8432-5A4EF62E9DCB', '4627115160090', '       320    500  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C3CA1FF-7780-4784-BB54-C58FB7058E25', '23FF8E6A-8290-4283-A438-3516EE8DE953', '4627126380142', '-    tore 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C1B2E2F-6E1F-4C0F-802C-498C912D0216', '9FE76CDF-2B89-4D41-ABAE-C73B2E9F38E7', '4627126380166', '-   tore 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('165226D9-C5CE-4CC0-B171-B2118A1FAC13', 'E0DF1ED7-4484-4293-93A6-951FBB965D05', '4627129210538', '         125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('901200AC-84F2-4330-B2BF-ADB04119C2E3', 'CA686F1B-3888-4180-B0E0-188E4CC6698D', '4627129210828', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B8E7DC8-4F17-4681-BB7D-F006C29F3B41', '2F8A8D5B-9398-45B3-B6CE-D3233BAB92C6', '4627129211214', '    10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAD8B479-270B-4EDA-B601-42A122149D60', 'AF01E3B1-1BFA-4E6B-A112-ECF4569B38CA', '4627135834186', '  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3C9B066-1449-4D08-8F30-68139C3EA4A9', '5C8935A7-A820-4026-8F8A-8B7D63C84223', '4630000191062', '    . 2/ 3 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4847B14-84A3-40DD-9870-D74A2B22E927', 'F0BD4526-605C-43F2-B775-2468C9A55D85', '4630000892013', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8646B1D2-9EED-4F57-AB77-9B6CF434B917', '3EC449C0-E614-4551-B38D-2B9D2235441F', '4630000892181', '     / 2,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CBBDA41-E6D5-4755-ACA2-755A7553530C', '227E1763-3F95-4329-AC77-C509A40DE14D', '4630000892761', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC0E071B-CF4C-4E00-9135-590B2EAC64AA', 'F832CBDB-1091-4159-AF62-9C6A7ED1D5DF', '4630000892860', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C10A57D-4B6A-4CF5-BB56-5DCBD9C9BE4B', 'FE686EBB-8723-463D-B2DA-BF15DFF315BF', '4630000893317', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DF0C3DF-BEAD-4CBB-A288-1B55497E2693', '40472002-D6CE-4764-97D2-DC31921B9D7D', '4630000893454', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61469C1D-5DC6-4C4E-8353-32D0F2EF4663', '5B16B444-DDDA-491F-AC89-9C77914A1534', '4630000893898', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FF55A97-0A05-46C9-A9B8-8CC3DB14F60F', '88F8F08E-9662-489A-A382-E4436D4FA1C7', '4630000910106', ' 3 3-  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD527633-EE0F-4AF6-968C-300FF248E225', 'D6AA6A8D-B2C2-47C0-A128-591B7B5F587D', '4630007837192', ' 3719 1000  /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('732F7C9A-6C1B-46BB-B92F-690312E3DAFC', 'E9A6C871-B976-47D5-8150-EE7EC5E6F1B4', '4630008131282', '- 80+4,5 +-  / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B055A4DD-BF46-4643-8FA7-350261335E9F', '513F4872-9446-4F88-8CE9-7180F8F6CAEC', '4630009186892', '   0,3   .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30B1B52F-FF99-4843-BA52-A88C15A4D3FE', '27EB8BB0-FD8C-4E41-8924-3FA9CCFBE461', '4630009510239', ' 20  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66BD815F-014A-4796-816C-3DCA6B35E9E8', '08515C5F-13BC-4253-92EB-C6FB4543FD77', '4630010490117', '-   10% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('341E9CB6-79FD-4DCA-9821-F9C2D346D26E', '1A3546CE-6182-4755-99C7-C9850E02192A', '4630011650046', ' 300  // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93043961-952E-4B89-A409-31AEC2D814E1', '91B1FEDF-38DC-4DE0-A51D-5DAAB239AD1E', '4630015180020', '     220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B5B2DBD-89A7-41A9-A92B-835FD33C8FA1', 'F4C7D4A3-9F05-47E2-9645-F855BE358E23', '4630017310135', '  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C2215E8-19E2-40A7-9619-C9C6103E6B3C', '63611DC6-E092-43C0-85D3-E05097B0BF90', '4630018880057', '  / dr.aqua  1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFEEFDD6-2886-4BAC-85C9-CE9B64155DC6', '7F174200-365D-47A5-B5C3-5C65986798FA', '4630027040022', ' /   0,1% 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('637801CE-6C1A-4B34-8EE0-B9CAA6A276F0', 'DF9AEC06-6338-4ADD-BB87-C461758FDCDD', '4630030920014', ' 500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B08809D4-94CA-47D4-A129-66C14FF7329A', '76C7BA07-BD24-4036-B02C-88029C74A419', '4631136742869', ' prolongator  - 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('187CD2B6-4239-44FD-880C-324D178B568A', '35EDF876-C777-4C08-BF39-B67A4CF1E2E7', '4634444136016', '-  24 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B9BAD9B-4352-4A8B-9CDF-D3F8B3702B96', '87E86852-55D3-465B-B256-EA06E4D69D2F', '4640000902803', '   36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0194899B-C12F-4934-BE9B-44EF82774517', 'F37A58E6-CEE3-441C-8E21-1C396C427AB9', '4640000905309', '     1813', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA1EF9FD-B6B0-42BE-8280-738206EE9F42', 'F1B51764-529A-4E37-AAF2-8FDEF49B374C', '4640000905378', ' 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C519754-6265-42F4-9F83-432C36A0FE2B', 'D141900D-FF41-4E3B-9979-E922F45AADB6', '4640001380815', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2657CD96-80F3-4101-BF90-36FA76A7BC10', 'E3602C83-6563-40AE-A4B1-4D988E536853', '4640001381287', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96D14756-3DBD-4BCC-8763-DF2065DA4BC7', 'A839973D-E34D-4BE7-A4ED-DC3FF418B7C8', '4640001381492', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B6DFCCC-5229-42D8-8ECA-44C7708091E9', 'FD8BF25E-3A8B-47FA-A8FB-2C9D99798608', '4640001382178', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D197C595-CFDB-4C99-A85B-57005DEE3631', '7FD25260-7EBD-4FB5-BDF7-0C48411394E8', '4640001382307', ' +mg+b6  450  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C02051B6-5A9B-4D52-B584-1DFC72222200', '832EDC83-2CE3-44D1-A2C3-8DFFEC7EBD57', '4640003261020', ' -   2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C05C3F73-268B-4681-9A99-FC1263CAA8FE', 'EA1C0586-5006-491F-BB66-7DF77A9CA2A2', '4640006304250', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8954AE62-F8C8-4D71-B5E8-7848754DE781', 'EC46EBBF-3E5E-42F3-8AC3-ADC150CB2301', '4640006304298', '   - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FDE8D8C-C08A-4876-9F85-E573B2CC969D', 'B1C1D3D7-8367-4735-95A0-3ACCE66CCBD7', '4640009710010', '  - 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AC7F372-72E2-4062-A2E1-52214B1EE5C3', 'BAAA0A33-C1F6-4A18-9DD6-C88EE202AACA', '4640009710447', '   /  .  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB3C3E7C-EAC9-485E-A34A-90F2FC3EE188', '1F6E6D47-EE87-4DE0-B671-3B4273D21260', '4640013550060', ' -  " "  6 ..150 .,', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA85359E-BA16-4262-BB92-F4B2F9CD4D27', '8540B5C0-AAE1-477C-B2E7-A2FCB80DC027', '4640013550077', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFD58D4F-B31C-4979-B1F1-65D2DDED3832', 'A1395CB8-5938-4303-B9B8-6E3DB95A7F59', '4640013550268', '-    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03577D0F-F153-43FC-963C-C18837238095', 'D3F8D64C-C5A0-43FD-914F-6AD36BE66BEC', '4640013550275', '- 180 6+/13971', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('642C731C-2E66-4F1C-AA0C-E91106E758ED', '62C9F101-0170-4971-BFF0-AEA8161E0CB4', '4640013550350', '    6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24B8388A-7405-44E2-BD15-C9EEA5634F70', '0AD8449C-E0E4-403D-A8B5-8FE74E357842', '4640013550367', '14081/144/12   (2.).  "",  6 ., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E9D4514-3990-43E1-B08A-A7DA4B967989', '5581EC87-BF58-44CF-957F-196D1B7CA072', '4640013550428', '   "  ". 3 . 14073', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2B09953-1166-44ED-91DE-B0ED84A8E597', 'BBCCFF3E-C0EA-4B41-8C45-AA8F3F6B47FB', '4640013551791', '     3+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A84E30C1-86A4-4493-B6EC-A708F80511A1', 'C7C79E69-EBD3-4378-AF80-8D717CE20370', '4640013551906', ' benovy  - l 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B2DFD78-1122-4F22-9125-393252BE66EE', '0DC5F1A2-C8FB-4FC9-8119-2B485E8F8E87', '4640013555867', '     0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8FDA2C3-72F1-4A16-895C-8E5F49DA03D9', '85AD4A4F-F2A1-4068-98CD-847DC7656B08', '4640013555898', ' ""  0  15178', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0740B19F-B261-41D8-88F3-1DC9134861D9', 'ED4F2CCA-073B-4573-B331-79AD3FD12204', '4640013555935', '     6./15182 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F9914B8-A7CA-45DE-A158-F3E7D43C1B7A', 'D678B787-F99C-459F-869E-779D662C6E66', '4640013556291', '15186/144/12        "".  0 ., 250., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43ED482D-339F-4BB2-9A5E-08AB4DD63C96', '8D94D1C7-1100-4AD8-BC92-FE711366AEEE', '4640013556307', ' "Just LUBBY"     0 .,250.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DD72FB1-2CE5-4294-916E-DD263BC06F93', '892B99A2-AC3A-45EE-87EE-4BE07D833D99', '4640013556321', ' 125 0+/ /15201/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5506012-EC53-41D9-96E5-97314A45E894', 'D48337B7-2885-45B6-8A13-60E512F5270F', '4640013557502', '- "".  0 ., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B59E42F5-DD39-4319-8CD1-7049B0C0F2EE', '4445390D-FA33-4A32-A07B-4BDF393275EC', '4640013557564', '16342/144/12 - "".  0 ., , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1184E8E4-9A6E-4E0C-8F82-6D367B6B4ABC', '47F14E5A-ED9B-4875-BB27-7270CAF23A9D', '4640013557595', ' 125 0+/ /16402/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E715FAB-6767-46B6-824A-0A5A2C835092', '57DA78CA-B590-4152-8FDC-BC22BC733D56', '4640013558035', ' "" 6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F7B7298-EFE4-4E5C-A8A8-7B9E0332A4A6', '0B2BF7CF-39DD-4CD5-986F-836B292DDFEB', '4640013558042', ' "  "   4 .. ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE6C1597-E6DB-4914-9C84-5D5920C71FB9', 'D2BCB5EE-32D4-461E-AB1C-0EE31FA2678D', '4640016742028', ' -     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8313581-7C2C-4629-A3F8-DB3633B87B81', '5D7CA292-3928-4A8A-B527-4EA4BE7D318D', '4640016743483', ' /      110', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E964FE18-8493-4AC8-BAA6-DBFBC335A156', '50BE85FD-5FBB-49A9-9925-CAE90D9E10E7', '4640017330170', ' 3m ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14762870-F116-44EA-9214-D07B625A8533', '20C1FB69-D445-4A70-A1E0-2E7A4FE092BA', '4640017590543', ' 9500 /-/ 0,3 /. .  - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('414E794B-DED0-49AD-8655-DC9947DC4686', '755E7965-8B4E-426C-B00E-CD8BC8AF048A', '4640017590789', ' 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B83FEF66-C20F-4A95-9930-98934C45377C', 'AF06CBD0-58B0-44A0-9EA4-C0904A3E6587', '4640018640919', ' 4  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A992B14-7EC7-4742-BD71-EAB4171AB682', '097D9713-1956-4C22-A75F-107C8CA9464A', '4640018990304', 'Gel   /    scholl', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC902646-A199-40E2-9983-C6D551D13644', '642C79A8-938F-4B72-B8E3-1A79DCFEBF56', '4640021710135', ' golden  /  //  / spf45+40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E664EBAB-ABC2-473C-B8BB-B7D9943F9600', 'F6983037-8BB6-4A1B-AACB-D8A58E56A7F6', '4650001680778', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC9872C0-083B-4344-8932-1CD30EB08306', '209A35F4-6340-4411-BF6C-11353D3C8833', '4650001681584', '       63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF85EC87-7FD1-4E51-8511-46F95CA5FC9B', '0A29C27D-EF9B-4BF3-B165-5D2590D39A1E', '4650001688958', '    /  0+// 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AA82FF3-591F-44DD-BB24-234C85E4F4A1', 'E6914F72-23F2-4BF1-A94E-0BD906B89B48', '4650001790125', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDD75461-31F8-4AC2-968A-9B5F7A1928F7', '797C5FAE-6C41-4376-B93D-2B132FADDAE6', '4650001790606', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A00AB71-5F68-4AC9-B73E-D5CF9672FC7B', '6409F00D-80AD-4C37-8F35-3514C45114E0', '4650001790651', '   1% 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CBDB8F4-E6B2-4D33-99F9-C89825387184', '657A3220-C991-4304-8BD9-5085578234F4', '4650001791115', '  // 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DB5003A-4580-4B9A-9E5B-248D81BD4F8B', '939269AB-9F7E-48AB-8DBF-6513444986FE', '4650001792136', '   / / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70505B07-6E68-4027-BD33-E8C305AC055D', '9FEA9BDE-4253-4086-98D5-22B1CAB33D70', '4650001792341', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC544553-15CF-4BF0-A961-571B7827222A', '88A6E14F-67FC-4239-877C-05F40CB19728', '4650001792662', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2006A759-63EC-4F75-8B58-E40EF4E955FA', 'AF169E75-D218-48DB-9A30-E1A6C2032428', '4650001793027', '  / 250 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84E17263-CA23-4F8F-BA39-31652D995408', '78D6BE66-F0A0-4D01-9CBD-2B36E3A9AB4F', '4650001793041', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A535D04-B143-4751-A67A-09E7C58B0F1E', '2E7AC771-C6F2-4DA9-B4B4-C98249B511A6', '4650001795175', ' /    , 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('359D1AD3-746F-4A64-9ADA-1EA6AB5A177A', '983948E4-911B-494B-B144-37A0E203BCED', '4650001795410', ' 03 - . , ,  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E396E40-529F-4077-8D63-E6B6CD16625B', '184610B7-F6E2-474A-9CB2-51F6AB8D363C', '4650001795472', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5548957-C5C5-492F-B299-94043788C008', 'CE0AB8D0-79CD-40F2-9CBD-C604E7534647', '4650002440135', '  / 170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC20EF3B-25ED-447F-A22A-1DEED3D29E80', '32B34D01-5F9B-4DAA-8AF5-9B313F942DAF', '4650002440197', '  / 170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E84F15B0-DDCD-4F6E-93E1-5E50328505BF', '3ADB8DEC-4CB3-4D30-BF89-33B61EEADC65', '4650055920172', '  3   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32C75B61-4429-455D-88EE-CAA1CEE7E5C8', 'DB76DC1C-05FB-41C0-A168-56111C4CD3FC', '4650057930513', '   0,5  0,7/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('281051CC-1E3A-4F37-8AFA-E3172BC2171F', 'E3182DD3-0742-4E2B-8E74-AEC4C375EEB6', '4650057930711', '      0,71 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F940E84-BAB4-4E1B-99CC-319CAFA7EACD', 'CB62C9D5-FB8F-4212-B6E5-8A631D697176', '4650057930735', '       11,4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE164583-FD9A-499F-90A1-C609FEBB0CE8', '1C9A0FBE-7C0E-4CEB-8EA3-42CFA4ABEB12', '4650063970015', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8A58D2F-2BB8-4CB2-A39D-0E43660AE1E9', '9BF224A9-5AFA-4272-882F-03D4E329DDAC', '4650065880312', ' Bugstop    ring 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04446333-7ED6-4C8F-B2E5-C549F22CB4CC', '9118C5DC-8A88-4639-8E60-6AAB3C82633F', '4650069650645', ' 80  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9F4E867-D8AC-46BA-A3E5-2D64F5DEEA3F', '29DB1BB6-8526-4B7C-BCB6-2C3423773DA9', '4650069651062', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FDE3F1F-6E91-4166-AAAB-83893BB6ACAC', '9929AEA4-42C0-4831-9BFA-5E1A334C19CC', '4650069780427', '   /        250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0A3D40C-8175-472C-979A-49774DAB6216', 'F36D78D4-8F8C-4292-B850-31A06C96E38F', '4650069780496', '      3  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F47A083-B226-418B-8AB8-BCEE276E0E8D', '1F5AD7E8-68B1-49BC-B927-BC7802E81262', '4650069782674', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C4394FC-F9D9-4120-A972-50DD13299266', '7E9E1DC6-523F-426D-9A3E-1CBB5D6DE781', '4650069830054', '   0.15/ 17.5 N 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43340886-BEA6-47AC-89B2-E5AB538D37B7', '4C30914C-A60C-40B7-8924-6F48EC982262', '4650069840244', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C78B9273-AE99-4E3E-990E-8C9EEB99738E', '7B87B645-38E1-4B5E-9646-B92629D68FBE', '4650069840459', '  . // 11 08', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A547EED9-6C6A-4849-AE9F-E6322662833B', '351DBD45-8980-4C55-BBAA-9632028744C2', '4650069840817', '  . / / 11 44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3793EE77-165C-44E1-AE90-41DD3EB57155', '61E86241-573E-49A5-8E4A-BEB5B6996478', '4650069841517', '  . / / 11 314', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7F7FB43-F441-4CEF-BDAB-BAD7ABBD1463', '20A22F73-1F82-46D7-A162-00644545235D', '4650069841562', '  . / / 11 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A93AC39C-FBF9-49CE-B292-128644B2F9F1', '5C353413-FCE6-4EE1-9896-1FBAAA986116', '4650069843047', '  - /  /121/ 11 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67D094B2-FCAC-4DEC-B86D-A136F2415A5A', 'CB3B2053-A2AF-4847-A5CE-F7E031C5D01F', '4650069843481', '    7 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('818B0245-576C-4860-A098-3DA7E207BC2B', '48C3943A-7FB9-46EA-93DF-40AF17A3D8AE', '4650069843559', '  - / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1246081-912A-4642-BCF0-0A9811410D0A', '155213A3-E2A6-410D-84A6-E65888B4AB1F', '4650070110046', '      /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('621F9434-9AD5-474F-8DA7-1FD6252F755F', '138E66BA-E87D-4002-9D56-28216F8664D4', '4650070110428', '    7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('124FF9E6-A31B-4206-BAFF-DB73BA65EDFC', 'A92D796D-9613-4218-8F82-313F67B4F095', '4650070510280', ' /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3524BCBC-2F3C-4F7B-9E7C-C635CEFF7086', 'EB6472DA-F6F4-4155-975A-E81ECFAF6C40', '4650070510334', '    /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD482798-2F95-4E72-AB92-DFF9A1EAC726', '4B11F1AC-A826-4C19-9C21-8A262D31D235', '4650070610256', '    10   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6FC6A34-9153-4DB1-8EB9-2C5853AA5F5C', 'DE1B3FCC-8DF7-4CD7-9532-1CA03B02F11A', '4650071435629', ' 310 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AF43814-F9CC-428E-8C6E-ADF2CAF90253', '07967517-25A9-47B4-9744-A72EAE064555', '4660000640109', ' -14  / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB64B610-872D-476A-94FC-36EC7B412BC5', 'A914C77F-49C0-4C12-96B3-8B02A6EA724E', '4660005620045', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('508517B6-94E1-46F3-84E0-E4B4FF18BBF3', '5552938D-0D66-4D93-8D29-27055E1E7788', '4660005990056', '  .   2.. 5 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FBD1D65-4DCE-4932-B1D3-4CBE57299C41', 'DB4D9F49-1437-4217-BC1F-E3D5CBAE24B4', '4660005990209', '  .   3.. 5 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20E67069-BFDA-4139-97B5-74CD1C137E44', '3E8DDB16-6C70-4BA9-9417-256A01DABF36', '4660005990650', '  /   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06BEDD8D-449E-40C6-90AB-41C8FAD46B3A', '8037D650-DD8C-474B-B98A-A133860068B3', '4660007090105', '  4500 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CADA818F-AE38-4E23-9164-D5E111FFCA5E', '76645784-99F8-48FF-BB56-1EB23FF9CCA4', '4660007701155', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A0C8390-1526-485F-8739-CD74C577DA22', 'F5272511-5194-49FC-9A39-3AC85C7BD37C', '4660007701513', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F11EF9EF-1352-4BD9-A21E-09E25DCB32E8', 'BF9C46BF-2DB6-4761-9A4C-73B9207BAA49', '4660007701636', ' 40  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8231587-303E-43C0-A09E-ADCC9C79475E', '019BF1F8-88C2-42E5-BEAF-B4F2ED0EE8D7', '4660007703159', '  10+158,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3228404C-2936-4B3F-B712-14C55EAA92DA', '072D24CE-0C6E-4622-B77D-D51A3771B704', '4660007703562', '  35  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82A5BBA9-88BB-4A15-B09B-D7F00FA3E7C9', '2B73611A-BB5B-4372-82D4-3B4CD0A3A4D7', '4660011213804', '  1  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1F4A2DA-51E3-4FD7-96D6-BB36A574CF6C', '97265673-6985-486F-8518-077DE1B93FE3', '4660011214641', '   -    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7BAB168-A1C6-4925-85F4-EAADE100D5B0', 'E5875911-FF5B-4FD2-92D2-752D42BCC2BB', '4660013570394', '     . 60*90  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('535C6E0A-2C26-4ACB-9B43-DB81A970E320', '8C13659F-B615-4076-BA0D-3B9125C1C29B', '4660013570516', '   /      . 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EFB3DBB-E7C5-4D3D-888D-FB53FC27714B', 'D44E8A9E-6179-4754-B45D-CFD04FE345A9', '4660014120048', '  /. . 2% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA6060AF-5F5C-4FB7-9989-42C9A710107E', '9EFD18FE-2DD9-4FCA-8004-D52313825BB6', '4660014120321', '    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1857F47-7EEB-4557-93B9-6B3DBF21FB58', '34921DDF-2296-43F6-BD4E-D85BFA16D112', '4660014180189', ' 50  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6170C8C-9B30-4843-BBD0-021786C52CCB', 'D0A13016-20A5-445A-9770-54EF32E65708', '4660014180912', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6DF280F-0079-40BF-949D-1B3E2F839E5C', 'D4E72A68-D23A-435F-B8C8-22A7E229974E', '4660014180950', '  0,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62F3700C-83F5-411B-BB79-5BC21908AFE5', '66E22943-189E-4F58-A83A-6B363A52EAB5', '4660014181339', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED0F696D-398C-4936-83D8-92818F0D0E5A', 'AF24C0A8-926B-465F-94C7-3D3691382C11', '4660016310010', ' - / / // 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E37CD7E-CA87-4D51-B198-8160A057D6DE', '3124FF60-3249-4524-8862-92ED613F3748', '4660018600195', '      160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA74B3F9-BDED-49D8-8C7E-592CA5C45E67', 'B80AEB04-33EE-4A9F-A1CC-4E7FFA350513', '4660018601192', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45775761-EF82-442E-AE49-CDA5DE2301D2', '8B60E4C8-33E2-4B5B-9A6B-5CD0BDF8F75E', '4660018601505', 'Sun time sey bronze -  spf 3 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACAE094F-B73B-4D7A-9753-C1D82E8B343E', 'F33042BA-1872-47C6-9506-2B4A172830E6', '4660018601666', '    /  290', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9B89B6A-657E-4A6E-A847-B12FD8DF0917', '17A9702F-DF52-49D4-9E19-5884F4B7E02D', '4660041990041', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6BAB856-ED8D-4245-B834-AAF484E553DE', '7BDE8363-0143-4036-A773-AD12B2E31F94', '4663111034928', '  / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('510EF118-C93E-4213-99C6-2814EA76C705', '40025749-9FA3-4EE0-B5F3-87A9A79D5DAA', '4670000470637', ' - / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3F6A8B7-7548-436E-9642-36C3FC2B9728', '50657310-8118-448F-B2FF-8B8303C71E2A', '4670000471672', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F2672A7-92B8-4EAF-A912-BBD351EC26C6', 'B9745DD3-6FC2-4D62-8E19-F9442ABBCA83', '4670000473065', '  /   530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1936199E-1553-4145-ABEE-34CCA4A75258', 'F051A20F-06A7-4DF4-AE2D-420775474579', '4670000473577', ' -    /  . 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7940E082-E3EC-48D2-ABAC-D18EDB6D9532', '55F93EC9-6837-484D-8274-AFE7AF6F6C7D', '4670002260403', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4D4E751-1C3C-4179-8306-1C3C608AB2BB', '7794253D-89BF-4C2D-9D50-258B27FC44FA', '4670002260625', '  1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D59102BB-F03E-438B-B07E-9A7B0BBD6C55', 'EDE23AB7-5FD7-4027-A227-C6306F222AE3', '4670002261028', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7F1F24B-58E5-4D6E-BF74-63FD24318B75', '3EADB7E9-E41D-4F55-832C-29242288D826', '4670002261103', ' 400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C61671B8-2CE4-4DF7-BEE5-D252C43CDC63', '04F22193-00D2-44E3-A514-5F22805090A0', '4670002261141', ' 350  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('892EFB5C-E49A-4B67-8446-4B13E4BB0676', 'CB06A0F7-EC68-49D2-BA4B-29F8AA329F7A', '4670003600963', ' 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29BE57DA-7CCA-419D-9C15-0F4A8D30B575', '3FFB5396-B49E-439A-9F6E-FA09F789B2CC', '4670005860433', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD55B43A-FBE7-4A91-8265-489AE649D42A', 'CBA1E1E5-191F-4787-B874-F369618D65E1', '4670005860532', '    /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C190E3C-35E2-4ECC-8A7D-D540874A8506', 'FC6EF200-2528-43A2-97F0-C173A8CE07A8', '4670005860587', ' -  /  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9895D869-5613-491C-8085-6E055BFE5F92', 'CE09AEB8-E8DD-4DAF-BB85-EA732E5169D4', '4670005860594', '  / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52D371CB-4DBE-4AC4-9F50-C9077DCCDA2B', 'A857C501-63E5-4B71-AFF3-B315B7BB4B45', '4670005860631', ' /     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC3EFC36-6641-4BD0-AF2D-680AE5B09585', '8B8BA6A8-C8F3-462A-8074-A8BA4EF0AA0B', '4670005860655', '         250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('922A91BC-0101-4B2C-BC1A-5971AF47F33B', 'D50A8430-5D1A-45AF-AB7D-B4516EAB0332', '4670010370101', ' /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CA76D09-1658-4881-9E31-4284279B8F32', '07AA3CDB-7FAD-42AE-8A1A-B194564BFCD5', '4670010370118', ' /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1865F86E-5251-4178-8F65-3678800F25E8', '15E836D3-DC24-4E34-84BD-BC63F9D7BB4C', '4670010370125', ' /    200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AB50B4E-CCFA-465B-B488-91FD343FF8CA', '93751637-7F7A-46F5-B216-B7C4DF2D25CE', '4670010370385', '  .l 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C550DC5-CBD3-42B0-A3E3-468222A48BC1', '37F54361-E6A8-4E91-8627-2B84CFD9B841', '4670010370415', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EAEA89F-11B9-418A-AA87-948AAFF92BDA', '1DC20E70-38B2-4D73-AF3C-9CC66B6A790F', '4670010370453', '- 600  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FBACD17-082B-495A-B5A8-F3B7CE2C9325', '95E61E8A-6C9F-4B05-8F4C-181E2A9FAE7F', '4670010371283', '    -    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16499D25-32D9-48AA-997A-F1952E4255CB', '9F70D7C2-783A-4E98-A741-EE17073FC959', '4670012610540', '  80/4,5/ 60  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6841B89-09E5-40E4-8E4A-8748C64C69D5', 'E7C19809-185E-4962-96E8-02E742AFA9C6', '4670017923072', '  /  155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E138A1E5-6037-4466-970D-AC217C2B1693', 'E20D282F-F088-4894-82F2-4B3BFA138FA0', '4670017924369', ' /   4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0946942E-E1B5-4195-89D5-709C79D9008E', 'AF8A5A55-E961-45C7-9578-A3855ED9FC58', '4670017924406', ' /   4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1BC97C4-0F43-4C48-B5B7-600101D194C0', 'B19334E2-8BF9-428B-8024-430D4F17D2E1', '4670017924703', '    / -  4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B0A2AA5-1558-47AB-B150-812F0C504263', '34F69FC5-2133-448B-8DB1-2A23BAA60B20', '4670017926769', '    ///   /  155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C073864-A42B-462F-9A21-6EECCF27CD8B', '1E2BFCBE-8301-42AD-A818-45A6B0CDF1B0', '4670018370011', '    - 58 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E4B2A77-6639-4C06-AFB2-D2B58E843AB3', '28911639-46B2-426E-A685-450E5869F46C', '4680002475769', '    100  -  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E0ED447-0AA0-4215-9D88-7F9B129D47D4', '5FF36949-435B-4FED-9E78-639C7A615D67', '4680002476209', '     200 .   5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA704835-1A89-4FA5-AAF0-06473B9771FD', '816F4C00-7446-4021-BA59-6FCD997E4A54', '4680002476315', '   /     6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A185DDE-8417-479D-8685-7570D20E1448', 'C2800B63-B793-4B3A-83F2-D633932EA733', '4680002477213', '  /  / c 4  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0C7955F-6C48-44A8-99E0-7A99F39266F6', 'AAA521E6-E64E-4B59-8F55-1B3E260025DD', '4680004854234', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABAD4869-ADF3-40F5-8AD5-229135C92ED6', 'FEEC9B48-C20A-4A1C-860C-4DAE9BAE6163', '4680004854593', '      // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D7516F0-713A-4DA2-B4B9-8425693AA7F1', 'F0C40430-0D15-408A-BC12-BE6D536E1BE7', '4680004854883', '   / /  . 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B70D7E87-6ACF-4D2D-9201-607155AA7CE7', 'D6D637C7-F060-41EC-8A6A-F58672215F5E', '4680004854906', '    //  .  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('885CF40A-C47D-47B8-A038-953D9958E773', '7F13528C-1C9B-4578-9A4E-AEE83D8FD485', '4680006523848', ' /. .  70%  - 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E7C33E4-F00A-450D-A088-A37A91324699', '55470CC4-BB31-46B9-BF33-03230FA1EBE7', '4680007750458', '   Lusan  60-60 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B310AB9-F1F0-42C5-92CE-CA7E4D2FA060', 'DB781783-F27B-4876-949F-752A4B777919', '4680007751431', '  lusan  60 90 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA6815B8-B02F-45BA-8B04-2800068DDB56', '19F7243A-0003-45EE-99CF-BE1DEF2F69E1', '4680013242862', '  0,5% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F75ADA8-891A-4523-A76A-D787B6829E36', 'CA5E3E49-15CB-4486-9A07-445EB2D6719A', '4680013244132', '- / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D66CCB8C-462E-4090-A048-FD5A32408540', 'EEE1035A-DEDE-4846-A119-05FA068D408A', '4680013246273', ' 0,1 / 1 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0A11543-6B7E-4EF9-A9F2-09F1EA700459', 'A27220FF-7BE7-4493-9EE5-AAF95DACD886', '4680013246310', ' 3% 1  - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BF077FA-0ED3-4945-AE82-840BA8628050', 'ADF580C7-1044-495C-9E2E-42F2D94CB348', '4680013246662', ' -  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CDFA5FA-8F3D-49A3-A426-B5D329594D0C', 'ABE6423A-D645-481A-AFA0-72E52F658CC1', '4680013249298', ' 7,5    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6A746E3-1A5F-489A-8B70-4A2E123EB77F', '8B353AF1-929A-48DA-BABF-51B401992315', '4680020180522', ' 100  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F0C7D79-AE72-45C3-B746-3665D0A67744', '8A1412A8-1C46-4799-BC65-4F6F66811A50', '4680038240287', '      155,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFB274EC-3A84-4378-A34E-5D6A2CA41609', '43EB6E80-F83F-4297-9DD7-16F0651AA5B7', '4680038243349', '   /      220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90C521CF-9DA5-4E12-B446-A050B7F37895', '9BB9BD6D-A966-4F61-8936-FACBD30BFFC3', '4680038900013', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22A432EF-B91D-4F21-8182-3C7C63C7BA1A', '0CFFDCFC-0C79-4331-8223-9F00CEE5E01E', '4680245001213', ' /     10% 6,0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C9C1677-E0E8-4695-8068-4AA306FF86A2', 'F74158D4-3A6A-40BE-99A8-3D3A933D7C9A', '4680287525609', '       2 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C818269-57A0-4C17-9142-3F7A194404A0', 'CB169949-9958-466C-9C3B-F0C59A59E9ED', '4680287525623', '  /  2 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26CD6CBE-27BF-4A1A-97D4-32EC9299AAD0', '0963C0F3-8B76-4452-8469-FE3732F4A171', '4690419009716', '  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EDF4B25-2B3C-4DA0-B20C-AB923EB01E47', 'F278A4AF-9A05-4101-B858-3AA976C5B8D5', '4690419012716', '        200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('081F9417-7AB5-468F-960F-5459613FB96A', '1947ED72-070F-4FBC-8613-B56718ED6E29', '4690419014116', '       1 4,7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8510FA8-8FC4-49F7-90CB-6265054BD801', '4AAF216F-7034-4F34-B2B5-2F814C60CBD1', '4690567004809', '  5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E0E2C47-5EFA-4F28-BA44-DC4485C58BD6', '46EF852A-53C4-4284-9944-B7D7432D3714', '4690567008241', '   1,97,2 .20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5E280D8-9C96-47DB-BDA4-E5E4C613DE04', '4F960B25-9F62-422A-85DD-0DC6679AA3DE', '4690567008692', '  5%  - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFFBF015-B26F-4E70-9088-4F769E10FDD7', '055C579D-1534-41DE-B12C-1233CD3B6099', '4690624008559', '     / /32009', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0FE6CCB-E718-4679-92F4-8C35E8404617', 'EB0CEFE2-7018-4312-9ECC-E73437060627', '4690624008771', '   / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10AE7AFC-9C15-4F1D-8D44-A68A0DF5D79E', 'DBC8A1C5-4BB4-47F3-A3A2-5C9E7B02D728', '4690624008788', '   / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8819869-7E72-4154-B235-FA76AE20A179', '47814EA9-2FAE-4BE2-92C7-3103590F4898', '4690655002908', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22EB2F6C-E05D-489D-9CA3-5123FA550F41', '15F0416F-6353-492A-9F63-C4478AE01346', '4690655011597', '- 0,025 //  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4F1C561-426E-40E1-BEF2-1892D891CD9A', '80E1FFDF-B551-40C9-8CC1-CEE29804689C', '4690655015762', ' 25  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10D1815E-2DAC-4546-A859-A921D6734E07', 'FFAC0C1C-C604-46E8-9AA2-C41540920092', '4690655015885', '- 100  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1C4EED4-AB27-4EB0-8EB1-668B42B661B4', '3981CFD3-CE9D-4305-AF46-5C51FBD832AF', '4690655017605', '- 0,05 //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49382290-D0D0-4F46-A9B5-AEEB0935FE41', 'DFB77173-1146-4C89-A385-C101ECA8E0E1', '4710425920345', '  10019', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0F0BDF8-CB9C-40A7-9912-81ECF7AE7198', 'B1A5B85D-5F64-40B7-85B6-54B5661B2C3B', '4710425923629', ' c / L', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B715DC0-9FC0-4198-9F1A-CD86A1A6CF6F', '94C9D56E-00EA-40D6-90C0-40A61EC6F559', '4710425924503', '   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FCA2408-5FA8-4120-AF57-BE9D48A23204', 'C59E7A2A-4BAB-4373-8B67-50894E66AB45', '4711146100139', ' / 10013 camera', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDD6BF1B-58FA-4156-B98E-B6DC5B1F11A6', 'FA1532BF-762D-4E68-B827-DD0BDBECD1BE', '4711146111302', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87ED8095-8DA9-4FA6-AAEA-D65A8C598155', '26E6560E-97D3-4A74-B95D-FC3ACC7665B0', '4711146455574', ' -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0651E347-F909-411B-B36D-78B22C98A1BB', '9D7CDD97-8222-4A64-9CA5-9076946CADBC', '4711934139617', ' wm-63s   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98C63E1B-9CA5-4D11-9949-5EE1D2AEA72B', 'EF66C1C9-91BE-4B6A-82A0-0724EF9FE257', '4714204026235', '  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB161CB8-1991-4255-B94F-DE2A3608BF5A', 'DB810DBA-D48E-48D3-AF13-4A7E154463A4', '4750232000502', '  /  2,2  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F7CB882-071F-48E5-A9CD-D941876254E0', '4B94A76A-340E-4578-9188-2C5D5A658E07', '4750232001639', '  10   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5D5A082-4F43-4823-A8C9-36062B923790', '3AB2038D-408F-4950-8123-BC1EA6A879EF', '4750232003541', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9997607F-433E-4558-8C99-346D78433833', '3EE6AD69-102E-4B25-8FFE-434949018FCB', '4750232003770', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C571043D-3317-494B-A3B9-3F954696C6B2', '8C3F5850-21AA-41AC-A244-7500BF10D606', '4750232004920', '  4 5 100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB6F0D4F-51F4-439E-9BB5-08941EBDB4D7', 'F29A752F-6854-43CC-B967-0A046E080EF4', '4750258314171', ' 25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5F81BA2-8F5E-4844-8207-B9AFB229557D', 'F9530F35-DFA1-4ED8-B29A-385C27927000', '4750282901279', ' 0,68 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB75FDA9-ADCA-41A8-80C0-31859DB5B38D', 'D27D9D27-FB4D-47BD-8FB0-5F8657FF8F4D', '4750282901521', ' 38 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('289F2E99-C297-4E9E-9574-434743CAEF72', 'F5BC2D4E-936F-4F26-8B41-B552F8500273', '4750283009264', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5967F22D-46C7-4340-9508-972C49F7BE77', '8DF8CC86-CB98-434B-858E-CD618F7FB976', '4750283009363', '  0107 1  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE354C17-F875-46F3-A137-10E729A8326C', 'D6426F46-7A88-448A-9119-822DF88B9D19', '4750283028104', '  . 0402 // 1.. 2 / / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15C19003-5D51-4CE0-B2B9-3A6F0D64B49E', 'BF96557A-1D67-4532-8558-46A1FFDDFD3C', '4750283035089', ' / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CB38F3E-77F2-4B1D-874F-52980CF64F4F', 'EA4E5AA5-3829-4D6A-896E-CE8A27EE67E1', '4750283046153', '  .    .4 /9509-/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF7E2EA4-C6AE-4AE6-81ED-00803A6DCC97', '0566B6A5-F0FC-4FD5-BBE7-AE1FD11E3F88', '4750283048096', '    /  2/ 3//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09271350-D39F-4193-9F8B-B9426571C708', 'EA8A65DF-5C66-4DA3-99A7-74BE1D912C69', '4751006755017', '     3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE65CAFA-72C7-4E99-BE9A-C8D7EAB6BDBA', '5B8B3008-79E4-4851-874F-13E79BF36B97', '4751018120049', '  /   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9051F1D6-72DE-4F98-908E-D1F331350B47', '859F99F4-1915-44A6-B05A-CD9BCF884A14', '4751018120247', '  /   C 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23F8D47A-B0A0-409C-9622-CB2F145A000D', 'B48C26EE-CCE5-4A4A-A197-D6975F9F61B8', '4751018120346', '  /  - 12% 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58C0E9EB-4727-421B-A35A-835ADDDA1C60', '434F9A45-EEC7-4537-B93D-F92763AAC0C7', '4751018120445', '  /    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ECF3833-DBF9-4061-9C35-8CA3198F7DE8', '9E44D495-19E2-4F33-8339-DEFEF4BA7B93', '4751023291314', '     63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FD3C84D-C341-46A6-A47C-D312B0FACC65', '7AAA683A-1BBE-4EFD-9D5C-D919CAF57841', '4751023293981', 'Lure vitamins   /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9245AAB-59FF-4CE8-8100-BCC16EC187AA', '489CEDAE-63CE-4DB0-B85D-E7D22781E039', '4751023294001', '   /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F074396-DC16-4B6A-90E4-913265F469D9', '5E336553-7E66-436F-8E7B-BC78DEBDCCF8', '4751023295954', ' lure  comple  /  .  - 450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4294DF62-DCEE-4471-BC0A-A9E0EB044D2A', '2238CAE7-E672-49CC-BC65-B5F5BC4AB03B', '4751023297200', '    /  0+200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A1C2A10-8C67-4C2C-9A64-AD13A0BC3C13', '4E677630-1F83-488B-928F-54A6D9A48A4E', '4751023298757', '    3/m 4-9 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8B075F6-2C48-4405-8F39-6D93BD6AD6DF', '25BB0317-6767-49A9-A4F6-00C8D4FED109', '4751023299693', '      / 0+/    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CB0744F-B7F9-4DE7-A63C-0E0841BDFAD7', '07BDF707-BF37-4179-B2E9-C18F783E554F', '4810133002262', ' 150  /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7D61945-03AB-4966-8E70-A42894112F6A', 'D5E117D8-269E-4EBC-AA6C-92A583821690', '4810153021564', ' . - /  24  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('632BDC34-42E7-4156-BD82-BE435C111C82', '6A850400-CC4D-4CC0-AC34-F935372DDB8E', '4810153021595', ' . . 40+ / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2FDBFE1-1407-4C65-89C0-A2B3B12C4171', 'DEF79025-9B07-49AB-8DFB-DF953B797125', '4810263028774', '  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47672530-399B-4BAF-907C-7DBC1194FF92', 'FB5305FC-8F14-47B8-97EC-159454DE69D3', '4810304013363', ' -     50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65D29EE7-2003-4002-8A86-987A17F11A06', '86196230-A078-45CE-97F9-A425748776D4', '4810910003758', '   900   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('319B7EA7-4043-4D6A-846A-246280432F42', '5F0D678D-47D7-4117-8855-5674484F6C25', '4811248005674', ' apothecary /   500 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC8EF0D5-1FB5-4145-A433-C6F950993398', '86BF3464-F44E-4543-BE35-6509869B8636', '4811248006022', '     /   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('520EB762-8629-43A4-8DB2-3DF1D881BCD6', '39CBB569-A95C-4C28-BCF3-286FDE03A12F', '4811379000098', '  -   / /+ /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E08EAB7-178E-4FAB-9066-9716CD40635C', '2204242D-DDB8-4A2B-A9A0-B9EFCC561B8D', '4811379000173', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('677FE28B-36B6-452A-A9D5-142E0519412D', '25F79759-EB50-42C3-93A5-6A725F3D9E40', '4812317000156', '  //         10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D17A0E6-E45E-45CB-BF93-103EF65927D5', 'ED058729-B8BF-4628-A25F-761BAB9D183C', '4812635002207', ' . .  . 1,65,7 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2DB0BC7-4B02-4591-8959-CE77FABE3674', '14C8E7B7-6231-490C-A40D-50F3C63C744A', '4813870002199', '      25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A27F9562-D8C9-461F-A676-8B9DDC390C76', '05E2AD9C-8958-46D8-A59A-59798338D09A', '4814488003417', '  /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F751F28-4240-4BAE-BE26-0621C1BCA8B4', '6466505E-D6D6-4170-8134-552DFD31A252', '4820000680707', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F67B300-582E-4AB3-8463-06A08A1F8360', 'F34E1DE2-2425-465A-92CF-E95746B0672C', '4820000680721', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48E9A6EE-E567-457C-9DB0-29ED362E5D5A', 'BF5EB050-41F3-41DE-8179-A924C2A6D712', '4820008311092', '          30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEB24791-218B-4F14-B205-A2B7820774CB', 'C6B81C84-BFD5-45BF-8835-5531D5470821', '4820008314024', '   /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59199FAA-414E-44F9-A6AB-C61386CCEE97', '67FF50F8-6F02-4500-9B99-57812F29283A', '4820065530221', '-    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DFC6B78-911E-45D1-A56E-912FEF78BDEC', 'EC02B6BB-600A-403F-A08D-C3F587B588E1', '4820121900821', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16985CE5-3993-405A-A4D7-4315D567A158', '8476C044-4E78-4B4F-BC8B-10207D37448A', '4820121901064', ' - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B4C8B54-8B1A-41FA-BEDA-A92923AF01E5', '65B69E54-BB0F-474D-9AC1-A0C32A99EE96', '4820121901071', '  , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2DF7A57-AE17-415E-BA1F-A2A3BCA67593', '25689E83-B760-4354-9832-DF218FEB79BA', '4820121901125', '  - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8012B33-E61D-49EF-B1F1-A6295AD938CE', '74D17341-D916-4B5A-98F1-1157B81A3C59', '4820121901323', '   2005', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C27E23B7-AC3F-4FE4-B120-32F4E4AE4FAD', 'B708A69D-AC4B-44F1-9026-660DA000D233', '4820121901347', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34186BCC-3B69-4C9F-9A87-CFE4992A903E', '32176DBB-1993-4433-8821-7C501767AAF2', '4820121901514', '       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC5F7CC1-2C3E-40F6-9C46-AD7B5D983151', '386B9789-B39D-4472-8300-FBBCDDEA8599', '4820121901538', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18E36A00-EE81-4513-9A89-A41CD95C96BD', '69277FD4-5681-4241-AEE4-E86D7F5A2148', '4820121901743', ' 0-6 .   /415/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37C79217-50D4-47D6-B880-FC68837EF5F5', '6493F34B-4E18-446C-89E9-E5F6A28B81BB', '4820121901835', '   /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0819B33-20F3-47DD-9685-22DA4E52C3E3', '8D7915E4-8CFD-4DDB-8AAF-159D14D97253', '4820121901927', '   /.  150 1115', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8E7851B-4B9E-4960-8DFB-51437DA1A980', '5FE22DCB-1DF5-4584-B7ED-4A51FF2CB21A', '4820121901972', '  /+/, / 96*72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('268954AF-9AC5-4AD4-88C7-34B56B62F480', '7B8F585C-1C87-4A0C-BD79-D4CE1F2C91AE', '4820127150213', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8763E953-8CAA-4592-94DA-78AB281C1D6E', '529FD2A0-69D9-44A4-B244-3A9C65263B1E', '4820142800766', '        15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE0BBF3A-E76C-4402-BD82-C2172640943A', '5A810291-AA31-4EFD-A907-3BC6B32E52F9', '4820153892897', ' health    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('178EF454-851B-4050-A54F-BCE463F78EB4', '07AAD135-F32D-4F08-809C-95DB44CE8E5F', '4820160035386', '     30+50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67CB7604-AC6E-4214-B0C8-E92001B543D8', '600FB808-64B2-4BFD-A501-96DC3B5B7AE9', '4823000804876', 'L-  0,1% 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2B56DEF-1EF2-4487-8218-9B579DBAB7EA', 'C51C2E83-992B-47D5-9AEE-60889F44A638', '4823015905810', '    / //100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22F7D909-E618-4F81-A224-7154F7A27EC6', 'EBDB35F7-EDF4-4E44-8DC5-42A54C24F5BB', '4823015906992', '   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9F19B98-F9E2-44FF-9975-14ECC6BF69A0', 'E93D2339-BDC7-4CEF-955F-C2EEED32BEC0', '4823060800078', ' . 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE735A22-25D9-4D99-ACC1-96DE2AAC788E', '0F824DB4-29D7-43AB-A79D-0ADA90712DD5', '4823060801877', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7DF3D6C-AAD8-4B17-9510-FB38321DEE83', '6BC0263D-4CDE-4CD3-B0AE-9B4408959E5E', '4902011751314', '   5 /n/b 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A84CE90B-12FA-4C75-AEE5-854495452A0C', '6CEBA0C5-49B3-46FF-8CA7-DAFC362F65B0', '4902011751345', ' goon 9-14 /l/ 54', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A474498-92E3-4214-B9CC-E494DBDF8239', '01590E5E-732A-46D2-B7BA-D64B55B5E8B8', '4987188521687', '   710 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56DA1AAA-FD7E-475F-9437-747C665244A8', 'BC036099-4A7B-4396-B94F-C09F8B4D5C59', '5000158071407', '    10  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59A207E3-A32B-4DA2-B9C1-DF1B41C50E48', '56DA4DA5-0A58-49BC-8095-2FCFDD5B97F2', '5000174415568', '    7  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ED27375-4511-4326-A362-9F6BC2D5E884', '3B15378C-986B-4431-9953-499C122788AA', '5000288302266', '     scholl 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DE92C42-ABEB-4678-84AB-DB0FB1BC2A14', 'F2C382B7-FF88-4BC8-90EF-4F2D4D86F0D5', '5009612931035', ' /  /femitest jet //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61EE6267-AF3E-4192-8D4D-3CC869B5F0CD', '87ECC2DE-5B76-4135-83DC-3CCDC6A3C5C6', '5009612961278', '   5c500c  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF74EAB3-24E6-4BB2-BA3B-BF88E2C98D51', '96EB49B9-D157-4869-93FC-AC5CB0466848', '5010006101385', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85CC7AE4-6E66-4057-A3A2-DB62BF9CFFDF', '1BF4C111-450A-4621-B3F5-37D049BB77F5', '5011597001016', ' / animals', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66FE080F-0AE7-48C4-B426-99773EBFAE1F', '10D9C07E-9FA9-473B-B56F-A8C1BCB31302', '5011597001634', '  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79327D5A-A567-4871-8B3B-952806BD4DF8', '73F0F926-DDC2-4C48-9A83-4DEAF5C70634', '5011597002051', ' / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C43E7467-7002-441C-95B0-6D6F7143163E', 'DC01E8B7-3ACE-489B-9EB0-CA3E699C363C', '5012909007603', '  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1D1046B-A51F-45AA-A363-948A96B186C5', 'A6AA7FE8-7B43-4C0D-AEEF-0F15BA8394DE', '5013965797347', ' / - pro-epert - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7598715D-D469-4B30-BB0D-46148C3A8B06', '3D7227B2-11A1-4616-AECD-E590EDEB0D6A', '5017034541053', '   - 5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E70BC3C5-DF98-4D2E-99FF-F54AF800B2E2', '8FE1A25A-7D69-4068-9EAB-A7BC40B1FA56', '5021265243952', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B629F165-9CEC-46E0-ABE5-AF645DD0591C', 'C3E8A29B-801A-4891-BDE0-149D0071BBCF', '5029053002033', '      1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDED209F-B2A7-4EB6-95DD-E6CBC4DE77BF', '7306D6A7-0DE8-460D-AFB7-ED8740293A35', '5029053541259', '  . /.   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11CE9886-07CA-4B2F-8061-0C5D559C1DA7', '55744352-78A5-46EC-A8BE-77AA263A0C3A', '5029053545790', '   / 3(7-11 ) 19', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E72AB724-2BEC-4E53-AAC5-B6FFFDD2060F', 'BC9C9973-4637-495E-836C-9A6D1734FA9F', '5029053550022', ' .   56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F3C8920-6CD0-461D-91C8-81DB2667D9A5', '80AE6C6E-6442-4F06-B2A5-7A37E9090D74', '5050474103719', '   10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B69A247-C600-486F-A677-CA548E322169', '4AA7DD49-9BFA-4DB5-844F-45CBD2F5DF6B', '5052197051223', '  elite ,  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF47144F-ED3A-4E93-A228-514A44CA77E5', 'DFC1CA03-9734-4FE3-BC06-D7B07AB6718E', '5060038502018', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCA30A3F-9677-4324-A9BF-0121D51B7D11', 'A27BD5AA-06DA-4BFC-B8C1-C1136DD64DFF', '5060038502230', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('991CABC8-F762-471D-BDEE-352EDC80251D', 'FD832782-4D27-4E7B-BE42-8EF3E986E1AC', '5060038502360', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9565262F-26CC-47ED-A6AB-E200746F257C', 'C767D8BD-A340-449D-8CF3-B91A98ABC5EA', '5060038502384', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85FA41EB-354E-4D7B-99B8-815C85A3E52A', '26D2DC0D-4AD2-4701-B02E-88FF7CD30F2F', '5060040302545', '  long love 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94FE4B66-EC7A-4A7A-BE92-DB3F7399BB15', 'F5CA23F4-C5F6-4F31-B423-56729F8B502A', '5060068527005', '   /.  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E411DF93-9D77-4481-B653-8ECA56BDC1E9', 'FA615D43-F28E-41FF-97A2-1472D53D28E0', '5060249172628', ' 2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('332326E2-9BCD-4A26-B6A0-32D272D94CE1', '9D6C53DC-1546-47D9-ACAA-7932A3AB8B56', '5060329480018', ' /   u    7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AF70B39-04CE-42F3-9F1F-26FE3B04C2CD', '9ECB7E22-7AAB-4E29-9369-C0F12EFBA976', '5292452000591', '  / .//36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF065298-8C90-4EDA-82F3-C57415D8024A', 'F877D549-0F6F-4207-A9E0-8A5CA22A3D4F', '5292452000607', '  / -. /./ 1 2 6+ 36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD1C826F-CAB4-43CE-BF72-71F21E002B29', '91B42921-C3AB-4497-9E4E-A925C2B5F906', '5292452000638', '  /    2-     / . / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BECD3A3C-C6EE-4B30-BA60-A6729FC0E0D9', '1F1F68CA-0D5B-46F6-ACBC-E9C282277178', '5390225547400', ' 350 100 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E58D67A-F76D-49C3-990F-01079383D4D8', 'ED06B6C6-C4C8-479B-BC02-40AE04A7157D', '5391519920732', '  1000  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9387D516-EEA8-40D5-BACF-7BC339748C4D', '29A0E76B-15EB-4F2F-B7EB-42B8551DAF22', '5391519921647', ' 1  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41AAA156-52D5-4734-8C08-B877A9137563', 'DE083674-1AF5-4C76-8D13-B9511C4B51A6', '5391520941368', ' -    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1485E33-F258-4E53-B300-39FB3E49C947', 'D018B9DE-7246-44B0-9408-907D24089812', '5391520945069', '  6 - // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAD2BFAA-743C-4AE0-94E0-AC60BB013D28', '750F8D96-584C-426C-A37F-E00A250802AE', '5391520950285', '  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B61AB899-97B6-47E6-B505-10B6EFB61A37', '24B52F4E-65BE-46C0-86C9-E17DBAEA47EF', '5391520951282', '   4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83FA762B-A9C4-4C4B-B3E4-70F307B3E7AE', 'BFD1C89C-0D99-4FAE-BB42-40F07B701160', '5410076260935', '--  7     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6C0FEB1-5362-46A5-9FDE-D2085EC469FC', '74A431E6-1F06-473D-AEB5-26F971564D1B', '5410076720972', '  // . 3,65 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A502CE5-1ADB-4F93-BEFB-8E8BDA976AAF', 'AC799F87-98F5-4962-A861-A33A44643A87', '5410076721030', '  // . 3,65 72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75665782-6B89-47BC-B97D-A49F8B4A3BB3', '9E7B39F1-7293-48C1-B654-871B6BC0DD12', '5411416008606', '    60/60  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18A75326-7B74-4046-9AAE-F4FC84D07AA7', 'C687F72A-6FF9-4456-B98A-D1CD628590A6', '5411416018711', '   , . 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('580D1773-A918-4D0C-A2ED-846C3DDA029E', 'B59020F6-69BF-4556-B051-1C379BC13AF0', '5413973241199', ' 25  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0D6EEAD-E410-4A7B-9E87-9A4D92E2D36C', 'F0BBC6ED-FAFB-4CF9-BB9F-A2B1610E7C34', '5413973342117', ' 40  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA80ACE6-5B03-4A9F-B6D8-5CD4D2BCA0EF', '6FDE5184-1094-4506-89C9-ACD20E9C8A35', '5414874004210', '     6090 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3014013-FDCD-4E29-9286-B42FAC3B3670', '058F9920-975C-4F5E-AC04-400ED65F6BF3', '5414874007792', '  terezamed   2/ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCCAF34B-4952-4794-8274-B9E1446EBEEC', 'DEE3A8E8-36FD-44DF-963F-C14A60B476AB', '5450557010284', ' 10  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E90AFB8B-CC39-4FB5-9217-6584E67B152B', '63064789-DB1C-409E-AD50-6805FD46364E', '5450557011984', '  20  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82D783E6-F495-4462-AB7F-525F74454CFD', '2A41BA59-0410-496E-99E8-ED2A8E61A22D', '5578411251007', '  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AF6CA8A-D8E3-473A-B99D-103568F47657', 'BB7CA054-F6E5-4CD0-9C1F-443B392C757A', '5700666025434', '-    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAB4C8B7-94B8-4B67-8E36-3AF394DC3E8B', 'A95DEDA5-1746-47C8-BB8F-2A8FA7FAD1DA', '5701780943390', '016930     60 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('390821B6-5DB8-429B-94BC-099123BFA443', 'D23ABAAD-6931-4D54-8BFA-7988F08BECD8', '5702157150809', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92AF4586-E0C7-408C-818E-0E63F010F7F0', '8ABF4B2C-C86C-40AB-AA6A-E74B422E6054', '5702157176502', ' 25  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77F9545C-C17A-46DD-B813-6349EAFF79D2', '43E2C4F6-EA91-49E8-8828-C7440AEB3684', '5702191014846', '  0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5647146E-932D-43EA-BAA9-DF7EF6CFFDB6', '202E3A3E-FEB0-4669-8D44-2FFBFB7F8F62', '5709932004838', ' 3      500 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22A4DA6C-73BB-4E0B-8AA5-E40338F4E92A', '25469EDF-DC33-4A3C-9E33-85C05242CF28', '5900002045915', ' Eva Sun      Golden Bronze  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EB7D2B0-CB68-47FE-A4E9-4383872EB136', '9C2BE951-987D-4791-A312-A4CD22F81DD9', '5900002045939', '   / spf 6 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4626897B-E1BF-43DF-875C-2979D957DE32', '3E05B266-6DAF-4BB2-8809-85BDA306F207', '5900273113252', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC919231-99FE-4313-844B-6EAF4524CB45', '9385300F-1B6A-4556-B4B5-79D84D141553', '5900273150004', '   360  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91F127E5-A797-4AFD-80C0-33FF4A48DCCD', '88FCE246-5F91-4971-A5EB-66B8B262B55A', '5900516057954', '  - / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F88B10B-C4DF-43C0-960A-249EA579B755', '3AB02DDD-A8C5-4EDF-9A36-D54A3E60E1AB', '5900516087197', '      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D46BE23-FD67-4096-BADA-8177336835F4', 'EF7E7C3A-ECCC-4B2A-B9CC-FECCB544ED01', '5900516088743', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11769D66-AFA4-40DC-B657-CBF4A130C3B3', '7B6D03E4-D1FC-45C3-B348-AC10CBDE41D9', '5900516320027', '  tampo      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D63DDB4-A424-480A-A96B-CC2E0390078F', 'F9EC7B2B-F574-4C08-8EF1-086782E7E50E', '5900516320034', '  tampo    +  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB3406C8-7ADF-4495-A15C-51D173A5935A', '5EA0593F-FE26-46BE-872E-E130453B2F84', '5900516401665', '     "bella cotton" 160 . . (POCC RU.AB10.00199 . 24.08.2014)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AE2A698-4495-433F-96EF-D28671004C57', '37E741AE-1F45-4601-81FB-EEBD14C7D174', '5900516421137', '    / 64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28E6976E-8E7C-46BD-9187-7674F08CCF1D', 'C9273594-6701-47A1-B209-EAFA1C0376BD', '5900516421601', '    64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('723388BD-CEA8-4B68-A236-E56D6BF1CE29', '2592FEA9-FF0F-4321-AD25-49533ED2CF72', '5900516600693', '    2-5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEE3B84B-25E0-478D-91D2-6559FD3451D4', '6195C007-45C4-4556-8B2A-01A6264A3207', '5900516601805', '   2-5 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA3979D1-B706-4AF7-9272-9515E0E5A476', 'DDC63C0F-6ECF-48D8-9C54-757A59F52AF3', '5900516650872', '     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3303B96-64AA-42A9-AB2D-43A0D89E183E', '01DF77ED-C25E-4432-8B43-4B6EDB98EBEE', '5900516691936', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE8F22D3-4EAE-4D19-88F4-5B3B70D20EDF', '336912A6-B355-4B3D-93CE-BF4A1C184B39', '5900516700744', '  10x20 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0412B70A-7F36-4D4E-BE75-5923BF9B909C', '4DC1C02D-1C72-4DFE-898C-E824A3AF76AD', '5900516849900', '  ( ) 10 x 10  5 .', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0055C53-B897-470E-B923-C8696E015768', '866A9EC0-3940-4A1B-88A0-BFC99A6E9493', '5900516850531', ' . Absorgyn 27 x 7,5 c,  5 .. ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF1DDDD4-C587-4202-91D0-C4E4F6DEFB03', '9AEC4553-D7B5-41E9-82DD-E78FBCE298E4', '5900516860066', '    8  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('583D1CFE-D07F-4454-B283-DC549688C944', '5D8EAA75-AF20-42D6-8D00-9B28FC1F0FA8', '5900516892784', '  /   . XS 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15D09372-F596-46A2-B0F0-CDF2389EA2C7', '38469EE0-D13E-41A4-AC07-CDE1C26322BF', '5900516893439', '  Absorgyn  10 .///', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E652C0B-5F8A-497F-97C7-C43A56EC6F29', '20833D1E-6BE9-423A-BBF5-597005071CF8', '5900516896973', '     absorgyn 27 7,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DC5AB48-96D0-4984-887B-97C2077ECCB8', '64D17A7F-F4EE-43EF-8D54-C727448070CA', '5900516984519', '   /  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('517C9FF8-48AB-4185-BAB9-D81D63C1C1A7', 'AC87FD66-5141-4759-B7FE-D33EF2B5AF3A', '5900516984533', ' /seni care/  //   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF63D2B4-8709-4BA2-A0FA-1854899FA06B', 'CD6324D4-B06F-4E4A-9829-67A8FF32A096', '5901845500609', ' elfapharm 7  71 /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E6022EB-C3C0-43D5-8405-E6E1F3C10637', '023A4C5D-56A6-43B6-A67E-F0E52809A511', '5902626302801', '  / porcelain   rose-  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AA75A82-7247-4C26-A33C-21C50F5B9BCC', '62F575B7-1335-4536-9C85-7254C363CC60', '5902626310318', '  -   , .    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4212D528-D7C2-4867-A9DA-CDB53194AB3D', '2151DE72-18E5-41F6-AE99-496F70AAF8EF', '5902768816938', '   /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26C034E5-B1C7-4246-980F-511463876224', '13CEF408-B3C5-4933-9458-B2AB3387FFEA', '5903060006430', ' 1200  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7CBDCB7-71E1-4714-A590-86304744CECD', 'F8491675-9335-486F-B93E-2CE017D4B8B1', '5903060009264', ' 100  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5BE16EB-A2D6-497F-849B-6B3C8171CB99', '3D6F2B17-12B2-419D-AB90-8582AA05D429', '5903060010826', ' 150  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAE1C768-1D42-484E-84B5-181A8C48A8E6', 'D483252F-5082-400B-A9C1-24B0E922333E', '5903407028101', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C2E372C-AF71-4B71-96B0-22AA633E6536', '54729F2D-8455-483B-8DAF-1E2408E0E121', '5903407091174', '  /  +0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A313DCC-9D68-4027-9BAE-DBB23C370684', 'A52BB08F-BA2F-43D5-9700-034FF9B21F81', '5903407092218', '  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C1D4C3E-E626-492B-A326-1BF8755A32AD', 'AD8F1DC9-6EAE-45C0-BC7E-B2A027C12A04', '5903407131184', '   .+0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F4B7414-8FEC-4D8D-B65C-FC0FA0167F9A', '056EBFF2-210A-4A50-8411-E8AF64F1F5C9', '5903407186030', '    /  l - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('828E39CC-1A3F-4719-8F62-6C2270104BDA', '815B554F-453F-4A66-88A0-E0A10047E74D', '5903407225173', '     +18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1C90EC8-EEA1-4DCF-B94A-BC3EDE3A91FE', 'D980AC6D-E293-4723-A812-726F2690BDD6', '5903407225760', '   +18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65926C3A-E9C4-460D-95A4-DAD3C46D009F', 'F4ED78BD-F535-4F80-BF0C-239F615CD234', '5903407225845', '    pinguin 6-18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1F488E9-84F3-49CE-90E1-0D76238D581F', '1AFBF579-6A1A-45E5-957F-1C895F420DEB', '5903407561547', ' +0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('712F5575-8805-464B-861D-65DD082D0869', '74A4F2E2-BEDD-41AC-9587-F30827AC887C', '5903407730035', '   /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('781497A6-32B8-4B43-BEC4-17B71109520C', '5BEF80ED-A026-4799-B2C8-F54E6C22CE86', '5903473009387', ' /    250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7A29877-4985-4653-887A-66604CBDFCF9', 'A452115D-1B3A-468D-AB4D-A1E038D11380', '5904913544017', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4736C6F0-475A-4AB3-85F8-60FCE0B906B8', 'FD8312B8-52AF-4323-BBA4-F2C88946F0F4', '5944728000155', ' 0,3% 5 / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1AC8043-AA24-4651-A2E3-8627220A4D40', '0FC3C59F-74F9-4D80-BE3E-517186D6C239', '5995327114583', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AC50FE7-DF43-47A6-B45E-3B16DF8B3330', 'B063154C-5F87-44DD-9426-AEAFEB8B634C', '5995327117720', ' 75  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27AB4496-CC71-46FF-9164-A0CE53036E33', 'C625A282-408E-4D7E-96F6-E2F88245F004', '5995327120959', '    0,4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EC5880F-AF53-4E6B-9499-55C577352A36', 'AD996FD8-6210-418D-B9BC-41995A3E1820', '5995327167275', '-  5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CBDF158-275D-458E-A03B-0FB5AD263588', 'D36B4D97-7BB6-401A-8AF4-C256F5E80441', '5997001303139', ' / / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA53C931-0A63-427A-8DBF-071585B7CC0D', 'E771F84A-BF1A-4402-874F-D744F92F70C3', '5997001363355', ' 10+10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B5767B5-5DB0-4546-BE5E-FC615934A817', 'C2936A80-0656-427B-9711-7CA9B9344629', '5999518577799', '   in-between clean ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A840C78-3438-4AF6-A255-DB0C9F975909', '92EF8DBD-5194-4F9D-893A-6B284077ADBF', '6221088040274', ' 10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E288498B-9E1A-4F2A-A515-B9F22F9E361A', 'DF356F88-CD7B-479A-BFA5-9DF50C8C7EE8', '6414100223506', ' stay    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBF5F738-10F4-470B-BBFF-95A02FAB5350', 'C6A298A1-0A73-4AFB-A856-C0CA3A1CDDD6', '6417150005252', ' 4     /  215,  200/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D7F2665-BC2B-4E18-879D-F46D1091B604', '9237C549-3F92-4CFC-B916-B5DA10C480D3', '6417150005450', '  4  1 //  215', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94DC2056-2381-4021-B5A4-846D77233968', 'F2AFE5C8-338B-4859-93BA-E7AD972DA52F', '6419716950785', '  0,25% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD51D7A7-FB15-4277-AFA8-C1E78C84D570', '8DF5615E-0C33-43C7-98A6-D95D6E53EC8B', '6432100002655', ' 40  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82626DEB-7B65-49DE-AC7D-550E8F99A7AC', 'C017FEE6-CA43-4B5D-9899-3F67EE70FC32', '6904566990116', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44E4CBB7-12BF-4A9A-A825-D2A9EFAD72CC', '154E04ED-C629-43B4-A861-1A11FD83ECFA', '6919678828868', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F641CEB1-E963-44ED-8044-DC9B891F0FB1', 'EEB6F557-BB2B-4970-B7DD-4085885EE81E', '6920579071086', '    1018 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCE05327-9903-4F89-8EC2-4F65E207F14E', 'D0E9F1B8-965C-42E5-BBA5-BFAA01F01662', '6921936909028', '     3 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06E32D6F-AD09-47AD-981D-851CB484BAAF', '96DD3C0E-C9DD-4B62-B9EE-357C8157AC63', '6923391320196', ' 350  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B55B543-18AF-4469-9BC0-554301B0A8EE', '4A27225B-1DDF-43F8-AAD2-934EC4E7BB49', '6927600705378', '  ./ /./.. / / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D27A4D2-918E-49C1-893B-1C02B792E85E', '1967A2E8-E4C3-4DCC-AD59-2C9FC2290A23', '6930169700050', ' 2,4% 10 - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8545F44-19A6-4BA6-B5F5-5F4925176C00', '2E205DC6-92BD-4185-BF56-204ACD24800A', '6933298203232', '   8 20 /  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6DD5C16-E146-469E-A6C9-E4A366B554F0', 'FFCA363E-5616-4E05-BD7A-AC1228AB50F2', '6933315521981', '   7    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C25AF8D-DD87-41CE-90A4-CA4BD34B7226', '8C2DAD31-0067-45CA-B836-A74487A04776', '6933315530174', '   7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17A515B3-3512-4578-A34C-FC6F93793B7E', '24BDFA06-3CD2-497B-9906-F74EA821DB7F', '6943809100257', ' b.well wf-5000 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C1439FA-CD68-488F-B761-EFFE8D961A9A', 'F5BFBFA6-C5AE-4E8D-AF89-8259DA73F2CA', '6950570782285', ' bubbles spring  9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0203229-636F-4EEB-9D88-1B8E9CF10567', 'D192EA25-1AB4-436E-987C-B74FF8C2CC4E', '6950570782520', '  arlette 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E1F7019-B5DD-46F2-9F6C-7A9F4E0B1761', '10C55C67-DD01-4A53-8E55-F51B5F2032B6', '6958627514018', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D48B3C3F-75C1-47E7-BC79-FDDA614E9C40', 'CF4F0C24-2B0E-4156-8AE1-7620EC2ADCA2', '7038319109131', '    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F72E977-A306-4BCD-9901-E955F1007842', '33C934C6-64B6-4364-BC2A-A835000EF652', '7038319109155', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACC70752-B275-4E6B-B12A-3D1E7E0A8FA6', 'F73BC331-2F9C-4873-873A-46DEA387C280', '7290001184936', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDC58179-40DF-4123-8E57-100B8A024166', 'EA0B6FA8-DDF8-41E8-8096-BB5372A23FA3', '7290010035953', '- .    20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4929D9BB-0FD4-4661-A193-AC7B688BDEA5', 'E281DEDA-7FA0-4976-A7D4-8B307E3D9A2D', '7290015848374', '      125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65B1FAE1-E76E-4D5A-B834-51CDC90C3AD9', '329704F4-4A14-4660-8B8D-D1D674BE31C7', '7290102062812', ' 150  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD52CF7E-F531-412C-A81D-165EACB3BC2B', 'E31E8919-7D4A-431F-9C34-B6357CA367B0', '7290102066544', '- 5  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC1521B5-A80E-47C6-881A-76EA899EE743', '2AC5EBF9-104B-42CD-80E1-62ADEAFCDDB5', '7290102066698', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90D516EC-1FE3-4993-8074-008D0DCCEF4F', '1EC41BB7-202D-4833-9845-3DA0B21FD823', '7322540056761', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11B8FC96-A8CB-4040-87A3-76E89F45CEFF', '63896BCF-BF8C-4621-AC30-4B98F72A105F', '7322540157840', '     25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6B5F6D1-8217-4D1A-BA0C-B62CAB652AB2', '15BEE58F-5992-43A9-9F87-3B7D89EA002A', '7322540206616', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C88AF402-3291-4237-8A3D-6236693FFE50', '70CF330E-4C42-4BFC-B6EB-3D8C94AEEA01', '7322540206661', '  invisible wing   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ECD458B-6EE5-445E-9265-EBC1A82592F4', 'A9AF62B5-122D-4525-92E5-51C42598C263', '7322540313369', '.      3 . 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9A65D6B-19F4-46B5-BFEC-41EACDA78B8E', '8189FFC2-DBAD-4880-99A0-74DEBF6046C5', '7322540426335', '  men level 1 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F13FE7A1-94D7-42AB-8752-CB2DF43DEE19', '5043FB16-FFF4-49F1-99ED-374E59822F44', '7322540523249', '  .  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8D99C7D-0BA4-49B4-AF4F-797C200219EA', '5F7E4213-54B1-4777-A974-4F2004BB3C22', '7322540717822', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4020F75C-42F9-4A37-89C6-099505D732F1', '26B543B3-9C1F-4409-81B2-002950F4FF5F', '7350012550615', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('848882A8-3A47-46EE-887D-6EB1365D8312', 'E3ACA1FC-3D70-4658-B686-8F534264DBB7', '7350061291132', ' dry  deo /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B64A797C-C235-420E-BA67-64ABA9F8FFB0', '5173CC5E-567E-46CE-BD93-686D1A8BE5F3', '7601276308444', '  /       50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07119976-4AC2-40FD-95B7-26D61D121720', '8BDD65C9-7539-453A-9C65-D660D110B1B5', '7610939002339', ' 180  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('882F3F73-0A77-46E1-B50C-AEDB866698B4', '443CBC5C-AA90-4274-878C-665625A93323', '7613034698735', '       // 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C40BAB7A-2069-45C9-81C6-BC7F5FB254DA', 'C2A0684E-FC5C-424D-AC13-2099137114B9', '7613035351462', '      400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19B576D2-5095-49DB-9B83-FB7E211F7A84', '83A73D8F-EDD1-499A-B1D8-9A0155DD45A8', '7630014919727', '  "S".  ,   0 ., ,  , 1.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9A7FF31-8ED6-48DE-A886-A4D6C3ACBFB9', '8D86BB52-5F7A-45AA-8617-1E76A691FCF1', '7630014919758', ' "".   4 ., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('760DDBF1-09AE-4071-9C59-0FAE717B4076', 'C2A8D08B-CC12-4C53-B362-1B27A9900542', '7640114720307', ' // 20 5 - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04EC80FA-43CB-49A1-A99F-3BD162654FA0', '3257AE2C-65F1-4B9E-A690-9EC5967B1568', '7640123861541', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45B5089D-6D30-4002-97A4-94E899C5C348', '124D431A-D954-485D-B212-24431BA0E042', '7640123861558', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5852F31D-6F3F-4D05-B526-DCB350B118D0', 'FBF58551-B50C-4E61-93B5-3BA88F81F8E6', '7640123862012', '  /// 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F751AFF9-7E05-4EE0-9DB0-D09EBA07D4B6', 'E93DB368-53BE-43A8-8CCD-D350C6CD1DFD', '7640148938761', '   -2 400 /6-12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54E5860E-2B84-4737-9919-6168FC9D98FE', 'C03B879A-76BD-4723-8A13-9709D2A471C8', '7640156393101', '  PRO-110    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF6A1052-937B-4270-B179-13E8D749A536', '5D3564A6-FC00-4BC9-BACF-4571000B0283', '7640156394160', '  fw-618  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B55A352A-2A6B-4ABA-9D21-550227DFC47C', 'C8F164B8-BB72-4503-95B0-7A502E8E1B93', '7640156395402', '    1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53F2A1BB-269F-4AD5-BA8D-9C8B9453EB2E', '037FBF67-2E9D-4582-9F75-AD92DB1BC5E4', '7640156395433', ' .  ..2.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8AE5730-7255-477C-972C-D7DF0BFD970A', '10D5BD5C-EF77-4623-895C-3AFA512B116C', '7891024128992', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD9C4BE9-1F1F-4941-8376-948B2F5C63E2', '9072B872-6191-4451-8E11-2D5D695B2F42', '7891024137840', '   /89270/   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5ECA72D-0A3B-4FCB-B527-5DC7A8266319', '4361A31E-8052-4023-AFEB-F62A013EA560', '7896070607590', '- / d3/  /-/  20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13078277-60CE-497E-A9C0-063A8D7C5A1A', 'ED03586B-A77E-4AF9-B5B2-A3BE787EF596', '8001040418703', '  160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C22CBDC-3977-4760-AEBC-C2292DF06932', '9A7D0F76-FD61-4A1B-AA53-1D0FF9FA019F', '8001090161956', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07019DD0-CC18-43CC-BFD8-0677A5836F32', 'FB7D8200-2891-41EA-BAB9-B3FD387E8B64', '8001090162236', '    summer   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BF15799-EAA1-4BCF-BC6D-D91BB46B247F', '30F5183E-DCB3-4C09-8242-81FFA49EEEAF', '8001090239396', '   .   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49BD8601-12D5-4DC1-8305-98E4EEADFAD5', 'C3F93C02-CA5A-48CC-9BE3-445E7681E5A6', '8003670713180', '     +2 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6825D6F3-0E1A-4BF9-8752-B803B4AB4ABE', 'B049683F-A542-4ABC-993F-5000EEB18C91', '8003670913825', ' /- 31g 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFCB7E3F-7928-4037-BB6B-9F8432F88EAD', '46A98561-9A96-41BD-8ED4-BDAF76CAC4DE', '8009315001346', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('401D6870-1A63-4631-9C70-415914118BCA', '8F2BCF84-F5FE-4ACB-AD57-8544656FF175', '8009315910129', '    //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9489DEF7-CA71-43D2-A745-3290374153EB', '3570A9B6-1611-4673-A956-D5BE1BD3C93C', '8019561171113', ' poligyn  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7540E791-E853-4C1E-B1FB-94993F0DC3C1', '1F6D1A32-48F4-4946-8550-FB2B5BE4F608', '8019561340021', '  12 / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E0F057D-5A51-41A6-A2EC-7C5F191CD43A', '1A1EA2E6-2B8E-43C0-956B-50471C47F908', '8021961001495', ' 0,004-2 /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20BC1CE9-A1F3-4375-B78C-904813EE8E89', '1979C164-6344-4CEE-8AC5-33A82CC46E99', '8024785000217', ' 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5EF3E76-2950-47E6-ACFB-0FA05E8F2258', '470A9834-68DF-4162-91F3-26867D906EF8', '8024790041021', ' 100   / 6  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64BA9FAC-1590-4A9C-8471-268412859361', '5148FABA-C834-4763-96C2-A98DA4619F87', '8024825000085', ' 160   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B2ED510-4679-4B22-8447-9E885AA727DD', '763B6DE4-3937-4ACB-8700-AA856C49E5C7', '8028117713974', ' .  10 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7682F3F-B528-449A-97D0-6F5B832F962C', '6515486F-F521-412B-867E-BF6FCBD7CEBE', '8030009400039', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('801AAAE6-9503-4E84-B3F5-85F9EDA09DB7', '8DB45A1C-54E2-4107-B995-C69B3B9EE3F2', '8030009400084', ' /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F75796C-919A-401C-A674-064D3A177F7F', '9C8F61EB-583D-4C2E-9502-6C0E5D5E8C05', '8030009402033', ' /  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EF98A08-136B-431A-AB6A-C1E7F4662227', 'E2CBD021-A10D-4824-A807-56BCF3946ABF', '8030009490627', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27A027BE-618E-47AD-BD2D-9A895AED63B9', '515E6213-CC79-4DED-AC55-906694F342C2', '8030009490733', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AD6105C-2C00-4F19-B5CD-EA07BBF4EA2B', 'F0FD493D-F58C-4CF6-A690-FCC82F137418', '8030009500197', '  /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13F6CB4B-76B8-4C04-815F-903BD78E6DA2', 'F66D1C8E-4738-479A-97BB-6E9B9B84454A', '8030009500289', ' /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92CCA12B-A069-442C-8D89-342371A8BD0B', '755EF828-1580-4EBC-8544-3BAE1F7BDD51', '8030009500838', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C2D38BE-4DC5-4A45-A673-4AA44C48089F', 'BFBE1E89-049A-4555-885F-E341E612A0F4', '8030009508308', ' /  //  12  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFC31884-0FF8-494D-9CBA-0884E1C0F994', '0EB1D23A-F006-421F-9BB6-B4B2A798113A', '8030009700047', '    antibacterial  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('963C4049-37A4-45A0-B873-49E596AE7C3E', '14DC4C67-4996-406A-8B9E-297C9DF65DB9', '8030009729666', '    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C5394A9-98C3-4E33-B02F-24E1DA48FD22', 'F6E51225-DA19-4A7D-9343-7D87CE813EF5', '8032578470161', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D3D2438-97E9-41DB-82B2-7AA13442B2FE', 'AFCE3073-A80C-4B50-8519-0C8C4B957425', '8032578474176', '         200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55E69EB4-71E9-4D69-A6E9-D679AD49B245', '67D98BBA-4DC6-40D0-817D-9F45C0E8F88B', '8300961752997', ' .. 70den .2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F284509A-6C7B-4EE0-BA08-366AB1BE879A', '1BB33D5C-42FF-4F31-95C3-245E3690348B', '8300961788217', '  /  70den - 4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19020A07-9328-4151-957E-E99C943A0006', 'C94ADBCB-112F-4951-93AB-884F9209BEFE', '8300961852215', '  gambaletto 140 .2 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D336F72-0A6F-4652-8283-0963F0BE07D1', 'C67D5E08-323F-4925-B493-ABAF05FC30CB', '8300961854219', 'Relasan  / gambaletto 140dens4/c21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F85D4A38-0EF3-44C5-BF10-C126A70CE988', 'C19052BD-F401-4517-820A-A987130238B2', '8300961872992', '  / stay-up 140den s2/nero', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C58CAF33-7B08-4B97-8116-0EA30635E504', '36378B6C-EA3D-468E-8E92-CFC9F7B7EA7A', '8300961886210', '  140  18-22 mmhg  .2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5253EEA-4816-46C6-A236-8AD2A59FCED1', 'E3B536EF-3390-4DB4-B7C5-FB4C87913BDE', '8427324822422', '  -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDFF7F90-BBAE-4F19-A50C-B7221BD0B550', 'EE48B6DA-1B30-40D4-A077-F4DF53DF40FF', '8584005703651', ' 850  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9026A513-773D-4EE8-B799-A245C844C071', '8DDD4559-651B-4DAA-A281-C07F202DBC78', '8585000209537', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A4961DB-3A89-49A7-AB0C-36C3BA6D5A8C', '557B3FCC-10B5-4727-AEDF-1677A95CC0EA', '8588000133703', '  .      .@ 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EA769EA-3113-44D5-B5B4-1D709C65B81C', '45E4BFDD-8F44-4DAB-B54A-DE3BFD0EC953', '8588006037517', '   /     350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E29FCA2-C5FB-41AD-A07A-6DCDBE6E0B7C', '3A9B2175-5E02-4EF6-809F-45D044E9E873', '8594044141680', ' 300  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9635D41E-5D4C-4C32-9938-B6A3EF52EF50', 'C24F9317-510F-4FB2-B9B4-FA6ED1518C62', '8594737200311', ' 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDDC8424-3972-445F-8A46-5D214C8EC0C8', 'EEB43C3A-B749-4C47-8429-211137377CA5', '8594737200717', ' 0,5  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B06E22F-3F06-451B-8A05-B68DE1D4019D', 'E9F13CAA-BA5A-4284-930E-A9D49F07DA1C', '8594737211119', '- 200  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('422DFFB0-C19A-48C3-B462-5487E53D7F42', '5B64E0A1-FA50-40BD-AD82-217DF8DE872B', '8594739035720', ' 0,15  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('685E1491-C58F-4E15-A13C-0BB10794C9B9', '27282B25-3818-4B74-B90F-661672277D45', '8699540015135', '  15  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F23C8B09-5CEC-4A1B-A26B-90F7B6883F71', 'C523E461-5D22-4726-8317-C8FA16DE271E', '8699541092005', ' 20  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64799B6A-A288-4ED1-88BD-70E65A483A23', 'EBE94547-1FDF-461D-B451-5931707DD0AD', '8699584900091', '-   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('403A6A59-0E17-4F53-8B78-912B7BE669A5', '34E8DBF8-4AFD-4896-90D3-9B81E2D859B3', '8710103498025', '    6-18 2 /86460/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B6D6F40-5C1F-4B10-8586-8E40A4C83AAF', 'B31A0EEF-F55B-48B9-B008-51E1E31EE437', '8710103536635', '   31 // scf284/03', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('056E1DC8-4944-4EDC-8CD2-F595F1083BF2', '87B63546-662B-4CD9-B3CF-2488B0A35DB7', '8710103558743', '  /- // scf281/02', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0EDFB0D-EF91-4100-835B-FC17E6D5C62A', 'A2E3C8B5-C67B-4A5A-B565-BEF658630B3F', '8710103576648', ' Natural   240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('923D8540-9893-4037-8638-04288FB6273D', '62A24ED7-2288-48FD-92D4-F74C9A3B3FBD', '8710103580942', '    scf633/27 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C78A9DE3-8FBB-4093-8163-0CB6F644C98E', '626780E5-11F6-479A-921E-A3FFAE76D3A7', '8710103618300', '-    0-2 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6ABBCD7-A04B-4989-9B88-FFFC3380C133', '653BEB06-84EA-426F-8678-75468E5F2A13', '8710103629443', '-  6-18//86124 scf172/14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('328B1A10-661E-475F-85DF-00E9E0C678E4', 'F431A923-6A95-4B82-82B5-FFBA305E68B9', '8710103655459', ' kiss me  6-18 . 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B4C98FD-FA63-495D-8970-C2AAE040F182', '0D0E79EC-6FA4-44DF-BDC7-ABF6BD5D8474', '8710103662419', '  80920 standard 6+ 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6FF5EE6-79AF-46EB-B8B1-9F7114BC0CD4', '7C7EFF12-466C-47BF-873F-FEC858552882', '8710103695561', '  / /81480/ 125 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('573700E0-1FC6-493C-B32D-3D52C81EAD66', 'CD8B504C-8AE7-4937-94F5-CBD2FFB97547', '8710103697183', '  /  / 260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1483097-0DA7-4B46-9F81-4B9489360C7F', '1C147430-99C6-4CD2-8379-5F64C7EA9174', '8710103791836', '   free flow0-6n2// scf178/25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB477AFA-A8BD-4D9B-9E51-BF1A19C4D1C2', 'D42EB56E-B07C-442F-A3F8-2566AC0DF8FB', '8712400800525', '-2   6 900', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('584BA7DD-1146-45BA-87EB-788C8E783E62', '946EFDEC-14EC-4984-8394-0C4EAD157DE1', '8714100922576', '   /      370', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADA628FC-1C63-4A02-828E-E6AA4AE45D63', '31440DE7-0283-4F78-9F0D-144323D956DA', '8717472292834', '   1500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('310F5BD9-71D0-4AF6-BF9B-CE946D9BF549', 'C20B9FA5-0E7F-493A-AE2D-6E177CF70D6B', '8718164962691', '  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DFDC0C6-EF51-4187-920C-2B7F618849CA', '71757B50-6B19-490C-9A82-655166D7351E', '8805178113123', '     1972 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D56F3D0-7BD6-4B1A-9CBF-FBCC0BB82176', 'BFC69AED-72F3-430D-B7E6-C6C4BA406D20', '8806011415732', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71C4C7BA-4F94-4F30-A333-38C9BACAB189', '359A14B0-4B02-4585-9A0A-930C77CAD95B', '8806037005030', '    /3 512/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB07443F-218C-485D-B797-D651F3B4182A', 'D15E0451-BB79-42EB-B88C-9A735D27BBAB', '8809033591163', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCE2D0A7-ED37-4A47-8B26-D1DE2F67D2CB', '4FD7BA6E-529D-4F28-878B-E8297454F9FD', '8809052585976', 'Skinlite - /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35572873-1A47-4929-9128-D15C4A6FA99E', 'F514F6FA-1C1E-46D2-BA1D-D9F9BB473BE8', '8809270620800', '//  /  3  - 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09FD2F60-47A4-4FF9-81E3-DE248709303B', '957CDA60-CD5F-4E36-B7E1-CB2D2DAC6A54', '8809371143475', '.       28+ shary 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39C21421-975C-49A5-9286-29358CF94353', '24CA4F02-3EEF-438D-9524-13DB8D913FE6', '8809411187926', 'Skinlite     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('348D01C8-3633-47E8-ACC9-09B2DDC13DF8', '0B09D8CB-E37C-4D15-B193-62944AD32A90', '8850006305485', '   / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDBDAEA8-4A1D-465F-8FBE-C744AE03DDAB', '746524A1-D154-480B-B88D-08E18BCA0B37', '8852961006667', ' tore    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E844C8A-2F12-4BCA-8237-D0BC2D5C1B2D', '1C1C4A26-B848-4FDB-B2B4-085BA03A78E1', '8901043000038', '  1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66A69F15-6F12-4B60-BB8B-F22E5B97FCDC', '34223F47-76E4-4FFD-8BF5-9C3E58CE690F', '8901043001172', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F29DA7A-4589-424A-B6EA-FB1D0098775C', 'D71D61AE-1D64-4EDA-9A1F-5DCE71506B65', '8901079010117', ' 400  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EE1E997-A30D-4F9A-9BC1-3065C7C36A3B', '3BF3B52C-95EA-47F7-BC13-E71EBEFA8A6E', '8901086160454', ' 40 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE981386-B61C-45D6-8A68-E97CF3051E5C', '76F12E8C-E19D-431A-9475-5394B4A7C7D3', '8901091000752', '        60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC6E1089-64B1-45BE-B77D-C33D7FC85A46', 'DECDCCF8-5F69-40C4-B359-7DDD5A5C9946', '8901109325242', ' 100  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3BB5E86-23AC-4B29-85BC-140B25416CFC', 'D2436B9C-4532-4873-9084-BA078C9A60DC', '8901127005010', '/ /  500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C91B57CC-F772-4DB4-A954-04F5E9A7D900', 'E5F09309-B43A-430D-AFEF-8A24C8E5057D', '8901148239821', '  /. .  1% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85D05A0B-76C0-425F-9EEB-FBCCA064F0F0', 'ABCE947B-4C31-4135-ACE3-8E358790516A', '8901236018291', ' 0,005% 2,5   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C784B385-F65F-411C-9446-9E06898FE5FB', 'CF4475DE-B844-4B6C-A704-6A5AC38CA704', '8901248337007', '   /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8430AA6A-DDD1-4A41-BDD1-C7CC76E079F5', 'A3E01034-0874-4500-8CEC-E66CB6EDACCE', '8901278005020', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('117ABB4A-1CFE-4BEB-8ECA-B6F3E18384AA', 'A8A0D3BE-824D-4BBF-AE13-3C4D324677B9', '8901302061299', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F1144BF-AC7A-4489-AD0B-53AF76056A35', '639181AA-2E4C-4BA7-BFAE-7BA5EDA7F0B0', '8901428000011', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('136286E8-38A3-494D-9EC2-9B1F448012EF', '3B7D0BEB-BF02-48C9-955A-5DF12D6AE061', '8901428000073', '  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7D4D136-0F2D-4891-96D0-D82FB6051B57', '18910329-A5CF-445F-BE89-90557B996FA6', '8901428000097', '    /    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21FE5986-D6B5-4F8C-AF54-31C31F9119CE', 'D77CBF12-C298-4C77-BC38-8F407C761E5D', '8901783000046', ' 100 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F011D0CC-0996-467B-AF86-2ACB9913FF1E', '8C6AAB34-ECE9-465C-97E5-1A7964F150FC', '8904040904019', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C095ECB-AD13-4019-9DB4-07588A16205D', '6B091759-05E2-4EA2-BEB4-7C42995C014E', '8904091109913', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDB6B7C8-4B09-446E-B0EF-D255DCB3BB97', '23D9945B-565A-4B5F-AB93-AA25FAE86C74', '8904091119868', ' // 100  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5680664-7EC0-4423-B8F0-399F03593FC5', 'AC8EF29C-5DDF-47EE-A455-2C1280AEFACE', '8906000571422', ' 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A75E29DA-C137-47DB-9432-2BBBC7F6A17F', '56F50790-9EB2-41C1-8D2E-8EFDF94BD51D', '8906046112719', '   /  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F370D6BD-C65C-4A7F-BD0E-1DDA03F5A7C5', 'AF67D19E-AE45-4A01-BE03-E5234FFD1508', '8906060500202', ' 250/5 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9088BFAA-C828-4944-8757-D9A7F8EB1AB0', '252A095C-CB3C-4094-87ED-9DAED08D2CA3', '8934574060271', ' / /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('423DCBED-74B5-408B-8A5D-D71D687EC03D', '669E996F-C889-4C37-9D59-A7450562760B', '8934901500128', '  / -      15 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E39F59DA-7973-4354-933B-A30C9B2B8CE0', '607BE998-8BC8-43EB-9177-1EE669BC886E', '8934901840125', '   /  0,3% 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A964A60-9B3F-45DD-ADB1-E128C44D38C7', 'C621AB26-3F53-4114-8D80-5BB1C77F4381', '9002260019854', ' 1000+200  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CE67280-2955-4B6A-B054-DD178B894864', 'A8E8BD2B-BF08-4ED8-8CD0-B08CE99A9A0A', '9003638059137', ' 60+100+60  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F38DA4FD-13B6-4A22-80DF-5CF6CF278C01', '9569DD17-2DF3-45C5-AE4E-A07DA78D7CEE', '9005441701289', ' .   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7E921B7-AA2D-4C58-BDBA-DC465DCE77C1', '1602330D-5CEF-4DF5-95F2-648FBED46BE3', '9005441702002', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC9EF8A1-F039-44FE-B061-92AB4DB553ED', 'FE7A71A9-D941-4C68-A81B-84257C8C3A87', '9005441705096', ' 50   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B404E64B-A1DB-4E39-8BCE-69434ADAEC06', 'B1D986DD-95BD-469D-B038-F347DB5EC042', '9006968000084', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('287C701B-25E2-4017-AA16-3F0A15372BB8', '2EA7D348-4F82-4B66-B1B9-ACBC7A450C33', '9006968011318', '  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B9B1FFA-D46E-4C90-AD23-3E301C169FF8', '081A0A57-E795-4E16-8863-E036B5921E51', '9062300104452', '      6-  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8460AF68-CC9A-41DB-B564-1D06D0857EE9', '4A16C37C-A368-4C3D-A1C0-A13F3776EE21', '9062300105824', '      4  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01D3EC76-EAB0-46B3-AFB9-65DB2297F941', '4E70EBD2-E18C-48AC-B894-D119D031F914', '9062300105831', '       4  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07A3ECFB-1B1A-448B-95A0-6C89F0ADCF09', 'A849645A-2E09-4E09-8950-2BB1A6C5CE84', '9062300408987', '   200  4- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FBBAC34-75E2-4A9F-B4EF-5D371721B2F7', '4EBC3CD3-D253-4D39-A9AD-D77094097FE9', '9088881254683', '  600 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('543B954B-0C22-4938-A388-20AD5FA69FAB', '2A5607B0-CD23-4285-8DBC-878D19660DEE', '9088881326649', ' 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DDFF4AF-4FC4-4435-832B-8DD79D3ED3DB', '887C4E52-1E23-4CDF-96AD-9EDB1071505B', '9088883520229', ' 0,01 1,5  / - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36562359-B990-4C86-863D-F942F84603CD', 'D12BCF4E-9A78-4023-BA38-F735CF930B0A', '9120029750173', ' sn209 .. s manual 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F8A8ACD-0413-4D1B-B2E8-AD81CBCDE081', 'CF544020-7FF4-417A-B42E-CE334629B022', '9120067250086', '  spa cotton  naturee   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EC63F0F-CCEB-4ED9-A593-6575FC0CE406', '5071E9E4-2823-4275-982F-7C3897CD9515', '9317129040925', '  /    56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F107750-9FCF-474C-9D5A-A54D54E7CDE7', 'A64A5FB9-8476-4B8B-AC74-F759806443F6', '9319871000776', '   glo   /  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8E5BB29-6BDC-44EC-93CB-95AA12C03476', 'AC59CBFD-2382-470C-B029-C6471802F800', '9557955000995', ' s   powder free', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5641FE2-1E2B-4D54-8B0E-D71F9152721B', 'AFDA1BDF-0783-444D-A305-1BDB5DC96A05', '9557955001039', '      /. / /l/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('341322BF-FC22-4CDE-A72C-98DEABB782BC', '85678533-1A1E-4B65-B53D-630470855658', '9785386057077', ' .   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FECE70C3-89B3-49C4-B942-712E924E291D', 'FEE19A0E-86FD-4DC4-A25C-0DADCB45C252', '9785496005685', '    .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E922435E-E4CB-4BD5-B157-F3125BD9EE11', 'BF47B145-BB5E-4278-8815-B13B1CBC70CC', '9785699985692', '   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5C948BF-F793-4436-B52F-18C5B6F9C129', '2DCFB077-4265-447C-A652-C18B2288C0B5', '9785971706991', ' .     .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58C0C6FC-FAC0-43FA-B894-82A0A37A0734', '66B543BD-B3D1-4315-81F0-4AC3ECB3DC3A', '1230000020039', '  3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D93C624B-5B1F-4C5F-A5C5-9BCE13BD4AE6', 'EC713951-F037-45B2-98DC-0968D78BAACB', '2000621425679', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6FBA8E9-7F49-436B-8D4C-9104CBFCDA68', '48F73B57-192C-45EE-B147-D0CE5120B5BC', '3574661233055', ' /      250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12C17926-0686-4C4B-8236-DD06C63A6E74', 'C98922C8-CBE9-4E0F-82CC-3213A8FB9EC3', '4607046740608', '  - 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A95E540-B507-4E04-AD25-8A5956E13D55', '00C20957-64B6-4C9F-89B4-A46F261CD314', '4680004854982', '+  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B6218D4-F400-4CD7-BC60-E740D5A60BC6', 'E0B9FCA3-D136-4306-B7A9-8A5C88050573', '4627129211399', ' .    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A21EF1D3-39A5-4CD3-9E4C-D0354CCB2BCB', 'CC1738B8-59DD-4042-937D-119492440473', '3838989550097', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2ED69F68-D8C6-4AFF-82D1-6A3D53A974A7', 'EF2437AB-26E4-43B1-9AF9-DAA0D02E66EF', '4010439203046', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A7E8D71-77CD-449E-856B-A3A42477137D', '5729B7CA-4F7E-43EE-8813-96BB4DB5052A', '4607076218610', '   /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBDF2A5C-9B14-4CB4-B1BA-79FE83D92FD6', 'F262682E-2C30-4F1F-8BF7-34A8C37CC20F', '4607094173571', ' -  6+200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBF127E5-37BE-40CA-8BA4-B8E65F24365E', '56FE39E0-CC8E-4E1F-94F6-AC206B0A3F07', '5029053543062', '   3-6 37', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A17D34B-6B66-4660-B4A3-6AD76CB1B16A', '004E892F-6FD1-4AE8-AFB4-FEBD95E6C52A', '4607109409961', '  + / .   scholl 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA480EB8-4F54-4AE2-B7B4-A3FB985EE183', 'EBFED63A-8BD5-4D43-87E6-912AE867FA1E', '4602242006398', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('041E5B8D-90FF-47A7-9B42-B1983819115D', '5AFA9AE7-D88B-4BC9-A3E3-190CCC8CB84C', '4605059012910', '5   /  25 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3E225EF-C68F-4FF9-9B0B-39EA9784AC2F', '33E5EDBF-BDF4-4285-AD9A-5A5124214A33', '4603423001447', ' - / 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D36806A-1187-4B88-AEFC-B9927E6EDC96', 'EF8552E6-AF57-4B93-82B8-6D5C149C1371', '4605658192020', '  / /19202/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D7D6ED8-6C78-41BB-98BB-5A7446E7F409', 'FCE284A9-4B3E-4F57-AC73-C1496234CD4E', '8002660020376', ' 0,250/5 100  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('344CB2DB-C7AA-48F6-B493-AB3314BFE095', '71C31CC9-DA3C-45FC-A134-C1B61D995CF7', '4602242006169', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7824E9D5-D0D3-4D79-9C4D-6159C9396AF2', 'F308FC0D-151A-420D-ADEB-BC15446C3D68', '4580198171042', ' cn-231  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C18CF421-E900-4C4D-B629-EA777563E642', '4C5893ED-B34F-4DF1-B853-18AF18AA1E38', '4607027210519', '     . 6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23CD78ED-AC22-410E-8C35-6277804E5504', '8418D409-5D28-44DF-A24C-AE4082525ADA', '4607003247898', ' 100  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D69884D-37F5-4578-B1DC-EC2FC9D3F93B', '9B426A96-051E-45AA-96B2-6E375A213604', '4710425925418', '    40den', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB65231D-952A-4B41-B867-223961FF7F26', '64592092-C205-4956-BCF6-3EE1D86FC8CC', '4015672103924', '  OMRON CompAir NE-C28-RU', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FD8B1EA-B66F-4797-9B57-6F1C2BCDC211', 'F9ED24F6-3E43-4295-AC79-6D5FF4DA335A', '4602210002698', ' 400  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05431D32-5658-493A-84CF-62C2A441E8FF', 'D56A3D17-497C-40AC-9E38-3D067109A03D', '7702133218118', '      33,5 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('366236E0-26DA-4D56-8FC5-2A5F13676EE5', 'CE8440A0-C732-42E6-B8F5-948C1C4D6A3D', '4612747430123', ' / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EC1F949-8056-4916-B5C4-EF60D63E33C8', '2A8EAE22-AF8D-4F95-BE59-6D70FB46B57F', '4610010013233', '     .0,6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C56E1DC6-3260-4017-9B5A-7464AF41CC55', '37228C61-79B7-4689-9E52-0748666FBF78', '4015672106215', ' OMRON M2 Basic   +  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('046BEA76-2D26-4732-BD16-D8D9054A5253', 'CE57F409-3C11-4938-A319-352E6C7F3CAD', '8850006327852', '    pro-relief   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2659B8B-B27C-4FAA-AB13-DF667C61A250', '9BFBC407-0331-461D-8AA5-6E8DA94A70E0', '4606677009641', ' mama / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DF956BD-F004-4B56-A872-6B75B4E29EC8', 'A7F9A799-A97E-41A2-9B24-AB968C2F2BEA', '5060038503794', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA521BC2-D2C8-4A9C-AC89-BC00323678D9', '6BF01484-8072-4255-AC0F-44DA7FCF6F11', '8718117600151', '-2    350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C583C05-9FF6-4CB8-9AE9-880E567A6203', '9BC87401-B77B-4402-B265-AE18DBDBCE31', '5700666024307', '-   / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3C2562E-F173-4E29-89CB-1C7AF905DB04', '9292B2E2-1CCF-4903-AC2E-B8A5CEAF74A0', '4620002183806', '   - 1 /  50+ / 125+/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9339A2AD-0A76-497C-87C8-A3E83AE4D5F8', '84EEAEEB-2411-4DDA-BE8D-29EF5412971F', '8901138190712', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B81E637C-4EDA-4B9A-B12C-DB031E7E24BD', '7AFF2C4E-AB99-4A66-8B82-AA90A5A89F93', '4049500141574', '   .20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3307E1E-583F-44CB-9DDB-A5E55086DAED', '386BC204-4174-40D9-AB86-109CFCC23824', '4031626710307', '- 10% 10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52B3D05B-DBED-4428-8192-83F5DDAEF1A1', 'EDA96190-9836-47D1-A095-9BA6949020EF', '4605453001992', ' 0,5% 200 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('535AE6D6-175F-4AD5-A9B0-49C996F4EB8F', '78C900B2-9F7C-44CA-B63A-AD547D2E128E', '4610010011222', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7916AD59-638D-43AD-8E68-43D603B72DF8', '41DDD482-4BF8-4050-973A-6346377A1FC0', '4820121901675', '408  3-6 .   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACFA302D-2527-4FC5-A034-B466CF52C3CE', 'E60679A6-020A-401D-AB83-B95775211625', '4607003247935', ' 0,4  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF63183B-264B-4E14-B34C-1C22A14F5496', '256DA065-5FFD-4245-AAD9-5DABF5D26E3F', '4607027219277', '   .  // 1211', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('749B4B72-FF87-4AE3-8F17-BED64489173D', 'A82BDFD2-E2E3-4A56-BB43-AA26B7161D63', '4600697171333', '   + 100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4D05C5C-1AC4-4CFA-B7BC-C380B9B3AE81', '4405E9EF-1EE9-492F-BB71-A565336FF70E', '4602784002469', '   /-  5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('394D91E8-55F3-48B4-B31A-FEB278A5ED86', '69E7B70E-CED8-4769-9E87-5F822EB0C66C', '4601061101307', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BF093E6-F7F6-46F6-944A-FE47946CCF52', '8AA3A982-EC21-46FE-8BDC-03F157487D4A', '4650057490024', ' 250  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07316568-1FA9-49C0-BCA4-BB6386739B41', 'A28B1829-E937-4E68-B601-0406E5B6845D', '4620006275088', '    /F-190/ - 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('337E8B41-0299-4567-95F5-CC27E8DBF153', '1FA374C8-7FA1-45BF-9B59-36EB4E8572B0', '4602228000396', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('323974C2-EA14-472D-B58F-763FB7B57400', '5619D044-E492-44BA-BB15-2277A224BB45', '4607104090256', ' / - - ag/cu 150/250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2FC4B69-5DD9-45E1-B567-253D89DD735C', 'C8F92888-806B-4BFB-B717-52FA5EC98E95', '6921570922865', '   /    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B1B6619-3191-4A9B-8942-7231881CEE30', '1FC3A7F2-3187-4568-8C54-79DE8BCE506D', '0027917104157', '   10 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('335E1175-7B76-4D89-9455-E17C28EECA65', 'C8A547D5-3C80-4B6C-B423-BB3BC1251699', '4015672105355', '  HJ-203-E', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24FCAA44-13D4-47E5-8D71-15EC0931E462', '3BCBD63A-9B03-4B40-A3EE-3AA3E7CA399D', '9062300111641', '   .. 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F47DB877-2C55-4AC1-AFCF-A337A9FB9D13', 'AE698C5E-E73D-45C5-BAE4-98FDA26E5CFC', '4670002260472', ' /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2CFDD79-D886-4C32-AD2F-FDB20E133DE6', '1213B4A8-D65F-4138-8B49-F5BE68560298', '8019561020510', ' 400 2 -  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD0762A0-4AC3-4C24-BB7F-BAB117907EFE', '501E7AE2-DBA5-4556-B14D-A65E151664BE', '2400006370585', '       125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37BD1A68-C3F4-4F0D-8076-959F2BC3487F', '2B246F04-A26A-4F74-BAEB-857CE47F0DF1', '4612738370100', ' 2,58  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50BD9B02-F44A-41FF-90C3-158EDE3A25DE', '89C0B9BE-40BC-4315-9B10-FA6A6DC9DFA4', '4036534778203', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CEB6CC0-CBFE-43E8-B6BB-F5E3DB508ED5', '1AEC8F48-CA13-4257-91FA-F4B8E3CB2DC4', '7795378004097', '  500+2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('659EC290-028D-455C-8D4C-BB21E44B6E8F', 'BBC463EB-BE25-45E5-AEAF-C699F7EF3A4B', '4650001570161', '  0,005/6,25  /- /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D34FD7B2-EE6C-4BF3-8F7D-85B8E2BF76C4', '2C3AF4E5-299B-4EFA-9890-EFE62DDD3DE7', '4601834004361', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A5A0B03-2BEC-4459-A224-F2AB53D3BB31', '512B2606-1625-4B00-9082-7292E6BEB0AB', '8699540092228', ' /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DBF9CA2-CDA9-48C8-BC80-AD1F75573BDC', '84007FE3-6314-4F68-B12C-6EA5F00D53B5', '4602824021764', '  12,5% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34229FB3-EBC2-412E-B67C-910BA41803CE', '43B88002-482F-4551-93F3-E34561E17E85', '4627080560017', ' /   diagnostics 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39EEF018-BE48-4A2B-96CD-692114E0457A', '47E7C90E-5F24-4A9C-AAC5-7542A2AB87B1', '4620006241922', '  . 5, ., -322', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('685DB615-453D-4F8D-993A-AE70022D137D', '7BE03B0D-0433-4CC9-B105-401E84AC8F5B', '4711146111418', ' camera  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AE6D9DB-D74B-47EB-BBFE-944E66A93EDB', '49AD5202-9178-4C31-A9E5-5975AE47AB32', '4602565015152', ' 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83384243-D1F2-4429-B334-D9B325C9D3AC', 'BED18C2C-2A60-4122-818C-9F2C810728D1', '4620002185497', '     4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CB24F32-4492-42A3-A8A9-6E40993D7109', 'CFAC2B6C-E03D-45F4-8941-B74F1F659C85', '8300961787210', '   70 .3 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FBA5518-FE16-4C06-8438-7F9DF8AA4CDA', '3D9914ED-1A8C-4467-8CBF-EBF4610676B4', '4680287525616', '  /  2 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8715A0C-EDD2-471B-9319-2E253046C09B', 'C5A02722-55F2-44D1-BF9F-493673CD189D', '4820121901934', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14BE67DD-D4FC-42C1-BFC0-9EC519015501', '55206431-2C2D-42B3-8653-16EA0D092F9F', '4605658230371', '    /23037/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E5F81BD-EF68-4FA2-97B2-877C09249166', '40AAE84A-2091-4B1A-886D-7EC1E59B442A', '4605658405021', '-  100%', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86BB5EB3-01D3-4D50-8205-64229EE8B881', '88047E1A-B6F6-42AD-A9AE-665E17511621', '4607027211325', '21320   -  /,./ 0-6 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80CF087C-318D-4EF6-BBA8-20A77E294B0D', 'F8F75CA7-F691-4DA0-A936-EDF7DE50BA86', '4607101201204', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8747866E-7B71-4429-946F-761CD850762C', '13931791-40D7-43DD-B6B4-E864E817E2B3', '4049500833844', '        (22-32 )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42433EA7-9CDE-468A-872A-9BA41032A281', '08948565-2EB4-4C39-82BD-ACB8E91EC4BA', '5060038503565', '    80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23CBFEDD-F016-4320-B097-675365CB0768', 'C704A5C0-B125-431A-91F3-297015BF953A', '4600209002414', '    220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB78551D-592C-40D0-B60A-4FFF07EA20DE', 'AC4F657A-0F5A-48CB-8657-0F638FF0C987', '4015400203346', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B9E1E42-865F-4498-97E7-F630D2A4B471', 'B882FCFA-1FC8-45C2-826C-9CFC239ABA46', '4030855502462', ' 5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A623FDEC-F286-43F2-8285-E30D69175219', 'B115BC76-3491-477D-9EF6-21B2A51D55C8', '4600728002803', '    /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B4FEA33-EC1A-4BDE-992B-08E05D4581DE', '7BDC498F-BBAE-4E58-9861-03F6FB967951', '4627074841078', '  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('364A2164-CE93-4403-8CC1-8C61B536FB59', '6362A2E3-CDA1-4AE9-80A8-84DA4CA6780D', '4601774006487', '   - 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40256585-EC5D-42B0-AD11-91B7E459C59D', 'C754C4B9-3BE0-49DF-AA3B-5B81084DEF4F', '4612750380057', '-  -02 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E097157F-A3CC-4CC8-9907-FB75B19EC376', 'D4C8093C-87B7-4EC0-9D6C-B9D3AA7ED430', '7322540523768', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C8F20EA-458F-4A41-81ED-B4C4B9BBF455', '986D1FDE-5B4F-476D-8609-26E1D8EAD972', '4607027217860', '  /  2 /2402/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7B43CB2-289A-4BCA-AF1F-F87BDE3C7C49', 'A864840A-225A-49FB-BD6B-3DD44091F6F8', '6925253922029', '    450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BF18764-30C3-4592-81CB-9E8E2F0E58EC', '20BE1D2E-0513-4301-A019-5C760D021D0C', '3838989563608', '   18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6699E9DD-9325-4D92-BA58-76F5D74FE15E', 'ABDA4835-0750-4F0B-B834-4E9BA03E1798', '6946159500579', ' wn-119u ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E423F9BF-BA5E-45A6-993A-F2375E76C336', '5D580A85-F880-4AB0-9DB1-AE3169BDD68B', '4690624011542', ' .  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD5AF2AF-F020-469F-86C2-1A4245D3C28A', 'FB4D83F1-45E1-4067-9E4A-CE9576B658FC', '4607027218621', ' - .. ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1368D828-70D0-4852-BEEA-79FBCEC78936', '5E359874-F1B2-4450-BFC6-1240C72DDB3F', '4600697192307', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B4A5849-D9D1-4F98-9DC8-9C352D73DA6B', '9A4713CF-0CD7-465B-AFC9-B6A4D588A619', '2400005566057', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EE1875E-EB77-45AB-994E-6331AC5083B2', '73AAD790-C3D6-4C17-80EF-80CA8DAD8C76', '4607027218157', '- 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D315FD0C-F6AC-46ED-912B-382159B20D48', '720192F7-2CD7-4DE3-A8A4-4829A4188A65', '4606666078320', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E5D00A5-B92A-4CC0-94E6-300B9A8ACB4F', '3C6E9F65-88B8-4EA7-ADE9-DCCE92992A67', '8901463002261', '  0,1 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('074D3134-2F0B-415D-B119-B32604BDAE6E', 'D3FBC2FA-EC95-41D5-B2A6-37FE496CC4F8', '4607021709972', '   170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6576A1FA-A297-4235-8A12-7723C7831FBE', '35FA10BC-B578-4240-A282-D4E30E9A19C9', '4850002160037', ' 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7300D66E-E349-40D6-911F-2961696050E4', '701C89B4-C4F9-456A-8A03-D8295CA6009A', '5029053542478', '  lu    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDC53CC5-B20A-4A2E-A4DC-38FD001BAC77', '4021D741-EE72-451E-AB61-AF1C1540A20D', '4603720177388', '   20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8101049F-9A67-43DB-9F55-C285677FCF88', '2F707CF1-150A-46B2-8570-23A5C68D5863', '3760008320674', ' 100  / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF881AEB-93B5-42D2-BC26-4562ECA623CD', '7E2BF48A-1E17-4D6C-B3D2-CF5FFB42A93E', '4032046650105', ' 0,15  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7FC8E65-9FCF-4569-9F63-A8D78FB28136', '5DA4B310-0251-413B-87F8-F0D7A2E89BBB', '4605319006949', ' 42  450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED43D668-033A-4CA5-B6F8-0685DE606D1A', 'F788C297-10B2-4067-851E-9D3F78C20D29', '4601969006841', '  1000 +50  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('311A1E55-7E68-4828-8ABD-758BC230AAA8', 'AB7E53BD-7741-4CD6-93EC-89057A000AE8', '5009612991114', '    20   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('616E56E9-3EF2-4379-BC43-EA5C6378A5F1', '58E889A1-E378-4EF5-825B-58F0BF41E907', '4607101200115', ' LUBBY . . 3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('625C04E5-C478-4D71-B6A7-E9A2F54867E6', 'E1D1FA2D-301C-44E2-AA8F-E7F7C71EB2C4', '4600490612088', ' 6-12  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE258BC3-81CA-4547-8212-1D2DB8652348', '05200FC9-62EB-4DA8-84B3-952927A80A92', '4601499003204', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60A73864-2C19-49A5-8C4A-7F34719FC296', '585D855D-9D2A-4D06-96F4-C632BF2D67D3', '4605738006094', '   ./. /-/ 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB11ECB-9994-46E0-B9E0-6D1C2A2408A1', '03BB51E5-C4C9-48E8-8781-7E494F075661', '4605059002348', ' 1%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5A004F6-DC52-4AF4-9F33-E6F56C98D450', '161054A5-9230-411B-BA4B-0BE18D2D61A0', '4605108000646', '  8   7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FAB083D-03FE-494D-BC6B-CE6F0386AAD2', 'C2766CA6-1AF7-47F4-A4B5-E65D46C80DEE', '4610004311369', '  /. 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3E8E425-9292-45EB-ABD2-8999BD7650DF', '8018810D-907F-4E24-A244-9A9746FE4884', '3830029295531', '  /. . 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('425E4B1D-620F-4F7F-B8C5-AD250750B832', '313F6B8D-27B8-4D8E-AA4D-665A9C9D3FA9', '8030009570589', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DA3C8DD-F120-4E9A-B093-F6DB8BC41893', 'F53D3B49-5114-4E77-824C-51C7A5D1CBF1', '5410076964499', 'CAMAY    French Vintage 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49D255CC-929A-4F61-8DED-8B03313EA030', '1358D72F-E41D-4B60-BD4F-0241A3F3FBEA', '8710103498087', '   0-6  /86180/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('978B718A-597A-4507-A10B-92653C28DB64', 'E43DB21E-DAFE-4C29-8155-20F2EDFA090D', '4627074842358', '    110', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B75F04A4-A4B0-4F07-B2C6-FFB736D83FAA', 'B13EB534-EE0E-41D3-88AF-133390A1BFB2', '4605738002935', '      200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92DFE8DE-DE07-4A45-9966-FCABC3A86F92', '7A863F0D-3428-4EF2-AF83-BA55EDA2BB34', '4610010010058', '      / 20/ ionational 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F29AB056-D299-4EE6-A3D7-5906008C18DD', '2535DCCB-0512-453D-89DD-976F2D16CDC8', '3014260799632', '  - pro-epert 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C1E2C9D-29BE-4273-AB73-A8607A390892', '0F1167B7-4FDB-4209-99D5-09E060DC282F', '5034676030080', '  1% 59', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF101CE0-AB2A-4846-AE9B-7B18ECA54219', '0AA8F175-FB41-4C4E-BD69-7A46D64976B2', '4607050160249', '      6  10 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F47E9A1-A0EA-4BE2-A9E8-C158DBF5DC8E', 'E413D559-AEB1-461F-A8EF-B6D6D3D72248', '4008500135747', '  10   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F0503C1-18F2-4802-843C-82D412868DD7', '1EA3CD92-2447-45DF-96A1-CFFE7B6937E9', '4607020642256', '  /   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEA7E02A-AA72-4901-92DA-BBB32BABACBD', '6EFEB53B-07B7-4F81-B1ED-EAF4779D9FA5', '4820142800223', '  Lili 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('679EA55B-BD75-4D35-9E7B-DD5746B54727', 'AF486DDE-139F-4E35-998A-BA6A12C9AFC7', '4650001680877', '         6 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77001C88-4B35-497B-B5F6-7DB8F3F6CE79', '8807E040-F20A-45FB-993A-D339504126E6', '4607155430490', '  /..  10 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DC317E9-3C4A-4818-B436-B2067F2ED52F', 'ED358BFC-77B6-4DF2-882D-2C416B5BDA24', '4037353010314', ' 0,05 0,3  / - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA4D03B5-9788-4772-93B2-9B706480A050', '737F80B6-A453-40EF-9C1F-96AA1CB3D33A', '4630009900436', '  6   /////', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F5F2020-5D71-4CB9-86C3-D6AEAB1D0FE2', '17A18C4C-CB4B-4248-A3FD-5339E9C5AF6B', '4049500886864', '  14 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0E617BD-7422-43FB-8107-ED34E84ED979', '9BCB97C1-A6FA-4CB7-A45B-70B5FE855BD9', '4607041061555', '  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8598F4AC-A0BA-465F-B979-054AA55B4197', '70F57FC5-CB49-4CF9-A798-71356FF44A53', '4650069782681', '  /     finger silicone 6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF44AAB6-8EDA-4DA7-8C63-D340809B5188', '1DE08D76-65F5-4F1B-A81E-A7A0FD1D33F8', '0608866894032', ' /    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAF61836-093C-41F0-94F4-CD7DF1907421', 'F792B241-4BF8-4553-B450-2132814B869C', '4620006253079', ' /  /f-320/ 11  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C471FBBB-E38F-42F6-97AC-AFBD956BC0D4', '4FF742C2-4EB4-4E21-8641-1CF0ECF91FDE', '5900516692568', '    60/60 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('842C131E-AFDA-4B71-BB9B-EF318E1E6783', '4843BF85-3774-4682-81CC-4A9FB909351D', '4820121901965', '   /+/, / 72*52', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C39568E-7057-46C3-9491-2F35BE817A14', 'A80802CC-C459-4C0A-BD61-640D598DE0A6', '4602242008248', '  . .  60  0.4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8144B165-CBB2-4FBE-A35F-DEE7C7EE99C0', '63AC0996-3B68-4A26-92D4-A58878E0904B', '4600936252076', '  - /  // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70EF6447-A9DE-4A2E-85BC-15587302F1F1', '3E9DC42F-24B8-4348-8FD5-DEA6B50C59AB', '4015672108479', ' OMRON M3 Ec  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96966C52-ABBE-496B-A512-7B3488B03A10', '1CD3CAC6-ADAE-4C31-A475-12D49246A3B7', '7322540630336', ' -    l 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C53FAC7C-CDE8-465E-97DC-C78A403994EE', 'CABE286A-B001-48D2-8B19-8CACE3F7D12A', '4680002476278', '          6 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71A30F72-CD4E-45A9-8043-D1DC2D4C94F6', '055CBB98-4C78-48C8-9870-8882722C8781', '4602509018102', ' 1 /- /+- / /  5 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72858DC5-DD8A-40E0-9A5F-CCAE76783B87', '573E4980-55AE-42B9-87DF-C61888D304A1', '4607056264668', '    300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6076169-FED0-4219-9E3B-1C60B67F5683', '5208D735-AECD-4F42-BE10-EA8586836255', '4605077003327', ' 400  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1051236D-9782-4805-B935-B2E7BE45CF44', '5AD13AE7-0F9B-4C91-8F25-1D7A10E4B138', '3574660144734', '  /o.b./  32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF0912C6-F5F7-46CA-8A3B-EC539C881061', '6C28277E-2BC9-4DB7-91EB-4A6B8DCC4762', '5029053542508', '    .  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C49DBD56-1031-4D93-BDED-89901284F68B', 'F1071A97-3A46-4030-A29E-27CF8BC6827D', '4601798060793', '  /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE3D5C1E-1CAC-4B44-9988-A32E58F2E5C7', '4D43CBAD-C6D7-4E70-8F29-5571B49562BB', '4660007701896', '  60  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFCE91C4-D598-4B48-87AC-753DD8CA86FB', '1135D10F-00F9-48AB-9D72-9B1DA76D127E', '2000004860028', ' - kineib  55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11A104E7-CCE4-41B2-8F07-C128BF70910E', '88437E5D-F2FF-4398-8D9B-49B96AEC45EE', '4602242008880', '    840 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31F6BB39-FDB5-4EC8-8563-AB9826BAC332', '7CBBF285-F3C7-467F-ADAD-2B6A597A452B', '4605059001587', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9852FD0-0479-46CC-A6D8-C0C080C8BDE0', '64E56C80-E57A-44AB-9048-42A124CF2E34', '3830029295579', '  /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('976BA0ED-03CF-47E6-A471-DA71A566E010', '457DFAB5-99E6-4115-A1AC-01A47ED796AA', '4607174430433', '        400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F84ADD4-984D-4D85-BEDE-016892F3C7BE', '44D9A97A-FE33-4BD5-82FB-18D47B9AE5D0', '4650001681553', '  /. maditol   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B684B5D5-BA25-4377-852C-05DCFAD7060A', '3419F728-2F9D-4545-8135-B993AA54D9B3', '6901301336178', '  80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7247013-9DDD-43F6-A223-7B34AF81D8BD', '358FD811-993E-4B62-8688-55C0F91E5111', '6941762681325', '  5500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1622DC8-9227-4B9A-BE7E-167D1B8B72DD', '5A68AF4C-32FD-4451-A152-C1D84A58E8EC', '5029053527598', '     8-15 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8FB823A-16F7-4D26-A67A-FE34DD21DCDB', '58864A9E-5E3C-44BC-BDCD-D4C7927468D6', '4049500949668', '   58 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8A592BC-B89C-417E-90EA-D70A22D0DBCB', '9B6BA445-6A92-4740-B919-EB2783CFE655', '4610012370570', '    /6060/  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70B52AC9-BAF9-4EF0-A010-9E760D761068', '16943B13-2BE6-499B-A256-1B2305F06294', '5038483009291', '  /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48CDDF78-F538-419B-B74C-C2C8770DBC2C', '07D689C7-85ED-4A6E-B175-569B8F8CE325', '4607020642010', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('706231C8-629E-4BBF-B069-DCFD35854A55', '253BD764-8F6C-4A0C-B365-B54936B84C0C', '4602212000067', ' 2,4% 10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C5D2D63-43F5-4AC7-A26F-647AD96EE0CE', '2F5CE26C-89CE-4D81-A0BB-70F1DBDFDA4E', '4606144007606', '     25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA263352-F7F2-46B9-8097-FA43CFAC11E8', 'B94F51A2-16C4-409B-AE05-476822CEF247', '7680466970142', ' 0,5 -  2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB494C22-ECA3-478B-B636-E5732AC1776B', '54440D99-3617-4650-A6C4-AB6EAFB354AA', '2000008700023', ' - kineib    55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FA45620-EA33-4C55-B66B-9FC1FB0BFCB6', '9A8AF811-69D2-4F2F-BAF2-0E7876C28148', '8712400736305', ' -3  12  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF1EE963-DD63-4BB0-8979-E001B03A3CDB', '282A4925-46F9-4997-8501-1EAC1B4AB9A4', '4627110041226', ' ergoforma   1/ 3/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DEED5B0-D28D-42A6-82B9-8B89148777AD', '73754855-DD45-4F02-8DC0-F3C2D81A4EDF', '4607086562246', '  /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2F22708-CAD6-4093-89FD-2D7BB8983BF6', '99377DFD-B487-4D20-A0A5-A985477E5150', '4607046740240', '  - 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E7728E6-B5A2-4AF2-82EC-8B3FE24B4598', '1426C02B-6D79-4EE6-B556-963E1E271858', '4710425926019', '  50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C469E8C2-CB6C-4EC0-9686-90F5A2BFD9D3', '5E614800-31C3-490B-AFA2-DA8E9323026C', '4011548013380', '          125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B53CAB43-D253-4C06-B94E-2D92780EF6D8', '3B6AD86E-AABC-4B55-A323-604CF3A448D4', '4031678057016', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A457A53-0E85-4424-B1AA-1D4F9EBE382A', 'CD56C6AB-8421-4701-96BA-EEBDFE81DD82', '4049500886840', ' .   2014 -1 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FB5BDF0-5198-4976-B191-C15269DFF652', 'EDE1210C-C279-4FF2-B313-55C979D507FC', '4016369665398', '     /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03B85C3C-623A-492D-ABB0-005333E3AC76', '2C9C3EAF-D7FE-40FF-98E4-74534B6BF4F0', '4104480466175', '   1000 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CF78737-49EC-4D89-BB68-D27A7BA7098C', '491E97DC-82CC-4A74-B8A1-CA3144D845A8', '4620002185770', '  f  /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7809A772-4465-4E46-AD9C-B7D5492961AD', 'BC0A07E5-6253-4F0E-89A8-3FDEAF635946', '8431306002696', '    /. 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A996D979-E1E0-4AE1-8EC3-7F5F38C2FC14', '4C614E61-044C-4AF3-B54C-F1EF951D2A5F', '4603014004949', '   juicy /- 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FFF3A9E-B010-4304-8461-93D646D35D12', '415E31D4-8802-4084-A694-0137F1E63276', '3629002762036', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9C1531F-39F6-4A35-B08D-AF5D60DD95EB', 'D0C956E3-C7F6-4B92-AB97-4BDE4D114157', '4607043670120', ' s medica cs-106', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11A53DBC-E728-49C2-8F3D-2B90A5CE7521', 'E0040416-1891-49B0-9F8A-99B0AD61154A', '8300961788996', '    70den .4  /.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DD6DF56-ABBC-4C46-B92E-B3D5D41D8357', 'F62A23F4-3CCC-4C7F-BCC6-7470B85D8336', '4607101209309', '   125 /12023/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2DBE8DC-CE03-4886-87E8-6CF9CF1A0897', 'F167DE69-C3DA-4D0C-A57F-C2C74EDFD3A6', '4711146500397', '50039 camera   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89649FE3-6113-487E-9941-D9291EC74B85', '46EC21C8-2CFD-4105-82CB-D123C18D76A4', '4049500608435', '      M 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD4A962D-2AB4-4716-A487-B72B1F8C10AD', '4698E841-06FB-41C7-A5B4-E6324987E56C', '4610004311208', '     2 // -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A556D4E8-69DE-43FC-A0FD-0BB6F78E1D5C', '24BB5904-F00D-4E58-97DD-298B7AB35E50', '4603695000933', ' 500  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('638B5F72-2AFB-4B23-A114-2AA7FEB5E753', '4B6485DD-9B04-4ACF-B4B7-B5CB426F3963', '4610004311031', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C00E44AA-F8AE-437E-BEAE-BB8B548071C5', '5B935819-69CE-44EC-AC63-AFEBA234ABD9', '4607008132243', '   .// 4 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94F23D98-1487-44C7-B52A-1EB2C6326A7A', '3622C2FA-9BC5-4DE0-9E5F-8A06A6BD611D', '4607034940164', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CCCBD43-87EC-49BC-B705-AE18C4D5F5A8', '46FE424B-DC61-486A-9BF7-126BA4379140', '4810263029313', '    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98ADD76D-D18B-428C-A5CA-6B4971EC8DDF', 'E8D50C7A-189F-4E9F-9806-8054DC931F8B', '5900516421212', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0982AEF-C781-44F9-A988-22FF943A009A', '29CCE751-4722-47EA-A176-902D1A85A9DC', '4603500007805', ' /    /108-112/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D346898-6CA7-4CEC-9BBD-C2F4BAC23901', '6E21F785-4AD3-4E54-9811-A3E4942B4928', '4603188000396', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D95E2F9-DC83-4EB8-A4C7-4572C9320113', '4BA03409-D1DE-4F19-8E8E-EEA1046F4B34', '4606272040162', '       200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B20433C-550A-40A3-86ED-41B2F1D4A8C2', 'E1DE14B6-4432-42AB-A3E7-8C56204B747D', '4620006273930', '    . 4, F-214', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0734D94C-0020-4E0E-A34F-4708B00AAFBE', '4CF2B068-A9A0-4C18-9112-F5F40CBEDA03', '4602210002889', ' / 0,036 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83EAB420-54B0-4BE9-84E8-D0FB57937493', '7A6A479C-0E46-4109-87A4-59EB9D467468', '4750283009370', '  0107 2  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF093C59-02CD-4B2C-9A37-15A7BBF12CCF', 'E9548142-4329-4BA3-B70F-3249835C1E21', '4607027217457', ' 2111', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EF07173-456C-476A-82E5-59BC27DDC272', 'FBC96D1D-3D86-43F1-BAD5-82B2761EE312', '4670000360136', ' 50 5 //   / -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15EF2162-90D6-47DA-AFC6-D4EFDF309052', 'D2BB40A4-08C5-48A6-8547-B20CEBBFE0C4', '4602866000512', '  1331 / 4 (M)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('334A5F03-2464-47AD-8AC5-3A3F58B9C2C9', '5B3F19BC-5CAE-4E0A-9F99-3D4FC7DB3A1B', '4607101205455', '    /   silicon  6 ./11395', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5ABEEFA1-36BC-4E14-B3C0-2D4F3F849BE6', '1D867B64-D40F-45C7-B228-FFB6ED516F76', '4607027218751', '   ..   260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('134FB173-0FB2-42AA-B448-F9B6939BF75F', '92A8E878-2FE4-405F-8C87-DEF8E9DF75FF', '7350061291057', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B14A5184-E0B6-4C30-A84E-CBC14EA943E8', '16C971D3-D2BD-4026-B65F-4B40006A02F3', '4603173000233', '    . 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B5ABA61-1851-4E74-9B85-144F441B1D68', '3EAC2CEA-5FEE-40AD-81F8-2531E9BFE8E1', '4015600002527', '     /8-14/ 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34353675-5DD5-4CBF-B883-942CD0E451B8', '921F3928-5454-4F76-BC1B-DAA3C32E1E4D', '4605635001598', '- 1000000   /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DB6DC42-4F4B-41AE-A466-57B6A1F7E53F', '08A887FF-13DC-4998-A8F0-CC5113CF04FE', '4670010370439', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA05C17A-D98A-4B7E-ACA8-9844B5C0C28E', 'EDADC595-03E3-4D97-B873-88F5A63675EE', '4602242008811', '  .  840 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB7A5E2B-4BFF-4D90-B6FC-839153B9CA52', '0DDB6FB1-CF9F-4945-A233-BCCA34DAED77', '4750283035072', ' / /9901/  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD9B44AA-DE3E-49E3-A0A9-96ACEAD8C7B2', 'BB81601F-4296-4A0A-B1A6-BE0CB17D9B22', '4750283009257', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('056837AF-A723-4A51-8FA4-F22A2B43C00D', 'BD880EA6-361C-488A-806C-85E2C5C7CAF3', '4605319003894', '  -  / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C46A1D6-28B6-484E-A7FF-34270C5BF746', 'F4D22EE2-091C-43CD-BDAD-9CADC0EE54AA', '4605108002701', '    / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1B5EB13-A176-42C4-81DF-5B399F111F83', '3A711CD8-E339-40F3-9ABC-2BDA2F350DE0', '4820121901552', '   122', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AFF7BF0-EF27-463C-B4AF-F5B28C05425B', 'D0C1C442-D53A-495B-8822-8618DC10CD41', '4605342000464', '     / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32F04E00-976B-43B8-9BB4-4639CC93C367', 'D3D1F900-EDAE-419F-949F-B8328F7B41CE', '4670002260816', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0BA8494-393E-42CA-8A4F-C1AC8290B096', '394FEFCD-7440-4E60-A237-33D0BBD65121', '8992781250120', '   550  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE7492B8-5731-44B0-B9B8-4A66E83BABB9', 'A942A8A2-0D12-4092-9D0F-685A42C74D40', '4602866045056', '-  /811l/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63A3A2B9-0813-46D3-8A52-0B77107C32F9', '578DCAF1-8DF8-4164-8103-68AC69F4CEA2', '4601429000068', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CB91149-B38E-498C-AA38-7A32D158CFF4', 'A5C24818-7A5E-4CBF-86AC-14DFD33BB31A', '5411416020042', '    14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19C26663-1C49-4A31-81F0-CD0106F3CA21', 'EFA2FBCD-3560-496E-B48F-E80C1F42942E', '3800010646208', ' 0,25 //  180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41E7E7E2-DBCA-4CB5-86E7-09AF3CDCCEDF', '34538296-81AD-41F3-8A1F-61874AF13D30', '4600702054460', ' // .   1 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('718977FA-68DB-41A9-9F02-01C6A841268D', '67078619-6D8B-4FE2-AB21-A262A20B53C1', '8001040096659', '  6   6  180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1A9928B-48EB-4256-BA48-D32C7A2C9894', 'C3FE12B6-F1C6-48EB-8B31-A1BFEA42ADA9', '3760008322135', '  600  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC4B39AE-E2B5-454E-B465-822033698CBA', 'E5F4F8B1-9294-4CB6-999A-CF29CE616ECF', '4607008960204', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('933EF3F7-AD37-445C-B78D-9428F19E4605', 'A6E50552-D8B6-4B43-AC59-AF73FCA5AA34', '4660005990834', '       4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9689FA2-EAA4-46B3-8416-5D62769AA741', 'D6370E3F-9E2F-489D-BB86-9BCABBD01FF5', '3582910056515', ' 300+12,5 28 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2D317D9-76AF-49AB-B5EB-D3CDF63A07AB', 'B2E30F54-7CE4-49BE-B2A3-A90039C6034D', '1705770301119', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38A7F2C6-0F2B-4D20-97CA-30226EF8DEDC', 'C01A19B5-3BA2-4B13-8991-E3B8426C1380', '5702157177301', ' 50  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40CC2603-0D09-4830-B88B-0F2F5D454BC1', 'A99B3468-24CB-4EDD-B89D-78C5F751C73D', '4627100131999', '   / SPF30 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46DBA5A2-480E-4388-8092-BE7A4C9A950D', '5ED9AB5C-A7CC-4DDC-BA45-160C18EACCC1', '4620008620787', ' / 1% 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('055DA1BA-1068-488D-9CCA-7BBD88033DD3', '54F5E658-61C0-4D13-81A5-D74FEB057976', '4607051430174', '  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3986A23C-7739-4779-8DC8-4928713D4E50', '63997F69-C24F-45D4-8C6B-B80B57377B45', '7612367016704', '     / l 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18B78A2E-4C84-49D8-9CE8-C34A427053AD', '4ED56868-E5AD-447E-92BA-72964B845FFD', '4602866045063', '- /811lg-5/ /2 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCB44B1C-C6A5-416C-8704-8856F6C11DBE', '91C030B8-2316-4F4C-A41D-FA4DB6B3C1DB', '3629002725062', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('610502C5-56CC-448B-BFA6-8BB64D297885', 'BBCD82B1-698C-4D1F-BC58-53178F6198BA', '4607085233536', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93D8D680-BDD2-48E8-B528-05082F15F2FC', '4DAA95B3-2579-4954-8093-3AC3B6B5136D', '4607008360691', ' 1000/4  4 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8C6AF82-D52B-4949-84AF-FB3AD74AA8A1', '1C0A364A-8E47-4542-88BF-096E14BF4844', '4640009700370', '  /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('675E3E7B-ACEF-41BB-97CA-525554D10C2F', '45065955-FFA4-4D32-85EC-05F485C090B6', '4603905003891', '  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CC0FB74-8716-49F8-B29A-82BC34E310F8', '8A233FDF-28C5-4DC5-B815-B7CE489B168E', '3800089813549', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99AAB246-8DDB-4FD0-849D-0A27C78DA1EE', '93B1E862-7258-4674-9595-035CE5F85A44', '4605658130169', '   0  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('459BB3CE-6BB6-499C-ADB4-11E18EFE4225', 'C9763D78-8079-431C-9E33-F5FE72994992', '5029053543673', '    .[8-14] [9402441] 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F79A8E8A-8BA2-45CB-8744-74281F6FD291', '0C95C77F-E363-4107-A256-B63359CA2161', '4607041068288', '   20 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF2F2C12-392B-4B1F-8A46-A23045547959', '63D9E0E8-F7C0-4525-BEB2-23F7686EA23A', '5901478901408', '    4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A51368A7-E661-4CDB-AA39-871B3DBC3C20', 'E95603DA-4DB7-48B9-9CF9-1ABD2C0C13E8', '4627074843973', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56EC08E9-7B26-406C-AD24-71DBA540EB80', 'ED9D6767-E503-4136-A4A8-119F7E0A918D', '4680007630293', '       8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('806B0766-7334-4FD5-AD71-AE17F12959A3', '1A8FD3F1-1CD8-4AE5-A773-D1210E929DC5', '4820121901231', '  41 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41ADEBF2-FFE7-4E06-9C04-F97B80EB7898', '7F0EB37D-C45B-4B38-88FA-967DADD2EE1F', '4602242004141', '  / 0,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1DA7A55-CDC4-4947-80CE-D0A38444D506', 'C6347A07-DF00-4F09-A8D5-86A0282B18C5', '4030685508740', ' -  1,7 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AE3933A-BA2E-459B-ABC9-0249F7C26CB8', '4AA47212-4AF1-4D34-AF75-86045BC57718', '4605722871318', '      400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB5C9C83-D768-43AB-B252-CD20BC2B0A77', 'A7A99414-BA55-4E9E-B643-977968608737', '5029053527604', '     8-15 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92ECA2FD-2FAF-4B8B-BBC6-4963391A91F2', '3282ECE1-B913-466B-BACF-43D06E5FB116', '4620002182151', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0B1743B-B99F-4FED-8898-CA9DA9E8E2DA', '54BD1C25-2A37-48BC-88C8-9693DE1B558F', '5413973222518', ' 40  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4AF883C-90E0-4127-BA9D-9EA7A28FD255', '9542B657-53B8-48C9-9B76-612979F0E73F', '4607077091854', ' /.   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B9D609E-4C63-425B-81C0-9523CEF1B06D', '095CE783-E1AC-4675-8153-24A7B3838414', '2400006375665', '    /F-200/ - 3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('034451A0-95C3-4C5E-BB3E-C30789F191FE', '1890BEF6-24E6-45C5-9F30-43399D9ED2E9', '4620006272988', '    . 11, ., F-320/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9551A57-962D-4FE6-ACD7-6FDF6D3E9AD0', 'B3DA0B08-7104-4AEB-8EA4-675933644FC1', '4607109406922', '        250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE552695-953B-4B9E-9EAC-7D4413D3DCE7', '06471A53-8E00-463F-B92F-8BBFF7120EB7', '5292452001932', '     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37B544C3-48F3-461D-80D5-B09280D63E20', 'C94433DF-FCEE-459D-A21A-DBC666255779', '4630010960283', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E0AFFAA-AD35-41BC-BF05-8E2B9916EE31', '79D08E0D-0E29-4FFF-9CE8-904C60D4337B', '4015400985082', ' head&shoulders    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3260729-9B20-4756-9996-6B855383050D', '9626FA26-DDF6-4F6B-AB57-A2903E39827D', '4605021001461', '   1 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDFA6758-AC42-4FC2-8A4F-8345F934E20D', 'FB9FE1FB-F331-4783-9B51-780E227D8FE9', '4750283009387', '   3  /0107/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F2208DC-C5BA-44A4-A06D-57EDB938AFBA', '94E8FCFE-0013-433E-B42B-C273094F6944', '4603337000031', '- 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BFB92B7-60CF-429C-A250-B813AC7526C6', '4F7A4CFA-887F-4D67-ADCE-9E437EA6244E', '4607011666087', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('121DEDD2-9D04-4B65-B31F-EAF6250AC29B', 'BD79E3B0-3281-4A0B-8EE4-024769215187', '7330304507138', '  nosefrida ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFE3D621-A527-4F9C-8B3A-3C560D95DA79', 'BE5053F5-98AB-493B-97DD-98A46ADA7439', '5995327151045', ' // 10  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B56F9F64-09BC-4ACC-92F6-539409C150B1', 'CFC927C3-3141-4DEC-94ED-C798B2B827F4', '4600702099096', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C2940DC-5E1C-44DC-A432-208FE0AE938F', '190C345B-46AC-4802-BD41-797B7188A124', '4607147690123', '  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5312E9F-5319-48ED-8EC9-2979055036B6', '74C0DAEC-9AC3-4B94-8F9E-702D46F6C2ED', '4751023291277', ' . maditol 6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47B3756D-1147-4ECF-B432-143CB8C93E13', 'F08376C0-3C46-4167-B6FD-77587E2EB0CC', '4981046450034', '  -233', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95655344-1233-447C-81D4-46CF173EEECF', 'D718371E-343C-4DFC-AD19-5A498FADA2C0', '4627074843706', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7459DE60-2ADD-455B-B30D-0FE76793380F', '83E9A51E-6183-4573-BB5B-76D3D01AB1A8', '5900516420871', '      fruits       30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8D82441-DEBA-4C8F-BCE7-B42DAD753256', 'B2BF77C6-8446-4E22-8057-D3B96C47E076', '4607155430124', '  /.  .  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E679C79-7CD7-4D9D-B5A2-02EE43C6B8B0', 'A591DFF1-D968-417F-B79F-52382390E88C', '3582910005285', ' 100/2  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89BBBE50-3FDB-43D0-BBA9-94438F69CDD5', '90ACD385-98EA-4C27-B055-2BFCC2A7217E', '3830029297160', '  r / 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0766A497-1CE3-404D-A1E9-AE88827F4E9F', '79008156-E7A0-4F1F-956A-C8BE8A7731CC', '4602824000424', ' 2%  - 1 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('372200E2-F160-41E6-9DE7-946CCB3BD41B', '7EF687EC-8399-45A6-A97B-F9651A123D97', '3838957880058', '  50/5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05AF7B95-CD4A-4384-BA37-C9275264520C', '0267EA02-51A8-4481-9DC3-F4FE75114A9C', '4810133000374', '- 250 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E9D0EA9-B5D9-48CB-A27D-E421C67B1CBC', '409C69F4-5E3C-4BFC-B466-92C564C3E80F', '3574660204155', '   /   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD162D72-A1EB-423B-9C24-3DB64F25FE1E', '659857CA-247E-4653-9EF1-A3C25C7B7135', '4607069190343', '- 5,5/75 1  /- /+-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92A62B68-B642-4281-AE2F-8C9078FACFA7', 'BACD610E-1065-4DD7-8E96-DF291A48BC73', '4623720997816', '  50*70 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C42EB10-FF1D-42AF-8E61-23B1BB3C68A2', '4276E17A-E073-469B-9922-D1BC70A2824D', '4820121900418', '   1075', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88F45073-213B-4B50-A27F-7D97097B219C', '07E67FA7-C2AA-44C8-BF13-72B1124C5619', '4606486013037', '  250  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CC6EA2F-E992-4413-AF6C-1393B9D69A49', '291A2F74-9953-4FF5-A61E-53EC2D463F5E', '4607017840597', '   / / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C99940C9-F6CE-413E-817F-858B968C54F7', '74E211F0-CFAC-4D4F-8FAD-41D20A6C5ACE', '4605964004208', '  one 20 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2062EFE-4ECF-4262-B564-B4612BC049A8', 'A0775A60-4A0B-4F79-A820-91ACB6D578B4', '4660005990797', '       2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43A14C96-6124-4CC5-95D5-1BCF4E76BA56', 'F8CB88A4-B272-404F-B085-B8F4CECB9BAC', '7612367023832', '   //+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72F27ADD-771F-42CA-8D73-2DA356684C62', '90051B88-E2ED-4953-8D43-94E63D79E66C', '8711218450007', '- 0,001 / 1 - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F5BB108-2F81-4DA9-9010-CF7D952896B5', 'DFA4DE4E-AFD9-40BB-A8EB-DD155AC497F7', '4033033417053', '   /evitest/ 1 ', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3DBC864-7A74-4FDF-BEDD-CA16F3FF52F6', 'AF707A41-1545-4C89-A9E8-AB6330F25054', '4607039975512', ' 0,5  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A3F6147-3E4D-4AA5-9FC6-016F33ED8F1E', 'D1A43EC8-B4B5-40D1-B16D-FE2996CFAC95', '3800200962590', '   / 330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC8E98FB-8CB2-4EFF-807A-549A0FCE1681', '8733F506-1A80-4BC0-B24A-E53C1CE9AE5E', '2400006370493', '    /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4515BD9E-A3B9-4D88-8664-78860EF85B99', 'AA0A8FE3-851A-4FCB-A836-68DBE66D821A', '4607027211301', '      0+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A666670-80D5-40BF-A71B-E98575502BAC', '1DC44028-D887-4718-B76D-E6524B7A68C2', '4607034940560', ' . /./ .   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B06137A-D2E6-40BC-8338-16E8C30E455F', '7A5E0278-9ACE-47F6-9999-E9EE68616CD4', '4602212006205', '   610', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEA0AE97-0181-47BE-8976-E89898016110', 'EB44DB22-A645-4A29-A594-6A926621FB36', '4820121901576', '  /.  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A57CABE-E07C-4533-BADB-D4525D5D836B', 'B2574966-764F-4BD6-B117-BDEE29BDD38D', '3838989592646', '  . / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5571373E-41BF-41F7-A6F5-8D24FDA5FD47', 'CF8D8D4E-9A45-479D-AF00-D9E4CE7250FD', '4049500749985', '  - .  410', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F342A0E-6DB1-40ED-9571-A6D0CB40DAB7', '0F198B4D-BF57-4527-8F76-B7ADE586374A', '5900516986742', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A106E19-A4E8-4C86-ABAF-C3AC227F9678', '2FA33B83-1F05-42A8-AB20-623AA0B01CE7', '4711934139693', ' wm-62s   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07331B2D-8A39-4B1F-8D88-23553F219B90', 'BC55C8B5-4C6D-4D9B-BFEA-58889E3B2C31', '3248140752336', ' /. . . /./ 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('155B14A9-2A98-4CDA-8ED2-026F70E327EC', '85936ECA-D6E6-442A-86BE-A3D130F0B083', '4607109407547', '  +   / scholl 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7A76F42-10B4-48D5-ABD4-A10076BD9FC9', '6802C04C-7E54-49C3-841D-0E9779B19B73', '5029053543130', '    4 / 7-18 /27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DCAAA93-DBAA-4909-BBB5-A4649B8020A7', '3DD8AE8C-9DED-4984-9DFB-3CAD2462A6CD', '7640114720390', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BA9472C-B575-4564-808F-62C5C0377401', '181B628F-E9C0-4BFD-9378-99E8E8E280A7', '4607101202850', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A8AE1C2-16A3-4C6D-8A5D-4E1F41BB2073', 'BC95B081-2DE4-4A26-A591-357A84F11580', '4602228000358', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D031F409-3874-4252-BB1A-7D547A6846B5', 'FC97705D-0DC5-4A51-816A-3AFE3F53D6DD', '4607109409947', '    / scholl', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0064FE6-D4DD-44D4-9B81-6D6629A8985E', '255CE7D0-91F3-4A11-B0A7-4DE271869741', '4607101205448', ' LUBBY   "'' silicone"   6 ./11394', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEDC4A80-E230-4C4B-B541-32A1F4B3051F', '7878289F-5E96-4415-A1E0-1433D53405D2', '4690624015182', '        ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA22DBF1-3ECB-4838-A739-71DE5E0A9EEE', '62EFB923-BA6A-4FD0-8760-43360BC97156', '4605185000515', '   .  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAB21215-DDB6-45E2-9414-9D04AFE6432F', 'C7C9D1C1-EB82-4CB6-A41C-2F9376A4B04E', '9005441702149', '-  20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58031A83-78CB-4B1C-A383-49AC64E7CC7C', '67AE662D-63FA-4CBB-AEC8-4A0CD193A903', '4607085860084', '  / .   .  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A52F6599-940D-4135-90FE-A52F088D28D9', '03AFC849-E1EC-4E0C-8F3C-E80602F46A7F', '4601835000423', '     // 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBD9D500-3D23-4F83-BFDD-5F3A351CBA28', 'EB71EE5C-85A5-4281-9E03-7BAC75726204', '5029053543154', '   4+/7-18/ 68', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE33A60F-F045-46F4-A289-B910F6AC8414', '8E7E7161-9CB4-419E-A6F5-823150007472', '4603720177227', ' /. . 20/ 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F1E335D-2899-4539-BC75-5C25F0F73C6E', '3B91B45F-24FE-4ADC-8E03-4777BBAC7DD0', '4605319002873', '   /  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7173E8A5-29AD-4215-81F9-098A08703E5A', '507777B6-6C87-4B16-A6F7-6D9E2DFE977D', '4602565008864', ' 2/ - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E752F57-DA8E-487F-87A0-D33382323F56', '119CB153-AFB1-4EDA-9D28-3533C9DAC184', '4607033350582', '    / / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2A1CC0B-9EC1-425F-9D91-C73168DB479B', 'E2DB834C-8A5F-430D-B2E7-76A5AC38AFEB', '4605658195120', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0A57B45-9363-4BA3-90D9-FB48F3767646', '84D3C858-4FD6-4B5B-A332-F41E3CFD3F32', '5997001308400', ' 10 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBE96901-7E33-45B1-8091-A65737B4CFA7', 'C0391D7E-6D11-4A41-B177-9B8E944C57A7', '4620002182755', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6C186A5-1C67-4A3D-A08E-47FEE446B51F', 'FBE4C7C3-D6CE-42E9-8B82-BC46B96E1EF3', '4607094173496', '    / 4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F5627F1-E2A6-4D8E-AE6F-C153465EB7DF', '935E5D98-3E86-482D-A673-4F70C085EB05', '4820121900760', '   /.,,/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7E00866-FBDD-48C5-99B7-2F9CFEAD1AD8', 'CD2D79EA-961A-4698-A65C-75399ED16883', '4607021272742', '   / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0E8199D-0550-46DC-9D91-C77C78C425A2', '35F9E3F0-BEBA-4687-993A-3CF398EBC3B7', '4607003667276', ' / 250+62,5/ 5 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('695B1023-59E9-47C6-BCBE-D7BB147A857A', 'B558B961-4D4B-498B-96A4-5465A1F0F62D', '4605108003494', '   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CF32F4F-049E-4FF1-8FD6-CEB278643C46', '32012924-C2C9-427F-8E90-D1193EBE68C9', '4620006242004', ' / /-326/ - 5   1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6113F6C4-71F5-4351-AA09-85B00CCA1AEE', '2F7FF3AC-76BF-47E6-9FBB-7398F2E5C462', '4660016670053', ' -051', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80469E43-95B3-4011-8613-B358AF1361A1', 'D11BBCF9-B640-4670-8E97-DD19F0C56CCB', '8710103667001', '    6+ 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EF3E71F-9DD7-4EE3-A77E-F17B8AB56D64', 'FBEC8262-E750-4126-B3A7-3359780DB7A6', '7350012552107', '  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6FA7286-4779-406F-A5DA-C57888DC97EC', '6A78EC1A-FCBE-4B1D-AF85-D791BE77E9FB', '4607051797369', '   /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D721112-5362-4AE8-9572-DC6131270BEF', '4579DD2F-8567-4E81-A08B-C2814EF5C21E', '8710428001498', '  0-12 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE0217DD-650C-4BD8-BB8D-CD8D4895D56C', 'E5B1C75D-5D3C-4D4F-9AC2-BF0BD9F9EE8B', '4607098450913', '   0,1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30FE278D-6581-464C-878F-0F4C25F96F81', '0E8EF948-D370-4EE7-B5AC-B730670400E6', '4719003310530', '   110 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6102709-7558-4858-B92B-9C9588FA814B', '18AE99D2-E21A-4697-9B1E-FE46CFF4B706', '4607051795648', '    /75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97247B00-E049-4DE4-8ED4-A22031BDBAEC', '3DD99179-0B30-408C-B0EC-0CBBF60DE4FB', '3248140756693', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66B5F706-7A27-4C32-9F45-D01CA2825942', 'E704AEC1-0FF6-4BC6-BDE3-A1A0C09A3CA1', '8901127004082', '  300   // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C567AB22-5381-4110-960C-1B175FF24D83', '650DC4D4-BEAE-45F3-9BA0-A92CA1D49323', '7290010035113', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('100ABCCB-8A55-4C26-9681-4EC3464959DF', 'D85D72F9-612A-4A1D-AE25-260D9F635166', '4603188000310', '     2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C4327D4-9F95-41E5-B571-6EB88BFEF5AD', '89EAC8E1-CCEE-499D-9A97-521D0F556C01', '7322540660135', '  - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD875E6B-9E19-4759-84D6-BAFA1F4964FD', '86F30F2A-78FE-4BDB-BD21-25721F984B57', '4607070020813', '   spf-30   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52A9C7F3-A934-4CC5-9275-EA4CC998DB4B', '5432BCC5-8DFC-417C-8EA0-CCA744D21BAD', '4751018120278', '  /     6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADE3ADF4-F74A-4E51-AF61-3F48F227D7B0', 'B8FA7C9E-81ED-4309-895B-E33E3D9F087F', '3838989501495', ' 4  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D570A33-0A58-4A35-8735-E777ADE80410', '0CBAD38E-887C-4E76-83E9-5B46989F77C6', '4610004310898', ' / / 2/ s/ 68-75/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62968CD8-631F-4D76-AC0C-3BEDC585763D', '7ED56D29-5C2B-40F2-A2AE-590B832EECD9', '4601370001046', ' /     . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69BC5310-7B0F-4B37-9CEC-34394ABFB62F', 'D1C78B19-EB4E-47FA-8C25-5D958A79793B', '4607041069698', '   -   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('053BCC39-6F3C-4822-81F2-C45E1DA2DC43', 'B434A562-0E1D-4575-8BE8-2BDD7C081240', '4605469002198', ' 5  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07BF0893-63B2-4504-A35A-09FEC48515AA', 'FF70F1EF-02BD-4721-AAC8-1C520E6AFFD9', '4605658195458', '   / /19545/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C5A9247-2E2C-4815-9179-FE86D79283DC', '2951B69B-FD1A-40ED-A835-0D2FD7D89C43', '4620006246088', '    /F-400/ - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77C4B1E4-8616-4053-B9D3-BB9B0B5B0EF5', 'D1029FE2-89D3-42CD-8303-9254DFADC7AA', '4602103002705', '  5   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28B8FBA2-6FDD-4126-A4BC-9D22226FC448', '64BCBB36-2438-4F34-89EA-0FEA04ABFFF4', '4605453000117', ' 200 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45909536-458E-4467-A3CE-CE5F158E2527', '4E1C6C86-6057-48DD-BA68-2C3473C83483', '5029053543697', '    5 /12-22 /  64 /2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF942411-0389-4E2E-9A2F-FB94DBD41151', '2D481717-6317-4AA1-B5F7-58EA117EAD73', '5900516601652', '   60x60 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E711335D-8717-4E26-8169-28A230FCF570', '21B3AD9F-FFB8-4627-B4DC-AECF8592FCD9', '4607027210434', '  -  /,./ 6-12 /11251/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB70AC9A-2C03-41C6-8EDC-1FC42FEA6C64', '152F51C6-4D18-490E-BDFB-29B3E49144B7', '4605635002366', ' 20  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B0A4EEA-63FB-4544-8CEC-4E5329E3B522', '08980398-A2D5-474D-9846-B0E7630BE834', '4719003312015', ' wa-33   + ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('382B6E53-EA10-4A64-871C-734AD3E34703', 'E183E6DF-DAAA-4FDD-9765-20133175C906', '4602210000823', '  200/ 60  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8F7A195-E023-48BF-B749-027614A53328', '5F2E7647-4AC3-4DD0-AA17-D6884BBA7F51', '4602866000192', ' /-1443/    /m/ 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B579096B-E1AC-4FA1-91EE-E809F0602D28', '36740845-BD50-4127-9D62-0D754D11E710', '4602210000847', '  400/ 60  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B56E2E6-9DF6-430C-B476-6ACC21123496', '4D5C9D91-7E93-47AD-83C2-059C1B132779', '4607086564554', '   / /  160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96DED5F0-471E-4906-8385-A67A9C2AF7D1', 'FB5AE80E-DC1C-4668-9476-2B39D241CFF6', '4610012020352', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBC201ED-2B93-4942-8F27-2BAB73B4D912', '464347B0-10B6-4361-B504-8275C9324425', '7702018877478', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('584F0E43-1BED-4525-8BEA-2238AEB97B35', '7651CDFF-259A-4E1C-BC09-E37BFA58C518', '5904016040119', '  30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB07660B-E339-4E71-8E75-10D150842A72', 'E2ABFB34-41F9-45A5-84FD-2E0F62DD2A5A', '5410765001467', '   / 3,3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('523C13A7-2615-4C99-8EDA-9570928D5715', '3C8C2CD7-AAF2-4394-A560-A09B7E923040', '4605086001246', ' 1,510  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42CF18D0-EC27-465B-991B-7747029ABFC5', '6E261571-4A5B-46D9-8838-A940B3664890', '6419716919119', '  0,15% 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A16E485D-9552-4BFE-B4D3-13EE88F6536D', 'CE38C4DB-9836-43B8-AFFA-44137BC64CE0', '4607020210202', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('755E3918-3A09-4F69-8204-2C64EFA84AAA', 'D65D13AD-9D46-4DFF-8109-00AF9C55CFB9', '4533213040496', '   /  42  1 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E3DEFC3-06B7-4B5B-9C5E-FBC0231C5171', 'CE99C8E1-FD9D-42BD-8E9F-283320427C9A', '4607003248239', '-    / 250+- 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D873E4F-D0ED-4724-AA0F-4DF1DB5699D3', '89FE38CB-E9FE-44E0-9B4D-16DB33D2CE7D', '4627100132057', '    spf50+    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6427AFB2-34B0-4E0D-A272-666F64AA64D8', '83F2A106-114A-42DE-8302-CEAD699351C4', '4620006246019', '    /F-400/ - 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52E13614-BB66-4BC4-B928-C821C927C8C9', '3EC5DC06-FCB0-4EFE-844C-3DC799189FCC', '4008600047582', '   / L 6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D871F8D7-B7D8-4D5B-BF78-F56957B9648D', 'B7FAA597-CDD6-4C67-B578-87B62DA9CBF1', '5000174898538', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B8560CA-5B73-4A94-93EC-D13E8AE0D373', 'A9D48C12-60F7-4674-A7AC-DC8E7B1EAAFD', '4811248005261', '   /        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CF9B034-B784-4C8A-ACEF-43BDAB1FEAC9', '709A3918-D0E0-4010-B475-1506BAC7BD70', '4607174434431', '      //.   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C7CA3EA-10C4-40B5-ABAE-D79ED0F30C6E', 'ABB31963-8004-49DC-B32E-8270219E04E9', '4607027219321', '      l //1206', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E8AD05C-D40C-4CF3-842D-0383EEA9B50E', 'FF4EE2C5-97A5-4909-82DF-49D8A03B4995', '4607051798700', '   /  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC404F32-5205-456E-BBEA-DC9BC6D5EC97', 'B732F923-5A12-41BD-957E-2FB94DC14D6C', '4650069843061', '   - / /124 / / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E50122E-8A45-4C74-9E0B-5E9F4138E01D', 'E0C53A1B-8A8D-427D-88C7-8D574B4970D1', '4250369505142', ' . 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('511A741B-075B-4866-B5DF-FE67CF95927D', '63673861-16D6-4884-8303-0723AE774503', '4602242008477', '    50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65C88903-3111-4429-A379-A4F915F42CC4', '8BCE46BC-25A2-407F-9FA9-A69FC9340A6A', '4605113000853', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7D5DE9A-7FBF-4EE2-AB45-04126EF1ACEF', 'C9559FF4-2134-49AA-931E-51EA1ED7DFEF', '5900516650414', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A93D7C5-DF0B-4952-A728-8CDF3DBA580D', '8ECC1951-7E73-4B34-8B73-29D90DF263E4', '4250234934060', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('034BDEEC-78FE-4912-880C-AB78D41D8423', 'E0E1E66E-2EDD-44E1-BDD5-CAA524866715', '6805188189912', '  1570 /. 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61AF40D1-5D51-4143-AD7B-A2D359DC5007', '843D3CC4-275E-4A40-9712-8E77D94E0AB8', '4049500582896', '  . 9,25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A33276F-4AAE-4A99-8F42-2C7340E91E2C', '13ACF23E-F09B-4479-B802-D4F06C43C84C', '4607034471569', '    74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AB4A836-C577-4888-B50C-37F46EBE6E5B', '7E1924D1-0B24-417C-8523-19C6A2C3EEF2', '7930043490977', ' / 250  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8B402F5-BFCC-4524-8771-4DE7A75F1292', '80AC2B95-0098-42C0-AE59-D29C6B8058BC', '4823002217612', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE051C0F-D178-406D-9D6F-D96A34A0D199', '8B454B9A-76B0-434D-B27E-D5495A3EC6EB', '4606371000586', '      35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('295E9714-620C-48F7-A01F-E29E27DA564F', 'F82E6F13-D922-4D67-BAE6-C456BD6C6A7A', '3838989582685', ' 15  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('333AFF22-6E16-4059-95A2-9BA52782FE05', '74B7B920-D9D2-46BB-BF7C-8B84BDD05EC3', '4607063890089', '  / - / 500. / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55D43277-6F1B-4681-9C49-32277161025D', '157E40AF-8064-4DCB-BA92-1578CA08B45D', '4602866002530', '  8601   S-XS', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4DCFD1F-BB69-4151-94CA-5A97938D0535', 'F36BCDA9-9636-4DA8-8A50-CE7F9D37AE4A', '4680004854289', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F86AAC3-4707-4F97-92F7-565C001582BE', 'BB2A0FCC-86A7-4246-AB64-D3C5E2FF49CC', '7680312159004', ' 1,5 /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC2C28CB-38E1-478C-99CD-6CF8BF781EAB', '7FE85A3A-9706-41F3-BB7D-4B2AF0F5CEDC', '4612741480179', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AA6FBD1-3F4E-4695-AC40-65C7E61CE411', '2C4AA9EA-4488-4C77-8670-4919ED03E074', '4610006200050', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8259C08A-A514-4B73-A1A5-4BECA4984BE0', 'CC567E13-F259-48DA-A3F6-9CE9E9A7CD82', '4015630064762', '-   mobile 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('107213E5-2232-4B20-846A-21ADAAD36640', 'D292407A-C7CC-46BF-B169-9C6EE9FF8368', '7680386059002', ' 100 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7ED44DC-FC13-4475-A828-CADAB4333587', 'B94C2AA3-B977-42BC-9097-B8391782A3AA', '8300496018568', '     - 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF9D8C82-FCE8-4F92-9C2C-2E8336A64695', '4F84A1A7-D185-443D-8E80-6DBEAF3BC54A', '5903137171009', ' 10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D616294D-4B1A-4719-8079-4E0BFC142D4A', 'F3EBF296-B30B-41A2-9148-1FFEAF20A371', '3574660607567', '   + 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48A532AA-FDE1-4A59-9404-E9A534E03F82', '9DEB090F-67F4-492C-8F8E-B888F8BB6854', '4602866000857', ' /-1552/  /6  ., 21/ /l/ 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BF53F28-5CC0-4ED8-A77D-153D27FC86A9', '3104F5B4-E033-429F-9C37-479A9B36A16F', '8714789162782', ' /     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97CA9E2E-F2E6-455B-9467-C970466BA74E', 'C18AA200-CAA3-45C8-8EB0-F2B7858A4690', '4602206001537', ' 30  100/ 3  - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17E0004B-DC90-4D26-9617-5CFC6D74EB5A', '8AAA6EC5-B4AB-43C1-90B7-6D903FB91839', '4602866063029', '  -   , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('733DCAE4-576B-4AB4-9D6F-3C2BB2ED36C8', '9611F803-F259-4BF8-9BCF-D3A4158D5E65', '4620006265805', '    . 3 ., F-216', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A40EE55-AE81-48E4-B9CE-17C8393956AD', '0C315C72-1B05-4AAA-830D-B33469500DFE', '4260090440148', '  .vm  / .., ./ //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13EEFD83-1C1E-4A74-9C2A-8B1C75D038BD', 'A998768D-4BB7-4FE7-8B24-1C4FAEC35D68', '4019338601540', '  5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DCD44D7-7101-4791-B476-E98AB477C422', 'A0808C25-2313-4985-84EE-96F8C7A8D348', '4607039974225', '  0,4  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D6D4EA9-0ECC-4E7B-8AA0-8487A7BE1023', 'E6B154E7-49BB-487F-A83B-4CB2F4BF87CD', '4607039973747', '    150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB734D66-9643-4029-B3BE-B409E2AB7DB7', 'EFAC6535-55A2-4E7F-965A-192D532AB819', '9617982000693', '  500 8  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6D63B4D-7C9B-4D10-AE45-6085D8985A21', 'F046FC1D-FB3D-411A-B6FE-84EB239120A2', '7680278379003', '  2% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10B94DBE-6D35-4C0D-991E-4866BCA8C908', 'DEAD0350-D87C-41C1-838A-A9CBA536C9B1', '4607011666155', ' -   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DFEFE2D-1280-4BAB-9897-0FACD686C4AF', '2BF9160A-EADE-45FE-A3FB-7890DD53E2E1', '4607039975239', '   0,4  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5DDC18D-8B07-4D6B-BC83-B6B3C5444B60', 'D7CB154E-F16C-4541-B777-94CBF1471A24', '4607136210172', ' / - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8D137F0-A247-4A60-9A95-8DEBDC3899F4', '61493FF5-281A-42C8-8F6E-3E7C17F2296B', '3629002725031', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56C65605-265E-4478-9FB1-AC68ED620205', '9FFD0980-9B1C-4C53-8E5D-155BB23BA466', '4605319007915', '  . / / +/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5A98A53-D362-4463-B7E4-BDC787CEDE3F', '2B0BBC6E-763B-4357-B902-4D0AC6368539', '4605658130664', '   0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('424A0659-7D59-40C3-9B36-1882BEE9DFBF', 'AB415566-341D-40E9-B58E-4738977EA491', '5029053543543', '.    /. 3 (5-9) 21 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5197FDD-2458-442B-BB36-08CAD9ED1D2D', '90DF1E82-1886-4E8D-943B-CB6AF83312D7', '8710103580928', '  / /8281/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EE7058D-2BFA-476A-886A-6D4681A737C2', '27EA1728-C0E3-4B74-BED1-4D5827EE23F3', '3587080001273', ' 6000 - /0,6  - / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81782E24-500A-41B6-B411-C8E068C693C3', 'EF240A6F-D54F-46BA-8EBC-E0E36D3D7D23', '4607027217822', ' -. /., / 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BC32739-66F1-4971-84FF-5281BBC5C76C', '13EEE7BF-2BAF-4CB1-8F45-8234D00FE6F4', '4612613500189', '      / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A14E52C5-3CEC-4411-A1F5-5A7255AD7E68', '6B27B846-59A2-48CB-8087-9DD7630A8436', '4606486000501', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('420DBE70-EC9C-44BC-93AF-3EAE4F7EC025', '584B0E99-0E20-4219-A355-522554609997', '5052197048230', '   / scholl', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE454EE6-9191-4633-9CEC-B82D4A2F2623', '656E0111-0A09-4E3B-BB29-1DE66DF141F9', '5997001359075', ' 21+7  / 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F66437A-B7C9-4F31-91AB-12F2C1795F9E', 'F9F2805B-9666-4B52-90CD-5AAA8E27218D', '5900002023883', '       225', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17C081D2-88C4-4E30-AADB-BAC081162115', '4CD6305C-9008-4E7B-BFC9-98A9B106CEEA', '4605059012644', '5        50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5E83964-6533-4F44-B4CE-0DAD202296DF', 'A671F1B5-AE4E-4FAC-97A8-24691C88F543', '4601774005817', '  / / .5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38192CB7-9F7C-4642-901B-27C213F546BC', 'D1756A56-5CCD-4ADE-94B2-D6111CB84143', '4606144008849', '   360 optic  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFC78523-54FC-4F10-AC42-1A941CB6CD6F', '04AC7D34-4252-44DB-A0C0-83BACBB29801', '3629004240068', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('818AB788-4E72-4F23-AAC3-BEF182D0DFC4', '665907AD-477F-4CDE-A864-8C074283C1D2', '9006968002903', '  80/12,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A64B24C8-4509-45B0-9366-0CC84AD8E577', '55F2ADCD-592B-4482-91B5-1B0DDFFB6283', '4602866034319', ' -117     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45EF5672-8961-4A0A-B675-1CE3A3386142', '2AE60800-4A59-4355-BB7A-068156E24E68', '4008600047551', '   / L 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE53AE2B-7FC8-4511-A568-2C7FE1C34EA1', '10707666-9833-4EA1-BD26-1710658FA1C5', '5702157150052', ' 0,005 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BF4F88B-33F3-442A-A2C9-7ED9E88D0D8A', 'E64AE120-16CC-47E6-820C-9B66AC5CD22C', '4620006241908', '  . 3, ., -322', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19AF80DE-6BEE-4A02-85E8-ADE0C2C84D60', '4A92D242-6FB0-4F42-8710-6085EB0A62F1', '3629003127063', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB5C4224-D312-448D-B814-578A95A2163D', '38457ECF-1321-4024-9452-783D6DD70352', '5420044310166', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66ABC3FD-C1B4-496F-8146-B29F63151F29', '4A9E3AF1-A9F2-49C4-A1C0-64C20228618E', '4046222415549', '  -   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CB03E76-6401-4C4E-B5FF-E10BAC0D772E', 'A715C67A-2D2B-42C9-8D9A-3927BBF9B415', '4981046050494', ' A&D ua-1300  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7A2D8DC-AFFF-4CE8-947F-5B21202D1B0F', '4266E172-AEE1-4CC2-AA02-59066CB01A35', '5900516691042', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08A1BD50-4ED8-43DC-9EC2-FC76977EC959', '130F8E03-ECF8-49CE-8128-F59905235244', '4602866021036', '  003/8 /...', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD401CB1-7126-43BB-AE17-1EAB08153499', 'B79C6FAD-4FCB-4A85-85B9-4D0E4B4B8CC9', '4605059019988', '5    -   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F75AABE9-0033-43FA-9464-81556F488790', '405D29CC-830E-42DF-BCF8-7C125CD881A6', '7613031096299', '  /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85501991-41D5-43D9-B97F-DD3F150E3821', 'D3869543-D4D4-4C88-8AD2-1A8477E6B157', '4607027218720', ' -.,.18 . /./', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41DCCF2B-14E0-4A42-899B-B02130A7CBE5', '983DF7B2-86E9-47D1-AB60-62680CEEB789', '4627074843669', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DC17008-0384-494A-8B7D-EFB49B3DCFDC', '60D1208F-6F96-4F3F-BA9F-CE3637E56F36', '4650001680952', '     2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B53EE25-09EB-436B-9BAC-C84ECF7A3841', '5A5CDD79-EC4B-48C4-91AC-53A03EF7185E', '4603695004368', ' 0,008   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A42E9941-7E24-4CFD-9E17-C17F23D2D884', 'E6B81B7C-A04C-49EB-9788-B11F9F2913F7', '4601808008470', ' 10% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F230478C-E7D4-45C1-9960-3E4E7F8D2C32', '091389D9-BF3E-40C4-A590-E554F03BEFC1', '4820121901040', ' -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('174DED80-F4BC-453E-8131-CD6025382140', '12D3177F-ECF3-4332-B25B-0FDB5B3C79E6', '4607008132373', '  22 +92 /   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7116A5C-DC8D-4C49-8F60-8A4AB9D0D621', '8F77EA9B-F41B-48CF-8689-E7ED5DEA1CF2', '8711141828522', ' 60 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('234F5018-9F60-447A-9C87-B1035FDD9902', '9D182BDA-4CF8-491B-B600-6D869FBB95FB', '4660011212159', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB967011-57F1-45F7-8495-B5FC549F2CE2', 'A5DB7DD3-3333-4579-8DD2-B9E0C6CD4866', '4016369355060', '  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('709D1AC0-DB7D-46C7-9D82-1DE1DE569E78', '14E18053-9737-4A9F-9150-6D60AA6F825C', '7640123861091', '-    500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50F75417-30C5-4E8A-8626-249FDD63952F', 'E549573C-5670-42B7-89F4-3C20B7C20103', '7350061291033', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2468788C-83B3-4663-8D6E-0C5732755696', '42779016-E3D1-45AE-A3E4-0D3BDAB71E9A', '2000103612894', ' 2/207 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A7367DE-BD26-4A5C-9DA7-E7946A6CB6BC', '32B33DDA-7B86-4121-9CB2-2E147ED2386D', '5900273113153', '   /253166/   128 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A0E5F2B-E1C4-4339-8493-352627318A1A', '98A1CBDC-5CED-48C5-97A2-474BE87B4892', '4601909000144', ' / 200+5/120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0003D267-F897-4E07-B5A4-A6D4E4F6EC7C', '09186B29-B0DA-4BF6-8965-B3BEC222B18A', '7322540591941', '     9+3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10F3BF6C-2C5D-4CC0-87AE-C1DF9EE8F5A4', 'CBE1F5AD-D19B-48A8-B60F-7ED974C52BB8', '4627074842631', '   .     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A572FBDC-CFD9-4E1E-B883-A73C8AC32C96', '4AADFED3-3C98-473E-921F-3D66A0812926', '4902011751390', ' goon- 9-14  /l 44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7279CCC7-68E1-426B-B0CF-EC0F84C0FB28', '5112A5DE-A584-4B85-931A-1DECF6DC4843', '4607041068998', ' / / 14,0n7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C185E17B-9ED1-41AC-A96F-AEA4F0AABEC5', 'FFB73527-B353-4B8C-879F-6BE60A9CC8B4', '4607027767334', '  0,005+0,004  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74F0FFF1-0EB8-4B29-BEB2-AD97E4D9AAA5', 'F7528824-9F2D-48BB-B981-5ECBBEE46E3F', '4607005321282', '     100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45218B6E-43CC-4677-ABED-7155A70E1780', '610BB7F6-9618-48C9-AC20-A191C29494F9', '5010182990629', '     /// 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B19E466-EA17-409C-9977-E12C3B322106', '3F3C1578-5AB1-4B41-854E-4EDC78344D83', '3282779027540', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5939E21F-CFC3-42E3-8AA5-A5ED53D1841C', 'D37B41D3-10E1-4C12-8BAB-E09D0AD8BA92', '4820121900128', '1013   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('865EA6A1-A683-48CB-84DB-E6BA8855D543', '5507060A-A9FE-4F6F-9A24-EA6A45312E65', '4601164001986', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29DACD19-5E87-45B5-A4C9-C7F2C7B0E979', 'FCD9288A-FB5A-42E7-9FF7-2D6F85F2BD9E', '4607101209514', '    /    6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5317F13D-2670-451F-9063-BF2FAE2FEA70', '4D3A53EA-5D4A-4494-AF3F-9039074FCC8E', '3582910071471', ' 1,5  / 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F5C70B1-C623-4553-B18D-D95313544C78', 'E488A42D-3AD9-494A-8FFE-8F87FFF8DE1A', '4600490618189', '     0  6   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A0AF1ED-B6D0-4E81-AE9E-F3AEF86F8723', '6FF06CFA-6835-429F-941A-22B25644F37C', '5900516650469', '       300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76C39E2B-47F5-4AA8-9E8A-D5A4388DEFF1', 'FAEBBE68-AC6F-4A13-BA49-351245E05610', '8710103662365', ' standard  . 3+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D342D9D3-216E-4D2F-9462-99831FBD4BCA', '4F5220AA-B928-479B-BCC1-71FF6184935D', '4601955000099', '  - 4 /  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D9EC776-56E2-4287-813C-0E11A7735DB5', 'F1F17404-9FBB-440B-9F5E-209904106416', '4601774006111', ' -  .327  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE7E905D-B347-4FC8-B694-4510A0726555', 'A5D54B71-5AF3-4EF5-9F5B-6E2B5243A3F0', '4750283035119', '  / 9901 // 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61227AE5-07CF-4623-9655-C59A27732D24', '2484CEE6-2FE7-4B25-9970-CAB4934335B2', '4670008162992', '  150/ 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25F2E001-1AA1-49BB-A064-911668271118', '90E2573B-719A-45F6-AF3C-20AD7028FCD1', '4601654000611', '  2,2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F3D0060-B5FE-4B69-803C-677032B85BD5', '5F8E2A70-2786-48DA-8D82-9C8D3C0E124C', '5997001359648', ' 250  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2DE4CBD-E9AA-4407-B552-947040ACA433', '6472D3C8-DD30-4DAC-9DD9-90F45A0D7580', '5411416032250', ' .   4060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F800008-294F-4BDA-88F5-5957FFAE372E', 'E1034705-9EF2-44DB-8D41-0B4310992CA5', '5021265220304', ' 200 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC1D1868-FD84-4FB7-9076-B4CAFF508683', '248A01DC-406E-4EC7-9C93-DD97950241AF', '4605635001345', ' 25/50  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B397C41B-64B7-43FB-9D41-23AC0DF6920A', 'F57411FC-5C5C-4A86-8BE5-5499F809CCA3', '4008600164142', ' Genius   0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7725171D-61BD-4302-96AD-17C152D03CBA', '112C19FB-F99E-4D79-A5AB-CFAEBBCFC7BE', '4607027210601', '-      6-12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16C61888-BD21-4B50-ABA1-E5AFA3B94959', '986E125F-6EAB-4956-BF82-D64B0F95A615', '9317129040918', '  /    // 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EE51913-1969-4CB7-9A94-F5BD74F1E305', '917F1A7A-5F6A-4348-9E1C-E37711796577', '5900516896560', '   .  2.5 x 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('965746BB-8A05-468B-A3A9-B310EB38B77C', 'FB2D4943-4B5D-4EB9-8B2F-5705A41EF5C7', '4605319001371', '    /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0F6DD93-C068-4976-8EC1-C8C97383CD10', '5F4CB300-06C1-45F6-9BDE-04904774D45D', '3629002751061', '   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E75E0287-1FF3-4235-BD1C-2CEDF2CD788B', 'B7BB8501-9152-4ED9-9973-042F61E01CEB', '4603423003540', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDBD360A-7D1F-448A-8A25-3E012AEA38F3', '05855AD9-2682-482B-A398-18A97F4D5DB4', '4711146553188', '- .   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B332AE81-B3EB-4014-A575-D227DC46C698', '3F42CB66-A974-465C-A3B1-1B6E901827D3', '4049500669481', '   2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C0AD179-BB74-402E-B8F5-0057186C31B2', 'B6BB631C-3597-4850-92F3-CEBCB4BF1A4D', '4600908021945', '-308 / //  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C820953D-463B-49F7-B649-B6BBAB9D42D3', '4DA896DD-F66C-4995-B974-FC0FEC2F8915', '4607056261018', '    170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35F0C672-3075-4F94-BB8C-3FA1E0D2EC26', '8F62CA91-416D-4A02-B7C3-8CE35594500B', '4660013570424', '        . 230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('878D1BC9-8F58-4CA3-A9CE-7D3EB2F470AF', '18DC4276-D55B-4168-91E4-408AAA3906FE', '4015400624219', '  - . /..  22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE32AF36-709A-4205-B03A-F97D5DFC224C', '29B08D7F-BDD4-409C-8345-8F0F96E5DB87', '4037353005051', ' 0,01 1,5  / - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A10CF2CB-42AE-4716-BDEB-C45B46683456', '42612334-1C68-470B-93B8-EB2F85314AC2', '4009932557046', '   / 1500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF5A21F9-4716-4A7D-B77B-91F2BC52208D', '18211B4F-5CB3-4000-A4F2-C47A08A1607B', '4601654000291', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A409869-38D4-410A-8350-279F3167F55C', '285A2FF8-3272-4BD3-AE7F-631A4E34A6EA', '4602210002520', '    150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37861B61-9656-403B-BDBC-77833EC036EE', '084DAC67-F572-4993-A1BB-C6CFC3A5C114', '4605108002367', ' -  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('958A8DA6-057E-4E17-A3F5-F321D8D2E0D7', '522FC1D7-7EA3-4E4D-BD0E-4F1084C8340C', '5900516601201', '       9-20 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0187C3A1-B9E1-4742-8186-64811D596AC6', '12EAA732-7306-4DE2-9C62-65B7E5A4E95A', '4046222415532', '  -    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E5D59C1-E7C9-4319-BE2D-375AB874CF82', 'C57C11FE-71F7-414C-8329-95E15EAF9BF5', '4015400198215', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAA7A31A-CDAD-4587-A1A0-E0B3287C4580', '4994AF16-3F0A-4D4D-A12F-530F0763CCF3', '4612750380064', '-  -02 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1D8194E-8381-4944-BF7F-FD5DD0323FA5', '52C6EA14-D1A9-4BFD-B01A-B8B264CAF1B2', '4605086000164', ' .   s /1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08227CCA-1560-4CC2-8365-95773826A4DF', 'E0B4FA40-071E-487E-ACD4-1A21B28E49FC', '8710103697152', '  /  / scf573/13 260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2174B2CE-6F42-4C02-9F69-427556B5A95E', '48AA2A23-6120-4CBC-B864-C61352E32381', '4607011666179', ' -  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD16EF16-16E9-4070-9F59-A9D07487A922', '5B0A106E-26C8-4786-AF28-87F0905BE361', '4610007760157', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C8EAC5D-6E1D-442A-B5D5-16EC403C279F', 'EDA5ED69-C13B-4EA5-A763-20C63416E838', '4602210002513', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('949557F4-E698-44E0-BA4E-F2D6DB6352A0', '93D3D853-B771-4A67-AE4E-DD2FCD09CB27', '4019338608006', ' 0,75  / 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEA23ABA-B128-4536-9390-51927D6B7FE1', 'C49F29CC-1AC5-4A5E-B606-BC8B42054611', '4610010011178', '  / /   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB7FC836-4DD7-496E-9328-BF9A4B47E0CB', 'F42A4668-1AA0-4149-8209-E0A504CC5362', '8710103497691', '   6-18 2/bra-free', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('469A9D06-406A-4A93-9AFA-5DD23E60C015', '7C922634-B0C7-458B-9269-6E6B84C5DA6E', '3800737000734', '-  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE724F96-6110-4D45-861C-921D77CF6542', '42D00FB3-1BF3-4023-BFB0-A4F98ED11DBA', '4601654000352', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2D85F8F-842B-41B6-B1E4-FFD953C3BB1A', '7322052A-7191-4335-A3DC-721DA23B6577', '8300961888993', '   140 .4 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0ED2B94-2066-46D8-B443-E7A39FBB610D', '6B49D92F-6547-48EE-9CE1-14A85DD34BBC', '4607025842279', '     // 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED14FA2C-D882-475D-8DFE-FC8D9923C3C5', '94D5E78A-6ACA-4E45-B199-A3ABD7D91444', '4607011666452', '- / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4251576-243C-4D05-988C-F2E05EC85C62', '41B6203A-6944-4309-BF58-9CCFDB245D95', '4605416004633', '      4  220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3A5A2A6-7687-4E64-B806-4A171160CD78', '9C513AD4-00C4-499B-9F5C-010D37F6B938', '4033033417022', ' /.   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B70BEAAA-D267-447B-9EBD-EA14251352DE', 'CB16DD4A-0044-456E-8A96-7654BC414F49', '4605052001423', '   0,45 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFE76B28-3880-4A96-818A-21D27DBEC07F', '3959E88D-AC07-4D54-8094-E0FC6CDB941B', '4607027216597', ',  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B67E9216-9076-45C8-8CC3-880B540C8DF3', 'CB279F20-0E7E-43AC-B84B-860767D69ECF', '5903546005285', '  75  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('693B9C12-ED92-480A-BB1A-70C4A9F55770', '5AD40C83-3D5E-4C53-998F-52DF6762CAEC', '8904091103867', '  /. .  5% 25 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D8011A2-D80D-4AF5-B238-A1CF7671F6B8', 'E73859A7-F6BC-4F11-93BD-03BBBFD84151', '4607086564097', '   silk therapy      350 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1EF5E9B-3EDC-4167-A2E8-63984A9BC0B1', 'D061BC80-C22A-4110-8C8B-CC50E2FCA88D', '4602866014489', ' /-110/ .   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C149482B-77F1-4BA8-A804-0A31087C6AA9', '504B167B-C352-48AF-B99D-948A1A6C0AE1', '4607008160253', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A677C2C1-4CE3-4363-9192-FFECDF3406BE', '2A8DDC3D-9DC5-48BA-84FB-52F3207D8883', '4820121901262', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72CF5E89-79AD-48A2-8FB5-9BA620743105', '746C60C6-BBE6-4F4D-BE02-251A49EE1EDC', '8710103527817', '   6-18 2/83520/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E59687DF-2A33-44BD-8A04-218044CE725B', 'AB6EADE3-0C83-42C9-A9CD-D2D2AE76DEDE', '4602196002545', ' 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDB2D5E8-57AA-49B8-8FE2-3CF17D5923D9', 'FB7E2667-629F-43A3-86E9-238C09871E00', '4690419004469', '  -    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('828A50D1-D8C8-4DB8-B821-D6691EE465F7', '74B13027-825A-44E6-A049-4A2AEB453463', '4630000190652', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DD78091-0454-48BF-AAA4-63A8D4F3BF7A', '2FE43B97-A49E-4996-B4CF-E824E4FF70F4', '4607027766634', ' 40  30 (1+1)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A8E439C-142B-4249-8C44-32469B9B406B', 'E6C27069-F781-41CB-A990-ABB042FF24EA', '4740412002013', '   . 10 / 1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B915E66-5FA1-4843-AF9E-16E48E7A47EA', '3CB1A42F-0DC7-41B1-8E79-2ADBC152F7F9', '4607056264385', '    120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2DE4643-E3B2-4CF7-A0C0-46B3224EBA17', '40A36D2A-6EB2-45A1-BD09-DC695818675F', '4607027766122', '  850 60+ 15 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2FC5850-4FD0-43BD-B448-CE443132B18D', '419A9404-C07C-4B21-BCA4-44D04BAF7362', '9005441701227', '  / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4233C8AD-70EC-44CA-9FB9-B06292EC0E95', '7D01321C-58FC-47F7-AA84-BB0BAE98D1E0', '4820008315830', ' - / 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EABA6DC5-8595-4E19-9715-637A9D397A19', '34492912-7459-4FDC-BAAB-CC98233C9670', '5999880412018', ' baby-vac  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39A9E92D-669D-4E05-9235-9CD691E56CF5', '97BAC44A-A79C-4D3B-BC31-3EBE39846517', '4607147690116', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0303B707-96C3-4BB8-88E2-E08B09559ABF', '4910F685-9FCA-4F5D-B57D-C9139AA33453', '4607027211264', '      0+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B94997C6-63FF-445D-87D3-87510EF8373B', 'FC26E02D-1CB5-407D-AA84-7550D3435178', '8850006304723', ' /     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('544AB57D-8DD8-4894-9383-FF5A651DA23E', '7CCC5578-C95A-413F-B480-E66628474934', '5050474102224', '  /blink contacts/ 10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F048F707-C088-4786-A5C0-B37F8D8C47E5', 'C827268B-A1AE-42A1-BBAC-DEDD163FA898', '3830029295555', '  / 1% 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C184AF75-3B20-4B45-AD7E-F4BD75F1F3DA', 'C2B41D50-A08E-42DF-BDA4-D53CD87AE911', '4670012610137', '  16+12,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C4D8D30-F4CE-49C1-8D74-D62B10E5FCE3', 'E9B920A1-ED56-4315-877E-E863C186CC7C', '0016401012436', '   7 11 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8BAE303-181F-443B-BD04-3A8DA385A7F7', '2C5F2DA8-DB2D-4C62-86EC-9738C224F982', '8711218163006', '- 0,05  /- / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAEC85F6-43A7-4327-9F40-E184270CF016', '7F2300EB-C93A-41D1-8521-CADFCC95920E', '4640013557243', '    /  4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AACA6807-3173-4D8F-92F2-B9EB5A2BCCA6', '749945EC-CFF4-4EFC-8691-1DCCFBDF3F75', '8992781280301', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C758251E-2E45-44BF-B49F-0DCF83BFA25E', 'D95C29FC-C154-4C45-9A63-8FD2E3EAFF55', '4660007701865', ' 120  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15B9172B-EA60-4448-B958-26B3CBDE6423', '6BE3F82C-99CF-4C82-8FB6-712501D6B8C0', '4607086566848', '   /  /  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D1606F2-60FE-414D-A30E-42FCC9F60F45', 'B74C62C0-C6B9-4AE4-AAB9-94733B6F63F1', '4607159860590', '   5/1,25 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47B25B7C-888F-46D5-AD8B-4330C00CD20A', '81AE2585-3401-4362-991C-57B281555E4C', '4607015598728', '   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52345DC4-7006-4311-A941-F8F073627051', '6B9A6ED7-8790-4485-9A1A-84A662F18B69', '4602866000796', '  1551  4 (M)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C19A3A1-FE29-45CD-8922-7FDFDBDA06F5', '27D9784D-E974-4D4B-9389-1E6B28EAF511', '8595026434325', ' 150 //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EA03F5A-2443-487B-A48A-2962CBAAE2E2', 'E415D4BB-1366-4A39-81FE-DE8DAB364C46', '5029053544014', '  -  4/9-14 34', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7EBDB77-B212-4EFF-AC4F-1FCE97298F1B', '3596BA1C-2D08-4326-B83A-5C48264C191B', '4008600047506', '   / S 6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB17277F-508D-4A39-BBF2-FC162871E519', '2FA05220-27CE-4B90-A692-22FC473A7CB9', '4607062320587', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0F7ED44-805B-45D5-8D10-45722D0A2022', '3023715D-2ADC-4557-8140-4D64823CF69E', '6432100000200', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9774A007-172F-4AAB-AC73-2D2DFC77622E', '934A0000-0B60-440A-B976-A12D1EF572CB', '4690624008535', '     / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CB7133A-7FEA-42F6-9491-820A1036C8D0', '885D01E6-C6B5-4E9A-B7F8-A86391F63700', '4607034472054', ' .   .(...+ /)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC8B44AB-8A85-429B-AA3E-2D54907B473C', '7A692331-4FCA-4D45-B44A-28EE589FA268', '4680007750144', '   Lusan 60-90 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40FA265B-7373-4344-BE6E-7C871D301354', '3C72FC87-EB4D-4560-AA5B-5AD5287BB77F', '4605655000199', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B7A90E5-6639-4976-A6DF-911B7859DB97', 'BCAC0831-6D4E-4C93-A3E1-21FF6C66FF29', '4690624006951', '20002     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C215CED6-71D0-40B8-A718-91666DB51729', 'CE09D523-2E7D-4836-84A6-B5C34341B044', '4607055133484', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38BCF97D-4937-40B5-82B0-BBFB7717F2EC', '51710274-6081-40E4-ADD7-F6076315012F', '4640006300580', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4334EC7F-6DB7-419D-96CD-955822329E5F', 'A8299133-9F4E-421E-A97C-5E579C776A6F', '8594739221543', ' 0,003+0,00002 //  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFDB01A7-2956-4CDE-8232-71841C6ABC39', '81F9E73F-BDBA-473B-98BA-E304FB0CE004', '4660018601529', '  / / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB2712A3-D172-47D1-AD2A-F70A86E58D09', 'EC4EAF7D-3BB7-4973-BBE6-1DF27801B2A5', '8710103527787', '     0-6 2/bra-fre/ scf182/23', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FA46A71-5EB6-4B3B-A1B6-88DEFAC7DCF1', '3007E54F-86DD-4D2D-B62D-4DEE7537ABD5', '4620006260152', '    . , F-701', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0AAFA16-E727-415E-8734-ACCC8B956C46', 'E3D6B2C1-CEB5-435C-8BF7-3521A15A550B', '7322540013610', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4F477AC-3F3D-46CC-88E1-8E0523721457', '13F38BC2-3E7E-40B8-A42C-637BC2225528', '4607053660258', '    / 295', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46AAB82E-C6E3-4491-AEAF-EE126AF242EA', '42F04C67-6CF0-42F3-9883-7B4DFA760029', '4607027216863', '  / / 4 .  /1973/ 225', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('819ABE8B-6568-439C-9DA2-ECC24C42ECF8', '4CA5B600-7400-4137-AA4D-927FF031770B', '4627074841344', ' +     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18BC4D30-EDBA-4105-B1E9-E340F7C758EC', 'E441E12A-1A6F-4A08-8CC2-A7B9C5ABBA53', '4607027213442', '      0-12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D11CEF7-6192-4F9D-881F-4105F19FEEB5', '5B277C26-E41B-4F66-B399-9FBC287D3E3A', '4640013550046', '   /13948', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3480103C-11F1-4158-B1A2-0434446A9A17', 'D851D854-6FEA-48DC-B801-E50E74458F98', '4605658210038', '-  //  21003', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79C45F98-5EE7-4C15-B251-5EC7854053E4', '27CFBB86-0AEC-49E9-8E49-BAC814826B1A', '4607035440403', ' 50  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F04CBD3C-8790-4F10-80AB-F3295B45C376', '2E2AA267-1B1A-4240-89A0-44633721881F', '8712400806213', '-1     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C97670F-4153-4770-AF51-CD2566B5E69A', '9333C522-41D3-423C-8051-EF40B985A44F', '4719003340216', ' BP AG1-30/  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD05FDBA-A072-4B2B-9B0F-DFCB892D25E0', 'A35A62B5-2873-4498-AF35-532222D22AF9', '4612738540107', '  - -  l /..108-116/ // -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15B294B7-1622-438E-B3CF-7C25F19679D8', '66A6A1B2-3F8D-4379-8051-55BBF52DE9B2', '4670008161414', ' - / - 5 5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD1B9418-F0E8-4CB4-A79E-70ADA807500C', '4A5E6315-5027-4B33-9587-8DD8A5C451AA', '4670017923485', '         /. 270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14E8ACCF-9C78-4DF4-AF52-7478C3D61032', '6BEEDE55-3EAA-4B8F-A3D1-8A1A0E8E7035', '3850343018784', ' 10  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58CD1F2F-FB18-4681-B7C1-D53E0EAC67CB', '5EDF0AFD-9705-49E3-A936-9EC8D22F1EA7', '4011548013373', '   +  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9622B91-B69D-480E-800C-AD740E7C844E', '11F8DB78-4561-4392-A0FF-DC4406AD974E', '4607022892536', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34604260-D97E-49E9-97C6-A9F46E8774A0', '419CE2B3-8226-4C80-B272-C2759243DA46', '5900273113313', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB5840BA-50F5-40B8-BAAF-B2A3F45CE1C6', '9580B8E0-6727-4898-BB76-D7E827D73C8B', '1117100005152', '- 500.  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AA1A2E3-7C86-4ABD-B924-A7902F0CCE6D', '4356C3AB-9D11-4497-BB95-31AC807FABB0', '4036534681213', ' .   / . /s,5-6/ / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2CB3733-B62F-47CC-AE6F-A0014083C538', 'C9DD0B75-3E51-4743-A6C5-31A6259076B9', '4607027213473', '       0-12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D373003-F199-44AE-90EC-6D1B6EEDD83E', '0C7ECFC5-9763-4872-B747-76230EB04C96', '4607159860552', '  2,5+0,625  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1336D73-D006-4A1D-B687-D0041CEE0805', '2BB0EC84-1DC0-4DE8-BBCA-EE0CCE2E2539', '4607101200627', '-        3.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62D8AD21-929E-4B39-8E17-9EB83DD28061', '19436C3A-53DD-461C-8995-D9E208CA5DCE', '4650069843207', '  - / /151/ / 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C9FCAE5-8ED0-4A63-B6C9-C4FDB85E44B5', '3B091D4E-5E5E-4FDC-9DEE-F9288C8BF91A', '4030096425353', ' 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73D6019D-2BE0-46C7-B91E-AF3EAB3FC111', 'EB910590-5FC6-4181-821D-000BAD2D4F29', '4602984010783', '  -   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F05F1C39-C296-4D1D-A3C4-53C48B16F9FD', '334611B4-FB9B-4E93-808F-2F20DE316CC9', '5029053543574', '   comfort / /- 5/ 12-22 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A905B13-6456-4294-A490-C1FE5C1F46E8', '15FCC599-1511-4935-B4CB-83F22A5C76B1', '8300961854998', '  / gambaletto 140dens4/ Black', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C61E7150-CC32-412A-AF3D-74B2123FCAF5', '766F19F5-A607-4D38-A9AE-0738FD3C96FC', '4630006000115', '   -01', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FE5965E-690B-412A-9F16-D44F9C93745B', 'CD3C30A5-AE57-4F6A-9A14-20F9A561C3E6', '4607039970272', '       .  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5822F9F-1E76-49F4-BDED-CF4D1537B11B', 'ABC9AB0F-57AE-47E1-91DF-3D5AC86A510D', '4660011214429', '      / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DA0B484-05B9-47AD-956E-8736E07E2F9C', '72F3B629-BE0C-4E8A-995D-845E0455F2CA', '4602866066464', '  -   ,  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31D6170D-A8FD-4E2E-91AD-4BADC0800F13', '95DF73A2-E7B5-44DB-9F99-9A2430AD01C5', '4607101202881', '  -  3./14782', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBD88317-5A62-43C2-B4BD-3D727711D454', '41F1C984-C6F6-4F44-9B42-D9FA5D99534C', '0027917101064', '-      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0822D66-0CAA-44CD-B3AF-1AD0CCAD7B4B', '05239E1E-E0EA-461A-A1F0-782F168145F0', '4049500019972', '      16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E2DD1E8-BF7B-4A24-AF96-1D0802483D70', 'DD04A485-DDCC-4302-BC82-2156E1FE3AE3', '4049500249393', '      35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28DB665A-8F99-421B-B507-59FF965DE9CD', '4EF289BC-6D07-46C7-A679-D029032DF3AF', '8906000570746', ' 250  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60640002-EA3E-4742-ACD0-60813569DB50', '503D1C2A-22D6-44FB-8693-A5312702BB2B', '4015400612612', '  active    6 /15+/ 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0345BE57-FF0F-48CD-B990-A4E2E3493CA6', 'F14E889D-889A-40AD-A284-F4E9ED62DD6E', '4620006258005', '  - /-502/4/ - 6  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17FE144F-6D53-4718-AD41-13899B0FF120', 'B608CA3E-FC87-47E7-86FF-7E511B6EEE63', '4603188000792', '- . . 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD073DB7-BBFA-4646-AA6A-F4D41D058372', '9C47DFEC-72F1-48AF-A63A-BD652AF8C8EB', '5900516070977', '   3  1  1000 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D068CC5-7BE7-46E0-BC03-AF29DB9D0DB6', 'DAD9D006-BCDC-4D38-BEDC-48EA37177DD3', '4607101205233', '  - S 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7196BC08-6945-44D4-8B9D-30DFABE929B2', 'F74A90AE-EACA-4DD9-8D64-91483492FD8B', '8600097413770', '- 6% 500 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0F689B0-3F0F-4352-82D6-E11D35F70391', '55E6C157-6431-45DF-8B00-097C02D44A32', '4607027215583', '      //5229/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B866D975-038C-43AC-9D64-032F519BE015', '3533B0CB-1698-4B40-A8E1-C45B82E955BB', '4620002184414', ' - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22A8DFB5-5E92-419F-A226-D13EC5630381', '7C223372-F92B-48DF-A92A-3D4208D168AB', '8584005014603', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EAABE91-0919-4C9B-A702-0DCED2ACB6BB', '2D920EBD-C1DD-42FD-94F5-E35CF06AC181', '4610004311215', '     3 // -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93B92EEA-F2AB-478A-B6FA-E898685B905E', '7EC5370D-72D5-476E-AF28-096EF487E45E', '4003583063376', '   / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2D5E8AD-C250-45C4-8773-44B44384E0FA', '810B9C95-3D58-4BB0-939B-94825E014799', '4680007632419', '   6090 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1E823D8-FB5E-4AC2-AC98-ACA72B3910B2', '0D99EBFB-2CE6-4AEC-93DF-8B0A88AB66EA', '6946159500821', ' WT-06 , .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A798202E-F277-4209-91AF-7EA4B7C54479', '0256AC05-53E6-4885-B649-95C11BF879C5', '4601774006449', ' -  .329  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58D246F4-DEB5-412F-9EEC-D6D68BB56E50', 'D20A961E-4719-4CE4-82BB-F5F9197C7C02', '8906036182470', '   // 0-3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5CD4030-89FD-43E1-91DA-CAD7973A43A7', '0D1A28D3-4BDB-421E-AC0D-A49E7F487E76', '4650001796042', '  40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6E322BA-3BFF-4753-ABC0-125B357345C3', '6C24FEF2-45C6-4A85-800C-255B6351EBCE', '5021265231058', ' -12  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E2E56BA-5DC9-4278-AE1C-A95E35B5FDB8', 'B3E4447D-8C2C-4045-9711-C179B4B26C0D', '4607041061067', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC871661-D874-4688-859F-BCD81DAE1BD0', 'F553CBC2-9FA0-419D-A4B8-4E7FC0D2AA7B', '4015400341598', '   summer   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F6230E8-42A5-495F-85E6-09C80C6ABFA7', '42D26871-E562-43D8-9679-8913FC5332D7', '4607003247874', '  0,05  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D99DD4AC-DBE0-46ED-B035-1F3D1133B39A', '0E039810-1C15-4896-9E1C-3C494906A3AC', '4602866000475', '     /m/ 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('430253CB-E9DB-4CCE-A41A-02A898E78E7C', '1A268A3E-173C-4594-BD14-9A3ECED912FF', '4612738540114', '  - -  l /..116-23/ // -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D25D55D3-9E05-41F2-8F28-77AF96F35E58', 'FF07EDF8-77D2-4C24-8C34-83E2C2F38ED2', '4607141998478', '  100  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7CEF20A-FF52-4557-A742-A726E4A6173E', 'D933AC45-98D2-4530-8E6D-5E6445699A4D', '8030009701051', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBF3A01D-864D-4C6D-BB95-06EE28454F7D', 'C82F56F9-4C85-4066-8E9E-1C9B11CBE87A', '5038483171288', '   - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C5C10E7-9374-4E27-A2D0-36BB07021206', 'F9B399A9-9CC4-4778-835D-E41636216DDD', '4607003111069', ' 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D010D437-4631-4A14-8B2E-E3D6A82EF01B', '48A324FA-C569-4359-89C4-5BC1A0654B7A', '4030142016214', ' /.  / 800', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C78EEB86-2D9C-4CB6-A549-483F551D4F99', 'B1D41FCA-3598-4AB1-A794-2C07FE8F4545', '4660018601581', '  -   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54F87802-79EF-4236-A766-AE33E46F6F6F', '4A23E792-22AC-49E6-ACBC-378055B59B6F', '8809052583439', 'Skinlite + / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0767031F-A759-4544-9160-EE0CEA7A1A19', '8C4E182D-D21F-42B1-863D-864C6CB6EA48', '4029917001937', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C0B3F34-6FDC-470F-AE36-CD788704F3C0', 'B12D4B01-7AF3-4A55-85E9-DFC172B22FD7', '4008600093312', ' First Choice  0+ 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A36206DE-57A7-4CCB-960A-3C2CA78E0EF8', '545CC104-6D5B-4DE7-B96A-5A7099E615D5', '4627110045682', '  / /m/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F55E0A01-6A13-47DA-A27A-5B2D505E7CBB', '680695FA-E40B-4007-8CC0-AE57B3791562', '0027917101125', '-    860  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0C5FFD4-600F-4E8F-8B51-A5B34D291240', '58B6C886-4D99-4DCD-81C2-A94C8E54C8F8', '4751018120612', '   /     10% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EC7DBF1-C5A1-4669-8B98-C84BC8C9C077', '6736893E-2575-44F8-BF07-0CC050510F35', '4620006247092', ' - "".  S, , . -500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A64E9AEC-DF80-4C5C-A635-CAC256D382AD', 'B8A3423F-14DA-49FA-A2F9-ED92C358674D', '4750258312597', ' 50  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF8891B9-2781-47A2-A7A3-3745CAC53D45', 'A731262F-6254-40DB-B250-04BDE4CF2010', '5903407892443', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D28A74BC-D3C6-434D-92E3-FE53BFC47A73', 'FF187FC2-4606-49EA-87BE-915D810C1199', '4610007620345', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2499306-14D5-4348-884F-09F5673A21A6', '05E9A898-AB50-4DBB-AD46-18478AD7594D', '4049500204323', '  ria   8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4335E4C6-D393-4AD4-AA1C-B06C58F1A123', '39F2608B-3020-41B5-B219-E5AE8F238D45', '4605086002809', ' .   m /2/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A3C0ECE-1220-4F80-A089-45FE70A4F5E8', '8770EBBB-0CB4-4422-B69E-208B31A2466F', '4250142199469', ' 8 +1 8 / / 4 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA1DEBB2-CF52-4174-B547-16A002D4ADB6', '3F396CFD-8DAF-4BB9-98EC-8DF26386BA3F', '3574660636437', 'Listerine epert    1+1 // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7B06B09-73AD-46FC-9146-4B6882CB4B26', 'D89E61A6-1994-4147-A898-3D5FA64B38FF', '8002660014672', ' 240+4 / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C527BC80-014A-41F1-94D0-5F3B6019703E', 'CF560A9F-0E54-466E-9200-BFD06232B5CB', '4627110046320', '    f9001 r', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FF0B3E7-867C-48B7-92B9-6E63D14742EC', '784DA85D-8302-485F-9943-834287C7D385', '4623720770495', '  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D60EB9B-6FE9-4988-89DC-634B14E16A94', 'FE736187-72A8-44B8-9DD7-183437A2C039', '4030096245050', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60FA5D8D-7A49-4298-87B1-731669EB01F6', 'ED8D76B5-7785-4612-8B1A-9C3FB9821EFF', '4612748580155', '     sey life wild must eros versace  10 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B46ECD1-AF88-409B-BC18-644A758CEFAB', '4ACDB969-8BB5-4D13-A1B2-93E77262C788', '4603191000116', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EC01EBD-A79B-42AA-BA19-EBC3EF5CE4A4', '172A4173-0B5C-4893-8EFD-F2DBC66AF467', '4710425921007', '   /  /s/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EB88A94-2135-4B1D-BAA9-D172F4B43BA0', 'AB2A21A5-AF48-446D-8E9E-1B16455374B5', '4008600110897', ' Genius   6+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D17BDFBC-852B-4474-BBE2-ACF5C43FD911', 'D0A1C9D9-90F2-4572-86E4-B7EEBE18EAAD', '4820121900104', '  57120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D60E65AA-6FDC-4031-9A39-00C2206A72D5', '27EF650B-2C32-4FEC-ACF9-125046327BF1', '4630027040015', ' /   1% 100 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7083898C-9026-4027-910B-CEE962F9E316', '9A0E9234-6925-4B0C-B3C7-63B3E9EE3B99', '4607037050020', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E04BFF2-437E-4E2E-9BE3-FA5B19EF41F2', '3F290897-283D-4EE8-87C5-52C3BF0EA48E', '4009932557572', '  -  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1098F1F-BDA1-4AD8-BD55-DE2D43366506', 'E354100B-70C7-4AAE-9F38-E47EE9EE34F9', '4607009250052', ' 10%  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B630666-93BF-4EB7-A5CA-2652539120E6', '1150AA24-2376-4B9F-AA60-6821A0F7B0A0', '6920354812088', '   . . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8214D98-2A8B-4AD3-994D-89D9D21988B9', '40A4522D-4987-4D36-B20A-995AE788F165', '4620002183769', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('914D8E77-53BB-41C6-82FA-54F4536F5953', '33C69B88-5506-47BD-A740-059AD77F6AAC', '4036534589168', '  /  -  /-8102/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA28C780-F25F-4C0B-82AA-107FB55A9761', 'E0F39687-319A-42BE-95EC-4DCF132F0F00', '4607034940119', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('893A88F5-D261-4D00-85B9-E4BAF19E1B71', '6515819B-48EF-46FF-BC01-7EDDEC1C6712', '4015400533047', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8F4F8B0-7331-466E-8D3F-B62EDD4EB316', 'E91B31A0-65E5-4675-BE08-5EE849153855', '4650001792655', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92448C23-A824-4D3F-9DE4-FECF4A21EADA', 'E623169B-31BE-43BA-B5EE-49702029950C', '8809270621005', '- /     shary', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D610F4A-74F2-4701-8A2F-E25833912A6C', '01B6608C-CBD0-4C25-9AF2-36237E61CBF2', '4660018600058', ' -    spf 6 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34A10C8E-AA68-4754-AD52-184B0795D3D2', 'A10CECDA-8CA8-496A-94E3-BC8A54DF4B33', '4751018120506', '  / - 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3CD3E2F-5184-4D7E-804B-D2CB1A8F4FC8', '52B348D4-67B4-40DD-87F3-88FAA8CC8CB0', '4602565016401', ' 250 2 /, /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7B9A00A-0238-423E-A151-358C24D674BA', 'F92D4868-BFD8-46AD-AB45-E13BE97EB7E8', '4660003400045', '  / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97979024-0306-4CA1-B4A3-8C46E33E0D27', 'AC8644D5-4DA7-4600-B22A-4364BE061E60', '4601164002013', ' 14  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('501D18EB-955E-46E8-ADB6-A499F26AA0A0', '812E6658-B714-4040-A46C-6902DAA79B2D', '4602666709707', ' 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('628F9754-3F22-4582-9361-22445EBF2B1A', '81848BF4-C567-4D9C-8E5C-AD542A9551D5', '9088881300519', ' 0,002  /- 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF998EF4-B1FF-4ADF-BDCD-E9C9D1936D73', '1EC1A53B-838C-4B2B-A8AE-1695EA8E8B16', '4607067060709', ' 550  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('921F202C-02C8-41C7-B3A2-186F4B6E1621', '1B7C943D-B675-4972-981F-4D3A5CAB1DB6', '4605059019964', '5     / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B761C330-1C19-4466-B086-A3B59BCFCFDE', '89518189-A2CD-47E9-91F0-70425EBBE8B6', '9088881326663', ' 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47AF8AF7-D532-4CE2-8D87-5B63A7729908', 'AE4DC8BB-5FE2-42D5-8955-E6E80B49F445', '2000018070017', ' - kineib pro    55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DF18503-546B-43DB-AEF3-4216A2448AB3', 'C309954A-06C0-4C22-89BF-47615DE5F476', '4602866027687', '  8301 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0F5D0FD-829D-4F03-AA5F-2127FFFC4BE0', '0FCB1F97-DB94-4264-888D-B020AB40BBEA', '4602866000468', '     - S 3 /-1361/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF2FCE7F-5B2F-4558-AE9F-3B8A2DA89A86', '1A1D3753-EC81-43B5-B625-FD02C81041F5', '4603713000884', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F342A2F-26A9-4285-9A85-B883730AB219', 'B532AE90-738B-494F-A2B0-F899EDCEF577', '4620008622262', ' 1% - /.  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C21B0EAA-B133-4426-90C9-A195F67BA351', 'D9C84167-4273-4E75-9546-06042F2349E0', '4607045191432', '  1%  2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1F92A39-E674-4537-B5F8-FB2D74FB6BAB', '61DEFB1C-9101-4BCC-B286-49D9E3A1FFB8', '4601834003661', '    4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8FFF82A-B59B-47DF-B5C3-6961B9BD1536', '40809B9C-2F63-4ABC-B116-664237F2A75F', '7612367014779', '- /   s ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E04E186-9D1C-40C1-AD81-581D220177F1', 'FAD8E30D-3CC4-471D-9408-2C47F920DB15', '4627074841177', '      125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('845C96ED-2E48-4918-A1A2-BECC9653A12A', 'CFD512CA-2AB5-4AFA-9FD1-2A816DC4EB1F', '4605108000837', '  8  7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88789194-FAC9-4D99-9E27-4D24D19107D0', 'E4BC165F-A8D8-4D86-8344-E2DAC1C497C7', '3573991513226', ' 50  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB6C5A5E-3BDD-4CAD-AA7F-5FAABE651968', 'B81EABEA-1B36-4ED6-AAC6-6EA6B1C87539', '4607083724654', ' 20  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55D71798-15AB-4C8F-A4AF-DC7EF84A5F6A', '3523FC7E-C89B-40D7-B577-114E0078134D', '4602103002859', ' 40  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DF15BDA-007E-454A-B917-A178D4B221D8', '06AEF664-B811-4181-A92C-E730124F7FFF', '4603188000419', '    -2  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C970569E-1CD0-4E71-8011-7642410DB329', 'BF8CBF98-F6C3-4E74-811E-BC643B025C1C', '5903407232218', '-   0-6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56C7E328-579C-4FA2-83C6-B27F61C8B2F8', 'F321EE4E-C456-4ED2-89AF-ECAB0101B885', '4670008161926', '  5 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B21393AB-46EB-4E86-BD14-68187E3DEFD6', '01EFD4DA-9B13-4B59-9BC6-96E39FF9E298', '4810201014272', '  50 3 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68D885C8-E2DF-4212-B602-67AAFE1200AC', '3FE1A78F-5A4B-4265-99E3-B8DE151A8FD7', '4607056263319', '   170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67C30996-6BBD-4E8D-804D-DC52169BB770', '9DAC4CD1-3D4A-4743-96EE-E21ECB023548', '4612738540091', '   -  l /98-108/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CFE19EE-50DF-4176-BBB3-4BD6F3CC5401', '75E9D466-6427-42C5-80DC-CE2D65417BAA', '4610010011680', '    . //.  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A72EACA-FEDE-4DE0-AE41-26AD6322241C', '94711607-CD32-4323-9851-F2D2AD02E17C', '4606486001867', ' 5+400  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84310EF7-C6EB-4240-A508-32200848257B', '69B13A9A-4A87-41B3-A308-652D45F17D95', '4580198174135', ' A&D ua-200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0F277E7-9916-43AB-B424-4F9BB769AA04', 'B208BEA1-CBEC-4623-83B1-92C1666DC964', '5995327140957', ' 0,11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBBC63BF-7EC7-4118-BF2B-3D23BBBC5CDF', '2DA0D77C-E357-49E9-99A8-454B6C2D4061', '8901127017389', ' 150 50  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('433C1E97-5294-4FB6-ADFD-CA0BAF1AA2B1', 'A8C1A80D-76A5-4BFA-8D7D-CD24ACFB8FF4', '8710103789321', '   free flow0-6n2/  /bpa-free scf180/26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B0D9EA4-6705-48ED-AB2C-EF2B245FCE66', '5D9E8110-B696-453F-B2E6-6E5912BBD1A5', '4981046050456', ' UA-668 /  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E0BE502-1A07-4EF2-A06D-50E78FC522D8', 'BECB9F14-DFD8-43DD-8BEC-96FCE88978D4', '4607003247997', ' 200  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('764EA56F-08CE-4AEA-8133-F9BBC4E3EDB3', '1B0DF6AE-A12C-4CC7-9898-A7E5DED8A167', '4607027219734', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('559FC0CC-6660-4A3D-8838-6C0892F480AB', 'E247DC9D-FC23-48AC-A781-D3E50010D0CB', '4607027219697', '   130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB2A2BC5-54E7-4AD9-B1E5-CA5306AE7F7D', 'A6B3B511-AD48-4F9D-B0A3-63313F1BC726', '4627113836119', ' / - 4/-604', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06A272C3-8C15-4D56-860A-92178C15444D', '965E6157-37D2-4E15-807F-CB850C493434', '4601774005794', '  / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B102F617-8149-41EA-BF02-552A641D21D1', '328BD3C8-0D81-45B2-BF98-31B7F77721ED', '7613032405700', '  -1  800', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84CCB3BB-EB92-4B69-A011-10298881DB97', '309EE21A-FFA0-44E6-9920-6B6A07D97C14', '4660005990100', '  .   3.. 5 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D35D851-B8E7-40AE-B336-4C29F4847D75', 'C03D1B95-12C5-40E2-AB58-C482DA741A1D', '3850114229845', '- 5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A069D08-2CA5-4488-B89F-A24AF63CAD9D', '26746472-7DCE-4D69-9EFF-256E5A0E93D4', '4049500605786', '      /s/ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5E04AE6-5E70-4A8C-9A72-2799EB1BA03C', '7EFEAD49-E79D-408D-8AD2-4CE0664A14A6', '7332343001349', '       50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1524E8AA-4CFE-44EB-BC5D-3FD263737EC4', '698B2A88-92EB-48E2-B493-EAC2565AA418', '8809270620961', '  -   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F040475D-39EF-47D9-BB2D-5FF19D00414C', '26CDCB59-53EC-410E-9F33-A0F02F5E7CE8', '4607003248086', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FA736DE-8AA2-4ED7-9E69-9BD8BFCF9922', '2B8D1CD9-CBCD-4DA7-B413-357008019A0E', '4607104090287', ' / - - ag 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('836D0DF4-10A8-4CEF-BE40-4179A64BE504', '599532F9-5E97-4C97-8930-9AD9AC347D71', '4680007380013', '    4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B81081D-A31F-46E3-B067-8104338A52F9', 'B247E691-4044-4166-BCB6-A6CF0E676E13', '2000103611743', '-  animals 6-18/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F79B3C37-6346-4937-9FCD-63C09F622D45', '51E8A44A-AE95-4A46-8D81-F73D35AC5904', '6941762681318', '  2500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F22BD832-504F-450A-B4A5-5AFFBCAF9343', '4455D1E6-439D-4065-9C9E-00533EFA5E21', '5391523054621', ' 4 /18+ / 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13BF948A-369E-4574-98B1-0AE27D10B45C', '8C2FDBAB-3521-413D-AA9E-9291ECD0D709', '4607070020929', ' -  spf-25 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA7330B4-F20C-48CD-9A0F-F769AA754FA8', 'D5EACCCD-FC3F-4B53-99C1-03963A918F03', '4620006245609', '    . 4, ., F-202', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46053B93-10C1-4D23-B0CD-AEBFFC509EFB', '1F711F69-FC72-4A2E-921A-A5775B76D115', '6955454322038', '  2000 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('826DE4A4-DD71-4BA8-8C5A-41F1C8E3B71F', 'B90BF2A8-BCC6-407B-9D07-C7BABFA5668A', '4750283046160', '       5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('647B7C99-F3E4-4091-A9A9-4DE26E3E6793', '234C3430-AA4E-47AA-A203-9A2435C51C02', '6921570930938', '  - - /  . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('909153EE-891E-4293-85EA-224FD0F5657C', '9CDAC7EE-3449-409B-A2BC-FA5F755399F4', '4601313007319', ' -     280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01AD52CB-4EE4-48F2-81BE-6302D1606066', 'BAD39E9A-E54D-40F8-8590-238BF5B8850C', '4607070020783', ' - / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('990443A2-03C1-4601-A9A4-37F7BA599B75', '2D2A55FB-4421-45B6-A52F-80404F819C71', '4049500487504', '      4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('237D7DE2-A866-4C21-A4DF-00FB163F24EA', 'DBF70976-6525-4F65-BAC1-8E47989ABD9B', '4601955000082', ' 30  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76AF4A3A-396F-48ED-A4F9-82B2F404F1DA', '24532624-DB37-46EA-8F54-44BD1F368683', '3499320007702', '  1% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D989493C-5319-4591-A805-B008A397DF39', 'E2E34BAF-C499-481F-9D34-BDF5E3C99284', '8430308130345', '  322/ 60   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AB349A8-DB9E-45F6-9CCC-3367BC99C97E', 'D87730A1-CB8D-4942-8B8C-01FFAE3819B9', '4607027217983', '        /2251/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FFE9F3D-163E-4704-9B14-3C8083E30037', '01C9498F-8672-4948-8FBA-AE602230B04A', '4607136210202', ' / -- 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E78155B8-D77E-4BFC-A3EE-59959CB6B517', 'A9860315-EC65-4F6B-B5BD-FDBCDD6952C9', '7393173216808', '      angry birds  3+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('337A35CE-89B9-4B7C-96F0-5CAFA00A711C', 'EB48A244-733A-49DC-B9B1-401028136D70', '4602737001402', '   5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76AD1702-AA67-4641-8C2C-82A6B2DD6A32', '93417C68-56B7-41B2-A98C-29A4D5DA0FD5', '2400006375733', '        4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85E8CB7E-448F-4BB5-9B57-ED823D96C69A', '7FBF4773-6E1D-4700-9051-1E17DD7F86E6', '4037353010321', ' 20 50/  0,4 / - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FC0F76B-9B3A-4A2A-9EDA-6E7CAF7F8150', '7BA39754-8845-45F5-83F8-D3B81858DE4B', '4607041024246', '      330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C88D6023-0D6E-4772-A52B-01A23A2202B8', 'F16A135C-4446-41BB-AA78-39AA1997B29B', '4003583121144', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12282667-FD31-4B1E-8398-6D819F9A285B', '8D6F26E7-2581-4043-9249-D26C16085497', '5060249172635', '-  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE14B472-1A99-4C27-9A23-13D6698D79B2', '8A76682F-7848-4C34-BA74-229FF0F2A6D4', '4607034940621', ' . /./ .        ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16CBDFDC-3A4A-47F1-8E0B-E9BE6BD3D8E2', 'D1C1C1D7-CE2D-4CE1-98A5-2F91DAE234C6', '4607178950364', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9B63DCA-804B-4EE4-B6C0-15700D5517DA', '42C13F76-5E4F-4765-B685-E4F6F80E1379', '4640013558172', ' / -/16628', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCC9BE1D-5535-4EBA-857F-AA1E469FD39B', 'A47D6243-E0AB-4528-B026-0712628273E8', '5038483745885', '  /    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FFD92FD-4676-4EEE-965E-8FA149A7C4D0', '1609A5B2-A2DB-4328-A957-DE607746F0B1', '4601835003226', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9F97BB8-83EF-4BC0-9091-129EE4321DFE', '7E5802E7-CBBE-44F5-9E52-D33E78957648', '8710103618324', '    0-2. /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22914A0E-49DB-45C5-9F5B-B9F9007B03E9', '2A970547-1946-43E8-A6EC-FF94CC284BC2', '4015400354277', '  &  /7-14/ 86', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A37DAFD4-5A8E-4BE7-BB78-AAE9CB0CED8F', 'E00AD817-E24C-49E4-8AB7-552E671DED70', '6950570782506', '  arlette 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F27B6959-3034-4A02-B175-722FB6E4440B', '24F50E45-CC2C-46D1-A83F-25A8525EBACB', '4600828000129', ' 0,025% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC43B5DA-E33F-4157-8021-8D5FB065606D', '91FAE324-3B6A-4F1E-AA1F-17704BB7C48F', '4015630006700', '   102', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD9C2FB2-7851-4DC6-A2FC-76E5BFA4321D', '71057859-36C4-4E7E-82D6-76FF76D2C17D', '4607174430846', '   / .150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F461664F-2219-4F62-84B6-127797CB8227', 'B6100780-71C1-4234-B057-8DDE54BF8D27', '4607025841159', ' /      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46FB706A-6557-4EAE-96AC-93B50B8338E6', '1C9113C2-1121-403D-BF25-695685D32788', '4603337000062', ' / / 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4257CB24-9F3E-4661-9DA0-4E13C8741F74', '3A4E7280-4A1A-4317-9898-4B4088B967FC', '4620006273916', '   . 2, F-214', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0847085B-DD91-49C0-BFAA-CBEBA968C758', '6C60CD6F-CD67-40D3-BE02-E5922185F69B', '4605658110130', '    0+ 120/11122/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1ABED3A-4FE0-4C0B-8FA1-479AC0A800A6', 'D9F6920D-E035-4E40-9735-E3F9F0C16553', '4603934000236', '   5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41FBEAE3-2EBE-4AC8-838A-7C20779240EA', '3F03A63A-5AC1-4340-988A-53CFC430C89F', '3499320007597', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBFD5388-D752-4A72-AEAD-F812675546AB', '7D6EFDC3-9BE7-4D45-B96F-C11A596BF650', '2000103611712', '-  animals 0-6/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0F9EF5A-5E93-4961-91DC-B34519292584', 'DC81C115-D98E-495E-9BD3-9F806BAD1362', '4601969005271', '  // 1000  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33DA4FBA-FFFB-410F-ABF1-B4E0DE9C9E69', '4286828C-71CD-47C3-9B1C-8F676D075BB8', '3582910078548', ' 40  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B4B8A3D-1BD2-44AC-BDB6-79427CCA3011', '7329B95E-6250-41D1-A293-2A8A8D99304E', '4640014200254', '  kids  6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03956398-A40A-4407-9F90-DB93647F0B64', '50B68549-E384-4FAB-8E58-A4A25507F5B7', '4630009430049', ' arctic light ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F8D09C4-DEC2-4AFB-93F6-4DAE7D4A00BF', 'C32DAF50-9CA7-4498-8972-25C249A75596', '0664942200128', '   amdt-12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70F5921C-512B-4B44-B45D-5B5DB4F2601C', '2029BFF0-C384-44D8-B55A-0742BDDBA8A7', '4607025201939', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B3E37A4-1454-4D77-9263-D002AC276AD8', '0C334967-43CA-460F-926B-9CAE6047AD3A', '7322540625837', '      7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C90E6CD6-ED07-43A2-A08C-0004967A4777', '4402E450-A0BB-433B-8CED-3F4EC4BE322A', '4602193009967', '9   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E374798-EA3C-4B9B-BCCB-5BD41A572DFA', '785ED04A-0674-4533-B20C-C34845EE5809', '4810201015798', ' /- / /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFFA29D7-AF0D-402D-95D5-8E0A71C9DCB5', 'AA2BA9ED-9130-4A69-AD6F-9B1D5C35B022', '4680013242954', '  20% 1   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F18EB19-974F-452B-AFCC-D70BEDE0B8C8', '0DC2A1A0-1EA4-4C2E-AE3D-35803B661111', '4602103002613', ' 20  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D55C764-9689-48BD-8B72-8BF516AE9319', '8539CC65-B67A-433A-9DE8-EDDFE7791C79', '4607010246624', '    /  10  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FF9EE3D-86E8-4EC4-93E3-2C9EF703712A', '023BB388-F888-4618-B8E2-274485880327', '4640013557724', '      6+ 240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D81B999C-E75E-4C2B-841F-CDE7452F486D', 'E3365301-7434-458C-8854-15FDA27A5B63', '4607141998379', '  25 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CF4B852-3E12-41AF-B0CE-CB34EAF5FDFC', 'F1BCE630-548E-4128-BE0A-5D9565F0AB2C', '4607039972634', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5DA0D61-D0B2-4DEC-964E-AFB76CB794FC', '685B4557-5A55-42C2-81B8-A80475E90BEE', '4670002260991', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38D0257E-49A4-4279-B24A-CA73CB75B275', '35E30C76-198B-4B42-86C3-03F3CC055C0A', '4606486019862', '  0,4 /   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDBF1F2B-5DD0-495C-843D-FACBEC4CD1AF', '65229D9E-047C-40CA-AECD-201E8F3F6788', '4605319005546', '  /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77603C83-96F0-442B-8DD2-8E4D80A9A7B8', '7F432973-0965-444B-B796-DFCAEBDC54A1', '4627128800013', ' -01', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA21EEE1-7784-4325-9402-1CD4084724AE', 'E2A1FC6B-7BB8-4456-956C-8DC5840C3883', '4601835000461', ' 15  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18A5F81C-8E39-4901-BF58-ED5399B6163B', 'D7E07CCF-BC58-4C3F-B51F-9B2B3EE56109', '4603907004506', '  0,13  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BEF604C-7787-443C-A473-FF77C250D7B5', '62E863E5-04AD-48B7-AF4C-B1D30B16201B', '3838957013739', ' 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB4D0744-5378-4504-A3E5-44858DAAB4D2', '9E621AFD-87EA-4C41-8D2A-00DFE46D0A73', '5029053543772', '   comf / 4+/10-16n17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76DCE24C-2B6A-40C1-9A6D-D055341555DE', '09989B8D-AA9A-4C02-BA4A-D822784E6892', '8712400718486', '     /2353/ 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD53D431-D194-46EE-8162-118F7173BAB5', 'DE4DCCCD-4E85-468A-947C-A3CA5633FD8C', '4602866091510', '    /-1430/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B867685C-80B0-4D3A-8B03-38403C7995CB', 'B40BA8C4-7537-4401-B15D-22B6E3D5B4CC', '4650001796721', ' -3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA654DE3-3FBF-4C94-ABEB-0D9A4E007387', '450A91DC-672C-401D-B7E6-9D353AF8C772', '4627074843652', '    10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56251290-6303-4257-B0F1-EFACDFFA034E', '09951E47-5D8D-4856-B088-AEBC8FB4D5AE', '2000018050019', '  kineib pro  55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B89A8F76-BE36-4D90-9270-A5E50E858026', '62809178-9F95-4172-9AC0-F66EA2C4741F', '7640114721816', ' 50/ 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('333D2F74-449A-41AD-9E1B-6AC48DAD7AE5', '41DCC19D-5865-4DC3-8044-BB910D099825', '4029916000658', '   60', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('566BB965-28B2-4DD2-8ADF-7A4F42B4F860', '73200736-0460-4E42-B354-5C6911C3EE95', '4607136740440', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D45F50D5-C78F-4978-ADFA-0E993EF90C9A', '758401E4-CCC1-4C95-B5A9-1AAF51B72424', '4032717005074', '  / 300   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B8D2498-1F44-4473-8742-234652862301', '9C206324-D4C1-4CE9-A8DC-66406248A4A4', '4981046350037', ' un-233 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB63FF58-1BD1-4891-8906-AE3BBF0F6AEE', 'F100F968-4061-4B5E-BB04-DB29670EA227', '2244928964763', ' 25  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA3B2312-8FF0-4F4D-93BB-B74F88B59206', '11052216-F405-4C94-B2BE-9CF40D471E0C', '8717202757176', ' /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42925248-3A35-4C24-B6EB-FF2A3AE77387', '6FF59884-5D05-4740-A71B-593CE7C9EF34', '5021265245314', '  28 /28 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88BC989A-0A02-4F22-A7AF-CCDBCD2A04D6', 'E807365E-BF4A-45A9-958A-6874695F519A', '4607158360077', '- 0,5 60%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F180EA71-1C2B-4378-AFE8-CD2789DC2FEB', '0E91F9A4-8D18-4FA5-A008-16C32D6FD187', '4814052000194', '  / 250 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C84A4D01-3734-4641-A03F-32C178A1B98C', 'E595C18A-431D-40B2-AC74-7F996E77A3D4', '4640011897921', '  fs927l', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AE3673A-58D3-42EB-9F8C-273F7B69DB91', 'CC1262A9-6EAD-4573-AACB-8E41F2671ED8', '4607100622208', ' 400 //   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEDB5B6D-AB4E-4DB0-AC4A-B5C609571F7D', 'C61B3539-A127-4F8E-938C-0DE2D0D6CAEA', '7611600609123', ' calmor      12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FA7C926-68D4-4F4C-8600-4C47617672EC', '068AA288-4BB2-498D-89A2-D96F49076193', '7381037681060', '   15/16  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('320D6774-3687-4958-8D57-3B710AB95C1C', '2DF96A72-0DA2-4192-B484-3447AE8DE815', '8710103696124', '  / 2/ba scf563/27 0% 260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BD7B466-D266-4A31-9797-54DF9763B272', '30E23A5A-2BEC-40A0-A6D5-7B9F5BF2988C', '4680007631986', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9449BBE-4911-4BDE-9CDF-F807FF9FCAC2', '3551FE20-6484-4FC0-BDE8-A7AE1F4AE25B', '4607141998485', '  100 //  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6695E88D-0F8F-4212-8E58-5611EBE2C233', '63544D0C-A2C0-4B5B-8CBA-24FB07EED4B3', '4607011632723', ' . 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A4ECD15-05DB-40C2-B486-D5A35A25E16D', 'EA1656A1-ABF1-47A7-BC51-938DB3DCA599', '4603726763127', '-   /   f 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B6A14B1-FB71-4DC0-B51D-898C65600A38', 'D88C4214-2A1F-4F1F-9A3B-995A251454AB', '4607003247720', '    680  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FE73139-748D-4138-B4BD-AA4B05A3EE5C', '47B28DF3-8334-406D-B54E-79663A24F722', '5413973173216', ' 100  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56DB25C7-85A4-4F03-9491-E1B6067D52B2', '592F6191-24AA-43AA-8346-CFB62E4B9DC1', '5997001362488', '   / standard', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57A0540A-1675-461A-A467-BE7A594331AF', '78567479-AE8A-40CE-B68F-B81C2F9E9F9B', '4607051790742', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3793E756-2C8F-4E13-AF45-868D00888987', 'C6C09A3F-5A4D-4287-807A-BBC74888A42C', '8300961774999', '  70 4 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58E2E57B-5F54-428C-BDCF-A7005EDA025E', 'AC3725E9-0F82-4D70-831D-8152BB26C7BA', '2400006372633', '911        150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9C9C06A-B6BC-48CF-8239-DB53817D5355', '5E73388D-23D0-4860-A3BC-74D6921BCB6C', '4607098450616', '  /. . 0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E138B02-F773-45A1-8026-7C9FACC567B2', '32031191-3B9B-459A-9F0C-B16406995DF1', '4605658085513', '     /19540/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2963F61-BCEC-4EF3-8B98-2D9A9B0A43CB', '14592A19-8B1E-4184-B345-CB00D1C9A577', '4607141990274', ' 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA1E9FDE-0684-4B91-9CCB-ADE1C95C14D2', 'B9BB26C0-1495-4C85-9A2A-C3391D900BDE', '4627110041233', ' ergoforma    1/ 4/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D5425AD-F9B3-4B86-A8D9-D578BA0689F5', 'CFECFB25-3985-439F-B14E-C36EBFF6F467', '4606486017899', ' 16  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D40B85C7-37E5-4CB3-A3B1-207D5700EB0D', 'CC7804F6-06FB-4264-A9F2-DEC766145E56', '4630007833217', '    // 600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3346A81D-5098-4CAF-B242-72036E4662C1', '682EBB60-DD0C-48E1-8B58-86CB46D9DE33', '4670016770134', '- 850  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('229FD40B-F657-4103-ABB8-9C732BB5D9E8', 'BEEA435D-2073-4AC9-9333-DCA235B1EA3B', '4627110264366', '   - 6/-608', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48B8A7DF-1FA7-4015-8552-C29C6BC55293', 'E73F0779-083D-4770-B498-CF1903E99897', '4650071435636', ' . 315 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9C7A7B6-2ADA-4054-AF15-63B4E93D6E42', '54339415-B640-42ED-86BB-0705A06B59C5', '5997001303863', ' . 10  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCA983CD-03CA-49D4-9D8C-44BC62FB66ED', 'B6E97859-A75C-4598-BC55-B0552312D66C', '4605658173401', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7277A96E-9AF8-43CC-8BBE-942D564D299A', '386A2128-2422-46BD-B9D7-1379885D337A', '4987188509203', '   6,54,2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ECEDD50-413E-49BF-8FDF-0A5503FA6646', 'A5395EEC-F8E8-425A-958A-15038EF71E74', '4029917001968', '  20 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC3356A2-44E6-4CC8-9573-C418DF1F1A0A', 'EA29B179-EB97-4817-8D26-EEDE0263B7A8', '4620006245951', '    . 2, F-513', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84E7C1B6-0C55-4F2C-914B-F14F7941569C', 'C4BDC22F-BA8E-4A5B-A36C-0431BAE833E7', '7793647742077', ' wn-115k ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62434ABC-D92B-40F1-A338-F022486CB428', 'D705E785-3352-4B0A-A6C6-4DF30082ECE8', '4607027217884', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BB06720-6228-4C1D-A3BD-29D952A5FA74', '6BEFEEF0-6F81-420B-8F63-F9CB0676A668', '4719003017514', ' 1751  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E64F162-BDA7-4A42-AF08-85C8A4599822', '65630232-6975-4F9A-BF59-73FC1D99E066', '4670002260496', ' / /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A333CD5-6730-454A-B89E-66E2BDF53AC4', '5F4A94F1-8AAF-41D4-A342-FABF0D6757F2', '4523568971422', '  2-  22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B3B8FE5-9FC6-4FDD-A6E4-76192079F877', '46F3925A-70B0-49C7-89CB-DD388B0A8B38', '4607039974157', '     0,35  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DA8419B-FD57-4724-98E5-D0E7F3B6FFDD', '9BE403F1-21EC-4862-9C8C-6F81B6C655BE', '4620002185510', '       4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFED342B-2760-458B-A9AB-C81C9B7F6392', 'FC8EA508-059A-4095-913E-1A49A59404B1', '4640001382567', '  500 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EB3DBA6-574E-40BC-A9FB-F6E27BB9BBEC', '3EFC2AA3-0C8C-42B6-B106-FF954585A4E4', '4612586500780', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA9B82E0-8040-4DBD-B086-CB8B095BCC15', 'BC8FACF7-2551-4E4C-B1F4-296A06090103', '5903407234663', '-   summer time 0-6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B645E611-581E-4119-8127-363B41159F77', '761800F8-0836-47EF-9DEC-29F2C0A05098', '4981046050203', ' A&D UA-777 // / . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4BBE7BB-1DD3-4485-9AEA-8C6F25B79A46', 'CDD0843B-2B27-48F4-9A45-58771AB88A38', '4607085315454', ' 20  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CC5146F-CB24-4D54-A0B2-A1BAAC0FFF94', '6EFEAA0E-1386-4650-A438-B64C4692037D', '4601764001478', ' 250  / 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92E6AF0E-5F7B-42DB-936B-E852E6729C46', '6CAEC628-FBEC-4571-AA64-438ABED230AE', '5702191011111', '  /. . 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79DA0E15-8C50-4065-9898-86A453B3DF79', '6A55525E-7E9A-4F2C-8910-4304B378CC3E', '3850343032292', '  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95575C60-EDAB-49A9-9B54-C6CED131B3FA', 'F166C1C6-5E6D-4B38-B043-67F57E009488', '4607143560567', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DA32A06-0313-495C-8528-D16FA51AE8F7', '5BA1371F-A824-4065-BBE3-81F10D4EA4C1', '4610004580895', '  6+200  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44566705-1459-4B82-91BE-6178E95A7814', 'B3F48AA2-9A89-43D0-A279-68620C046ED1', '7322540761788', '-      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30E98D09-2E38-42FE-92C9-FAF801B2DA77', 'B4B62E97-B8CD-44C3-8D22-0607968F0B5F', '4607064299225', ' /   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17DE9E3E-3DE0-4805-9DA9-9F24725A412A', 'F9931A6B-CBAF-4955-96C1-2F19241438D1', '4049500267106', '    /. 4,56,5 5/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8540714C-6802-4CAB-8521-6C8D45B5D8C5', 'E84D781D-1FDE-40A6-B4F4-0B7162D95D9E', '4680004854579', '  / /  . 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F33A3B0-03E1-4F25-904D-C415BF5D11DB', 'E4A92819-EA8B-45DD-8275-0D4F4C86DF1D', '6001159111948', ' -   , ,   125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AD9454A-B4BC-423F-AC41-07504680F74B', '5BCFA252-7F9E-485A-BD7C-985255A089FA', '5013965850455', ' / - pro-ep  protection/  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7711A73E-7EAC-4F65-921E-D164E8F616A5', '170C10D6-D15D-4070-BF7E-2DB18BF6B451', '8030009500999', '   /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5312DC40-EEF1-4EC1-B27D-84F077A7B8D0', '4B87587A-5E1F-49BA-ACEB-23968A86E0A8', '2000103610869', '-   0-6/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B6D4386-6BFF-494A-A8E7-4671D56F494F', '0A8ABE15-35B4-4243-A308-5209CD5E450A', '4009932559095', ' vip     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B214CA5-119C-49DB-B95C-E7B4780EDD77', '4FCFD431-3664-4919-8EE2-B82C1259D5B0', '4601907001334', ' 240 5 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8DF145B-F5E7-42A0-B5C2-D21CF59A2837', '01AF0694-FF97-4142-AC3F-CCF1441E5D34', '4008500127179', ' 600  / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBD6C5E9-CCBE-4386-9BB9-118F98E7CA56', 'A12096BC-B79E-4C5F-8157-17A161C1C62E', '4607017268247', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0F0FA9E-CE99-4155-B344-8DED664346BE', '36F07B94-3BE1-4ABC-89B1-B8E3F78FD8AD', '4640001811340', '   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9374C359-A5C5-4747-8A31-CA369054254A', '0CA7CD3D-B62A-4FF7-B6F5-AFDF3E6906B3', '8717644089262', ' / .   150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5FD2089-0DDC-4764-9CEA-54302093A489', 'A4FE5192-FBA8-4662-811E-08E530C56F30', '4607046740448', '    9 320 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3D19C66-2391-433B-A368-77C51807AA84', '5B987FE6-5D38-4519-8CD4-CF0BBF934E6E', '9900550693121', '     / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37DD0069-0734-4664-908A-C7DF52A7A11C', '73B8FA70-50DD-4928-9AB9-DCA08ADF467E', '5900002047988', '   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C775A03-0D5B-4F8A-AC1E-72156591B4B6', 'C83E6F38-903A-47A8-906B-34905B6981BA', '4660005990193', '  .   3.. 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5963192-A6F3-4EB3-889F-41FB6399B563', '75C39AD5-3857-47DE-97F2-5044C921A779', '8600097300735', ' 150 2 / / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB3F4FEB-27F4-405C-AD47-0A28575A3CDA', '63962538-5523-4D04-A128-73ABB22DDEED', '4630008131121', '- 3,75  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46BEDD5F-E8A7-414D-8D46-D201D83C393E', '25FBD458-B037-485C-AC47-805639997C75', '4640006302874', ' -   /.44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B81300D-8F87-49C6-94B4-9167DB5B2011', 'EEA89CD4-3ED9-4A2D-BEA7-00E23C1776BF', '4049500112857', '    / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72054797-5BAE-483E-9507-900F694B972B', '747CA675-666E-4CE1-A125-5A08814251E5', '4607069270922', '    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8A63F7E-8DF9-40C9-B31C-DB0937E3C1BC', '7D29DE10-632A-4655-AD15-77364E164C92', '2000103611705', '-  animals 0-6/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6593D42F-6A38-476A-B72C-BCA3B6FE0DB1', 'B3691D6F-ED12-4D9A-910D-03C3B4238807', '4607131043515', '    /  355', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2D5329F-2CC9-42A5-BB67-8FFE54D912A2', '10DDCCA2-DA88-493D-BEEC-779888FB3B8A', '4603788005036', '  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('048125B4-189E-4CCF-8B18-66121FF10990', '286BF8CD-2196-413D-8D4A-97D6075F7BD1', '4605379000116', ' 10000/1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6D59296-4036-4ACE-83BB-53F05F59EE52', 'BD76D0D1-C173-4CC7-9420-A25FED8510CB', '4640000904432', ' 83    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D258D2C7-40B8-46E6-9C02-2309513C9214', '89BB0CEB-8DEE-4FA5-87BB-553B6C9D7F94', '4603569720998', ' 20  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7B68C48-75DA-485A-9176-7AFBE372CA1D', '68220E62-6620-4074-A4FC-5748B24B83F1', '5900516830175', '      15  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D32661CF-BD8B-49D8-AD98-1B5C84CF6F46', '05E3F036-5C1B-437E-A44C-02CFF1227452', '4601764000662', ' 200  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81481BF0-1583-40E6-8450-DA378DEEFD90', '4F542EEE-A928-4452-9D41-C05B684C5D61', '4607098450562', '  0,03% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D79B3C86-62D0-4D34-BC69-93DB5A22B926', '708078A2-81EE-4A2E-852A-93BB053027CC', '4605635002755', ' 0,002  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('885F878E-C810-4EB2-B50C-65ED6E592220', 'A01CE6E9-CD7A-4BFF-8465-6436A04BC367', '5997001363805', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD39A859-AB56-4890-81A1-9E972ED11E02', 'A85B7682-023A-4BAD-B58F-B1A689A48D92', '4670000790025', '    /44-46/   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC47A948-925F-4C37-B33A-2D59470A2EDE', '542530E5-11A1-40EB-BB93-8D1DBA724411', '4602902001336', '   - //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40097DAF-35ED-4E1B-805F-8B2442D26D65', '8E3A0ACE-7C54-4201-AA77-DA47BE000F06', '4660005990773', '       1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F95DF72-FD70-41CA-946C-66C97451746A', '02FC7E82-5599-4AB0-9AC2-DB0D450C7283', '4660005990162', '    , 3 , .1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC88CD6B-5446-4964-8EB0-BBBCC442562B', '95F83D99-13B4-42DD-8A74-34886334E5AE', '8470002358201', '- 0,2% 70/100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('003311C5-DC4B-4513-95C0-ED539031DD21', 'FCA36188-21B7-46B0-9950-A9716E7FBE7E', '4602424006512', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00AB1FE3-84FA-4CEF-B710-C911E435D3F9', '50B0A77E-9806-4FAF-8FE2-5C716FCA9698', '5903407565101', '      350+12 pirates', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AECDB1D-F9D5-47C1-AC68-9FD74ACEF734', '2B07CF8B-3FBA-47A0-ACEE-D05B229BCC6B', '2000103611248', '-   owl 6-18/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE376488-F087-4072-BEB6-79957767142D', '309AA2DE-AF13-47DD-BBA1-71FE916C0935', '4690624015175', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5D24E4A-6E9B-4731-9EFA-D3DB8A5FF26E', '0F0EC1F6-20C9-4318-B4E3-8B3FE82BF9FE', '4601951000635', ' 5000/0,2  - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2CE73FB-83BC-4723-986C-CD92347C922E', 'F9C403A1-E085-4428-9155-09116415E177', '4627078981190', 'Gess ortofi  /   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDC6B724-EDDF-40C0-878F-19036538DBB0', 'C45BABCB-0A43-4A35-99A1-E49A552FEBE5', '8714207410501', ' - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09F5B5C1-8B14-4974-9590-834085E847BE', 'A5EE9258-F531-4316-81C3-CF4192F2499E', '4049500116176', '      .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FD6516B-AAC7-4042-83E7-7CF1B7C888EF', 'AA1F27B0-4843-4411-BC05-C0A5D7742295', '4627079833528', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('247DA7AF-587F-46AB-A141-5E05036ED4DE', '7CAEFF6B-8C8A-4224-B09E-F00222F053E0', '4620013730129', '   /. -  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24323300-B671-4161-B584-8B67022C40B1', '49F93CCF-0867-42B6-8CE1-43ED8057D183', '4670005860020', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6120AFC8-991B-4745-BE10-F1845BEB64F7', '6D3BBB21-BAA3-48B3-9F95-6BFB37AFA1CF', '4719003310059', ' wa-55  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F724722F-BE5B-4550-B85E-A3B8FC1A5E83', '76B366FB-A1AB-4D33-926E-5305D599016B', '4630007833194', '    // 600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5599BEA-942C-4DB7-9648-991BAE08D3EB', '6A948188-A424-4A35-838A-041213A5A631', '3760102851098', '  /      /a/tp0r01/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CDA05C9-659B-4086-BE6E-BE58C2F52325', '5C77F2DC-B896-4C36-AE66-107080F10B46', '4630001120429', '   2  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19AD4BA1-9C8A-4EE4-B7ED-DCA702AD2981', 'B5DDC6FE-B9BA-43A4-B96B-7A878974E089', '0027917104096', '      5 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62E4EFDA-D53D-4087-8DF1-D7DBB39FF2B4', '5AE40A65-8A2F-441C-965B-47002789F2F6', '4600702098365', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F137574B-C4EC-43E6-AEC0-00D1DCC03311', '1E2347F5-EF91-4C22-9E9A-113260E3D55B', '8901107003203', '  // 100/5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90901B72-6906-47AD-8151-3C304E04F55E', 'F5156469-3E78-407F-9B23-396547FAB364', '4620016240137', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E47EBE3-AFD2-4512-AE39-9F5B5124FC59', 'CFAADFCA-0B73-4076-B5FD-B5FB94374B2B', '4610004310720', ' ,   S ( 68-75)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E9C02EF-F984-40B4-8840-2A1B47DFFEF0', 'F017FB68-3409-4A33-8DD4-C152854055CC', '4607041292331', ' -  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F7CDBEC-C0E2-4E5F-A940-E32FB4621EEB', 'C063CD1D-07D5-4B9C-AA4D-B0E4DB7F54D4', '4620759290246', '  /- / 3% 100 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('867BE9C1-E0FD-4449-8258-F2AA9571B328', 'EFF38222-7C4E-442A-91AD-21DDC61ECB0B', '4813870002229', ' /    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('612612CF-9270-4058-919C-D6EF77097219', '2A60419F-6576-49E7-9F0F-56FA2FE0185F', '4750283010024', '  9509   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36921DEB-37CC-49BA-909B-E0FF06C6D592', 'EAA15439-943F-446D-9A24-EEDC125C8224', '6935791706913', '    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49BD469B-F7EF-46DE-BD20-B2145824CEFC', '2743FB37-E477-4AA4-8AA1-71EB2EEFEAFC', '4650001794000', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D5C0A20-C9C8-4A19-AE52-91F79925C020', '432704A8-5B13-4312-981B-50421711BBDA', '3850343001281', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0942B5C7-2CD0-4339-897C-39FDFA691A1F', '77995B50-79E2-4986-BB45-EDE7059F33CF', '4601774007750', '    / 2/ 3//505', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F23878FC-4BCD-49DE-A921-DFE66C9CDFB4', '645E3C7A-A8D8-44B4-B53D-24CE751AE7B4', '4602565021290', ' 500  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AB84569-1CA9-4E42-A275-055DE72E0BF8', '57FD5A42-9ED7-41A9-97F5-ED38B3A9F13A', '4607010247249', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20FC9F6A-2746-4FA5-A5C3-F18F817D3BA8', '48D64FC0-C7FA-49DD-91B6-1C4B59DDAEA5', '4640006303086', '  - 44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('775ECF67-09B1-4846-B901-1FBE2B3F0148', '83041EB6-A588-49DB-96B8-AE79AEE0ACE8', '2000949736181', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BE41092-0850-4748-A648-DAC2CE93468F', '9306414A-AC33-4640-861D-7038468EC333', '4602210001172', '  1/1 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06F14F95-294E-4FBC-B272-5C23C79BF9FC', 'E980ED95-C0F9-4845-97F1-DC98836AD981', '4003583191154', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E84C496-0887-400B-9F3F-80E1BA18E7BF', 'B7066D66-6D04-41F8-ABE4-A22D3BF38B3A', '4640018990168', ' Velvet smooth  + /   scholl 7,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DB1A3F6-1727-41E7-8AE8-255FA46177EF', '8A804565-28C0-404A-B59A-5258B85C61BB', '5413787998302', ' 0,05  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F3B87BB-9C2F-4DD5-9389-CEECCF937B31', '19DC95AB-303F-4264-943F-67963F29B7C2', '4660009150197', '  58  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23D902AC-4440-4E5E-808A-B2814C2E1B69', '114E6E6F-1763-496C-A148-23D7BC5036A2', '4605658110291', '     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3769D937-D329-4924-971E-EAF2F3AE4BF8', '62C1637B-7C25-40A5-AD85-E9BD6C9DB685', '7290102063574', '  70  12+1  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D62E0844-A58D-4ECA-977F-D3E6BCFC044F', 'D7725B28-C59E-4341-98CE-606FF9019CDB', '4640013555140', '  just   250 6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FC6B490-9836-4C45-974F-F4E40178EEE8', 'C16B939A-7AFB-4F77-B61C-E90FBEE85F1A', '2400006246644', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F446831B-E409-451F-8111-2DFE809D5B17', '331F5765-57BA-4EB8-A823-610D580AA0E0', '3838989500467', ' 200  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3EAD919-78ED-4BD9-8CFA-AB5200ED12E9', '1038E95D-6A2F-43ED-BBF4-F651D33A527E', '4602866000345', '  1114  3 S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6672828-CECD-4890-A7F1-937E16FC3D38', '84661BD5-3E2F-4387-804B-115F8EB49541', '4640006305455', '  44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('176D47F5-198B-464E-AC88-095B47FFA2C5', '94537E83-2C12-4D4D-B10E-93343AF14D19', '3504105027179', '  /-  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59D2FA7D-BD4E-4358-9D60-84817ECC454C', 'D5946DCB-764C-4587-B1B2-08D9BC689C59', '4607011667190', '  .  .  - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8BA27E6-3612-42DB-BBB8-060552290E67', 'EF9BCC9A-5C0B-42EE-859D-A68413F31356', '4710425923834', '  / /l/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8329F7E-97FF-4989-BCCA-AD8A56D2290A', '947EB89A-B10A-423E-A501-ED33F81A3A48', '4607131043683', ' 300  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD06A152-B4F4-46DC-9B81-FDF2A93986A2', '43E46595-A37F-483D-9566-65F7296DB913', '4607051430020', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E11C41FF-9F08-40FF-AE3C-A5FE5DE4B035', '4338C8CD-4B7F-4B5E-8384-EC5CE3852E87', '4603788005029', ' . -1 / 0  ./ 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98A8ED23-F58B-4A2A-92A8-8C8C1573BE69', '737B9666-8BFE-4128-AC41-962D8BACF643', '4602943000848', ' 0,06  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('615098D9-5062-4BCB-BACA-B6A568C146AA', 'B18A2FCC-5BD4-4F3F-B6AD-D832DCEFFAC9', '4820008310811', '  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1472BF68-AD28-49E9-B78A-DCCBCD57714D', 'D33364D1-3935-48C2-AE3A-49A9491EB7E4', '4610017750520', '     3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC0E9177-A94D-4DBB-BA6D-E621C187AE1F', '81B2C1A6-2E6F-4D4F-B46F-20F6A87CC650', '4605342000495', '     500 / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9A15AE7-1ACF-490F-9035-BC35E76EE987', 'E1F7A77D-795C-4D86-A823-610316C66523', '4603742000626', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF45025F-26C2-4B5A-B310-FA7778EC734D', '97902F55-6F7C-444F-8C7D-6425B711673E', '4627079833559', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EC30507-EDC0-4D96-9C3C-4B7A02E4DCF5', '1C3B906F-6400-4CB7-8061-D583933A2CA2', '4620002185107', ' - -  // 1 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1A062A1-B70D-46B8-A26F-423E18C4A4A0', '4013975D-E2D2-4BF0-9E48-28C9D2D007F6', '4631136742845', ' protect  - 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A88EB91F-F12F-4475-A946-71CF95337C02', 'F0AF2507-E79E-4A4C-B27E-D26B7BDB0C6E', '4630012030021', '   /    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC419E68-DE7A-4E6A-BFAF-9F990FCF35C9', '3D1F7BFB-F923-4C54-924D-76C80E08ADC9', '4680002552835', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EA031CA-7840-4C69-AABC-1B9E86995C79', '9E53BD50-6758-4AAB-B135-C983024D8700', '3574660709285', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEB73504-CBF5-4814-9BA9-B4039199C819', '8AC5F508-A2DC-4458-9836-C66A8D8AD187', '4610004311321', ' / / 1/ s / 60-67/+ / / 1+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27DBEEFB-3423-4B1A-AE82-FCB6302BB1EE', 'DC70AB5D-CBE1-420B-90F2-2873D5129BFE', '4680013246976', '- 0,02 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBDFDF28-4184-41F8-B818-F594A1987522', 'A0F6425A-37E8-4442-A4E3-2A6DBBF6592E', '4660005620489', '  /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1686006-9697-43DE-BE01-544C94C3B46A', 'B13A02FA-D6B0-459C-909F-E0D4605973D9', '3582910056522', ' 150  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00A4F0F0-18A0-43EA-A4FC-6C95D629D1E5', 'A08E8DF9-7C2B-441F-9755-8A529136C973', '4600697173580', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E34DFA58-4E53-4D1D-ADD4-478CBCD1AFBE', 'B7F433CD-8DCF-410F-B07F-3A78FB7D4E52', '4607155710028', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F524CB55-7115-43C0-8F8D-FFC9FDA89F0E', 'FFCA1E0A-27AA-4E50-8BFC-B8650B5CBD64', '4008500127032', ' 10 - / 50 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0460A3E5-42AE-4518-B90D-7E15D876E1AD', '9A444745-2215-4703-87BE-C70BBC22507F', '7640114720819', '  50 2 / - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD724792-667B-4891-A712-F54FB1A6FB0A', '47AF77DE-C9A1-4537-9CB9-65EC1EF7F975', '4987480010100', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2B3120A-7315-41D5-A322-59AC50B689E8', '4D47B517-2EE7-441D-9D80-CC26CF332434', '4008600162759', '-  night  day   6-18  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56092825-6189-4BD8-838D-E53EC7940C9C', 'B247CF29-E68D-4A5C-8641-5858F7ED2DE4', '4600665204025', '   l // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B549489-022A-4D1F-BA0D-DD20DCA7FB25', '9CB4EA02-93B6-4141-85FE-6C89DD471024', '4620006259446', '  /-301/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59226BEA-8D39-4769-B233-B2F445606EB4', '2CAFEE5F-0780-43B3-B521-FFA786B06060', '4607155640233', ' 1,25500    leiko', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B79A8FAF-EEFC-40A3-A7DC-EF2C5FD72A9D', '0EB43D19-2991-428A-8EA3-8AD6C5B90894', '4607008132816', ' 50+10  25  /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91D629D7-A98F-46B1-BE51-E6509E8C1DB5', 'DDD513FB-4162-410F-85EE-77A5DF5C6CD2', '4630004540019', ' 500   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6282DE3C-976A-425E-A27E-81939E0C05A2', 'E0CBB3FF-59C7-45D0-B007-ABA2EC4A971A', '4607027769055', ' 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27E4F614-3551-432E-8EC7-F3B1C33FD2A6', 'A41F2736-BD11-4919-A5C7-47D43C767160', '5413973011310', ' 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1188D98-D8BB-40B6-9189-9F893AFF3BC8', 'EAD5B5F2-C7E3-4F47-B3F4-9E280B690C4E', '4037353005075', ' 25 10/  2,5 / - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91616148-E297-4192-AFE7-66E880898B45', 'E7786C73-C026-492E-A597-4C04A3C24CD3', '4601969004946', ' 10 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD581602-C8CB-4859-834D-97F5A62D8767', '1AE9B962-0FA8-4598-B278-D11C0A8D3F90', '4580198174012', ' . ua-100   /.io0000/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E585EFC-F99B-43D4-9487-14993CC81443', '5290BE3D-AED6-4A5B-A34F-2BC3D22A4B64', '4602866016094', '  (S)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4968D680-A8E0-4344-BF7E-2262ABF9E55D', 'A8FF8909-2C9E-47F3-A860-14596A9D51CE', '4606249000069', '   // 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78A76BFE-3446-4058-8AAD-25711A09A285', '4E77AD74-63CA-4D51-8765-BFAEDF062549', '4607082853973', '  /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4E479A2-B1FA-40EA-B34A-CCDF98406BB3', 'BD522328-ED88-45AC-B974-313E1F9848A8', '4630008130759', '- 50+100  /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D95A007E-644B-4F39-ACDE-252B27F53656', 'FCF660BE-8EB3-434E-A035-BA21B90335D6', '4680007210198', '   / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC0F05CE-B8E3-4EF2-B897-E3FE8D0296D3', '92914E45-0389-4322-950A-1D2A7157467A', '4601764005063', '   500  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6B849F3-04C9-46DB-897B-80073036085E', '8A905CC7-8A0D-4584-8FCF-EBB3D5A04A77', '4607027218782', ' . .+  150 1196', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB3B961E-47AD-409A-83E6-873F12FEFBD1', '800C7683-E0A8-429F-9338-9D706FE30F66', '4630008130261', '- 18       /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E7FB741-766F-439C-97ED-A5766A32C7AD', '94D8B96D-FBCF-4D1C-A57B-4BCF38E9D63D', '4607118051823', '     1% 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('473465A6-6018-4B22-B89B-18256EBE324B', 'DC174D09-C3F1-470C-94F2-F21C6BDCEA27', '4680002476155', '  0,2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('220F1A91-8E0F-40F0-9FF8-085FA25FBE82', '8C966730-F217-4A1A-8E26-0408185099F7', '4610004310225', '   / ./ 27 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFDD5929-920D-4168-A9BA-35D173DAB88F', 'A550109F-0890-41C8-876E-9909D149E93D', '4606272031382', '        250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DE6AA2B-18F1-4021-A559-A7A19E3F3F18', '84CE203A-25A0-4441-BB46-B7511F2E59F3', '4811379000012', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84F40F5C-5EBA-4071-8088-CE8295802446', '7BCD8520-1588-410D-85AF-42E4F8ABE939', '4603500042769', ' - .108-112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('304F6906-604A-45F5-9EE4-71C1E6221517', 'BEB6BA71-4DAD-4A19-BD6E-742193647350', '4049500036832', '     (Tensoval)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7B745C2-E671-4589-A09E-023F2203719D', '6821A6C2-4AF8-493B-8444-0D2D982410D6', '7640156390131', '  jw-214  //18-22   / 5/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72AB8357-EF8B-4AC9-BF84-85532A25777C', 'A1C43D33-240C-4569-B00D-8ED85D3D00B7', '4602676008296', ' 0,02  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DF2E824-5F2F-4053-A205-00E1F2C5068A', 'FC0B9E1C-3163-461E-8408-236AA3A9AB34', '4820121900012', '   250 /108/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BCF2294-3D91-43C7-A3FA-C6D5D46856A8', '2862E40B-A2B8-4C86-A710-5FF8E70D6F24', '4607045192330', '  1%    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B798475-BE51-4629-BA65-632765871E96', '4625AAC7-976A-4262-BF50-01B144E3FFBF', '4602866016100', '  /m/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36EF1360-296D-4C46-9DDC-F75BAC3CD555', '006726FC-2143-4E87-AF7F-B9BC2C7261F5', '4605920000558', '  0,205  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8D56E9F-ADA3-49C0-8955-88B52F1F15EB', '82148DC6-E953-455F-BA19-4C5874A16D27', '4670012600251', '   0,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D06406D-E775-440C-ACFD-CC81F525CAD0', 'AA88BFA1-7049-4478-91FB-C9812F4E6B15', '4002857006736', '    1-4  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FADC5FF6-B481-4511-8DDA-18A88C3DEDB2', '930957E5-D1AC-4FFF-863F-060DE5C7BFA9', '4660007811144', '  // 0,002 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C616CCB-B19C-4BAA-96A5-5B4B4FF92B1A', 'CAE3E5DC-9150-4678-AC15-2CEC4BE8463C', '4650055920295', '-  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B7A02C7-9433-4173-9552-45F8AEBB07E6', '5B93E14C-AC7E-4D36-BE22-3257277B16F5', '4670018481632', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDE14277-AACF-46C0-A037-060D66320BD0', 'B146B68F-CD04-4255-A633-6449749FC869', '6950570782711', '  arlette 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90980827-2D92-4581-ACC0-6FA9FE88CC9A', 'B2B2DB32-78A1-400E-890F-2019722E0B36', '4605059019933', '5          125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E75BA65-49FA-4760-9A2C-4FC496BF5D1A', '94332D81-DA8A-475E-9DE6-92DD09E7593E', '4620004952202', '  13 -  60 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C6BDAE4-E15D-4233-A23A-51B777BA2BF0', '3E6FA3EF-F3BA-4B16-BC4D-174AC1792D3D', '8908005685197', '-  18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69087A7A-DDC4-4510-92CB-6404B5DC4186', 'E91FF318-333B-4123-9C03-4CA1E26D3E0A', '4602866021081', '  000/3,5 /...', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBDC342F-7094-43AC-9FC2-7EBD558654FD', '6249E917-6869-4949-81C6-B7CE5FF432E4', '4750283048140', '  . 0403/lu // 2.. 1 / / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBDCC1FB-4FFE-4566-8CD0-D583999EB9F3', '2C128CBD-EB20-4724-84E2-E821E518671D', '4627093275779', '   -24 110', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDE29F2C-15C3-4EA5-89E0-924DEA80FDAE', '85DE46AB-C1BC-404D-B77A-5D2B9D29B71F', '4606144007187', '    360   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FFBFA73-706A-4B0B-9BAA-758472E0EC6C', '1902D569-3B94-4077-B42F-01788B3F5C74', '4605658213671', '   /21367/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E05A9265-3026-45FF-A61C-0C4EA6A634F0', '86144C76-9F96-49C9-9AB4-62EAB323C210', '3574661064543', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AAB4AAB-8D65-470D-9FCF-7CC7E1226BE4', '80A39764-CDB1-451C-AF97-682B3D92564D', '4600416017034', '     32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B26CA282-7DDF-4202-96A2-F0CFFBF39067', '4798FEBF-9CFA-4D97-8220-DF8591455D0E', '4605927000704', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('163C64D3-447A-44A7-974E-21B7B0DCF348', 'EFDA3A23-95FA-4DD6-A762-E1523458A345', '4601834003616', ' /  frautest candida', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('915B2E13-7AB6-400D-9F9B-74CE6D8F2110', '3B7676FE-5923-4F67-A446-EF5E90DED335', '4600209011126', '-2   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB866098-6AC6-4EDC-AFDD-ABCC117272D9', 'E70A5F51-CA8A-408F-9920-AD4F8035E6B4', '7046260992429', ' 1% 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A62E135-78C0-4F7D-B96D-482984044BD9', 'E7D748BA-E161-4FBF-884A-9DA0EF95BF85', '4052199238388', '   55 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C635361-E98B-47E6-A08B-5707D11110F0', 'F640BE69-35E0-461E-9EF3-5146E407ABE1', '5900516421151', '       " " 56 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E90D22F3-D3EB-4630-AD95-47D7C8ED88FD', 'FBB0BBBA-9CCD-4553-AC04-64176EF963E0', '4037353010338', ' 25 50/  0,5 / - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30CCA4CB-8A82-4521-87D6-81375E7EB6FF', '0FCCC4E8-5EE4-41BD-88FC-DFCB86DF4D89', '4820121900111', '  1012', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11631DC8-1028-4440-BB2F-55BB793F3D70', 'CECDEC57-043E-4727-810F-8A62667C84E7', '4620002186289', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB49A2C-13DB-4938-9EC5-EC0A75FA2045', '6480E8F0-992C-4777-A4F4-626461775C95', '3582182850033', ' 3,75  /    -+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70C2C746-8B71-4C60-B208-ACDC3E6A85E9', 'B4A23CBF-6351-4E6C-80D3-4794246A72AB', '4601774006470', '   - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97726224-BE0B-4310-B5EB-37E8BB557A10', '37027261-E543-4E18-883C-FD4648B46F96', '4046222419622', '  20  / 98', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2A1B209-18ED-4920-8BAD-7F94664D6026', 'E2C3BFFC-1320-490C-BD29-50C171710F3C', '8413600511012', '  /  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D24E464-FD9C-4C25-87B1-A2F228EC92BF', '9329D029-9A93-434D-B2D3-5329A2570939', '4620768931017', '    9*10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B443E954-5047-4DA8-AF7B-1C17F1EEB5DD', '57412662-F3B6-4382-B830-A79855818484', '4750232006245', ' 5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F6268D6-C6B4-43F8-8F43-97025947A7BE', '476FEF3D-1527-4752-BDEE-2A6B6854542E', '4607076219259', '  -  /   0+100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B694A151-6BC1-487D-A980-501BA22911D9', 'AC5D5552-FE37-45F0-A70A-4DE2ABAB4086', '4810263025810', '.    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3110EAC0-C76F-47D9-AE15-C9B944E9F5A1', 'E38C121C-AA40-4F56-8601-BC97ECC0E261', '4521356897541', '---23g ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B593B2F9-E67A-44FD-B8C1-D7FC6F1BC9FB', '2BD37E1B-4DC2-4307-9F76-F8BBBD3E594A', '4650054310035', '      / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B02EA38-3F2A-4150-AD56-57B175C9EE88', 'BCFF677C-7EEF-4F34-ADE1-86D2CD4EFC06', '0033732511094', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('467C6A26-6458-4600-9EFC-D7C910E21091', '8444DF66-0B26-4A1B-8A82-CB4939F03A3C', '4607094174257', '     12+9419', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48811D87-CBF9-431E-A746-B07658589886', '6DC4AC1D-4E76-46B5-AEE7-69A2A34942E4', '4602509018256', ' 100/ 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2694454-4B23-4D4B-9BA5-12F88515B393', '683B4628-80CA-48A7-BB98-7F9D0FAB44D5', '4820077020758', '      37-40   5 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18C894E2-7797-4AD1-A548-E223C28B3755', '7AAFE2CE-78D8-4097-B7F2-526957B0EF51', '5413787998289', ' 0,1  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A140B632-03D0-4472-907A-2CD85958E089', '20D56735-B5A2-4B6E-89F0-1C6C83861524', '4600697173610', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37E123BE-DCC1-466E-A844-C6A451561974', 'BB844215-5122-4EFA-893E-4AF3ADE3E1C3', '4606486003045', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BFAA518-E998-40C4-85FF-76997C1ECD5D', 'C83B130F-55D0-41A8-A6B4-593FB4AC6229', '8887786800404', ' ld-210c ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57F97656-5BAD-4F1B-A5BC-131FA4821C5B', 'A95A490A-E3F8-4C15-B425-7D11F72D4730', '5997001360897', ' 0,4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D711B6B1-922C-429C-9A60-09B0CAE86BF1', '3D04C10E-768D-495C-91F0-90070CE91B72', '4607094170563', '   2,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E11FEAC-A546-4ABA-BD07-5184EA3820EC', 'B57ADD95-DE17-4F73-BA3B-7CA4C6802FE1', '4750232002322', ' 0,25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73432D46-6B51-4346-B69D-C206ECBD4C2F', '0AC07A37-3C92-4443-80D0-B22EFEBBC114', '4606677005407', 'Mama comfort   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83D52B4C-1E81-43A0-A50F-7C5AF467A9F9', '056AF356-D646-4421-AE8A-105B590B0AFA', '4607056260585', ' /          180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23816C9A-94FE-470C-A73C-CA48821197EE', '19A9B0B5-862F-47A4-86F0-8A42E2DC8D49', '3800041903042', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9E054CF-DD6C-4978-959D-8D8CD4280A18', 'B3B53796-5C5A-40CA-8CDB-1717488387CC', '4640011890410', 'Armed  fs-913l', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD916463-144C-4AF0-B323-A8A18A80C8A1', 'F1B4E4DA-3835-4BEE-9022-F56127066DDA', '8887786200419', ' ld30 /// ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E303E7D-2467-43F0-8C55-F8A6E00A7DD3', '53A3F69B-79E2-401F-82DF-7FFB34816D30', '4607094173984', '   2    6+/2611/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D4BF959-2FDD-457E-B2EB-4BD9CE2D05D2', '8575CA14-A77F-4CF3-BF75-49F528F0E85A', '4602866034302', ' /-116/  .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A19CA249-CB40-493F-9C03-6797B91F018A', '94D4249E-7FD6-4CB9-9D61-8363E161EC86', '4603423003991', '  /  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A4DA083-43C3-4F24-8EF6-385D92813494', 'D98C9B73-F0F5-4866-852A-D892E478B8DD', '9006968000091', ' 30  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A244D37B-C350-4C67-9F6D-97D4E852FAE9', 'D4983897-8E6D-4AD8-8315-CA7EA279D644', '8033661800124', '  0,02/2  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13B5A18A-C071-4C73-BC17-BEF7C37F1216', '0F10F731-E140-4C9D-BA47-68CBB2245044', '7350061291101', ' -    35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78EDB05F-5D2A-4485-BF28-B86C76D8D2C3', '5DEFE3E0-9A51-4368-8AA8-0890C206799E', '4610012370877', '-  / //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EFF3AC3-4D0B-4F67-B78A-C72182E4B0B8', '2A2D78C8-FD3A-4547-B518-176C9105F095', '4610004311338', ' / / 2/ s/ 68-75/+ / / 1+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D353B8B6-52BF-4F2E-BFFC-23684B96F4A4', 'AEDFC3D9-860D-4489-8F35-67B807B26180', '5702157150700', ' 10  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E6C543A-E6F4-433D-B49A-1CE0E3826CB0', 'D8821102-113C-4762-A9A3-B00A51A0D01E', '8594044141673', ' 300  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6BA535C-361C-49AD-970B-4A82F0F84B09', '29945F23-CD43-4EDE-9E67-C288FE7F2677', '4607003247485', '-  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC15AF0B-B570-456F-BEC2-B00596361216', 'DBE15B11-4E51-483A-935F-957CB5AB88AA', '3504105028930', '    stelatopia 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FF6239C-656E-44BF-87EB-B42616AEECBF', '71F9E128-BE6E-4E13-9573-6B302055599F', '4620002184186', ' / sk . 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('084A187D-9B50-4870-8E76-58DB321F2C04', '97AAD496-4B22-453F-BD78-A08C177121DB', '4620002185183', '    -  3  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE85786A-FA90-41F0-B47A-1F39AC271303', '7152E770-7194-46F6-9AA9-583964F8CC1B', '4627135834209', '  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46E2C011-C9C0-4488-B651-14524316AFB8', '31C2F141-8ED9-49BB-9528-A0EE2A65DA55', '4640013557458', ' -      0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBF19B91-E1BB-4D54-9925-1AC27B9296BB', 'B02DC86D-AA2E-44E5-BA75-903AE699039D', '4607174432369', '    /. . 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2037EEE-9E6D-4D56-8FC7-A27F3EDBAAC0', '35646705-7A91-4700-960E-D1E7131F0E62', '5903407041131', ' 360+12 dino', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('257B1FFE-5AC8-4A32-8181-5AE42A9C14CC', 'CA2C0D7D-4C69-436E-AE0E-1340C7431E49', '4600697171234', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1177F4F-7403-4FE6-AA70-F04E6D088502', '4222F8C0-A913-4CC8-ACE2-E1C3B1FA0DF4', '4605180004235', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70734AE4-1A08-4AF1-9018-0BDF3EC7310B', '2E7DD248-5C29-4E70-A780-3E0CA74B7F86', '4607109409855', ' -   play delight', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('386D3ABD-9537-4E27-A122-7A020AAD69D5', '5222FEAB-A4F0-4500-AB9A-A617677A091F', '0033984020511', '   3 700 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('537CBBDF-1C98-44F1-9B94-08CD34281D7C', '3D12014E-87EC-49C6-80C6-A3FE1011C782', '3574661309453', '  - 21 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B16EE42-72B3-499D-B627-412A1CBB9DA9', '40959AA8-5773-4D99-B6AB-E4306CF81871', '4607094173748', ' - 260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EFDA8E8-CE3F-4138-A843-77837CAECBAE', 'F2D527C2-85FC-4E4F-B362-1DC454F46E0B', '4607054702384', '  soft  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12C29189-429F-426E-917B-AEA5EEB1C9A9', '4F577A40-B6F4-4C0E-B822-D572738504DE', '4607174434516', '  /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAF7FE29-AEC5-41CA-BEDE-611A14C87C65', 'C9AEE5D5-9E3E-4706-9DDB-AB0D06BD1600', '4605370012163', ' /  + global  , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB0DC261-8717-4AA7-B27F-552435DD588E', '134BC644-6998-4018-9795-004F248DC5EE', '4627102800015', ' -199  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15B63808-9004-483B-8A07-CE755BC6A93D', '60F1773C-5C3A-409D-91EC-DC043DCC6EF2', '4008600122982', '-     6-18 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5727FE71-AE8A-4632-BDA8-37D9939A95DC', '9D1D6969-4DB3-4B3F-8208-FAF6B947878D', '4610010011055', '  //   ionational 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D11C248F-B500-453E-AF41-6EB9DF304034', 'C65EC19E-8479-4F2B-9217-6F704D5CF3C3', '6950570782728', '  arlette 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B24C1B24-95AC-4B31-B0F7-AA13A4AC1550', '27CAF964-F03E-4942-8598-7956A45D1596', '4670010370583', '3    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE4AEB80-AB6C-4F3A-8B98-3D2BDBA43244', '26B99560-3B8A-49E2-9662-2DC81B2CF4D4', '4606486003076', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06CA3B4A-0CB1-40B3-AF86-06C4EECFBBC6', '643E88A2-688C-4C88-8862-213D53C85F41', '4605658192006', ' 0+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0A57951-90F4-4D4B-A1BA-5CAF74B591DB', '16B65B56-E25E-4CE8-BDED-AF405229099E', '4008500127421', '- 30  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98CEF8F1-0876-427E-946C-63376D6A4BA2', '205445A6-7350-4807-A4D5-53966079A935', '8715131006518', ' 0,06 1 1- //  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CAE645F-B58F-45A9-8AF2-5F2CA8B32376', '9DC0AA0E-6DBD-46AB-AC7F-49562CEDAAF0', '4620002183660', '  F -   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFDF5477-E089-4A1D-BEEB-217C915581A9', '66540418-6213-4995-BBE3-D545B4FBBD96', '4620002185138', ' -    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2CEB6AD-8ADE-4122-8443-F842B369529F', 'EF490AD2-50E4-43AD-8068-B3E02AE94499', '4605658195809', '   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41575A48-1952-43A9-BC94-813CF29CDFF3', 'C896BF29-803A-42B9-A4B9-B6A8C702C2B2', '4603341000270', '       220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7635004-A272-4C74-90B2-3187B5D7CC90', 'A64DCA03-47B7-4771-915C-E35DB4891085', '8711141806292', ' 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA1BB319-8DB2-4299-9BC5-3C439FF3E579', 'C9853B10-73CA-4CD4-AE38-E515F89600A0', '4015400515623', '       50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('981A8615-5D8B-43BD-90AD-7F6B1AAB7C22', 'A6602BC8-AD34-443A-96A6-49C2185A6C2F', '4610017700075', '- 5+2,5+8  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6C3CEC5-6D88-4CAE-9B13-96BBA095C743', '9A2543F9-697E-4F95-BE0F-A99EF59BA572', '4650001792488', '   /   150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61D6C3D7-E42D-4A2D-A2C2-FE91AA4A8783', '8C3958B6-A2B0-4339-9C7C-A0347E779943', '2400006370349', ' 5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8EE284C-ECD7-47B7-9CDB-7CA3A7D6FEA1', '26FF6B36-4AAB-4B24-B01D-705D9E808EF4', '4823077504754', ' health -  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29AB6B13-2591-4D63-B707-7A1AA10DFC43', '4ED31E7D-95EF-4B93-B7D6-BC749B5A5618', '4607141998850', '  5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D048FEA5-D888-45C9-9BB8-8754AF343E10', '4275B3DE-1307-4620-9E19-71CFC48557CD', '5900002049258', '   SUN TOUCH  EVA SUN 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0FEA55B-EB60-44CC-B5A3-ECDAEF598200', '7FE48346-8D88-4E0A-A6BC-50D6F91E708A', '4607003247867', '  50   / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A9CD058-E3FD-4DBE-8F1C-9C62DBE28F4C', '2943FF10-CC13-4BDC-9733-DF89365C8C40', '4601955000204', ' 500  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('785C0F02-1117-49D1-A6A1-30EBAC2ED5CE', '7C0B20F3-A74C-4253-82BA-7F91CEA1CD8D', '4607024944820', ' 0,1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41BEF6A7-6B0D-40B1-9D0A-54DAE6C5C976', '9F25E1E8-53A5-426C-9E51-AD968EF5BE5A', '5900008020909', ' 500  42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F4807F0-824C-4D9C-BD02-8DA66B95B02B', 'B7223E0D-BFD6-4368-ADBF-162644BF7E62', '8430433000711', ' 0,2 //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEA212A3-BFD9-4248-8A9A-CC56602A5F15', '0C867E2F-CC16-45F4-8836-958E242469D4', '3850343021371', '   /   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F4CF3E8-6C3F-439D-8882-3AADB60CC9AF', '7F98A8FB-394E-44A5-B045-FB63295249B3', '4605319010861', ' . /.-/100+/ .+.30/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98E2EE18-F234-43BA-A189-E8783FFC07C6', '711A0D75-4A0C-44B7-961F-0AFB100753A6', '4640013550725', ' "''"  6 ..260.,', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49AB06E0-4027-413F-8F5E-D5DEB9755BE4', '16B05742-C0FB-4827-A228-F6A0091ABBBC', '3504105028602', ' - /150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99E05EE0-6A9D-4DD3-8817-A136D1727D7C', 'E12D2DD6-A79C-451B-AF26-D37F45ACC7B0', '4607008360660', ' 500/4  4 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28BE0576-40F6-49E2-B68E-FCD8AF39E138', '34CEB9BA-A1D5-4B93-85F5-9C8D84C7DD90', '4690655004704', '- 50  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88CE745D-A370-4518-8472-CC62B31A949C', '1F6DB991-6864-4609-AB2F-C178F2707A0E', '4610011893339', '    1,5 /  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DCA9335-550F-4C43-AC4B-4162D24E34A6', '95AE1F7D-BEAE-49CD-A34B-15021D3C3824', '4610007620024', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47DD7EFD-1E63-46D2-BCB8-D17BCE80CA66', 'B5119D12-8F94-4123-9A92-4726E01CD2DB', '4008600194170', ' Freestyle   / 6+ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33CB77B7-E861-44DB-A61D-CF9F441BEE10', '7710B7E2-695B-4D0B-A575-7583BCA35906', '3838957499472', '  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05C69604-D3C0-46CB-9CF9-9F1A9638A55D', '2C267A8C-36BA-4530-B6DA-975C34E22119', '5036519000939', ' 0,002  / 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C4A3F32-E87A-4082-9C0E-BF2ACD4F93FE', 'AAE89117-ABFC-4B3A-B551-FDE4CE72CFF5', '4610004310249', '   / ./ 31 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30160C65-443E-4D1C-A7B0-3D06094F5E48', 'ABEFD2C1-28AA-4744-AE15-3C955633ABEB', '4607094171003', '  /  12+2019', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D14ADC06-1F5B-4EAD-AAC5-ACA163881096', '9731D5E8-AC66-4FFB-A9BA-529C159045E4', '4751023299259', '    /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E941AFC2-036D-431E-8870-C6DDA07ED0AE', '03543A38-6188-4A26-BAC8-10E684FF8C2F', '4610007620321', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28D72BD3-3B67-4E23-A265-66F935FF7DA2', 'E42581EB-7158-406A-957E-7DBFB9666829', '4660005990957', '     2/ 6//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1935B199-A83C-4F64-B8F9-25B888C94E26', 'B6164676-D7CD-4DDC-BEE9-37B55B7E7E18', '5010006101118', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('317791EC-49FB-46CF-AF30-376862705036', '2BF26308-E2B5-4C72-8394-9C3E61867283', '3629002716107', ' + 3  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B543810-1D4A-4875-8F84-A2D3C27970D2', '50BEE0E7-E1FC-4F9E-BB6A-8AE559CAF11C', '4601969006834', ' 100  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94407EA8-1729-4148-8CBE-FD390B1719ED', '9A87BFC8-B00C-42FD-9437-BD1E518C74FA', '4601951000710', ' 0,016  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F32FF95D-3905-453D-AADE-9B17A96327F4', 'FAE8DD83-9936-499B-8932-B00FC114E143', '5391520941191', '     . 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5C82464-587D-4806-9BFD-5A59E71C45FC', 'B7A0B5DB-2B0F-46D5-B03E-EF508432137F', '4607018197232', '  /   /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8D09E3A-4326-4C0A-88A5-C62B975D1319', 'C2B5CC37-EC0A-492D-BCBB-811E3EB606F8', '4600702061062', '  -  240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B805B8A7-469D-4369-9F4C-844D90CFE32B', 'E63B81C6-2173-4DB3-9480-E91D5575DF3B', '4601774007521', '-   /  /  3/c 320', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4738C041-ADEE-4D03-9A3E-0130DDDB5201', '19E0EDF3-2373-4303-8545-05992C534C68', '5701780744034', '61523    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('630A198F-C60C-4B34-B8EB-1701233FAC15', '9BC1B913-3138-4E9A-AB58-670D171618D6', '4751023295992', ' lure /  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('462CA29F-74BF-4C26-B417-E35756D36CB9', '1178E0D1-C75C-4D60-83BC-69A903B70BC2', '4640013557151', '15766    " "', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94975E1B-2566-4563-9478-7D9D69ED53B8', '1556CC22-2727-46B0-8330-1A9A400F3F28', '4620006266611', '     /-470/ 4  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F56995DE-7F5F-42B2-8E6E-30E75E64B357', '700F33EF-AAD5-47C9-8051-3455A3652CA6', '4820121900449', '  /    1080', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0984D447-5DED-4A38-AF8A-9C0535161D36', '4F7ECD34-BF53-44EC-90EC-51B9410DABFA', '4601969007756', ' 0,75  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB17C8B6-B25A-45B3-942D-C83C41EBC851', '8D9D2204-F5ED-4C8A-806F-8ECF6FE6AB85', '8025153222163', '  800/2 /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26446F06-DA49-4493-8E5A-041AA04169CF', '9C845F38-F6A0-478A-81E5-F3FB52CD3F94', '6430046751170', '    via vit  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51234C59-9A62-4CC7-8E66-0E89E4517B20', '51D17C91-1792-476F-BE95-029AAFEFF73B', '4603713000105', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDB1391E-E223-46F6-A017-F59D088560D6', '4DBD50FE-23C6-40A0-81FB-66AD69672871', '4607045192507', '  12,5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECE22F07-B6B7-486C-8A4E-AEED6514B1C6', 'CFD35693-7DBF-4D23-B971-6C74150045C0', '4603184004312', ' 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D418850E-1570-49D4-9433-CC8F55970426', 'F19C17D4-7F80-41E3-B04C-34EA93297C5D', '4660000410344', '  . / / /..82-87/ 4 // -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B87C221-9F2D-475D-A822-E0F65A5A3587', '544CA963-120A-4BDC-8A44-CB152FB4D3D7', '4607096870355', '  50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C10F20DD-2647-449F-BDB7-0B05E381DDD2', '3F26AE00-F31D-4EEB-8705-D806488B9343', '4680038241901', '-    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB63619D-DE3E-45C4-8F76-ABFB2DE6DC81', '4CB4413A-CCEF-421B-9DE7-7BA6E6CD876D', '4603188000594', '   .5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE47180F-D949-4F32-8779-96B6E46E394C', 'A815B255-3BCD-4512-A576-7B70D097C860', '4104480706158', '  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B2D51ED-4C51-433F-8CE1-2E0931015911', 'F5B54D68-A1F1-4829-93E0-744958343E65', '4820044110994', ' 5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1ACAAB0-0466-45C3-B66B-B7A279362B79', 'EA85F2FD-AA96-4B4F-BC59-F8003FB936CB', '7612367043359', '   /   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3C7A212-E567-49F7-B93C-ABF61C512F02', 'C2F78E2C-044A-4D80-B777-2244864B95D2', '4600490618127', '        350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05ADE5F4-F378-4D5D-850D-8B8DB66888F2', '3FBC6AAF-FBA4-49A3-AD99-17A3653F2E81', '8908005685166', '-  18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96BB683C-EAF5-4CEA-A732-CE251FED7529', '294E86C0-4F18-458C-BC7B-C91F3595FD44', '8901138834753', '   /   / .// /83475/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10552EA1-3313-4D8D-B906-C044387D25D8', 'AEF7A512-4841-4855-B45F-00C96F71BC9E', '8022086001322', ' 0,05  240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9ECFD338-88D2-475F-9F15-9FB0DB093010', '3536C10A-D8CA-4832-AB28-BD5EA706935E', '5000174726527', '   _   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E9BA9C1-47F1-47FD-BB72-5429AFD318B8', 'BABE84F4-2E4E-4461-AFA2-2031EED02B1E', '4607076080149', '   0,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B0EA2B3-CBD1-4D29-B6FE-CFFCA9D8F3D0', 'FC9A8A3B-DC64-4ABF-900C-DEC48561783B', '5900516400828', '   / 72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21602031-B051-405D-886A-46737508934F', '228A9C75-65AD-4708-8AB2-F075C418BC8E', '4600697171388', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88A2DA88-CB82-4E32-8B8D-9564C96F129E', 'D5FB1356-FCBF-45A8-B11C-F307E4A5C031', '5995377010873', '/ 1,25 +5 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FF7E1F5-4BA3-43CD-8055-367C5020EF61', '62014CCD-D38A-4296-AC2A-38962786C9FE', '8032568302441', '   spf 50 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32AEF3C3-0117-4358-BC5A-872701E78E8C', 'E77D3AF9-0535-4367-9E5B-2C440E786BC1', '8716900569661', '   125 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6716A22B-6744-405B-A137-428E6F6B2C97', 'CB66D8DA-DAA9-4D0F-BEF7-14B0D053CE86', '4650001797193', '  -   150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA0017C1-20B5-4423-9E27-A6F740536EE4', '6955CB57-2216-4F70-9C9B-713B6E7031CF', '0617015000101', ' mt-10 .   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47939BB7-0805-406E-B929-AF72FDBB390C', '767404B0-95AD-4B11-AA78-55CDC2529257', '4680287513514', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3C4D80C-14FB-482F-85EF-6CADEAF4AA68', '1975F0A2-44F3-47B4-BC95-F54D5FD1FB75', '3574661213163', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5507FB5B-7EAF-4C4A-95DF-E0B4C5F81440', 'F030CB37-9570-4063-8BB4-AC41F388DCC3', '4607039970357', '-  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37CC0916-E5B7-422E-96B5-E59A6471D41A', '9BAA3EF5-4F62-4765-BD8A-4D003CFE4F99', '4580198172032', ' dt-635 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB87AE3F-67B3-409B-9202-3D1322D06728', '3D8235EC-2C39-4BBB-A1E3-CACF72A1258E', '8710103662358', '   / 2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDA84FBC-C440-47E0-BDF5-9D32CF012270', '1F419855-88F2-40B1-9096-C35C41CB6A65', '4610005630070', '    ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BF1E30B-BCA1-4114-BCDB-CB9B4F9D5337', '12E9A2DB-8D2C-4E39-A359-93464E15351D', '9021600168038', ' 80 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31BFB368-F92C-4FC0-8CDC-62E01CC17813', 'A2CF9A88-0FCB-4CFC-94FB-8666AE89BA43', '4660003400120', '  / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('122CD294-A026-437E-A1A8-B7537A1C2C2C', 'C37A77AC-CC97-49DC-AD26-BB748C2DEEDB', '4607051280014', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DFA9B1B-B471-418E-901D-A504671A350E', '7DAEA0CD-5E24-4D64-A16E-154AF1456FD9', '2000949845913', '  750 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('447D56C5-5BB1-43AE-B8CE-62D7C3C74E4C', '925A7F92-BBBA-4CC4-9B14-0597D63BD14F', '4603276008228', '- 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0F0C0D8-D85C-4D60-AEC6-02F1C87BC9FA', '9FE14C8C-B413-499F-A32D-8BBAECD59D64', '4607101203680', '      250 6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1F0F1E7-D3CE-411C-B0F5-AC92786968D3', '05A54C4C-10EF-4AAF-B6C8-424ABC2394AD', '4630017310258', '  2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9451F4A7-34B4-4533-A982-C13386B9A327', 'F1BD2B6D-BCDD-4580-8310-4C657E222B43', '4630012463478', '    / - 6,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40CCA95E-EE6D-40F9-8CF7-C7CE181B4BE8', 'D1AD1270-10D9-4801-840D-1E197DBA0459', '5900516899141', '  "" 8*10 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48FD3408-C366-4104-975A-9757581FF1E4', 'C3F1876B-2FBB-4528-94DF-65789DACC39D', '4602242008729', '  6  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5626AC71-9D0A-46B2-97ED-F80018305DB7', 'D9606D99-827D-41D8-B3D1-5B946440674C', '2200000166036', ' oppo medical corp    l/2022', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('154F839F-1A39-48F8-AE3C-4B350606F4AB', '52CEDF21-DF04-4E89-B396-6ECB2D5AA904', '8030009570015', '   //  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C562EADF-1393-49FA-9A68-7EB06A779910', '55FFA0A8-E1B7-422C-91DC-CDD635FA9342', '4750283010031', '   2/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6502FBDF-C757-47D7-AE32-FCF09E18E17A', 'F4C5B0FD-5DE7-40C1-9B3E-B7EDADB4BB5C', '4602866001533', ' /-105/ .  .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED8FB33C-AA13-45F0-BBF1-6BA5F286470A', 'B435CF80-EB8D-40E7-A657-C6D56C3F19E0', '4640006303031', ' - /  21 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84BC2619-36FF-4B83-9BE9-7DA68B9E7F3E', '67C6CD3C-93C8-4F52-94BA-956966338353', '4601774007545', '  /  /   5/c 320', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A413A61-7288-4149-A7CE-1E262229E869', '1DE6236B-6FD7-4DB1-9A5C-1999427FAA7C', '4620003221927', ' maneki chibi-neko 9-14 52', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF02732C-AB8E-4027-9723-8643B8136370', 'EA0658A8-F6F3-446E-902F-F2A1A03F4624', '8809371142577', '   /  28 shary', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA74923A-CBC9-4AF1-848C-E6542361D564', '5B07F94F-DACF-4FB3-AD55-B75E4DA698A2', '4603726763103', '-   /   f 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7653C3D9-1319-4D0A-883A-1C6CA6D2F6D4', '658266B4-0BB0-4083-A1F1-4FA434EAF741', '4650001790712', '         150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39114462-D791-4BF1-9824-E14E0B3E7EF1', 'A4F1CD12-12C5-407F-8FDD-76A1EEBD7624', '4627114711729', '  /       5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F71A078A-584E-42ED-84AE-078F4D586630', 'A53DD4EA-0CEE-4067-A195-87C6B09BBB89', '4607008131116', '  1000+62,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76926058-147A-4A84-8FA8-CECD889603B8', 'B907B039-9DBA-4A9C-BC66-87D10184FFB5', '4607166380104', ' 350 - / -   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52CA640A-759F-4983-B99D-10FF388725C7', 'EDD23431-E52E-4D53-B538-7EF27ECC9C20', '4601654001274', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BE81068-1155-487A-9643-0B3D146EE58D', '9D2A8678-A21A-4CED-9AD6-41A8D30E5D87', '4627078983545', '- / -4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D4084DA-D61B-47B4-823F-50705A135271', '2B0EC0FB-CC54-43DE-AEB8-8F985722E99B', '4030142016948', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AB6A690-0916-4991-8997-7803B4B794E1', 'DC1F52F0-B021-44FA-A1A4-3FD6B422CBF4', '4627079830671', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85CF4998-259B-475C-B900-C957C192C2C9', '07988BEA-5B2E-4D95-BC26-5422A7D9A1FD', '7331709100016', '       35 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCC125E0-708C-42ED-B364-57802F4A220C', '68F9409F-61BF-4827-90D2-B2E1F113AED9', '8712400764285', ' -2  6  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04FD2A92-02C7-40D0-9D5A-09E351D33E61', 'C247E35B-12AA-41F5-87A8-A7600DE3047A', '4605658050061', '    2 /12045/ @', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBC586E4-ECCB-42D3-9F30-567A77973306', '01867301-F95E-4AFD-BD78-9C427248349C', '4620002180416', '   0,2 /  /-01/ -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0ACC40C3-BFAA-4766-98EB-A25825875371', '384EF892-860F-45BF-B62A-B99D1E762C47', '9785699976447', ' -  . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62C0CA8A-8477-4790-A33D-021188023C27', '9C340298-94C4-43A5-9272-CDF9D1B78A58', '8901083200122', ' 200  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03990EA4-C9D2-48A8-B4D2-F04D005C7B48', 'F15C0115-4C3D-4D27-83A4-589D14254315', '9006968008363', ' 5+80  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0C3DA4E-262F-49E1-8790-7EE60F215DFB', '0E0B4B5F-19DF-4EFE-BFD5-6E7101090A84', '4605658150013', '  .   . /15001/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0986AE66-72AF-4127-8890-89EBA1868FAA', '6C00D961-91DF-4403-A018-E6887B25F24B', '4606144007507', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DD0EAA1-FC64-406E-B2E8-0C3D772DEB85', '4CADFCC8-3656-4CA0-A3E3-E854DF130B66', '7630014918430', '    6+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22157745-6B80-4E84-92F1-0477DACF3C78', 'AF3DAD24-D8C4-45AC-9B86-E6AB85F749F9', '4620771240014', '- wr-221', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58D1BBA0-8F03-4DBA-A016-C554A6A951A0', 'A3208030-43EC-4384-9E99-52528A588B86', '4009932559064', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68BC1916-69E1-4470-96EB-EBC95FBCE34E', 'FAC4C68F-493D-4FAD-869D-CF2EDAEDAA10', '4620006945967', '       6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B3C07D1-BA90-49D6-8B61-67630B64E461', '60EF9782-A28E-4EB9-9D09-7F634A0439CF', '3850343028943', '  5% 60 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96048263-BE4D-4619-B2C9-19041E38E90C', '1BBE9EEC-BC1B-4B9F-8949-E186381A0F46', '4670008163685', ' 100/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('990D91AB-4F02-486F-A3E9-A681200C12B7', 'EAE0BA65-882A-44ED-A8D8-451AD85CCDE5', '9088883772055', ' 20  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9471672D-69A0-4CAB-891A-5FFBF98268B2', 'D14F0C74-0D73-4614-9A54-E487D0F15069', '4603014003768', '  /      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03974AB2-AF79-458F-9C7E-5B8EED8850B0', '6F4B9B09-4C8F-4715-A538-DF677E92EF5D', '4015672103214', ' omron peak flow meter pfm20 ///', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23EBB5AF-8338-4FE2-BC63-FA669CEE0F5E', '2DE04668-55F6-47FB-8248-274550AFACFA', '3574661376226', '    /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C37D7F57-2EAB-4C35-87CF-8A193CCB09E4', '5306C799-C388-45A2-828A-1048D9C54027', '8300961775217', '     70  12-17mmhg   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CDD968E-2FE4-4FE7-943F-6976E5EC2B7A', '77371AF6-7077-4160-9AD4-24CAE6F2E978', '4607174430730', 'Natura siberica - /    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A903E4BE-63ED-4188-BF09-55D335B09ADE', '86C1BE48-2342-469B-94F8-6F8A74AD46E3', '4670017923034', '       45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5120932-DEC1-49F5-A3CA-5DCA243E457F', '0F7EA5E9-2B79-402F-9387-A17B00B3AA11', '4605658110307', '     6+ /11030/ 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BB1DD23-ADCE-417D-9499-4A385F313BB1', '82CD7D79-0157-4C32-835A-58C3ED932D19', '4627079830275', '     250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C10E7680-71D7-43DE-B9F6-DF2346C8BA21', '07462752-C37A-4071-BA6C-9AC6AD6395B2', '4602656001262', '  20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F133E177-060A-4D51-AD9C-8232C701B9F3', '030A63AD-95B6-4B82-92EF-329276E3D716', '4660013570240', '     /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('389B42C7-3FF5-4006-B572-BA824A29A4F4', 'C995C039-3EA8-449D-B9B1-2335D7BF0927', '4630015180204', '    30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC8BBF1F-9C00-4638-8EE0-B8EB006DAE35', '8046F509-D94E-47F3-B3DA-E371382C7932', '4607131042358', ' 20  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21DB367D-518D-4CFC-BE88-BA0218C6BB98', 'A292534B-5811-4C18-A695-652680CA2FC8', '4605086005336', '    30 - m', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8C6C011-50E0-49B8-993C-6E8027430C99', 'A918A4F6-E24D-4AC8-A5A7-A81B4377831E', '4610007620048', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4339411-FF02-4941-9BEF-A9B74936A81C', '74DD48C9-EA12-4F87-A299-4072472F5065', '7640123862067', ' ///  / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1945CF2-3CAF-439D-B701-16F2EDAF5C9D', '7DB3073A-1823-425B-92DF-8135F9B272BA', '4601808010824', ' //// 2. 1 - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DFEC329-71C4-4B8A-8FAA-0B5E2ADB3950', 'BFD60045-BC70-4FE6-B856-02C2E13DD795', '5413973242493', ' 50  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B613DEE0-3710-4C2D-B635-E41618858FBF', 'B2962A6D-1962-42C7-AF26-9BFBF2E3B152', '5903407183169', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02DB830A-D464-4BCF-9E5F-B74332F57A49', '74993D84-A52F-4275-9DF3-73F285624896', '4602606003711', '-  /,  ,,/ 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A8C09EF-FBEE-4E3F-98E2-63B40BFE3E3A', '5A920E7B-5E8A-43F1-B043-A27E36B201C0', '4620002185091', '    / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F26858C-A852-4E63-A7E6-A11A6997BACE', 'A1B5C00C-7EB8-4AD2-A58B-5C027F77C22D', '4605319006956', '  /     450 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BDFDDA0-FA9C-4FAE-8E09-995C5A3D6678', '49156B5E-487A-4578-A730-C4B1946387C6', '4620002185022', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43AA64F6-3E21-46AC-A3D2-8D86A62A9745', '521DB85D-B6E1-4965-9285-F3B70B31C3A3', '4607131042556', ' 1 112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46D63151-853B-465A-A356-402F251DE1FC', '4AD719B2-CDC1-4E24-A598-EE13BB31DE2C', '4607086569221', '   /  160 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B902605-A5A3-4F34-AEE4-6256EAE8BBC3', '433CA4DE-9361-4232-863A-7F366EE191B3', '3564300002111', '   20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB0F2795-B5D0-440C-AC30-74919B5F131C', '9B6CFC5F-5562-4675-94F5-8826BD72BAAE', '4670012600282', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69F06809-52C9-416B-ACAC-F766ACC6ABAD', 'BF95B113-FA03-4C81-AE2D-5A96DD66051C', '4627078983590', '- / -3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3111512A-EA09-48B3-8EA1-2E7C7942369D', '7BC2062D-C524-438C-8F82-F39B0D3814AD', '4013054025222', ' /  140  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9019F00-DC7B-4828-9933-8A81350A0024', '44C924AC-93BD-44BB-966B-31AA70F0BB8B', '4620002182816', '        250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5445050-32EC-48CB-BA35-265DFDE6362B', 'B843177D-1754-4B02-91ED-200D9CBD06E1', '3282779354639', ' -   /c24780/  500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFF19801-39CC-4081-8A8F-A6D69C2721E3', '2B080F20-107A-4176-AF5C-DD3B8D73316C', '8887786800039', ' ld-250u ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF08ACD8-5515-40EF-AAB0-6B7DD9A8E853', '66434502-A9BB-4D8D-8B37-40B9BC6C0258', '4605052001515', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D47B4F38-8237-4384-A777-0695BA441A1D', 'E196AE50-8BAB-45DC-9BDD-E68E1E7F5301', '4630015180280', ' /./    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28595BD2-D3E1-4FF1-AC5B-8CFC1E76F692', '6652FF69-5BB5-46BD-A38A-7C11746DE68B', '4607136740624', '-3 - 1000 60%  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74833845-C386-4E5E-BCA2-912FCB5C1E41', 'E1B5C5F5-4690-4E7D-B490-E2399E606BA4', '5900516844578', '   s  . 6,59,5  /  5/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72C99FEB-4D4B-411D-BFDA-5212328624C7', '09B3A384-5DD8-45BE-9D46-3D39D79B139E', '4607003248833', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE70687F-08EE-42CB-B854-8139F89D5AEE', 'EF4B23FE-7477-4FB0-B655-CE57FDA04B4B', '5903407232577', '   6-18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA4D0000-B75A-4147-B369-577EEFAB0246', 'A9101754-23D1-4342-8EB6-1D608431BEDC', '4607076080019', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('365B4718-39AD-42AC-AA28-7AF21B8F1FDA', '3116B2AA-2EF6-4DDE-AEBF-A342E0E491CD', '5701780888936', '63000 2000      15-60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('223771E1-85EA-47AF-B689-1C25E1C74BD7', '4BAB90BB-5659-41F0-803A-A4DC4CEDEB74', '8030009401111', '  -   6  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92E5D2F4-721D-464A-B15E-CA83CE67D4C8', 'F3D08083-7EE5-45A7-9CFE-8C05F95D1920', '4602866010511', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCE6DBE4-0337-4BDF-B584-E62C1B0AEB10', '347F5208-BA86-4018-9EC7-E82DF982647F', '8300961874996', '  140den s4/nero', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A336A583-4162-4805-AB78-5DEA99F375DD', 'AB8F18F8-8AC0-42BC-933C-F7AA11178A39', '2000949744261', '    7,5  8- 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6A337B0-6D74-4085-A84B-C40B18D3435B', 'BA036CD2-62B7-4C4B-A00F-C68597AE3865', '4605871000102', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D41B0F96-135A-46EE-BA88-BC39D1956F0A', 'DD2D38D4-5D29-40E6-9100-49C07C9538B4', '4603720177043', '    4    1,5 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63129B90-D7EB-4A2A-A5CF-414D49F59F03', '28698EB9-C743-4E0E-B293-8A7A51CA1B9F', '4607027763312', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1EED6E2-67FB-4602-9073-3AE48C0E30A7', '19C1E70A-9D49-4682-9D0D-3357568ECCD4', '4084500283695', '  - /.   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC4E05F0-19F8-45A5-8086-21C82F1FBACE', '66C8567C-720D-4E9E-B93B-49782F101850', '8001090604040', '    52', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DA9B9BE-10D7-4088-90FD-19850C2520AD', '18F652D6-9358-4B9B-8521-A064C2132C8B', '4680007632396', '   6060  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F9A6689-0BAE-4CD5-B8DE-30EF034CE68A', '32077AA8-67CC-4663-A0C8-8525F645D3C7', '4690419012990', ' -4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EF0449E-F53F-4222-AF27-75F6521A7B07', '31069C1A-F266-4000-B434-E47BF612A8B9', '4605446000216', '    / 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B86F74F9-250D-45DC-8450-978AA9FDA64B', 'DEB67992-BAC7-4A62-8B85-0D9717861028', '8717775823698', ' /.   1-2 . .   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A2C5BD1-42E1-47F5-8D96-09D3C2E67E59', '5373D106-3A34-4135-A70B-C3D0B9E5823A', '3582910082477', '     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C839B18-DA98-40AE-85E0-657629FF8BDE', 'D2BA351E-57A0-48C2-8F2E-4BD8143C88D1', '4607053660241', '  -    295 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABDF82F2-EB2F-4FDE-8570-8EBAA2CA648E', '58734EA7-69EE-46AA-9F2D-3404A828DCB1', '4607011664045', ' / / 44-46 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A762CE67-9C20-405F-BD40-CE11D4C648D3', '51FFA881-A944-48CE-817A-287F6F732CCF', '4680020230708', '  250  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAE412B8-C553-4230-AC6C-05AC8402C87F', 'BC40BB2F-052A-403A-B295-E55F910CEF2B', '4605469003720', '- 100  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15EF76D7-52A1-4E58-A40A-D7B9FC4B6E48', 'E7DF17C4-F62E-4C9C-8AA5-CBEC8FEC85DC', '5413760054025', '  / - // 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD8DED8C-FA9F-4EBA-8E6C-D93392B90E1D', '3197EDC5-C4A3-4592-9A88-D5335BF48190', '4690567008357', '   2,5500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('142A307E-5D13-455C-9DAC-E81F0CD9BA03', '3D68ECCC-6F68-4B6D-8281-E76B6CFD5CAD', '2012042000519', '  -14 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F89C102-C4CD-4DDC-B017-258C1A199DC2', '99BE85B4-3CD7-4B81-A590-E2B689465D02', '4607027769796', ' 50   / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93E5A34C-CB2A-45CA-887C-6A2D7160A277', '24A92172-035F-4785-950F-E7E6CB1FAFBF', '4013054020661', ' 1000   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('977266EE-89AA-44CF-8609-58055438DA38', '967B6FFD-E076-4170-B950-CBAB5BEF8B4B', '0000000000000', '  .  .  .  5  5.0', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E00D17D5-F78C-4E38-831B-A27681220414', '39F87A72-4E3E-43D7-B9B5-03B405A81931', '4607136740549', ' 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF253A96-08A2-47EB-9503-DADB143AD2C2', '785032AD-025F-4338-B2FC-6D4DC76C3D5D', '4779033720044', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('894AA8B3-B337-4011-B824-7C44F06007AB', '4F83951B-6430-41F0-8801-4E1B332CA681', '4605658175337', '  6+ /17533/ 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E03F908-67DB-4A7D-9116-EC59EB39971D', '619B1707-568A-449A-B89B-1F4A6E81DA59', '7640156395501', ' . .3  JW-216 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73031A77-F783-44D2-B94C-461F3405B7DC', 'C2C546A8-3D0F-4917-A33C-68305557D3B0', '5995377010866', '/ 0,000625+0,0025 //  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('420C4E50-AB15-4023-AF21-A7ABB26E2F85', 'E0D4C758-4BA1-435B-81F0-C16893D565A7', '6428300093159', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9008CE7-CD5D-4DC1-B25F-CCCF060A70A4', '3128F6F2-4C30-41DC-AB75-EF8A025EFA04', '4901301230843', '  6-11 64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('032443CE-9D6C-4491-8EB7-3C0EE6463020', '18578F7A-AEE2-465E-9169-33B3683E404F', '4605258002682', '  0,9% 100 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B457EE79-D675-4A50-8D73-DAAD25D6BE8C', 'A34E198A-2C07-4D46-9742-81F4C6301FC5', '4601808011777', ' 60   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2B2C1B0-E5C6-4C5B-AE77-9220A62C12C4', '2AA00C42-618C-4A18-9889-81406578D348', '4210201746324', 'ORAL_B      Precision Clean EB20 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD64F22E-13FE-4E88-8D9F-B65E3BAC74A6', '37084E79-C309-4E2B-BC62-23BBC27EE74C', '4607029291424', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD0C5FA2-7102-4592-9BA9-404CD40AB6B2', 'AF2C624B-CFCB-4B9D-B4C6-BAA8DBC6A6D1', '4602606003759', '-   /,  ,,/ 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35CB671C-63B6-4021-96FB-4D5F1C0E64B9', 'A21817CD-63C3-4602-B033-3D30EBFFA4BC', '4607034474072', '  /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('999CB02F-AA0B-4C88-A792-4EDF5747B1F5', 'A35D5DF7-63A6-4912-A99F-F64112EED71F', '4650001795380', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F15A0F28-AD84-4CD5-A30B-C223933C492E', 'F602545D-A7F5-481C-9F12-A536E4B23322', '4026600682701', '  // . 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FECCC467-9441-490C-92F5-7A4E0DA9DB5A', '48EB6478-5470-43FA-86E2-4D61F39549ED', '4605964002716', '  /  2 2% -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('050941D4-DB18-4826-8E1F-51016856528D', '97B34FF6-67AB-4C85-B386-7746C6C3BC98', '4607101201693', '4653/144/12   "LUX  L".  6 .,  ,  , 2.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E2C000C-1E60-4B76-9277-AEE2F6DBF476', '4E03A994-EA99-47A4-98F6-DDDF1BDA1223', '4607061790596', ' 100  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F29D1DD-7006-4DCB-B662-F94E8AC6ABD8', '2E878D09-1D08-44E5-AE4E-57CF3D9325D3', '5413895003523', ' 0,5% 15  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2106CED1-4B94-4FA5-AB70-52BF0C5DBE26', '9B629AAF-2ECD-439D-A2B5-54C96EB285BF', '4607025843023', '       5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7681199-ACCF-45FF-9640-612FE0C194E3', '19241C7B-87C1-4E26-AABD-877530EFA413', '2012042000571', '  2- . -10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02E348CD-B904-48F7-A9B0-DE806FE78DB6', 'DC14D593-124E-4F7E-8FC7-6724F2E7FEE2', '5450557005617', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDABAC12-40FA-4CB7-BE84-76D43F4D49DF', '1F86AA66-3936-4748-8F36-C9D049B1ECD2', '4820153892699', ' health    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5BF825F-9ADB-4089-8597-C6728FE8E512', '5033D135-6A54-42B3-8013-A30BB4C96CDA', '4607020904859', '  35    2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92DE87B8-BD6F-45E1-9580-17DBB814E3DD', '16139BA0-6869-457F-80DE-6692029DBCCB', '5060105142314', '    -1,5% 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B33A710-938B-43F1-A4C4-6C12BA41C8E6', 'B11FDEE7-4401-49E3-8186-3BF409F945CB', '4820121901521', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3383F124-6777-4320-A633-9EE2E4E8124A', '54574255-E319-4009-83FB-C3D8743107C1', '4003583189144', '         5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E286FB0-832E-4FC5-92C7-35C99485A674', '0D5E281C-3D10-4B93-9660-C0F38FFEC281', '4620006245579', '    . 1, ., F-202', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5477070F-AF0A-4CEF-9C5B-8C97565E7942', '933F33BC-3404-4D1F-B1EB-6D9B6A852B15', '8904031201844', '  400  / 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55802B9F-47B2-4DBB-B07A-9BEC025E1A2E', '555FEC0E-3866-46F6-9724-50E0D9BD783D', '4627110263710', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C34423C-7F3D-4AC7-BE16-C92F325B811E', '0AE7FE3B-0C02-40E9-AC17-A79978891AC8', '8427030010717', '   // / 3,75 2  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C703353-8E10-4A79-81AB-19DB71CD5457', 'E06309CB-6084-45B0-97EC-60E4F937A258', '4710425924442', '  / . 70den', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECF40963-B59E-4D83-A7FB-0FB5A6A027DF', 'AC309CB6-7150-4523-B38A-FAA9E85CA960', '4690655017896', '    /  400 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F886553-9D5D-4A89-AA51-0AA4421996C3', '2BDD9D55-E006-44B7-A47F-D16826CDDDC4', '4630015180105', '     200', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B142B54-B365-4E42-8AEA-41BA3690FF11', '05D84B7A-28D3-46FE-978F-3A4B12E74999', '4640013558011', ' "",  0 ., 5070.16586/144/12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C98B09E8-149D-4632-85F2-C79630E97AAB', '1E7732E3-F59F-4DA7-9BFF-7BCF752CBDFF', '5060255354490', '     90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EFBA0AD-4277-4352-88EF-6683AF3B8733', 'A9EA3586-B62B-4AE8-B478-AF1E257B2A17', '4605059010244', ' 5    /     35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB91E60B-7CE5-4ACD-9F10-F92B46579B16', 'C57E67F3-D2F3-4692-85C9-7A319E653A54', '4981046050470', ' ua-1100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8C6C20E-6655-4BF3-A1A2-2F6D82C012AE', '6768E273-DE01-4E4A-A45B-1D7FE7F98940', '4600702084634', '    0  240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C26E6C0B-05F7-40CF-8478-B115DB8FADE8', 'D81700B5-451C-478C-A573-B590A1DC49CA', '4811379000258', '   /  / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7362248B-D203-4D65-98D4-5B51348B75D9', 'DF40D91F-42FB-4087-8AFB-9F3284EF98D0', '4603014003034', '  /    /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('227BA80A-0D8C-4065-8567-ACA4F0CB942B', 'CD97C2CA-35C0-41FD-996E-6C367B62DEAC', '5391519921654', ' 2  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD41A1FD-AE61-475D-857F-88BB620FC692', '04129F8B-015A-4898-8986-D894F2F87965', '4605658171124', '-    6+ 300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8E3CD5F-5377-4BEA-B646-75C3A0CE920B', 'A344D9C7-0ACF-45AF-B5F9-0877241D01FC', '2012042000588', '  2- . -12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5A3D4D9-5FB3-47CD-B63A-0D6FF756264C', '9E83545E-6ADE-4687-8CB9-FFD86DCBCEA3', '4560273810141', '     3/s ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E6BA812-85CF-42CF-B205-58E114D1627E', '0417706C-4CCF-4417-9524-2E0682DE62B7', '4605518000649', '  /. -  4 5 5 / / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D77F438-3423-4460-B168-51963F556C36', 'D4C81193-F64D-4D78-82FA-7322BE65875C', '4750232005149', ' 15/ 1 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('639A55F2-D86B-4F5E-BDFE-03DFD19679B2', 'E1AC363B-6C81-46E8-A991-21B3FA0440CF', '8300961753994', '  70den 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('782F5A84-2016-416E-BF19-64185E5126B0', 'B9A5A2A0-B8C2-42BF-BFE8-F419CE796A4B', '4605180006895', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8BED28C-5E22-44D2-A0B4-D0ABC8878960', '39E37076-BC76-4AC0-AAE4-682991E4267D', '4607010247812', '     /  // . / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FE12013-CA87-4833-8523-0A6C1B686508', 'D130A570-4521-4472-A006-028EC9A5861E', '4605994029851', '    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDEFEB12-9F3B-468A-A226-A71811835429', '5201FC9A-1191-461D-9029-F40E35B00D43', '7640128544623', ' 2    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9265C407-A312-4103-AE36-8C57D4C626BE', '5DB45375-0DB2-43A8-9486-A298E2E57ADB', '4640013550022', '   /13949/ 4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36CC9D3C-FC68-4C25-8763-AE81EB663D99', 'B86A35FC-544C-4444-A88D-6E49745BFC0E', '7322540599961', '-  +   /10-14/ /2652/ 16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0289942-3782-4EFD-8C2D-23DC99951231', 'A6CEA48B-D173-44DE-9571-7CBA19E0496A', '4034541001123', ' 600  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('822C01C7-426F-4494-8D32-ABA42AEB77A2', 'E2E35849-C417-41D1-8BF0-54230F3E8104', '4751023298771', '    4/l 7-14 44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A5554B9-FF5B-4F0F-92FF-3C8FAFE9A577', '705074B2-0DBD-4F70-BE2C-53045B9BF024', '8887786200471', ' ld-23 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A9CA72F-254C-466B-87D7-42BA9BA3237A', '5194A0B2-12A2-4B9E-A3FA-BD2A15E1B004', '6428300091759', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50E8170C-4342-45EE-8CDC-0EA147351EBB', '73DBF1B6-0991-4882-8B54-B7D387D830E9', '2000949800639', ' /  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88CBDDBB-5C95-4763-A185-F6D6B5A16467', 'D26C4DD0-EDFA-4E82-BCDB-2AF135A6C0F0', '4605108002817', '   / 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('017A73B9-1858-4B03-A45E-66D2032535AD', 'A8E3AD17-3814-4404-A211-E0E48D47639A', '4030841007766', '- one touch select plus 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F19E145-A7EC-4EF9-A269-093296375D8B', '0F6E8655-3297-4FEC-8066-7195F20A99C7', '5701780492669', '4720      60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23983703-AE9D-4F36-B16E-4F7B37A83F92', '474FB0CE-898A-440B-9DDE-60B6F7EB60DC', '1705770151042', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('975B066E-5ADA-4D98-9B4C-5EFEA008440C', '87E56E30-6C92-4ACB-99C7-D62755FABB9A', '4607011634086', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0C3237B-7A6C-44C2-8853-C1551249AE97', 'EA07AB1B-2111-4589-ABB0-FEC69F3DB90E', '4030674002112', ' 300  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FA96D15-AE74-4640-8346-3D2435890B94', '9291AA00-DF67-4843-B5F2-2CA58578FC3B', '4602242005247', '  0,1n1  //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63614E69-8F39-4B89-B011-78802D53683A', 'C7E152F0-0EC9-40CE-B4F4-693859459D7C', '6938697600071', ' /  attest', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36CF1658-DA58-48CC-BCE4-C92E2F86EC1F', '054E5DAE-C07E-4691-91B2-CF45E9215A12', '4680008980281', '   / /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FB678AF-E02F-416B-9CF9-B5D73FC2EA37', 'C8AAB43E-2C25-4CDE-93BF-A8CC91A7E465', '4601669011978', '   30  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D035C4E3-84A6-48A1-A189-0655873F3C6E', '109DDCB9-D3E4-4D07-AB67-7739C40A072F', '5903407225180', '   6-18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39F7CDDE-C62E-440B-928E-DC8B44279CED', 'D8EC3FB5-739D-4B18-A4A8-9E17B38138FA', '4049500112994', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38876B2F-5467-41D2-BAD6-35D0C5768091', '66717250-3F40-4302-B8CB-AB4F48A37B81', '4640013558998', '16989/144/12  " ". , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA11399E-98E6-42DA-B71F-A520D0531CCC', '4DB4390F-EEC0-4E4E-A909-D25594DE33B6', '2000103612559', ' 13/109/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('549D8A12-F3F0-48B9-8900-B96B6623CD6F', '0639E46E-94CE-4614-9F29-CAA41F4531AD', '4606486026303', '   / -  3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('923FD4CC-1FB4-465F-ABED-D8EB3361BB0F', '40C32301-E440-4A36-B426-903EC4F7F4D2', '2000103611088', '-   0-6   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCDB1C5A-5D6C-483C-930A-F67E58DBE394', '4D1BAC1C-3B8D-4EC1-BE47-8E486F90EB29', '5903407026145', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62B69A5C-5F77-4F24-B38F-ABD8C4FB9092', 'B72F4C66-EDBF-437F-A7F4-173C3AAA29C1', '5903407232225', '-    space 6-18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D92D0E37-0A6B-4F03-AB13-FA11FFAEB3B6', '5CFF1B90-4EB9-46AB-AB3F-17FB9A78E2F8', '9785170887330', '   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5651DF24-674E-4785-9812-62809383499C', '57A84EA2-D6F2-4676-BF15-DBE8971C375B', '4607078970639', '  +// 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97A86D64-07B8-431D-A988-F3CBBF7B981E', 'C33A49C5-D885-42EC-AE0E-3BBEA01E34E2', '4602206001544', '  100/-3  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5612619-B76F-4C24-A984-DEBC627D5A63', '56FC0D87-6A13-4180-9D17-50C5E263FA8C', '4680020230715', '  250  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C59A82E2-B613-4FBE-8064-F34A4921E810', 'DF0AC220-F6B9-4CD0-8A45-A165E3F72C0D', '4823060801556', ' 12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2F1F077-7125-47AF-BCA1-87F703092B09', '4BC3D55F-F846-41A5-9A08-EC34A0C6420D', '4640013550084', '      /13952/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9583AAC-9549-4CB5-8B0B-1F3D56A9E377', 'B8C79F35-311D-4042-A457-D4BB2CEB2250', '8001090586315', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1428176-F0F0-4FC6-B00F-0B615104FE83', '62736833-44C2-438B-A306-EB3B1B2C6FC6', '9001434718012', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1B306C4-8D61-40D2-9736-19B40B0308D9', '8780DCD6-26A3-413C-9791-287C3204AF10', '4607077091687', ' -  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F74A07E-288A-4D8F-B0AA-8B377DB9C029', 'D897B540-3193-47A3-A622-9E872225E309', '4607066410512', ' 1,1 500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADE5B9EE-7FC2-4E3E-A8DD-DD40E0E15709', '60CC2182-89A2-47C1-BB92-1A07D8A8292C', '4250369507665', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DB370C9-7568-47E9-8909-8EAEBDFC0B77', '8172E3A3-4C64-479E-A2F9-86845ADBA96A', '4620006257213', ' - "". . -203', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CEEFD76-5642-46F8-B05E-D43AA78FCB0E', '3F621378-2030-42BA-96FB-036183D09D70', '7640156392210', '     2.. .4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58E8A255-9A7B-442B-AF21-F2CC1C256614', 'F3C549CD-4846-4D50-978F-893AF3EE4103', '8901783008172', '- 0,1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D7BCD0F-B0A9-4E0C-B5DD-8227CB4DDE0A', 'B0F324E6-192F-41FD-B72C-9DDB55E676E6', '4602866000956', '  1555  5 (M)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4A9978E-112B-43A9-B755-33D9716D73FE', '2F186FF3-5979-4DE3-88F7-AB6F16EC4951', '9785699949786', '    .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE05045F-6AC8-4DE0-B260-53B8D3935731', '33ABE38A-191E-451B-9E53-B9C6816DCF4C', '4607066260117', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98714E27-20DF-4E6F-B126-F1096D8CF67B', '77E3F953-2AF6-407F-AE9A-C0F375A99893', '5900008011310', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A037408-EDD9-486B-AF22-416226C5DB53', 'CEA42A57-B786-410B-A6F2-B41E00BF2E39', '4650069650607', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6577C12-3296-4773-85DD-92EC3202A949', '77D29533-11D3-4A2C-B27C-91D5B8568442', '4605658112141', '   125 0+ 11214 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E1C5C23-DFB4-4997-BBA5-FCA5126351ED', '86694E1B-4CAD-43D5-88A8-81DB6DAFF23C', '7640156390124', '  //18-22   / 4/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D51A3081-1F26-448E-B369-6650EBC99B48', 'C39D1142-4496-4209-A1C6-D4ADDC4FC0DA', '4751023297231', '     /    - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB7EE805-519B-4323-9D36-5DF9B55117D6', '538678AE-0280-4884-AED2-EEAE690FDED9', '8902502117403', ' 250  / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C65B023D-C30F-4526-98A0-F10D5D15D5C8', '726044D8-836F-4F4D-B804-7BBDE55F7CFB', '4607011667350', '   / .  .    . 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35BD1B66-CAB2-478F-9574-592C159447A2', 'C21B72D6-1B71-4850-810D-3EA11A20F01E', '6921570930969', '    /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BA5C055-9A9F-400B-81E9-CB328153AED7', '0BF5F278-914F-4CC1-A254-DCC906E62974', '4690655015014', ' 50  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFC79650-788E-4D3B-930C-EAD53A83CEDE', 'E05EDBDA-4D1E-47AE-BC74-4E70E6E6B442', '4627119620095', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3F11DBB-B887-412B-9345-6B38F02E2212', '3063B94A-6428-4ECD-8040-E3AC7ED9A03B', '7322540630381', '    XL (120-160 cm) 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F23126F-AD6F-4CD0-87AE-CA09D578A0BD', '852FB9BD-C5AE-49D0-9010-3C2F4BABC1EE', '4607043671301', ' cs-404', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D98ACD2-E157-48E1-B638-D7F1ED1E78B9', '0EB078CE-34E6-4F44-8835-B2048601F04D', '4680004853688', '    25 % 100 *', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39000CDE-5F49-49C3-B7EE-AE49B8A89643', '892C2A97-464E-4714-B18A-41AA0031DFC4', '4605890000411', ' -  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49360A89-D9FB-41A1-A5EC-7A4A2F0B6990', '9635CDE9-25F3-4512-AA66-794D56CB8D27', '4607008160154', '  -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B5AB6B8-E206-4C5D-B481-167224AEABC5', '465DE0CD-AFD6-40F6-B02B-FA46030210CA', '5903407217208', '   /     +3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56870F18-F620-41AF-9177-B2C0037A3622', '7A5F2D15-FAA2-4B4C-B839-0FD71C9101C7', '4008600248545', ' adore -    6-18   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1A18B85-2DA9-4C70-8A2F-D312F5094FF6', 'C4D5A000-25A5-48DA-862D-BF7FEA0F40C2', '5903407225630', '    6-18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D9661E6-FB5F-428E-A37B-A21BFA252A72', 'B7EFF38E-FE7F-4545-A237-76C198C7AB1C', '4631136742807', '  -  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('419036C0-D903-4007-8D78-8C56270EA105', '8B76ADEB-575C-4653-B025-167ED8F8C6D3', '4612750380019', '   -02,4 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CA9FAFC-4CB8-4420-AB89-03C581940CFC', '507B5C3E-46C0-4666-8BF6-FD424DEE03EE', '2060130184993', '    /  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCFEF583-3D2A-46DE-A525-8BD99DDA207A', '1F34E5D7-7ECB-4B0E-A700-32DBCE770F4F', '4605658131463', '  6+ /13146/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97338123-13AF-4B28-A93F-7C0BAC73DAF0', '511C5A65-AA27-4D2E-AF64-F0E557FA90D8', '8710103787259', '    / 6-18 . /scf182/14/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CF661F1-A317-4F5D-94FD-6B0E001F69A1', '97275BEF-62A2-4224-91E4-8255B539E888', '4627079830251', '     250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BE64F9E-3ACC-428E-A751-F1630E8A1E7C', 'DC3CC5DF-2AB8-4402-AB9F-AD4780E2AB91', '5903407225692', '   6-18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8114A0D8-6972-4491-9055-238A6B3E900F', '19D6AC4F-AC9E-45A4-B958-D4F785E2C0C6', '8594004692658', '   360', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAA2B57E-9056-4867-88F4-E4C78D7B229A', 'BF685B7E-6DA6-4DDB-B372-A8551AFBF178', '3582910005407', '  5  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EAF7858-F571-4E5B-840A-9BD15D2A9072', '4BCD0EDE-E4FB-4B58-8A12-9D69961FE1CE', '4603014002051', '  /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76ECC219-A6E8-4CF7-BD6A-E4934DCBB00C', 'E4450807-3D8E-4C0F-9333-6D59BC04FF71', '4607102010409', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62FB14B2-4121-42FF-B686-E8ED7F7CABCF', '307911F0-154C-4BB0-9839-FE3D834214E8', '5907506237839', ' /- droplet 31g 6 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB34C76E-10C0-4BD1-98C7-57ADD79DCDAF', '95DFE91A-154F-4F83-A4DC-05855144AA75', '7640156392197', '     2 . .3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C0AEA18-C417-4B22-AB2D-9CB9278011C7', '2CBC0031-113A-4086-AA44-45AFCA7EEF0A', '4607020904231', '  27     2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D81BC705-30E8-442A-A527-D662B3D36169', 'DF84F019-45B3-4BA9-AE90-F5668D81101C', '4601774006197', '  - 10  150  /-306/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11B9CCD5-7B2A-49C1-B44C-B954650EBE6C', '0C64A25A-E9B8-4BC6-8F92-93BCA40B0B40', '4607020903296', '  13     / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EECAE9A5-66D8-4E66-BAB7-844C0DD2E6E0', '6EF31A76-C758-463F-AD56-CA865BDABEFC', '4601808012729', '- 0,00375  /  // / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB8D8B62-D176-4C86-AA5F-8D3EDEB0E76F', 'C497D71B-09F3-46CC-973F-1C0465B2DAAB', '4620002185473', '     4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BBF2F38-72A3-4633-A411-E99C4B80C2A2', '3222FB08-65CD-4749-A71F-28104FC55B49', '4607061252650', '       35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B4031F3-FA72-4129-AEBC-D98EF0A14B9E', 'AFCB6256-094E-491B-8A8B-23E06D8A434F', '4030674014504', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB8664CB-66C7-4CDE-ACC2-E84BB41A47F1', '3D937BE6-7440-4BF0-AF86-6EA33D3A7D05', '5391520944765', '   +-  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20566784-346A-446A-86DD-2DA8FBF2C050', '3CA190C7-CFC3-493A-BDFF-F68C7FC72C83', '7640102780344', ' 0,05  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55677E07-01B2-497B-B51F-F03F6623D83E', '002FE8F4-522E-46F4-AAC4-CD0C97732821', '4607027769819', ' 50  //  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13569A91-18D5-4580-A66F-C8A63C75FFD9', '98A86853-D5D7-47F5-9BD4-27401B4DE74B', '4650055920219', '-   c', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30F4323D-F4C6-43CA-A9D7-32BDFD7A2D52', '6E9407DE-7750-4988-B3F3-075D37840CBF', '4690624008764', '     6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9844DF65-92BB-4480-B095-1023D3844184', 'BCBCFB1F-1F9F-4EF9-88D1-B4AADD274F3B', '3594452300025', ' 5+10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBDCA9E5-8827-4711-AC9C-B2CC34D31C2A', 'B2DA7FFD-5CE9-4C0B-84E2-C32F870A86CD', '4601811001376', ' crystalmatri-fs  /5n5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8646C1BA-37D4-47FB-8B47-3979B81F43BC', '4D093B15-C2FC-4716-AFB4-40E0FA459AAD', '8001090430588', '  .       16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27573591-6E9E-4C38-B150-724C57CCDE86', '585AA499-23A9-46E9-94A6-5B1EF1F39162', '7290102062911', ' 1  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC8040C6-DD6F-4B11-8BEB-A28DF5F6044F', 'F7FC8E14-5750-4409-986C-5242B341CEF2', '4670010371290', '-   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85F27252-36CE-4212-83ED-6D62EA8E3787', 'C421BE4A-F145-457F-807D-BF7D3F8516A2', '4607010246907', '   - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26186440-3E00-4D77-9709-45236EF80DBA', 'FEA6FEA1-D89D-4F5D-9C67-27CC44E74CE6', '4602887000041', '-   / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46C5F8C2-D7E6-405C-AA3B-286D93DC1D8F', '7D31A59C-1F06-41D2-BCC6-54240709D9F7', '4623720846930', '-  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2B59237-4AE0-4DF4-B9E0-A55C578914C0', '5FFA7B29-73ED-49F3-891C-A210512601AE', '4030841007926', '- onetouch select  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('627D0165-6E31-47B4-845E-A9C6CE906641', '051A28D5-E500-4A1D-B0C2-FD3B3F53AE82', '4627129212914', ' /    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E0192A7-708A-4D6F-BB94-53C23F824652', '0914783B-0F03-424C-B602-52C76F52EA7D', '4606677023302', '   - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20A230C5-56D4-4099-8A15-2B1FFAA992B6', '983B153C-1D8C-408E-89D3-7D71BA713E81', '3800003303606', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C6DAE7D-CBC9-4B53-BA20-4D049BD19AAB', '8C466305-2BF4-43BE-8159-164E4939CCE2', '4751006750845', '  /  3.15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14BD0DB5-BEC8-4CD1-A7EB-D0134A2B9039', '6276BB50-D747-445A-B013-154A3AFDE1F3', '5411416029533', '     11-25 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6306D1E-8CA6-4900-8357-09EA6C715E06', '4CB5521D-85AE-4B0A-AEB5-152ADB23291C', '5995327120799', ' 75   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9615534-E791-40C7-8F1F-3FE4FD5F8482', 'ED83694F-1BA4-4030-9E2B-8E0D6BF47A34', '4607015598155', '  6060 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1785524-1D5F-4977-B902-8F45765793C5', '309E1C06-82BA-4EFE-8EE5-A60C71D4B4D9', '6430046750210', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B07DDBE-42BD-447D-BB53-AF11B35FD909', '28DF3FF2-B7F7-4951-B20B-B44F425F1B94', '4810133002873', ' 1% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C349A3B-9715-4D2F-8A38-546FC8D686ED', '8373F137-9527-4F77-AEDD-C5FE1943D59C', '4719003937034', ' st-77 // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B105E7DE-FAB7-4EB8-9B10-470A6B6A25A5', 'BDB74BAC-0C58-4482-A9B3-1D5855931AFD', '4600490620434', '  1     600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36A5A60B-1A34-4203-A9C3-4C4013203552', '89D3D2B5-A298-4DB2-A5CE-F1710F420023', '8300961888214', '    140den s4 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9DB8CED-5718-4DC0-A472-821B1426F1BB', '7F8A5FF1-1E2E-4ACD-B5E1-CBBBB1BA29DD', '4607136740860', ' 3-6-9  1600  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7EF0459-3D1E-4703-96E6-161CF248266B', 'DEBE7113-07D6-4F14-9F1C-3A5DF5B6B071', '4049500981750', '  55 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D83746EB-1562-43B0-A6EC-E1F11C4B9F5E', '039BC857-7A4C-4F06-99B5-C994783C5C1E', '5903407217222', '     +12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9957D6C6-6579-4053-BB48-5761A272EACC', '64680CF1-B2A2-4BBC-859A-8EB552ADF44A', '4260026691194', '    / .   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26054596-280A-477A-A2F9-6D5C60F35912', '981EC26A-AF47-4B5A-8575-106C1832D266', '3282779405553', ' /avene/  a.d  - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9318D291-CA6D-4A01-9D1D-51EC5C144619', '6782129F-6A77-4938-948B-C277D546105C', '4650069841395', '  . / / 11 302', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0B9C60D-18DA-4E33-9325-C8F29F4B6134', '089291BC-4FA0-4CA8-B43E-8FACF8D159DB', '9006968010335', ' 40  28 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C1DAF37-7770-45DC-9577-54295013B7C6', '52FD84BF-4305-4582-92BF-D0E8ABD48650', '4630000191055', '   2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51BCDFFB-6A0B-47CF-BEB9-49AD9AA01790', 'F036B218-F345-4DD6-8320-A8DE67900959', '4823000804951', ' 0,1  45 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A974570-F42C-4C13-9524-3DA668FE829E', '8C43410D-2613-462B-9786-1B2B5070ADD7', '7640156393750', '  - -L', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('339ACE58-F643-47F0-BC02-88CF51FF3E38', '218F404B-33EA-4FDD-8E08-CCD45570DD6D', '5903407232621', '   0-6 l', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36D6301D-B325-4D2C-8733-2FF4CD710D31', '9D13BB75-C1DF-4ED7-B9EA-145387D79B84', '5391523054638', '  4  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F22F89AD-A2D9-4377-B4B8-C47EBF52B53E', '311F3541-A029-47B4-943F-87D3853BB351', '4030841009579', '- one touch select  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2772AF67-D5C8-4D93-9963-56A989705CDF', 'A06C03F0-C87D-47B2-9FF5-CA971B59FAF6', '5903407239033', '     +12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E274E54-997A-4B94-B880-704C724AE7C4', '46696923-08A7-4D49-B2CA-6B375E8A91C7', '4607008132564', '  22+55/ 30  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F80C70C9-74D7-4386-A1D6-7744F2589D42', 'AD5B5241-111B-4603-AE8E-BAC2B1FC29A0', '4607174652491', ' - 1 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C61A965B-7D21-4CEF-8F8B-45F67D1B71E9', '06EBE7BF-6A3D-4C48-836A-C93CC7470D2A', '4607019390502', ' 155 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E782F216-D984-4763-91CB-6A8C0480B746', 'ED7832CC-FE11-4F13-B126-3512FC9ABB22', '4810304014957', '  /.  290', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('428AD8D4-9C5F-4873-8D79-460E19E97F27', '36495CEB-5459-4BC5-8190-3EC12D909741', '4631136742821', ' stimulate  - 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAD27CE1-68F2-4ADB-9668-2DAD75D0E66A', 'B52B10FB-62D5-404F-8060-F010ECE6AD9B', '4607159860279', ' 5+5 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('843A2C43-4113-46E3-B5D6-F160FF6D87CD', '904E5B21-5457-43FD-9D79-85B4335EEB68', '5903407225791', '-   space mission+18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('905ADF5F-39A7-4C61-B56B-CD4F0E1D0442', 'D44F7864-9C94-4BA0-9E18-1CEA68FD1FBB', '2000949909288', '     // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('998AAE8B-CA8E-4771-967B-D0E9628C1EC6', 'E0C3EF47-59E2-4A18-97D6-D77126EB4DFE', '8710103540694', '    260 12+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0005287-FE39-418D-9F3A-FC0EF8BF29FF', '002C8901-A7AC-43C4-9A9D-D03019FBF84B', '4607017265024', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8520923-5F5E-4689-9B25-FFC1C10A1E36', '05CF0A17-DC2B-4BED-A938-CA78AA5EBFE5', '4630008130391', ' 12/  /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8667B448-EEC5-4E1F-9536-B573D26E8237', '428FC8EF-7101-4C36-8352-6BCA3D499AA0', '4640013555942', '15184/144/12 -    " ".  6 ., 250., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5563C3FE-033A-4B71-98EE-23E9678676F6', '28E79CBB-3393-4798-90E7-DBF05A882832', '2000949883090', '   /         ii , ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3E9961C-93E6-4777-897E-0270A43F4464', '840E7102-BB6A-4518-86D2-F80A5FDD0A15', '7640156390469', '    3 /2  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93FBB39C-5DA3-48AE-8557-587C8BCBAE31', 'FA7E46C9-E181-499E-BACB-441BFB35D239', '4607073910043', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD3AC2C0-9A31-4261-9CF3-85C866EA626E', 'AAD87191-0D3D-45FC-8533-88BB776CF572', '4607029296023', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A54EE0F-8B6F-4D0A-975C-E67B512E8BDB', 'D9EA9E77-81F0-48A2-862E-87179F35F667', '5609069007538', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3319E51B-2837-44DA-881A-E254CF9820E1', '095D6C29-0B80-4734-84DA-FD0A3558F8E9', '4810153021588', ' . . 30+  / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E479EEB1-D4C9-46FD-B499-B8C54B4BF9B1', '611D4069-03C5-4A31-8A5C-FBF5077585FD', '4607041292447', '  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CAF5257-898C-4B2D-8A96-C897F3DC4D91', 'A519C05D-A7DE-445E-87C3-A2A876EAA9C7', '5903407118406', '  /   250+12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACDE949A-0A72-4D15-86AC-52CAD7FAE3B9', '3F5DA920-22F9-4BC4-B95D-50239A111332', '2000949883212', '   /        , iii ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11FA8574-2531-4816-9FE4-23B9AA0481E5', '0F907C9B-BE45-4C9C-94E4-0841958A8429', '4607005320810', '       2  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDBD679F-28E7-4F54-84AD-67B34661B644', 'F604BA67-45DF-4611-AFD9-F802335E41AF', '4650065230018', ' 30 5  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4B4898A-CB48-4CC8-B6E4-5DDE19BF7FB7', 'ABFECD86-A586-4D3A-8542-C1913433B043', '4607131428299', '      100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53245F80-85A9-4B26-92A6-478BD7D3EC1B', '9B53D57B-920E-4D06-B7AE-6DE43CA326D7', '4601808012910', '  60   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('445693E3-FE64-44E0-B264-8A1875E6FC28', 'B071A718-06B0-455D-9C1D-6F99DD5238BD', '4603679001031', '  0,5% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEF6833D-763B-4B95-9397-B36EAE9F46EB', '4CE6FF9D-479D-4044-AA94-23BD9D635A78', '4606486026921', '   500   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80B6F2B5-D6C2-42CC-9A5E-EA99C333DCE1', '156091A8-DE93-45E1-859D-808DDF31FEDF', '4602866025263', '  /  - L /-8102/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7414760C-939A-418F-A3FF-6613EF24DE34', '9DD54489-830B-4DE2-8160-E96DD8E22E7E', '3800003304375', ' +   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A02F9D8-C97B-4570-8887-35FCEF483832', '9C1E2B9D-E80F-45C3-8E73-678763ABD64A', '4607094174790', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC621C84-B6E4-47E0-8B57-A86E1DEC0918', 'E73E91C9-A099-46A6-90CD-F6E2BC225167', '4015400985211', ' head&shoulders      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF2FA273-F42A-4E33-A8DE-32CECBB1B1A3', '32F698B1-2C85-4B4E-BF04-43AB0E865654', '4627129212815', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70F8D001-367E-49A0-8657-0432E45849EF', '6440A608-7E9D-436B-9C3F-5E1739611BF5', '4607094508274', '    250 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17E2E157-E9A8-4619-90FB-7B9342154F4D', 'A6F9F250-447F-4D5C-A20C-FA7677CDC2DD', '4607070026624', '  spf-35   125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A40F3335-4F9E-49A0-8DA9-713CE8D88E21', '9B068411-394F-4D39-8919-8F586F4212BA', '4606982004980', '  /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8A49763-A050-486A-8082-BA02C0354AC4', 'D204A47D-35DC-4F53-B552-BC825BBA8856', '4601774006210', '   /c350/ 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11E048B4-59BA-45CC-8C8C-CB0EF4E6D18A', '0942320F-0B7C-4043-B6FB-A0A729F7F597', '3014260025502', '   3d  lue 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0869A8F-F1B6-47F1-AE7F-3A70611A75ED', 'C88BACDD-A7F8-4C62-91E3-32239D588860', '5903407225555', '    18+ 22/555', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E059797B-F558-498A-92CB-D76BB3925C91', 'CAC64562-73BD-4DDE-B6C1-6551C93A787F', '4602228005124', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('450D959F-1ADD-46A2-A765-2A1E3BA676C7', 'BBCE4F7F-2206-4B2E-B75D-AF1FC70C4AED', '5903407226040', '  fairy tale   6-18  22/604', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1F02978-B0D3-40B0-B922-A37F97F28A02', '27A7E59C-7888-45F7-B1EA-EF2A0F65B9C5', '8809063770255', '   / / // 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37BB4F1E-4AFB-41EF-AE11-2F8CEA47F123', 'AFB5F8C9-F8BE-4EFA-8367-63AE3BAE0D21', '8904004821130', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0D03677-8EF6-4953-A4F0-0D0A02710D75', '8011317E-F2B9-433D-BAE0-B8A631C089B0', '4607131428336', ' naturin -   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10B116A8-545A-4FB6-8077-7A3B0EF001D6', '6786946E-A284-410C-9E17-DCE7EAA8DC78', '3582910073796', ' /  0,15% 120 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D015A300-9726-4865-961A-2D841102CDA8', 'C2246ED8-CA35-476D-835A-207E4332C3C6', '4606982004744', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A57E97E-5C4E-469E-8F49-7570F980677A', '09D6C088-55E9-4EA5-B291-BCF81ED87724', '4620020891370', '  /aqa baby/   spf30+ 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8BB664C-3A86-44BF-9CB9-F1723D5AFC12', '925CDF54-C5DC-4E08-8FE2-5C096FEEDCC3', '4603726763363', '-    /   spf30 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBC7A283-2912-401A-A44C-A50CA1ED0C7B', '0AEE7597-45DA-4E15-900D-933CA853BE2D', '4605658251758', '  /  /25175/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C23D66C-420F-4937-B522-995483F3E97C', '2DA998D9-3BB6-4F03-BCD5-BD90B7151F86', '4049500247849', '    2,59,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D8CA3CC-E7BB-4070-BCCD-298902627FD3', '005F7F53-33BB-4B6D-8618-EAAEE24A2FA7', '4670010371191', '   / 5% 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D24AB22D-C70D-4521-BEC5-CC20A2C6380A', 'A4C42C55-894C-4B93-AF48-E29070D0C718', '4620002186173', '    /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FF94523-349A-4C52-8C0E-A51203CC6540', '28008DFD-3B04-42E8-9A3F-CB28CE8C82BA', '4650002420076', '   bugstop ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0EE2C55-07B5-4F7D-BA15-705B9AB01131', '10EE802C-8FBD-4E7B-8BAC-199151064F63', '4602876005736', '  /  100  2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FFF27B1-B586-4CC8-B9E6-F02B90C868F3', '690130A7-AF91-44D2-9333-9FE5A0265F51', '5997001308530', '   / 35 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37A5D197-C1FB-49B9-AA9E-FA4F530A3A8F', 'D257033A-960B-4CCD-AF35-13E8702C0D4C', '4640013551951', '- "".  3 ., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5AF52D2-70AA-4933-8811-19C99AE0F513', '1BD6EA81-7742-4A4A-BDBC-E36370723E99', '4605453000674', '- 400 - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E077AD0-E0AA-4A35-94B3-83AC08224963', '17A941DB-2633-4912-AE84-BEDD16D1D039', '4049500859936', '     S 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B97E1046-E851-44EF-858C-73B65FB1C410', 'FC7D9E2E-B999-48F8-9D64-B99CFAFE0B8A', '4670010370088', '    3% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0719E52-4888-4F6B-A084-215B98BD68AE', '4B5771C4-6D81-4010-9557-51B4FAB69197', '6428300091742', '  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06F51774-D74A-48C9-9993-0CAD30FAFE2C', 'A61D4705-D327-4C06-9907-230D2A3D0FD6', '3282779402866', '     spf50+ 200+  /c78039/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F300CF35-33A8-4984-B506-CDF90A88953F', '53395682-0327-448A-80EA-939DA4C2EBC2', '5995327120805', ' 150   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A475ABE4-99CB-43CB-964C-609E9335B187', 'A3B1F0FE-BA53-4A9A-9A00-9D6B3A8717F9', '4607109407325', '  /    //  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21159E5F-1BA6-48DD-885C-F4A320BB721C', 'C2934C39-3688-4E6F-A4E1-EB496C944742', '4602103002521', ' 20  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8956781D-799B-4D00-B5C6-98A5D6FCB84B', 'C4EF1CA0-D1BA-41AC-A53B-9FD86C0611F3', '4680020231392', ' 250  /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18371522-CF62-4349-99EB-A6CF614E0603', '1B5A1D9B-6D5D-4180-B92D-6A8D1D8ADC33', '5000488106237', '  //  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72C2F765-8D10-46B7-BA8E-0ABE33802F07', 'A4382FFC-C8D8-4789-B364-DA5F6768478D', '4820180330836', '     ,. 100 /18 /.35 /2/ 100%', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AFCC2BC-8792-4539-981B-C215D2E16F5B', '20DA398B-EE63-472E-BB20-810F7BC9D944', '4607055139523', ' 5+10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D45F7510-7C2C-4599-9D40-4738C7DA0DA9', 'E3E0E550-39A9-45F1-9D65-33F58907ED46', '4680020181437', ' 100  42 /1+1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D0AB14A-FDC9-4A5D-B4C0-46CCC0A992C1', 'F8D8BF2B-1DB6-4F7B-9035-A290BC8C502E', '8001090430663', '      14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D13970CE-1835-4B8D-A064-3BFBFA72644B', '0C030AF1-5431-463E-A121-831E3162B06F', '4606486022954', '-  12,5+50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53216470-26A8-4BCB-8DC2-95C8B216E2BB', 'ABBC324C-9E48-4753-8057-C05D0D7493DF', '4605658406110', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCFA91D0-722B-4BBB-8542-A7A16E2A609F', '13FA64B2-E5B3-4643-8387-7E9078619949', '4605342001225', ' /      500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC35E179-2181-4264-AD16-8BDE60F294F6', '11318016-AF5E-4B35-8BC1-EBBC9C93E350', '4601910000997', '  68 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('811DFABC-7862-439D-B945-F48DDF88C2E2', '39FF88D5-1099-4AC6-8322-2ACDB47D1F2C', '8714100919125', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52E0B1C7-72DE-4FB5-9C80-E8D9AB7C4D10', 'BC4EE896-608C-4B1E-B887-0B9361E423B9', '4607006490314', '  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83D03609-5616-4294-90FE-BB25A60D2B8C', '908220AE-174A-4BDF-8782-544931DC51FC', '4600697174402', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8686BA1-A1B9-4A04-9E58-07C85E61F346', '1283E755-ACAD-4B24-97EF-73719C056F97', '4987866400907', ' 0,09%    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F864F9CB-E217-4F08-BA66-0CA3604FFFBE', '8F9A9F50-9111-4DB3-8837-4ED230FA20D3', '4620771240212', '  ,   83-93', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('296E51AE-E15C-4413-A092-77100B6777A0', 'E4A90DE2-B368-4AD0-BFD8-9E67D85DA9CD', '4620003221903', ' maneki chibi-neko 4-8 72/s', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD5D6ACA-8D97-428D-B157-01DC6A761B0D', 'DE4C4712-5945-45CC-A235-13198C252EF1', '4610007620376', '  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('356689BF-C6E9-4B95-8C94-67BFC64EC264', 'B8C273F0-6CD0-4C9F-83A4-84EB19658DA9', '4009932555578', ' vip   3 /, , / 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('464560BC-4B5B-47F1-A15C-CB538DD11570', '4DC780D0-157B-4955-BF9A-40E890F2DC7B', '4600697171135', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F957AA22-6AE6-4D59-A4C4-67327538C01E', '758C0090-9D81-4332-9AFA-7FC122C4AFEA', '4820180330812', '       100/18 /.35 /2/ 100%', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26EFB78E-F51E-47F3-A612-B248C75C979A', '7110DC07-E50B-4CF6-9272-0AB8E616E0A9', '4601808008432', ' 0,05 / / 2 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E47BBEC2-3762-48F4-BD4E-D6854B6ACEC1', 'F6C24E28-8452-4626-ACE2-EFBA124E4F11', '4650002420144', '   kid+mama 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A19FA483-52DE-4CFC-BD2F-79497A2950FF', 'B0A045AC-1F0D-41E1-95D3-1F0B5213EA29', '4602866025270', ' // /l/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('615CCFD7-0FE0-48AD-9477-4E88A9FDDE1F', '5C181F33-38D0-4C84-AA35-299B48ECCBF0', '4008666217776', '/alpecin/         200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BF08AF1-43F3-48E0-96DF-03A9A4D08C84', '342987CF-0D21-421C-B2F9-0317FA5E57CF', '4640013555959', '15183/144/12     "".  6., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3B7A848-399C-4DA9-8B8C-2C0D8A23C885', '658C2391-62B6-4771-AB8C-FFF150B85ED8', '4712803561638', '- unistrip 1 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A647387B-4D3D-4032-A369-F56DE79274E5', '11910E7F-DDAF-4E85-A61C-6540CE793E90', '4607017941959', '   /. 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C2F9681-520F-4DDC-979D-36E290833B38', '5812568D-FBEA-4921-AECE-250FCBF38503', '4627129213072', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C49CFD5-D766-461F-AF51-03059EED0D60', '210A2CD7-3297-432B-AAE8-BC321BC5FF84', '4600697171142', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('718D2D27-8B1D-409A-BDF5-D5573DD3AF64', 'C6994708-C9C2-497F-9523-366E1BF47A42', '8300961753215', '  70  12-17 mmhg  .3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0D84CFC-A942-4EF6-863C-E9C0924EF918', 'ED8431D9-A3E2-4724-8F96-68968F8F9164', '4670017926141', '   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2FE07E0-09D9-44B7-9FFD-22A881DC46A3', 'C55453CB-5751-46DB-9708-2C4AEDE20C2A', '7038319109124', '    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E7351A8-1517-4183-B0CA-BB0BF96D3168', '5C609106-E2EF-49F2-B6D0-E47AA074F77F', '4810153021625', ' . / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5348AC97-4E96-4ED3-AE90-2245188E61EC', 'CC3FD378-1CB2-4E22-959A-F6CF6759ACB8', '4620003081699', ' /   1.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90104179-B585-4E21-913A-DF83E3D2EF2E', 'B1174B76-030C-4AFE-8A3C-C678D9FC39C6', '4810304013356', ' -      /.  . 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B80C6C1A-2D3A-4F8C-A7A1-930284186E17', '91C39373-D922-4C5F-BE14-B741367EB46A', '3800009140465', ' 300  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45A10B55-5F27-4B75-879A-755ACAE7F50B', '53B252B8-59B6-4B2E-A8AE-8C630B6A9C11', '4607003248987', '  // 0,02 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A51BE0D-F2C0-4E98-BA98-9EA6DFDCC6B4', '73E6C1C3-B56E-4A54-9AA1-16E4605F6522', '3856013212681', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B59D5E48-85EB-45AB-AFFB-0848A2B4024F', 'A0A59D1B-F1C7-40A9-BF8F-E8846F971360', '4607024944516', '  60  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F65B3C4-F7C5-440E-9907-5D259D1B01AA', '9E4CAEE3-3EA2-4D64-8172-1B531B8E3686', '4601834004668', '-  hi-tech  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7130738B-4D6F-4384-9D9E-E1EDBC397DEA', '87675A23-F9C7-4E38-9F58-6DFAAFD01631', '4049500749947', ' peha-haft  /. 46/  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B15B0E72-5F3C-4B91-8A98-B428707F2821', 'ED90511E-26DC-475A-8542-D7219FAB81CD', '4634444070815', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BF87F0B-5653-4664-B312-257D955EDE26', 'FA4B57E4-6B3D-4B95-9D1D-209CD09999E4', '4605632246282', '  -      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF340D4F-EC11-4CC1-A6FA-50FACA087CF3', '9782C334-6FDB-4A53-B2F3-70366FBF2EC1', '4601811079900', ' crystalmatri-fs  / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4085213F-89B5-498F-A293-5C25D956ACD0', 'C78F6357-00ED-4231-8E30-FBF6FBA16FA1', '4810133008066', ' 2/ - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE7AEDB8-757B-4801-A541-2619E1EC933E', 'D36350E1-1F0D-4ECE-92D6-D3B651ECFF16', '4602210002902', ' 100+5/ 120 /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81C114A3-50DF-4DC1-AF2D-2D3EAF5C9678', 'EF018541-513F-4CE3-904C-41426D0F5053', '4607131425496', ' etrem  -   80  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1285E884-84F2-4495-B86C-0545711A817B', 'EBFE6ADF-64FF-4A1D-94B8-8F9D51A39D4B', '4606711703733', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B65EA648-7FF2-4198-B789-8E3F74B80818', '83604BD4-554B-4D53-A78F-1A68B5E47D65', '4603988014562', '   10 1  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54EADE37-EF3A-4811-98B2-9772BDE0135F', '68568E77-6BB4-4FBA-8640-B9E750DAC862', '3629002756035', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D9EFD53-8354-40BF-AFFA-3FE6EA787DCB', '855DA7A8-277A-48CA-BCED-23F4D11F1AC0', '4813870002175', ' /    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CBFA7A2-45D3-4AEE-8638-21C9D812CD7D', '4ADD790E-650B-435C-80EF-DE70130E2CB0', '4053800411404', '  / 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74444EFA-4B48-45E4-993A-AA7ADAAF00D4', '3082CF65-B120-4D92-96C9-45E8519A1089', '3574660183856', '  /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D149BED-8CC3-4BE5-A8D6-344CAFD3503F', 'B3F399D9-CCDB-4095-AF12-41F9CC0EFE3B', '4003583125029', '    spf 50+75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D0D3BA7-FFE1-4FE4-9359-610D4F148765', '47D68983-11BF-4EC0-A4FC-5210F54155EE', '4605370010046', ' zd  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('445651FD-D850-4D22-85EA-061BBAD18443', '7972D110-9BD5-4195-9F65-C93C4E171375', '4008666217752', '    c1   . 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('866FB621-29F6-4146-ADE2-7487D79FD18C', '723D1456-6385-46EF-86C4-0452AACDDA3A', '4650001681362', '     60  60 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78A02242-BB9F-4457-BE92-77A24111E903', 'BD129705-6810-4E4B-80E5-0C278E4B18CC', '7640156391893', '  . ED, II  .4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1641937-B88A-4FAB-8318-2AA9BB842D38', '6D72E3A3-3C1C-4934-8E43-20AC89F7329F', '4607051797406', '       . 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC89B738-013F-4D01-8E19-A7001729AE6A', '5A12962E-828C-4703-BECD-72212BB0E41D', '4607174432475', '    /  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A425EC47-4F03-43CE-AEB5-B3AD51D81CBC', '81E8D1FE-304B-445F-BA66-8D12AA3DACB7', '4640016743254', ' ./    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F39E8372-8267-4931-B02D-1BBF82E9E45C', 'ECFA82C1-7672-4460-B6EB-2BD25E5DCB26', '4606486017585', '  160  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1941469E-908F-4C7B-939F-9906EB5CFD13', '5E2989C2-21D5-4295-9F29-9DA1CF058835', '5009612962077', ' 4500 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6699578-3F11-47E1-9227-BD91290F3DEF', '81BC327A-00C9-4B6B-A4B6-11756F991FDB', '4607056264439', '     350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B04500D-5016-48E9-8049-054B9C91D57B', 'A3F3CC66-39A5-412B-B12F-1E9CD8648F3F', '4606711703719', '    / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C68B03EE-BF6D-4874-8004-9178E033EE29', '98662AD6-EB98-459F-AD03-150A6683260C', '4602565019037', '  500  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A1929EF-9BAE-49D3-86B2-50BC91611E50', 'BBD5A4D9-DAD7-4D36-A95D-7CAE8648D36F', '4610012371669', '   6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6496101-58AF-49E8-BCD9-6153BD2CC7ED', '4D4BFA0E-2FE0-4C34-9DD7-112547998319', '8437009433836', '   3,0+0,02 24+4  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEB77143-000E-4883-950D-5AADCFB52990', 'A668A6BC-3DD4-4D93-8EA5-5A40FAF8F689', '4606486025115', ' 0,002 /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CF94D81-5F62-4E8D-BA80-1024C342C67F', 'A0487E6F-8B93-47AE-B1AD-BD8BACB4C04C', '4626016682731', ' tl 201 l    . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A714CC8B-D22C-4020-B1AF-9B8014D1067E', '9E566D15-80E1-4374-94ED-029576CC618F', '4030096116800', '- 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F944012E-4834-4E2E-ACE5-72A4AC86F4B5', '6F3B6147-5EB8-4571-A7E1-825C1CCA9364', '8002660025098', ' 400   / 5 +-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C0C394E-ABA1-4828-8985-4C23B543324D', '5D01D880-DE40-40F2-8373-96714637D8EE', '4640013557533', '  / /  /16034/ 4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('349B27A0-2526-4B6D-AAB5-FF1BD26BB797', 'EABD8795-42D7-4F3C-A13E-C6AD329240D5', '2000000273532', '  /    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B969D20-8437-4501-B39A-11017140F507', 'DC368CCA-9C2F-45F0-95C7-4281AD7D4483', '4601774007835', '    / 2/ 4//506', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D89F61F-6EDE-4B7E-ACB0-6B0FEA851BEF', 'A6330C90-5E22-494A-BF9B-55C2D198C800', '8901043002254', '   5% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0957ACF-34DA-4D5D-A04C-78B80030CDF5', '916FD586-F48E-401B-A903-A76C96F46260', '4605635005190', ' 3      / 1  - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3E8832F-1CD6-4D78-925B-570B9F052562', '130535ED-8293-4856-B00E-8444EBEF3E1F', '4601774007163', '    / 1/ 2//501', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C598F6DE-1E49-4D7D-9BCA-122D84866F9D', '95C2354A-F33A-46E1-BADF-EEE982CF3BCC', '7640156394825', '  .  PRO-39', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCC0C3A7-BB48-46CF-B799-D4BF7F38373E', '6B805A4B-852D-4ED3-AD81-2C6B1C5D315B', '8002660019394', ' 40000  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('876CC0DD-D95D-4253-89FD-01923983E021', '37D92FF8-CFD3-486C-AB16-276733E59158', '4602329001490', '  - 25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F8F0030-7FDA-4835-A4A2-D12E563675CF', '8B451578-9D2B-444B-AB18-C4C163AB4908', '4810304014605', '   /    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88D70714-2EF7-480C-A950-954067A816EB', 'AB440501-4663-49D6-AAFE-0E302672B6B3', '8714100918920', '    . /.    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D099183-3BD0-4C36-BEF3-5DD36B1F9AD6', '43207F94-1433-4560-91B1-3FE93155F4B4', '5903407231068', '     +0 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B9281A4-A2FD-4DDB-B430-A84539648BF1', '56017A7D-C897-4EE3-B7B8-1DACFFA760CC', '4810844002810', '   - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FD9F102-61CD-420F-BBFB-9444B1A9CC4F', '63EC1EC3-2173-40DD-BBB9-61B2BA902D21', '5903407232638', '  .6-18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E1D47DD-154C-4FA9-8F6A-7CBA96A05756', '9D82C3DC-7074-4141-A942-2E2AAEC2D596', '4600561030339', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAE2310F-FB06-49A2-80E7-FEF4E7B50575', '209B161D-81B6-48B5-BD1C-329E39D15CE7', '5903407101002', '  12050 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9387E03-A814-489E-9D06-6701A95D5EEA', 'D578E2C0-C69F-4559-BCAB-8E09E43084E2', '4607147690048', '   0,3 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('682BBC1B-050B-4454-987A-AC65FCDA7066', '0992B12D-DB04-4F60-BE45-278582AE63E4', '4601774007538', '  / - 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD42DF88-65DC-4115-8DB0-66ADB11457E8', 'CF0C55AC-4959-4CF0-B4F3-9918806CAD97', '4627129213225', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEFAA2C4-477C-4EC4-A9E3-E75AED02F437', '743414C9-A6E7-4066-B9BD-6ECC87E8232B', '4607033350384', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7919E64C-146D-471D-9DDD-67FB4042114A', '79D3B0AF-6441-4300-A508-BD9CBBC6D4A5', '4603380005274', '  20% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CF14D09-F55E-4ED6-881C-9CA89A5FB78C', 'CBFFB59C-A370-4352-950A-302498E4BAFA', '4607008160307', '  dolce   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C32A5AF4-E518-438A-8D5C-4E15AB4F8AA7', '7F882639-B7E7-48BF-B387-2416BAE57822', '5944728003484', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('348F3EE7-98ED-4B7F-95AE-65E2BF2577CA', '7E40A106-2245-456A-A495-E0EBEAA80B44', '5000488106213', '  //  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A023B50A-4D73-4BDB-9B29-0BEF6200FB27', 'FBDEAA3A-41B6-4DC3-8D38-EC982C201F6E', '5900516695378', '    air  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBC3191E-9D83-4B3B-8275-12137B7AF43D', 'E34C4525-5EAC-4DA6-B088-787A527B1CE7', '4607039771176', '    0,601,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D995070A-44CE-45B4-A620-1CAA5771369F', '46412100-184B-4393-93B9-500DA1B0BC2F', '8588001193614', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45E15316-3601-49AC-A6CF-F0BFA1E6DD19', 'B09A6C56-1F75-4196-80D3-71C11E45623C', '4607041061173', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5B099D6-8191-4E0E-B191-8CB13171FD3C', 'B6A9CBDF-D612-48D6-B72A-26396C949BE1', '5903407561318', '  / / +6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83527EAD-8FD9-4410-8386-AD7C907441FD', 'FC3B8D6F-17A0-4CFF-B4D1-9C1AAB7B7EC6', '4049500209304', '   / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAAFCFF2-8756-484F-B166-E5D27FF0694D', 'F594D0DA-6DD0-44CA-8DC0-B8D7C7D9627D', '4650001798305', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD619F13-2B1F-45FC-AF50-34FAC65DE07E', '159879B8-970D-41EE-8825-E49BA6DB7567', '4607027765873', '- 0,625+2/1+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DFB482E-6565-41BF-B206-52D42E05B29F', '7F361376-EAB8-4741-BA8B-0B1EF505A223', '7640156395631', '   2 . .3  JW-224.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9FA94D3-E3DD-428D-849D-BFF63E86F4AF', '0CBC0E91-4908-435D-BF4E-E48A089532E3', '4810153021656', ' . . /  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2BBD6E3-70C1-4519-9AFA-D1EBBEDA9CF1', '017046CF-33D2-42EB-954D-047C1202C24B', '2000949956589', '   ,     / s/ 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DED4CD7-633B-4974-BE14-C1C5BA86096C', '1DA4F381-F1CC-4437-AF0B-7C206C20009B', '3594454200026', ' 5+5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AB8302D-8855-438E-86E4-43F44CB529EA', 'B5958CDD-A940-4DC5-904F-DDD98A9FBD96', '4660028030074', '   10*10 8 28 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('595035E7-7F81-4CD4-A041-4F9DCC72F505', '31B3668C-5FFA-4EF7-8D71-BF895FD98D92', '7290106065321', '  5  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A86B9921-DD59-45A8-8B3E-1B3AF632A00D', '58268757-93F1-4F12-B9CF-A6E983763431', '4601669010735', ' 0,025  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CE72DD4-FA49-4F23-A4ED-95FC71C76EAE', 'D5004A07-649D-42AB-93F4-2DD505500537', '4607003249038', ' 0,2  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34D6E72B-EF35-4A50-A8C2-E4976F7F7F91', 'BEEF138E-7673-43F2-8E2F-A53859E7B1C0', '4600416017768', '  - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F871EDA5-BAB0-4FB4-9164-DA6386028852', '9D940307-146B-4214-B27C-8060F0C70933', '8594737199912', ' 25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('345E3A02-4F48-42F0-B444-946F41D0734C', '1EA5AFA6-C728-4E8C-A238-536E1E796906', '4607067060051', ' 500  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87FF43D3-DD95-4D79-9D5B-0D1E5FFB2159', 'D74A8980-4636-412B-83A0-F4181B4FD30A', '4823060809125', '  1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BA977D4-4F5B-410A-BCEA-E9752EE29637', 'E675F739-A93D-4A5D-A454-D28F4DBCD84D', '4008617226178', '  0,1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74126FB8-CCA0-42CD-8944-B9B65AA0340E', '6EDF0F33-5995-40BE-9081-2347FB2871B8', '6933584162113', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1828A3D6-987B-441D-A5D9-C64030BF1F99', '5DCB481D-AA7F-408B-A83D-60B43853FA7C', '4603276009843', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EF0848B-76CF-4842-BC1A-79E2D902A89E', '58BA3B82-CF86-4064-B06F-214988235DE6', '4607020641358', '   / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF43B766-9572-4629-BF7B-51818A44EA56', '59A07226-EE86-4B04-8576-F7F217E4BDBD', '8300961873999', '  140  3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B63A53AD-55F3-4759-BE0D-4407046187C7', '19FA50E1-DC5E-4E85-8C47-478A872B666C', '4049500307451', '     wattestabchen   / /50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6524594D-86F8-470B-9DDE-D66FA48A72C4', 'A7E9EB67-E1FE-4F8C-8097-B9D7D402F7CC', '4607174430402', '       / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CC26A03-0770-428E-9010-3D658FF90A78', '6A3A3F4E-383F-4659-B188-845E1AF33869', '4600338006581', '   / /  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F34A2E4-7739-4568-8144-DDC5C1DA03B3', '38ADF842-F8D7-4048-9C0D-12835B1C561F', '4640013555829', '     4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8AC06D1-7E70-483B-8C90-960993161974', '802DFA22-971F-4C8D-8923-AF925D294657', '4620750540166', '  2,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0870E2FC-D6DC-4BA0-81AD-350FB6A6C702', '98EA8161-1686-477D-8B89-D6C9FFEDAD83', '4607021271806', '  /      10*25 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21D1AC0E-005C-4393-97BE-2C78A2267780', '64A7B4DE-F7BF-4991-93F1-F3AD09A3A3EE', '4607094176817', '    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BC6F8AC-F165-446F-827B-4FFAF5AC3EF1', 'C45788C4-C438-4E92-9BBA-40BD55E7C541', '4600697174396', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF7F9E87-26A8-4510-8A11-F5532A827FCC', 'C675FDB5-561C-44C9-9921-82383C3EFD32', '5702191009897', ' 2%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4432599-21A5-4D8D-B46A-547488420B79', '3BD5B508-2CF5-4104-898D-8279BACBD566', '4601774007279', '    / 1/ 3//503', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D6E8883-4817-4D8A-8490-1FC926B32818', '19657F3B-E9F4-47E7-B376-3829527D53EB', '4605319008905', ' 74  //  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EC53830-AEF8-47AA-A846-FBDDA3EA71AD', '8F708CE6-2441-4C3C-A843-F3AD54C4E332', '7640156395365', '   1  . 2. . /636/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A160A2E0-A25C-4A08-A1EA-8CD09E1B64C8', '8F626F03-93B0-4E69-BF1D-BF69522E7AF0', '4600697174587', '     12   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FDF0D17-3736-45F7-A11C-58EACDDD9CB6', '3DA086C9-4262-4373-9F44-01CC1E2FC1F7', '4627129212921', '  /    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19A4063C-8302-44D0-B823-7D65940CA2FA', '01234F33-81E5-44FE-90AF-B8CB1326EE22', '4640003260399', '      / 2 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E30F2D2E-C890-4CAD-B40A-90C793EE5C1A', '6F72EC67-EEA1-42F2-9048-D1C4299A2050', '4600697171159', '     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F799E52-EEDD-4CA8-AEAB-A7AD34AF0C96', '1BB9CDA6-A395-49EE-821C-7993EB14E000', '4607146761183', ' 100  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4616E871-2BBB-4100-B2BC-7334811BDC0B', '21CECEB6-6DA5-4BA9-830E-A5E75B6E8768', '4670017926196', '     /   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29600D01-16F7-4F85-BAF8-6E30671B4995', 'F8C2A881-979B-4381-8E2D-5BA9FA23425B', '4620006945608', '    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F94F7B67-F103-4776-A6F7-C844516AD1C2', 'D07A4097-BAC9-41A2-BD4D-4DC0A789A000', '4650001790484', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D240BFE0-832F-49F7-99CE-5EF10B0E37F1', 'FB57986D-99E8-4DCF-A971-B9897C71E4BF', '4605059020298', '5        30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88353286-F76E-48FE-A92D-23051B89CC01', 'F4B265BE-C308-46C6-83E4-545F90F12CDF', '4607094177456', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21F859E6-EC93-4D4C-99DA-A8C81C9781C6', '030EA9E8-6C55-4507-A0B5-B9B811E8D769', '4607091486391', '   /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF2F84D3-A30F-4914-AEB4-4F9751C8043B', 'C59FA103-F451-4A70-A333-E9655EA92B7B', '4607003248611', ' 100  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61F5E231-BF6D-432B-B328-113D4A879D25', 'FE76749F-767D-4F70-8200-C6BF65119DEA', '4620760951365', '            17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('554ADD0B-2228-473F-BC65-73E4C5D407C0', '82314498-BD02-4B6D-AECD-E0A3E784D19D', '4752171003095', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F66B9B03-9A62-4A29-BB1E-8C56775F90ED', 'E3026B49-428D-41B0-BD57-0E381EEF9B68', '4620002188061', ' -  2+1/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('372744EF-040F-4FB0-8C4A-945C8E4F9207', '25C03752-ECD3-4C89-9968-AD0829FA4C3E', '4049500976268', '  55  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26BDE315-B307-4C7A-A82A-AC84505B47CE', 'EE8AE9BE-A0B8-4A05-93CD-290B3FE319D5', '4607054703138', '  soft  100/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2915B60-EACB-407A-A9DC-54D67F806E9F', '3EE09938-4AE3-4D1D-A8E4-666AE110F687', '4660007703180', '  15+153,5  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60FCD554-FB69-4C3C-9403-C73F8F1658D0', '94779F64-96D7-490C-B17C-D5D69B629CEB', '4605180006352', ' 50  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74AFB134-2A73-487A-A3C2-C6628884FD22', '5BB79E6E-135D-4B80-A4A3-0DF656963C62', '4049500737036', '  1010  1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BA65857-D6D7-41DA-950E-A25D667528AE', 'EA038EC3-F7BA-489A-A123-80758AAD2277', '4602009401503', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F04FFB9-CCDA-45E0-86C4-41A9BC6C0DA1', '29019861-5B89-4C15-A53D-8A25FB3CB16E', '4605108004866', ' -   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B802410-BBD6-4D84-B756-4FA61CF2B062', '3712441B-1FC6-42A6-A36A-885DA8668172', '1230000020046', '  3  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E319E712-F928-467B-80E2-27B6FF413FE0', 'F576B161-E1DF-4659-B54A-7E9556DEDFD4', '4670003600956', '  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8961761E-D2FA-455C-A850-1196AC45E64C', '0907D0A0-A759-4C95-B396-6D5E85BE9014', '4022536645568', ' 100  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('944F55B2-7EE5-48F2-B2A8-B3BFF91D5D88', '35BA3349-A01D-4416-A15C-B3FC677F5E6B', '4750232007259', ' 2  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B21DE554-8F07-4CB1-9FF5-3160DDA46E6C', '674254C3-73B6-4F81-822D-FA4431DDC758', '4719003341510', ' bp 2 easy .   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8E78F11-B3BF-4082-A524-0AB4D733F486', 'C9DAEE13-B1AE-4C5D-A723-3C2D630F3455', '4602866068505', ' /-109/ . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8EAE360-F529-4A42-8864-BC3A1E77EC67', 'F2544686-AA16-413B-A15A-43F54A542935', '4607175610506', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66EAB5F2-C3C4-4DAB-9180-FA50E04922C0', 'F1D8126A-76B5-435A-A057-C8A120C59CD0', '4601654000659', '   2,2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26DE93A0-CFBE-412B-9390-294CCA145A6B', 'AD360CF5-8F8E-49F1-91AF-6C94AE8297FC', '2000103611200', '-   0-6 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B3A7811-6269-4974-AAE2-189F75C7FC5F', '436C3755-FAFC-4FE2-B742-834E21C7E68C', '4610017352465', '    - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6577C1EF-9E5E-4A01-9DBE-E7FA060F6AF5', 'B431FEE1-016E-45AA-AB17-FCC01ABAC01C', '4607122567075', '   /  6060 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DF6E1E6-21A2-43B5-B155-14BAF1B647CC', '5EFFF07F-3161-45DA-B01F-16799301B259', '4607086569672', '   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6689F4CC-695D-4113-93DC-1FE15D6E0C00', '789508A5-11B1-43A4-92B0-4FE7A2F0F6E9', '5000456013307', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6E1B54E-52DB-4D31-9FC9-0E64AEE37AD4', '9BBA6279-6FC4-4D4B-ABBB-E6DE21431B4A', '4607008360417', ' 500  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB05822F-4F22-4F95-8D55-C2BAE892ED98', '1EB9C6EE-354E-4BDA-B20B-351885AA694E', '4600999002359', '      /./ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5218ADAF-B59F-40D9-A9E8-41E757351645', '00E43CBB-906B-492F-A9AB-032274FCDC27', '4812317000071', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11BB30AB-DE14-4F17-A78B-ADC3EE4A399F', '820F531F-0993-453A-A946-8A8E95910A1A', '4640013550305', '  "Just LUBBY" 6+ ., /13974/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6452520-C056-4380-AE2D-471F222B7D6F', 'AE7B426D-2F59-447D-9700-9DCC9F225BCE', '4607101205271', ' -   0 , , ., ,  11396', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E31E4C41-037D-4C17-BC1C-B651EBDDADC4', 'C80D1CFC-8AED-4618-83BA-83AB1EA0EEBB', '8716677005270', ' 3 gold     800', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32F781FC-81C6-48E3-85F3-2428E5128F55', 'A5A0A1D3-7CCA-495D-8B65-F1BE7A082679', '5411416053217', '  id m/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D09BD7BF-3C84-4E77-A70D-AFF398F85302', 'C4928143-004A-4BFE-908A-ABF902C5C228', '4600697171074', '       50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1C571A5-934C-412D-BE17-DD2BE623435E', '08C0680D-8887-4222-977C-077730BB9D3B', '3582910091066', ' 5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C2D96AF-A3C4-467D-B925-36A12A82F7FC', 'A45350E4-DADC-40C9-8265-42FF38BC7D3F', '7680526579018', '  0,1 50 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('982F8862-92E1-47FE-BB9F-FC5B11C4AD93', '4D108779-8960-4A66-AA70-9B357BAEA2AA', '4602565015947', ' 25  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0302C807-B7BE-4B65-96B3-1F8BBC54DF35', 'ADFE6F2C-8FF7-453C-9B74-BEF528295CE5', '4603256006176', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('734D90A0-C89F-4B6C-8BD5-CAD223445D78', '7F0A7965-BEF5-483F-BEDF-C401C3EC83AB', '5036519001011', ' 0,025  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('077AFDD9-B820-458F-9CEA-01C03FB211B5', 'C5B9F48D-9087-4756-91AD-7C9CA87F9750', '4602565017552', '   / -  1 / /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B04F37C7-340E-4718-ACE2-91DDB53EF9DA', '0B3E6F5C-42E3-4AE5-8F86-5B59F088309E', '4603933004815', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B36876EB-3B49-4BB4-9D89-E741F75E9A4D', '78054828-A072-4047-927E-BD3E7E3B4E49', '4607003249090', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF77AED1-3322-47FB-B2BA-FF930B4F1B43', 'D48E8C14-BCC1-43F3-8F3A-5CF27EB49F9A', '4250431918832', ' 5 3 sf  .  22g 1 1/2 /0,740/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F4EEA70-7823-44CB-922A-9378CB2D1610', 'B64A6360-1D1B-49D3-BC46-81B6E7102CEB', '4605658230722', '   4+ /23072/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD62EF45-CCC5-41C7-939A-AF968C9B700F', '31E0C87E-30D5-4C89-869A-A0184E756AA1', '8717775823230', ' /   1-2  //  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FD42FEA-6423-4A83-AE93-2A0FEE82A19D', '51584865-FCDC-4901-8F94-86CBF89D5D8A', '7322540949155', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F804A77-3827-4A98-AC85-AB22D0D7E214', '92457355-4DE3-48B7-93CB-B66D595AD7B5', '4603469001210', '- 3,75 /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28E71BE3-FAE3-4C30-A944-E763F3B33C02', 'A6F9B377-165F-4565-A42E-188D8A9C2DEE', '7038319109148', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93048BBA-CC4D-499C-A6FC-E81BCD95362B', '8D9B02E4-6998-45E2-A583-32DB00E55DA2', '4601661000802', '  50  ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52D9E23A-D9E5-4F93-8CEA-4C34E3514B30', '50902D26-4525-47AB-B0E9-0646CC814756', '4607011667275', '  - / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09BD2FDB-C166-43E6-BC13-D21D7A3D520F', '49AC258D-CA71-4173-9D2F-DF1715393665', '4660007701162', ' 10  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BABD4F6-D182-43D0-9BBA-847394CB0150', '4AC7B664-18B3-4178-8C77-CA47C66857D6', '8901140114126', ' /  9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BE9799D-587A-4E27-B327-F6F94B414714', 'A9C75702-4B0B-4D23-89D4-08BB14523024', '4680020181123', '  1% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57CFBE73-6FD8-4AF9-A08D-98AA7F6A958E', '87C19C70-8F0C-4327-8C19-A06CB118517C', '8009315041137', ' /silver care/  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C3C2FCC-9135-4FEE-AD98-3B348AA95502', '8CAF3FF8-CDEF-4127-9F7D-0A947A4DF850', '4602122003240', ' /  60  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FBEED5F-2A45-4D5E-9FB7-979E2F975012', 'B3E87BC1-B6FA-4C27-A916-B00139EF9112', '4602379001198', ' 25/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31280C9F-37ED-425D-869D-AF0D60067C12', 'A5CFC1B6-F90A-451D-9D57-19356C95767D', '4650069650706', '  25+80  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5370FAAE-6365-45C5-8561-EF620E7348D3', '763A86C4-D526-4620-B203-7EE3134E0FCC', '4606486013099', '  500  / 60*', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE7A68F5-5587-48FE-90B4-551A945A0F36', '0BCA48B6-82D8-4662-9689-856DDCE51980', '4607086562789', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63D84A7C-E91F-440E-BDE0-F164763D80F2', '85C5C848-7DAA-4DCE-991D-E99F8C067DD6', '4605077006724', '-obl 12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BDFA9BD-C1E8-42F4-B592-7AE0B7F1B552', '58377F43-ECF0-498B-8143-FF472D5B77FC', '8718309700997', '  /    /1+1/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('331E69AB-E477-4DF2-B08F-E01965D06B0E', '43F3A7C7-E573-4536-8E96-BCB6C656B477', '4600697171197', '     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C2B46E1-627E-4DF8-82AE-BE3E4E09E8BE', '1C8DAEBA-0338-4350-8FB0-55FC1BAF5BA6', '8002660030160', ' 10000 150  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C65386B-72CC-467F-A427-D6BFA294C5DC', 'B2A43B3E-DE5D-43AD-BE9A-6CE9F88C746F', '4210201746263', 'ORAL_B       Stages Power EB10 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E09CB86F-53D1-43C2-BBF6-4B76BF9C4B49', 'BCF62DCF-19AA-4B04-AECB-75538E119EFB', '8901043002155', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24C3FDBF-EC26-4EAF-9AF2-7F6B14D87BFF', 'E10E1557-1C66-4735-98B8-896F86688E84', '4605658175085', '  //17508', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37A571F7-5E42-49CA-B619-78EFA6261E6A', 'F75FD75F-7FA1-4573-8557-03BD56EB87D1', '5904398627021', ' 250  / 1 -  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB5B20FF-1E81-4A84-AEA5-C7B004292DCF', '00DA8C3F-2A47-4721-8EEA-6B0E75B53B08', '6921904705911', '  9060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BADD9552-A4F1-4C5C-AA16-F5671FB18973', '1FE96CC6-BBF0-4890-92CE-E07EF0FF922D', '4607046744941', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEC9D218-AB1C-47EB-8D38-C086906B67F9', '5CC7C6D8-C1AA-414B-A8F6-FAC9ABCD2D23', '4605095009455', ' 0,05%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A57984C7-8F1C-4FC4-BEA5-37A181651A19', '02B8DFA3-86B4-41C5-937D-44A2923742F6', '4640013555560', ' "  " 0+ ., ,  , /14373/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A22FFE6C-3722-49F7-A639-9818570076E5', '8843D881-B339-4025-A883-E1E84D66FF6B', '4620018874736', '- / 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECB2A81D-FB39-4748-ACE1-4718F375C112', 'C0FA26D6-3259-4A83-AA59-AAA18629A225', '5903407098098                       ', '   ( +  + ). 0+ 9/809', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A84C74E-E173-4C47-912C-8AE5767D47F8', '3B4ED15D-F36E-4086-9BCC-D90C49BFD5EC', '4600665204483', '   6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('463BF9ED-2664-4B19-B94F-C748F0C4BD7B', '53709618-5975-48BD-AE07-8DD040C84D53', '4606484009377                       ', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8900325-93E0-4961-B91A-E68721BC4A86', '54D40B0D-AFF4-445A-9AD8-61470165B399', '5900516720490                       ', '  S  8  15 1 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CACD8AFC-0B84-4B85-AA94-08A718B48628', 'EEDC596C-D9D8-4ADD-9C31-5B8F4184234A', '4680005640782', '   50 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F20D8E16-5EED-4FB2-A065-E5DB3F8C837B', '7CA8CBFA-80AB-4F8F-90E7-DD79659B4928', '8700008290503                       ', '-3     45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B9E9077-82D6-46DD-B905-967F8BF6AA94', '6DFF730B-1B8B-445A-80EB-61EAE76A7D23', '4603380002730', '  0,2% 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58787D53-9B0E-43D2-B73A-BE8F7D45997C', '1883CF04-9828-46D5-8754-20F5B6E3211F', '4607051796058                       ', '    .  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F81020A1-BC5A-4566-9F9E-570A54E2767C', '3B12E5BD-0DBD-4C96-82C9-488346FEB991', '5995327253237                       ', ' 2,5% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2AB95AE-0B07-46A2-8DA9-ABD6AD03EB3F', 'B6982CE2-6816-4539-BDAF-D303A2ED7274', '4810133001197', ' 30% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77A4D112-80C9-495F-94A3-E709EA350F18', '0B7167BE-C702-4621-BF76-56584EE44C0F', '4640014200384', '    6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A2FA645-E2C5-4957-9468-8FF355340CAB', '42108ECF-1A0B-4474-97DB-93CB762923A4', '8887786100047', ' LD-302  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FE7C9DB-891A-44A5-96C2-C723ABD34540', 'D4EF7E8E-A3D7-4E8A-AF48-9BC728CD1B19', '4601969007657                       ', '- 0,025%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0570BC25-D380-47E7-A513-C6BCFBFB9F7D', '2AA7B41E-805B-4248-B27F-04DDA1CE3D3D', '3585550011494                       ', ' 15  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E210707B-B6C9-40BE-8F88-90A8ECEEFCFC', 'BC1E143B-2331-4059-8321-54AC5B828740', '3800002303355', '    / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDB3A17A-D36B-425B-B7F7-FC16DDE74AE7', 'FD96F3C0-7858-41EC-B66B-68A0F6D42148', '3800200961128                       ', '      230', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AA17D24-0CD7-461C-A617-30630237788C', '69C4AE4A-62F0-4557-A668-8B0B17719D67', '4605894001384', ' 50/ 2  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('336DAF7F-D2EA-4ACD-90F1-34E4BAE4FD7C', '060CD613-9FAC-4498-95A0-BAB1557CD250', '4008600162483', '-  Adore    6-18   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FACECB8-A461-407C-AF12-FFC8D8EB3D91', 'E170C7EA-9E93-471B-AC0D-D6E16EEFEEE2', '4601969007855                       ', '- 0,025%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E178B8CD-6C3A-4679-A8DD-8F38684057DE', 'CD935CBD-1931-4197-8A85-D09C27E655EC', '4627129210880                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2604225-3558-4135-A9E9-55269FD13319', '54599D3B-76FA-43AF-9F24-3433FA7556D7', '4620002185701', '   -   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6413D89B-597A-4C5B-819E-25A6F3631BCC', '5EF22ACD-206C-4072-897C-A7F58B1A53BA', '4605108002749                       ', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A75BACD-4F26-4CC9-BD5E-E70B52D70577', 'EDB1ADE9-9FE1-47CE-8462-CC32B223851D', '4607146826790', '       /200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5394A05-89C8-496F-9965-A5055FC1D82C', 'B8450C9E-AA05-4CBB-A556-3CABFFD4CAFC', '4820121901477                       ', '     1043 28,5*28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4AA4973-A5D4-41E7-B892-94849CFDB2A4', '8F85DF9B-9982-45F9-A2AB-C2ADAD9D0B7E', '4049500952217                       ', '  -   44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA025131-3B98-43EF-AA92-D63576CB65C1', 'F35007F5-D194-4A45-BD6D-26FD348D3262', '4607033840076', '   75% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBC270E5-1CDA-4C9D-B363-10596C27A47E', 'F019A70E-DAB6-40BE-960A-217D26013F0F', '4630005642637                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C5A6823-88F8-4090-85F1-4407FF271AFD', '93ED513D-37C5-46DF-AAE8-512EFCE901AD', '4850002210022                       ', '    0,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27CBABBA-CD7E-4B17-A9B0-E3B0AFB8FE90', '5395E13D-1E1F-45A8-9F22-C93A7503D7E6', '4607020904613                       ', '    1,5 / 26 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A85E3297-B449-49CA-AF4D-BE9FAE558586', '43C6B63C-1B40-4EEB-9DAC-C3DFF350DBEC', '4607085860985                       ', '  /     ,  60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D75E1534-5330-4F21-973D-97C8309E32E1', 'EC51D617-9BEF-4E27-99EF-BE85EC3D5638', '4030539062404                       ', '   0,9% 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('158C5352-67DA-4D94-B4F9-CECD9BFD3C59', 'D5CB0DD7-31E2-45B6-A436-E1DA91BC85EB', '4603988014319', '   20 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DA24441-35F0-4BAB-8303-F016CDDFA4C0', 'A519438C-E037-4EB4-B845-5516FA6132B9', '4603988014197                       ', '  20/ 2  100 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FE1A562-7808-4636-BF8C-91D5416EB229', 'E2161753-6B79-47C5-93FA-65C029BC4D4B', '4602546005523', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2788DBD5-A356-4681-BB69-9ED500C72045', 'DEF6435A-02BB-4A1D-930C-521BB23D14E2', '4607153456263                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A17F383-8382-4E00-B3E8-8CA7C8265FC3', '57FE53A6-A041-4B8F-8EB7-160C3EE2D066', '4630001700560', '   1,25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE9B4888-153B-4C8D-B6AE-4062E9B584A1', '13D2AAA5-C1D4-4102-86B7-675BE2D2AC4D', '4612751230122                       ', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6375DFBC-3C99-40B3-AE19-9BD26E811FF6', 'E2A0D879-3DCA-49E4-9019-477A0852576B', '3574661174952', '   /   50+-  4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C950297-6DC3-4293-88C5-7A94D0438B0A', '265D5ACD-0EE3-42BE-98AA-F261344746B6', '4603988014418                       ', '  25 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BBA1EEE-282D-4DFB-B95A-471E94C4A3B6', 'A6C8514E-EFE2-45C5-8A58-74A904314356', '4607078792002', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D818AD9-9351-4D50-8728-FBEA95399601', 'CA8C673C-641C-4E9D-984B-7DA17E0D9DB1', '4601026301407                       ', ' 20  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5406566E-DCDF-4C57-8E7D-D516C0676BCC', 'AC90B569-D557-48D7-907A-301B9AE33F74', '4620017360681                       ', '  7,57,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E9F0949-3765-4FBD-99EE-1BF7262A171E', '3AE41E5A-CB77-44FE-B0E5-B26D9FE9488A', '5060038502810                       ', '  Ola Silk sense 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63227B69-C9A5-4AFF-9C81-FFD16447BCBF', '1C811926-095F-46E9-9C9C-3E3897215774', '4602228003090                       ', ' / evisonic 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0311D3F-2979-4109-A879-B0B7E5F1DB9F', '0E3A793C-F167-4C3E-8052-1267D9BD91D2', '4612730250066                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D6B777F-F1AE-4C77-82E9-A25EA2B87372', '7838B42F-6E68-4283-BA3A-9328421F9D15', '4607039972399', '   2,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F7C56BA-1D06-4DE6-825A-27239279F56B', '0E820307-DDB4-4BB8-A500-A67D1E583A60', '4603788000031', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C44B4EE5-A4D9-4C5D-9216-DFC9AD53002C', 'D91F67B9-E385-47C6-A0ED-99959F4AD931', '4623720904753                       ', '   009', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE401DEB-A4CC-4C53-AC80-2A1DAA0B284E', '6E41E876-C918-42BA-98F9-3E2DAC147EE7', '4607163095728                       ', '  200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27BC1A46-C753-41B2-BA4C-AA1A50E35C07', '1F145DA0-F3F9-43BA-A34A-551F80E4F8DF', '4602884002550                       ', ' 5/ 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FA6D3AE-4296-4AB0-AAAF-3E850E3C33D8', '80C221B5-DC77-4587-A9EE-F60B7E5D7081', '8887786200495                       ', ' LD 23  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF2380E5-250C-4CF5-83D1-D5947FA56FA2', '192EB428-A2A9-40F1-92C1-C51790226B95', '8887786100023                       ', ' LD-300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B66F6028-DFBE-4837-B752-77C78045D35E', '1790E2C8-8DBB-4511-991B-CBB2D8E93177', '4607111278623', '  - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A20E00E5-7C18-4B03-914A-230A918DBE53', '578C471D-5742-478A-AAC7-D0ADE22D354D', '4602509000800                       ', ' 15% 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A15E2C29-E84F-4D63-B945-1E4153A38118', '3C1CEEC1-5FA3-4BF9-9A3F-0E86EBD92C62', '4603988014401                       ', '  25 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCB821A6-3555-4776-894C-18DF7D8BCDBF', 'BAC990F7-776F-4159-AAF9-C3488C6C2291', '8594739206045                       ', '  160  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C08C4FB-860A-41C4-BF9D-1BF03C89A5F4', 'CF86B9BD-D6A4-441A-86D2-36B6F81BB14E', '4690419007491', ' -  /+ 2*5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('812726A9-2FC9-4D55-B22F-68668FF36E94', '9FA0FD17-E429-406D-9BB3-CC6562D98A2E', '4812635003075                       ', ' O vie plast   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('410FD4FF-7320-4983-8D39-09BFC52675C7', 'C188178D-26DE-4469-81ED-383DD008CF5D', '4600665204346                       ', '   3   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5907F883-1143-4514-8F2F-DF01F1A55CFA', 'F1C4B8A8-8577-46EA-AF62-37CEF328C35F', '4670017923614                       ', '    ..   /   270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF63228A-DEB8-4CA1-95A8-9567145FC9B3', '95C86115-8788-4036-9B2C-5EFCE8141529', '4670017923638                       ', '        270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14676C4D-8E57-48E6-945A-1174D7BBEEBF', 'D078E0DC-AE3E-4AD1-A7DC-BD451E5706F1', '4680005640829                       ', '  / 100 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38397BA3-F4E1-4CB0-AF98-02C807B0DBAB', '5DDF28F7-457F-4AE4-8AD4-3681BE5E49D5', '6950570782445                       ', ' Arlette  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C31AEF0E-8645-45ED-AF48-802072D93C11', 'A20FF60B-BB60-40CE-9769-2B6337D295C0', '4607122564609                       ', '  6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8275359-94F1-4AA2-922B-53E147D33E5E', '0D1AEC68-0C4D-430D-BEA8-CCDC8967E902', '4650069840268                       ', '  /  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A926F5B6-C1E4-4B32-8377-BF71D6F2FE39', 'B6D13C1C-3014-402A-85E3-1BFCBA43899E', '4640001381553                       ', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4CDA31D-98FD-4EB8-AB9B-1E00E27FE939', 'E503FBEC-0CA6-4396-8DF6-D1DBE80D4628', '4607118051755                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('684D5818-E299-4B5F-9D72-537FCC9461AD', 'EFF9A2AB-042A-4F9C-954A-E9500C63C06D', '4250142199018                       ', '  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5E1C4CC-CA74-45FE-A9C2-A514C3387E81', 'C9A00F0E-5247-45AA-9D12-72FF0A305622', '4610000290446                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84ACFE7A-A836-4120-B6C1-060DE3CCB91A', 'D0A78090-1BC4-4BA8-A132-AFECE79ABD9E', '4627108140016                       ', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF8D2009-EE1F-483D-8A5E-8E38BB8F95BF', '4A00FF29-F8D6-426E-81D8-D06BCED4CE0D', '4627108140030                       ', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E337A94-4365-4587-B0AC-4924F1038938', '9DB6EEAC-C766-4574-A743-B3ED16BA173C', '4605738005783                       ', '    4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6785FE08-BCD5-426A-B53C-587EB16B19ED', '622E68B6-180F-49AA-945E-3DE542B43941', '4740412002037', ' 20%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE3CE83D-A7E3-4BF9-AA67-1A5E13EA134D', 'FFF42B7F-1CBC-433C-8591-806E115DECBF', '4602866000642', '-1334  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6EB76C4-90EE-4BEB-9BC6-C706014BA824', 'BA08EC8B-CBB6-46BF-936E-E4D2BD3B9F48', '8901428000042', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97F6A0CD-5A85-42C2-BF22-DAF62D3EB531', '5279B6F2-4427-4675-9173-A34844039619', '8594739217584', '- 500 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53980455-2F17-428C-9FB5-26560232D8CB', '5F1D10AA-0347-44CB-B08F-2524502DBB94', '4607116941119                       ', ' - / 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34A59C7A-1DE9-49D1-82E5-5DF738B19A7D', '3D3BE738-2392-42BD-B400-2D88B7A7E5ED', '4605658195779', '  / /19577/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C1D5C14-5217-4B18-A484-40A407212BEE', 'A246710A-8A18-430B-B5BF-68C1F20A843E', '4600665000238                       ', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45FD7289-DE79-4443-AB95-B5D27C3A86AA', 'C1AC098A-B537-43D4-9A0D-4E1FCE096E0D', '4030096288460                       ', '  175', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('516DBBCA-8FAF-4042-AD7B-673C7D3B1239', 'AA0DCD2D-FC7B-47C7-8D49-D9250D286A8B', '4601808006018                       ', '      / N365', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B338FC05-E3BD-4B84-A6B9-9C8B02C137F2', '18552D26-2C95-4D01-81F2-F082EA1F51BD', '7901302007885                       ', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62046F07-232B-41E4-A55A-9A59D5F6BE15', '85060825-914E-4D00-9934-743745101CFD', '4607015890686                       ', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADE9CFD9-27E9-4DF9-958E-6EDED2BDA1FB', 'D7D7CD15-2C5A-450D-9AE4-45B0B9F0531D', '4601969002089                       ', '- 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6C7308F-6DF7-424C-BBD7-C060A0E9F951', '56E2753A-85B6-4D26-933C-5E012F5D5694', '4680381004123                       ', '    5  5 10', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22AED62B-D863-4D81-87B4-9F7A74A47092', '54832272-29F9-461D-B798-D2DEC269DF0C', '4680005640799                       ', '   100 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AC59C39-BB77-4BE9-B78D-F82BB184875C', 'E00413AA-C204-4ED4-B3DF-16709A797532', '4610000290514                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20542B40-6F87-42E5-9C47-1BF3F8EE7440', 'D16D9F29-4806-41DA-B479-0DBDF127047E', '4601798006272                       ', '  / 18  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94325B1F-F513-42A4-AB9F-D033B729C5FF', '839F99BC-86F9-4C0F-AA26-CCF8B1A7D471', '4601834000417', '  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB1464E5-A288-410F-AA2C-A1DE3427BAD2', 'CD68FC10-BF4A-4D41-BDC8-25BF6CCE0DE2', '4602666790576                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C55951B4-A688-487A-B81F-33C0FE190223', '0C3DEC1D-0C65-4AF8-B101-2DA0B79205BE', '4620017365303                       ', '   7x14 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D5676EA-2641-4425-939A-62FFD579E2A7', '0168A0D4-061D-4048-B04A-40091220EA41', '4607153456294                       ', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('825B7F09-AEC4-405F-AE1A-724344FB160D', '64B02A98-05AA-491F-9F62-9B6ECCEAE793', '6941762672040                       ', ' silkoplast  6x10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8FC949E-7DBA-4549-988D-6EEC74876F7E', 'E151D0BE-5FC7-465E-B739-78A3349E167E', '4605962000134                       ', ' 0,25% 10 (-)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13D70B9F-0007-4C5C-9D83-60552DD6DCBB', 'E5517EA1-C4E8-435A-82E6-922911310C06', '4602866063753', '  BABYBELLE  BBN05', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3B4818E-B22C-435B-BA95-65755C0790B9', '986EAB7B-B6A4-424D-B891-0A6720873793', '4607101201709                       ', '  Lubby    0+ 2 (4661)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('398B67A6-3492-4FEF-B13F-1519A4D56214', '37D91120-F5B8-4B27-A004-815B0D4F5109', '4640001380198                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2C9E212-977E-45AE-A384-10E7C2A63EF9', '138CDCAA-1AC8-4507-9135-BF444D3FCDDF', '4630009181453                       ', '   500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF6D83C5-15A4-4534-B3F6-D6AD50A27549', 'CAA60558-39EC-4EF5-94EA-DCCE11D4FE8D', '4602565014148                       ', '-3 600000 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0913CF81-F150-47EF-AD50-73DEC80FABAB', '29F048DC-04FD-4132-9F8C-13BD16B9233F', '4607020903319                       ', '  14   2 / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE6D05DD-4EC7-41A8-9261-AFE6A6668B81', '2A34C2C1-2343-40A6-AA3A-BED7FF6FEF0D', '4600338000435', '  500  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABED92D1-B80F-4DFA-AD75-A07DC55E0B7E', '5010D4A6-69FA-4903-8737-E4A0B5FA082E', '4607055563250                       ', '    5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08EFC24E-453D-4660-8E35-E78D20A3CBD0', '995257BD-03B1-42B5-8199-86AB535E4C35', '4820121901453', '    26*26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F01D4B66-2CB3-4042-A61A-404063189605', '70081F9A-70D4-493E-B10B-50F98DF80507', '4820121901422                       ', '       29*28 1038', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AADBF240-FA4C-4680-A49A-EB65B7295367', '5B446D9E-E47D-4B71-A2B7-2DF40CD4F153', '4603988014371                       ', ' 10% - 25 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7D7DA83-0884-44E9-9F6A-2B3B931FCCAB', 'B5D88F67-469C-466A-B00D-1C8F0ED3583E', '4049500952224                       ', '     64', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C20AD41A-0392-47EC-B4F6-FB35CF6D8C09', '38EE9208-AECA-438B-95B6-29EF12C262A0', '4602737004229                       ', '  1614 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78E385D3-09F4-4CE6-8BC3-CC8DFE41B4EA', 'D4A5C494-5F2F-4C79-8D19-55CB8448CAD8', '4607147690369                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('554C43AE-8411-435F-8A13-072D316A6043', '16837884-759B-4E47-AA3B-6288C3C6E3C5', '4016369669891                       ', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3F3E14B-4BB1-40C2-AE49-D95675884E33', '531C19D9-1BD5-4A52-A5AB-C1A2A67E4610', '4610008493405                       ', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B60B6E6A-3B1E-4EF6-858D-45147618CF26', 'C30174D3-8A28-42C3-8EAA-2CBACE97D14C', '4603014003096                       ', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44076F7D-7082-4254-AEA5-3FF5B4E32BE0', '91CFF9BB-FAF2-46F1-89A1-6BE2D5E02BF5', '4607041024529', '    /   4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5FEF8F2-65BF-483B-B108-6406DD4F24AA', 'E626ADA2-8C58-4110-9EA9-E72CA183BCB0', '4670010370323', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72B4FCC8-D625-4BC9-B3C3-01A988FE0021', 'A996CA10-B7EE-4645-B4A4-FBA8705ED300', '4607029296009                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0110E37F-D3A2-49B0-ACAA-DBFBC39A7FED', '1D5B5415-8FBF-4F06-8E39-59A73FC682A1', '9120029750227', ' Manual fn309 .. s', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A084763-FBFD-4B77-9E61-E91317E35605', '821B6E71-F9E8-4ADD-A346-FBDF89541680', '4607163095872', '  950   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AE9D224-2A46-461E-8D16-97B02C906592', '828BB85B-EE33-4D53-9DF5-B8286EE57D17', '4607163095773                       ', '  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF6117DD-2D7C-4C07-9848-EF8FE385D843', 'CCD25314-E68F-4A88-B6DD-1115F59B6D11', '4607163095704                       ', '  200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F73ED14-FEBC-4D0F-83E2-DF1CAA769E12', '0DD102AD-9D78-4A9B-9548-22715D358F28', '4620006500111                       ', '    100  40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('060A776E-D486-433D-A56D-D427D363C102', '948AE775-BD84-4940-9EAB-01477CBEB62C', '9006968003085', '  80/12,5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87BE738F-F84A-4788-BD54-F67ABB53FE29', '308A604C-71AE-4340-BDED-44FEEE5432D2', '4607015598193                       ', ' Siamed 60x90 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED199D56-C667-478D-81D7-43F167E8399E', 'EF61148E-526C-48CE-8B0B-A65D337DD39F', '4606486023852                       ', '  8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9100950C-51E9-4F13-8508-9B47832EAABE', 'BE918911-4AA8-46E9-93C7-B6B4C41899B7', '8594737192548', ' 0,1%   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11756B6B-35A5-4727-BA76-7FE2DB7B8F96', 'C73EC9E1-BC83-40A2-A30B-FB52E88C8C51', '5029053543147', '   7-18 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E92381D-B087-4BA2-BBCA-0F2F0A2C0214', 'ADF3718C-E1C8-45CC-A3D9-6C726800F02E', '4607068627611                       ', '      120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6999F242-BF6A-4B35-BA56-E67FA5BF5812', '5D5E2605-1FF4-4AA9-84DB-0EA1662876DB', '4603988014241                       ', '    2  100 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEEBAE77-6A53-469D-B461-112C829C3AD5', 'FBCC36F0-12BE-4F01-95AA-A1471894C208', '4605319005966', '     c - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BDD2834-EFC8-45BF-8D21-7B37DA4D19F1', '09CB31BE-9190-4CBB-87F9-C86CEEC22DA7', '3574660483550                       ', '  reach dualeffect ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65A7272F-A3FE-41B4-A041-D9B548B029DD', '51856711-D6B6-4F62-9490-4CA616925ABA', '4016369662229', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAE4799D-F9C4-4F1C-B4CB-B0164D3B8F3C', '4A5289AA-3091-4347-AEA3-06DA4A786FD7', '4670004410301                       ', '  100 - 3  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17076B5E-92C4-49E4-82F3-720964AA7B88', '9E96B6EA-B3F5-42DD-B1CC-C86233441EDA', '4605658230050', '      4+ /23005/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F73E87D-BCFC-426A-96E0-29D1D46E069C', 'C81504C8-8976-4FDA-9459-AF8DB7392343', '4627090491547                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B486128-A133-421C-ADFD-97D9BF3E5B33', '55B58059-85FD-4D16-9540-70370E935A8F', '4823060800306                       ', '-  .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('631A4FD7-04D6-4037-BF1F-8EC00C887706', '04607798-DBF0-4E42-ACF0-BA90FDD3EF2A', '4607078971131                       ', ' -  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84140E0E-BF53-408C-B65C-D7FEEBC573B8', '0FD52959-48BB-4021-9ED9-C309BD41F48D', '4607017642443', '    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('411C9B20-7B7A-44BF-9684-0605164CD67E', '187CD4DE-A92F-4992-ADFD-2652B0EBE850', '4605658175030                       ', ' /  6 /17503/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCE969FA-F6D8-4EB4-90D0-941CB2C2FE62', 'F0E23822-AA6A-4BAB-B753-0465A64CCDEF', '4605658250683                       ', '   /  .  (25068)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65FD167D-9DA7-4D53-8636-CBF91CED540E', '47F34C7E-F539-48F0-A1F3-D1139B3A0190', '4603726763011                       ', '-      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA74013B-3345-4055-9A1D-4CB0531C60E4', 'CB6F1E17-B5E2-4A69-80AB-8ADDE8C91FE2', '4603907000201', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BBDBB98-0E0E-47CE-B427-752311E60063', '06A69487-82BA-4944-B6BC-A1D4E38C958E', '4607024970522                       ', '  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02E2B160-6360-4577-9307-49B029194EC0', 'BA2B59B0-0D97-45E7-B90D-A38C06895524', '4030031898228', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE48ECA3-EAE4-479E-BA54-C2A6B27A2B80', '3FE4289D-7352-4D89-A58D-C61E382965E6', '4627074810623                       ', '-    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3145BA82-0145-44A3-BA1A-3CB83E4F4640', 'F9A2EC9E-F688-4F11-AD40-945D78CB0AFC', '4607055070208', '  070208    120.3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD939C52-F12B-4F27-9973-3CF3694CBB8E', '1115E27D-AD48-4266-AC6A-59D36FD66B3A', '4640001380211', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A737C39F-593C-48CA-B4DC-1032E75AAB2A', '3552A6D0-E3F0-450C-9BD6-E076665E09B7', '4607055563267                       ', '    5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82A53396-C9F1-4B39-B012-4E8C14CEB5EF', '966B9614-615F-4B8D-A557-BF98824DB6D0', '4605658174125', '  /  2 /17412/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D427CAF2-454C-49B2-9179-E711B24F1E11', 'E2BF3C94-0B12-47B7-8C64-117A165194C3', '4607050179821', '  /  / / sr17 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55E2986F-8CE8-4FA5-9A91-705B0C9B5B27', 'A63487E9-CBAE-4782-94FC-0C48EBFA5448', '4607005932310                       ', ' 0,05%  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89BDE609-FAB4-43F4-B17A-7D359F47A6DC', '3ED7FC1C-BE66-490B-A755-4C7DD98AA015', '4603922000019', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFA0D667-ECD4-41EF-832D-7BBE2D26DCBF', '8B4D64AE-29F9-45A0-B207-9755410C74FA', '4605108004750                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B5C3211-FF6A-49C7-BFE8-62A351829317', '31C2BEB2-CB39-4C8D-8D03-077891E29C74', '4605658120450                       ', '    2 /12045/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D98CB360-9776-427D-9047-6B20D59EFC5A', '353800A8-1390-4D08-B470-6F4B6F6F7B76', '5060038500045                       ', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('169269C0-F75E-4641-8A0F-EAF9655A2141', '4C5E91FB-4CF5-45A8-A98C-F4BF10B67E71', '4605370004151                       ', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21538897-4EE8-469C-A08C-C4580F698D63', 'FC5B7597-24B0-41D0-8DFC-34F88B82F9E5', '8594737200212                       ', '-  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDE4A520-6B3E-4937-919F-979803A5109A', '8291949D-F7DB-49B5-91A6-70F7C9B1342A', '4600999012273                       ', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D0FF669-47A2-49FC-B485-89259D18E535', '3EDFBF46-2424-45B1-9315-832B494B5D1E', '4049500585880                       ', '     55 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4FBDF45-E693-4455-AD72-A1443BE662DA', 'C1A10A77-2AE2-4E87-9827-7CF100AD5D5F', '4400498306824                       ', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16D42BE0-0043-4F6D-990A-0F5B3482FE31', '60F599A5-0E83-4C53-8F4E-9BB354E3FA68', '4660018602076                       ', ' -   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCE20256-515B-4361-9B63-3BAF6DC03C49', '164FA309-BA9F-4E7B-B326-57DAA144EF79', '4640017370039                       ', '   4 0,5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C88C107-44E4-4C84-9D9E-F6DE96445C0B', '2EF5B6C8-1229-46B9-A9E0-0DA14E66F2DA', '4640001382864                       ', '     3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F7C2CBF-DE3F-4930-B008-FFD97B617EB5', '3A28690F-341D-4EB4-BA47-780D873FC499', '4607010249250                       ', '911     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C249E31F-F9A2-4DF9-B8ED-DB8E82DAD965', '832B201C-2BE7-4D52-8CED-65082A9D0F4C', '5903407131092', '  . 0+ 13/109', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D2AB2BB-DD7D-4814-95EF-9626B864BC3E', 'B1357BB1-D489-4A76-ADE2-6FC0A86730F5', '4600286001911                       ', '   0,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('788F8DE5-6141-4578-A690-DE72999D40A3', '8E61DA92-CBC9-445E-B5F9-5DB361B8439C', '4601654000314', '   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('283ECFF6-1F6F-4C30-ADBE-5F5F1733202E', '535974E3-C882-486A-9521-F0E181DE0849', '4670010371252                       ', '   45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AD28C5B-6B20-4ABB-84CD-6082CEB2B0DC', '626D02DE-4EE3-4C82-A4C1-CE905A68F7DF', '4605108004811', '    75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7BE4E30-204B-4CF3-9529-EE2AC498772D', 'EEFEF182-A8FC-40B1-9E58-955A1B76BA23', '2000103611903                       ', '    0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C7485DD-254E-4CE1-8F29-FAA1D847B3C5', '3D533162-B7EA-4281-B140-43322C0098A1', '7322540764161', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AECDEF1-C51E-4429-8DE8-7914289C717F', '696E8A7B-9EEE-49EE-B32B-0E9F85B4D9A3', '4640001382840                       ', '     3 10 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4ACD243A-478E-4EFB-BB6F-863BDAFB9B77', '6DDD7D82-BD99-4E4F-A168-0683A8F01D22', '4620016304617', '  /     / // -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A0E91A1-3ECB-448D-86CC-D356300A73BC', 'A2769BD6-E17D-4689-8C3C-EE500125F285', '4620016304600                       ', '  /    // / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4D71802-3FBC-435D-B422-49989A09B8A8', '9CBC53B8-59F2-43EF-A5EB-80C2BAFE45D9', '4620016304594                       ', '  /       /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DECFEA5-69D5-4215-9D5E-0580075D41F6', 'DAF50CBB-47CF-4F03-838C-2002E2C48A29', '3101190806995', ' /     360', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F0A1E76-547F-479A-B062-776724C8D752', '3890FBDA-80D5-465D-A3D2-66C563C5E6CE', '4620016304662', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB96A3E1-178C-46B8-A202-7E384416FF22', '7598B170-39C4-4C83-9C80-AEE684131570', '4620016304655                       ', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1024878C-24FF-482F-92F4-F349D76D39E4', 'BD2D30ED-AAF0-47D6-944E-62747589B091', '4607174436107                       ', '  - /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('027EB1B1-69E1-4917-80CC-BF790D5AFA44', '3960400B-05FB-4488-B21D-0E9DC04EDD41', '4607174436077                       ', '  - /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC21795E-8BF2-4123-99EC-4317E69BF1DB', '5E103420-CAB8-4FC2-BAE8-C4ED3EED8BAA', '0361841025530', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1080B104-DC2B-48A8-9C7A-32D286F9500A', 'A24D8CFC-3059-465F-A382-5098E529F5CC', '5903407226033                       ', '    0-6 . fairy tale /22/603/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49D69119-4C9E-4B2A-9636-7AD705F7076D', '4D3B7386-851C-49F0-8C9B-7E8244F85597', '6417150005481                       ', ' 4   4 /  /   215', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8442E8C-E3EC-47B0-9EC8-AE67C297AB7F', 'CD5550C9-9B79-4CCF-A819-5CA1056A8AD7', '4607051797475', ' /    // 530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('417BE661-CC12-4936-87FE-617F4B37F6DA', '68521939-EF20-47C3-94A5-D53707BF68B2', '4670017926264', ' /      0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F14B398A-C755-42BB-8AB7-63BC5DEDCD15', '375629CD-4800-472D-8E62-D037184B2FD3', '4627090498591                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66E6F616-BAAF-474F-8642-9BCA247B17BC', 'CB820904-C589-4A17-9F31-C3375424D773', '4627090498492                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2D08842-F69D-47D3-8E55-26DF044309BD', '172F93EE-1F5E-4392-BCAF-875692E804EC', '4627090498065                       ', ' pellesana   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F81226BE-3F58-4A62-A9F8-B3D4D1109F3F', 'CAF5CBC3-7213-48CD-AF55-940D2889528C', '4610008495683                       ', '      10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDBD3D5C-E1DB-446D-9C66-5A25137491B3', '1A16EE79-FC53-4C11-B435-50CFF858841E', '4605927001213', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31738118-829B-4AAB-B7C0-3886F7AC7740', '0BA2E3CA-07CA-4B13-BCC2-1C370B2191C5', '4605722871523', ' 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9149163C-C01D-43E3-9B91-4B8D73FB38F4', 'AF4CD246-F09E-4640-98D5-67FAAF4801FA', '4623720904869                       ', '      006', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91A69D3A-ED50-47AC-9CC5-46F4A100F017', '4F225E2C-23DE-4601-9614-0F2FAE0DB2B7', '4627090497198                       ', 'Pellesana biohyaluron gold    -     15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('956D5884-011C-419C-B29B-175D933383A6', '5C592D16-1360-4A95-B4A0-85A703BDE5A7', '4607086562970                       ', '  -  /    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCF1A510-CA88-489F-B894-96027AA91339', '44394C40-3B19-4D31-80F7-7062B3689F49', '9601551000016', ' 10  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A23DE811-B4C3-455C-A89B-7C9CD84DC9D1', '371E21D1-0532-41B5-9826-ECBF96DABD67', '5060038500090                       ', '   80  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1AB218E-A1CD-47A2-87EB-207E632F04FF', '1ADD8735-B970-44A7-92F6-DC52886CB05D', '4605077010288                       ', ' 25  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CDFCD64-5202-4127-B561-8AF968467C45', '24BE7230-EE49-4E25-A5C4-61F916F177CD', '4810155001991                       ', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21420E64-A245-425D-93F9-AE9FC51A2967', '1D0A52E1-F0E0-4CC3-971C-5754F5CBCA89', '4620016300152                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEE62BCC-0DF3-49FD-B67F-749EC5C79C0A', 'F2E810D9-9418-448E-95E1-CF00443499AB', '4606677022909', '   6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CE8AB20-F3A3-4D55-BAE0-F8BD754FC710', 'E17FE2D3-2831-4450-96F1-630A8BCDA722', '4607059540677', '  1 35 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE358E1E-B550-4BA5-9D55-E522AC93B14B', '357824BC-9BCA-4602-A0A9-7452E6227248', '4049500340601', '    6060 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF86F17E-6162-4C10-B189-867F0BBAEC62', 'E8A2B3FA-F89B-4B8E-9A33-45285E345852', '4610008493375                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D954131D-0D8E-464C-A6A2-B000924B2DA9', 'F6E257DB-7ABE-4602-914C-CBDEFCF1F05C', '4019338000336                       ', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('334BD82E-C0CD-4701-9EAD-454699CFB7A2', 'C960EEA5-0072-407B-9B20-71F6287016AE', '5029053528397                       ', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('753F40E5-E8B8-42AA-9CE1-B6A794F4CEA3', '151A2398-4C26-4F28-BB4A-59B05BC0BE0B', '4607020901575                       ', '  7     2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6958CA38-C757-4793-ABEC-21CD1777F40C', 'A98687DB-1F2A-4331-8508-3E80BF2FFE38', '8801051068801', '  perioe breath     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9F83462-294E-4886-911B-75AC639AEFD8', 'BB1514D5-4E73-4786-A754-D99788B7192C', '4680018496840                       ', '     1,42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77A35471-5C7F-4A9F-92A0-495824573072', '6CA41601-5BEC-4770-9FE1-FDEF35AF2C5E', '5292452000867                       ', '   //    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C540466D-6ABC-487C-B019-EB06AA7B1795', 'DE1D2F37-4491-4296-9033-FBEE9ACF408B', '4601499003112', '         4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D713F56E-E5A7-4BD0-A4ED-2473BE7021C2', '184B0EEB-7595-47CD-8367-F09C61E2F70F', '4605126002547                       ', '  1,5 / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1692545E-4129-45DE-B60F-0DCA3FCE21F8', '6DD0ED73-2F9A-4928-86D9-0C7C313BA298', '7612367022163', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16AB7404-7DDD-48F4-A998-1EC6C0D1B27B', '0EDA3825-4261-46D5-A2AA-FFB296258D90', '7622210500212                       ', '   9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BE1F296-4712-4E15-B56F-0F7A379B6461', 'BCD27A25-2DD1-4998-A421-0D0620B764C5', '4680381010551                       ', '  16x14  10 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8228791E-4EE3-4A22-A487-C4CFEA096C57', 'C0A5FF0B-F8DF-4FA2-8B76-3D2F27224077', '4605738005752                       ', '    4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FFBE3F8-1204-45C8-B00C-FEC7355135A8', '3B685860-02A5-47BA-9AB3-CD25D91F1305', '8887786800497', '  LD-212C', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72545315-8EA9-48E7-BADA-902709735CA4', '7012261C-0C11-421D-A7DF-0D6F924FB7D1', '4680005640751                       ', '  / 50 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('521FBD61-2D27-4E54-A28F-165B14EEB392', '2D60902B-4146-4994-9FE8-1BBEF93503E9', '4607155640134', ' leiko 4x500 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C49D61D6-ABDA-4392-AD1E-70D98091B81C', '674A825B-EEFA-49EC-B0F4-36F0A323B381', '6958627514094                       ', '     ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A497507-7149-43A1-A066-0897A13DAE05', '6F371414-AFDF-4A51-9C51-73C3179876C2', '4607155641391', ' leiko  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C20F2C2-11F3-4C40-99D4-5B03FA00EEA9', 'D83BFF4F-5D0C-4D7A-82D5-994F5C466290', '3337872413063', ' r   .    , 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEE08D2C-E212-4E3A-97AB-F8C04F0BD87D', '2ABB95C1-008F-44BA-9D42-6471416EAFE4', '4034541003585                       ', ' 10+10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F99579ED-AC7A-44AF-B982-C3AFB748DFE0', '79008584-5BC3-461B-9473-E9801A9FA5DD', '4603988013732', ' 1   - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C06EF7B7-679D-4A34-9461-DCF886C59EB0', '5B00C084-72A7-4659-A88A-FDC064EC3241', '4660002690034                       ', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EF5A6FD-5D10-4F8F-B008-BAF1D8EB914A', '731C7194-0065-4065-916A-17A5DAABE0EE', '4650069780816                       ', '    / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('819EA02F-C996-4DF3-B4BF-57E453D64B44', '3A050DF9-9194-4AF4-A875-6148B0B8B9E9', '4605342002352', '    300. ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D2CCC82-525E-461C-91CD-A9834C170AC9', '887FF912-4551-4E29-87A2-875D4920E991', '8901138500306                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36D6D4B2-D7DA-44C2-8A83-E72EB304B0B2', '8872B6B2-C9C4-4DCD-B756-81F4255B3486', '4607033350414                       ', '   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B774BDD-0DE1-4473-ABDE-0241CB2B0023', 'D3E87B84-3C53-4D19-B529-11148DFF0D28', '4640001383526                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEB70910-2DC5-48C0-8F32-2D7B88828356', 'EC260ADC-B23C-412B-B946-5B238DC90617', '5903407231020                       ', '    2    6  23/102', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BBC4FFD-C659-4FB1-86C1-A6FB7823323D', '6A28E2F3-0B11-4833-9FAD-0C2990A5C101', '4603720251033                       ', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('438FE506-265E-4BFF-8508-A600E5A69DCF', 'EF6E0C58-9717-486E-A1B6-405BA99CE292', '4823060800214', '-    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36F9DD64-A45E-411C-ABC0-8F9469ADB50E', 'E95660E9-5677-424B-9F73-840C97C46A01', '4008600155492                       ', '   -   18-36 3     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFEBB7D2-59BC-4B7B-8D41-D313A5A48ED9', '475E7B8B-30B8-4197-8442-4E4D619776E2', '4601772002474', '   40 4    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B656F15-E0AE-4580-8CE1-BF2406C69BAB', 'E0326FE2-1E21-4352-B077-0057B4F2051D', '4630009189343                       ', '   0,2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDE6EDB8-AF82-4242-968B-D17DC76F2C72', '3B1E80D6-6690-4B7B-8321-6D833BCA802C', '4640013557984', '   - 0+ (16581)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('648CA3D4-29C5-43F3-A11C-FFA1E9299494', '770F8A68-3970-4F82-9558-DB7A163C3A8B', '4601835000355                       ', '     3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F97D6563-3ACB-4186-8C1A-A3FDB48C917D', '37AC3318-58DE-4982-BCCF-D16B9C9817A4', '4607020901537                       ', '  3       2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63BED20E-23F1-411E-B76D-4AE920DC8725', '9F7BB40B-A912-4A2B-B231-E05DFB6F8D44', '4660007703197                       ', '  15+153,5  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01C10265-A551-41B3-BEE0-3260577C7F41', '2D16193F-FE90-47FF-B8F3-2FBA00804D0B', '4607003245887                       ', '  16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A59272A-BF16-410A-9580-10AB59265E59', 'E1B90AE5-8812-4F6B-A1A3-C80205FDE4AD', '4606711100259', '   2,8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7413CD3-D159-4B58-B3C1-1A9DCAB39DC3', '805E2D56-45CB-4BB9-AE2D-7329D6159A29', '4627084350034                       ', '    60   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10BB55D2-E677-414D-8CEB-FEDB39BAE364', 'C4581BA6-A2D5-4654-BECE-C5A5E3245E8F', '4630000892891                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7612163-1C92-4BBB-B497-E5E7BD9A0992', 'AD75228F-649B-46DA-9B79-E83009F5D579', '4603988010373', '  200/ 5  10 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C42125A7-9610-4B2F-9C90-712803BE8E14', '4D5463E4-A766-478B-84F6-58A0B7CF722E', '6950570782513                       ', ' Arlette  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C5E0BF6-63B6-4B6E-AF07-4A241F0A9278', 'D41390EB-36EB-43B2-A5F9-E5120C82A681', '4680005640485', ' 714   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1779DA1-88FB-4220-AB99-4E674C9C8C72', '217D1EFF-58FE-4F1C-A49D-1A595EFE89D9', '4607083728409                       ', '   2,3x7,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B7D23CE-E248-428D-84FA-95907FE87C36', '75F13C91-00B0-43DE-8A5D-A4F7547E050A', '4600338006703                       ', '  200    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5134AB27-884E-4454-B925-06F2AD024BA3', '069C0594-3D90-4FFD-96A1-AB852F057BA4', '4607097010545                       ', '-   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E512E913-B576-4D2F-BDDD-FCAF26266663', '20092103-0308-4465-9077-4FC98F17A92C', '4601498009306', '  3 2 / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22282496-636E-47A0-9D75-CF91E4CE3953', '76AB8859-808C-46B6-893B-194C97600208', '4605086011313                       ', '    8x150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27D9547B-8818-4BDB-8CBF-6515CBB05DC8', '77E7FABC-64E7-48DF-AE67-B29C1B4CC052', '4607003241964                       ', '  7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B36A734-A3BB-40FB-BEB6-F1EA13A57626', '3080C4A2-5B86-4B64-A553-45F34C136FC3', '4600999012280                       ', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BE8AE7B-7C45-4A35-A7EA-24A3905BC582', '46710472-F368-4B99-BC1A-53BB6CF314CD', '4015630063956', '-  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD55F9C6-140D-430A-99AA-EE919D034BA7', '4419473D-7F07-4C84-8904-2C476FC6C7C5', '2910015070012                       ', '  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E0A8E75-BAEA-4ED8-B194-062DA5ED0DE0', '84DE00C1-814C-4B77-A95C-070BF1F9F393', '4610012372642                       ', '    6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF3F6919-D298-4055-B95C-BE1B71ED5E07', '2628B0DD-7095-4A15-8F54-BA5CA3872C3D', '3574660020502                       ', '    wonder grip /6-12/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B18A6AF6-1843-4A85-8C41-0DCDC22C3A09', '87BF3DAC-48FD-49C0-82A2-AF1AB9D17A05', '4627129211191', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFC9000C-E0E7-4803-AF93-74640B66B968', '21267FFD-F135-4EA6-B84E-774030E5D445', '4605095008144', ' 0,1%   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D99C82A-356B-496A-88C2-3009CED95254', 'F9C744CE-B93A-421C-B632-FEE793BFDAB3', '4607069270038', '   0,3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A254E3A9-1641-4D35-B90A-81F4669608B3', '92689060-AC16-4687-A667-94022BAF3B04', '5060040304051                       ', '- Contex Flash 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76835882-2356-4C34-8B33-56DB4ACD8EC7', 'A999B915-6BDD-4571-9D3C-B2F74EFF32E5', '4607006490826', ' /  1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D00BE96A-BACD-4349-B8F0-3042F48AEDD5', '1BBF9F8F-F134-42AE-A7E7-86EBC8397A36', '4823060800221                       ', '-  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F003970F-49BC-4136-B518-7265C30C648F', '4C0866AC-B221-4F50-9FD0-FDF80303B930', '4630009180135                       ', '  1  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A4EAAC4-7568-4817-BB32-A60EA705A04E', '48AF0011-FCA9-4932-BCE3-5B2455E3F1D2', '8992781250311', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8000130D-D119-4A82-85BA-2737A0E6A4BE', '3E4232EE-2C06-4107-947A-A9741D7D235B', '4607020801035                       ', '  3 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20BB27A2-1A51-4D1F-9D73-78EA13CF3926', 'E88E2403-84A9-47A9-B96E-17E8A98CF921', '4607085315751', ' 40  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAFA6674-2621-4B21-98D5-26CF1C99640B', 'AC84B4A4-09E3-419A-95CE-C0D0C66C6270', '4640001382031', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76A35796-01A8-4D45-8A7F-656FE39CF19F', 'F9F40599-C85D-449E-8FE7-013FCBD21C59', '3838989502317', '- 25 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F902B6C4-2B2E-4213-B5FA-41B031507610', 'CE632E7B-17BC-4786-95CF-3C7A3DD958F6', '4603988009919                       ', '  20/ 5  10 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A6B503A-08F5-4C74-97EA-F5619A06E57E', 'EE2237B8-E80B-4226-805A-8289107EE4C6', '4652655546363', '    .   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4EC3D2F-D42E-4403-8947-62169B2842F8', 'ACCB0FDE-BD3B-4A87-8160-7DEBAF2576EF', '4037353122000', ' 500  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09CA88EC-5680-44E9-A3B6-029F4E1D0DB8', '9CAB1C39-C64E-48C6-90CE-2FC326998B1E', '4605077011643', ' 25  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAC49C88-4EE7-49B7-9EB9-3970C17A6DE1', '9129D6B3-AFBD-480E-B595-997793BE9548', '8588001193621                       ', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4021154F-EFE3-42F5-8927-7B1A593D328B', '9325FD3E-EC45-42F2-B1B0-D07B31153183', '3850114235044', '  3+0,03  63', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14A9E735-FA50-4763-924C-DD973B7C9D9E', 'A5F04F09-F3BD-4D9A-996B-9EC30C049A3B', '4603695003972                       ', '  50  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D63818ED-C037-44B9-AACF-12C043FFCA09', 'BDD881A2-50E5-40DB-A6F7-CA7DA53B8550', '4680013246860                       ', '- 10/ 1,5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A05BACB5-02F6-41D9-A12A-C95D49485371', '59F110B0-906F-4746-AB58-C97FEA2F3DCD', '4607106002165                       ', ' /   /meridian/ / 25/ 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BFA28B2-FDA1-4226-A31A-5F3066E99E93', 'D463D735-B093-4955-B126-2F0B7D174D7C', '4607329893045', '   1,5 20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15005741-3577-41E4-866F-1DC66DEF428E', 'AC72E757-FF29-49D5-84E0-9937B4386ED1', '4015400278849                       ', '     5 /11-25 / 21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D78DBC1A-3CB6-460A-82E0-90E2F7A442D1', '2E44FC02-C5F8-4E77-A94A-8180BFEC5B1E', '4601834001902', ' /  68 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A56BB3C5-64BE-4A2B-9433-2AB0ED1BBE46', '68E7D156-15B1-4A95-8CE9-767DFD031523', '4612739990017', ' 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDB30751-C277-4887-A2FA-09D5030FBAE8', '9AA8D729-4647-4550-836B-C6D92635C1D6', '4607011664281                       ', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('022F97F3-DFF7-41D4-9EB6-FBC9C287BEA3', '1A692930-DA29-4B1C-BD09-7C8400628CE6', '4605658121334                       ', '   6+  -    12133', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E9029CD-E6A0-4A2A-AD10-0836DC82BAB5', '7F3CC8E9-B4AE-4271-A329-A36B6954C92F', '4612730251124                       ', '-     /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66C33580-6BC0-4425-8087-783FF7DF0AD9', '460B1828-AEE9-4F56-8A34-8BC69503F38B', '4607027769437', ' 2,5/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8FB3B0C-CECE-4EEC-8CED-B850C4563E40', '2F947C86-C900-4B09-8EA7-961A1BF89BE6', '7322540613872', '    3-6 24  /6/2572-01', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA6AC1DB-0C21-4A26-B99F-2D1FDFF8D552', '020D26FD-034E-450F-8904-C91602A3376B', '4606486021346                       ', '  100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B371B91F-EDBA-4C34-BFD9-4063D7992299', '6E32ED40-0786-4C3A-A386-F25EECFDD771', '4640003260375                       ', '      2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE7ED30E-3650-494F-A4F9-E7A8AC7DBF5F', '43EFCEA0-B7DB-4EF1-8DAB-36102E8B0606', '4607051910393                       ', '  500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('174D42CE-B57E-4F00-8CDA-29480DE0E0B1', 'DF917CD5-F6F2-4663-9E72-D2422A783D66', '4009932557312                       ', '          15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1A1B037-CC4D-4891-9CDC-49646B15147D', '878C991C-D044-42B4-A77B-CCBE99FC84B9', '4627108140436', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('896319DC-7C7D-4928-A720-A80E4A20DB5F', '5FF7CE2E-44C2-46BF-AA4B-E81697898933', '3700281702583', '     /  1 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72AA5758-2B3E-4DC9-AA60-18F88299DEFD', 'EDFCEB6F-4EA7-4DE4-946C-CC2701DE7605', '4902011751406', ' -goon / /12-20/ / 38', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A24A3D0-038D-493A-8268-BEE0A5875015', 'F33CB3CC-A8A2-4074-A1DB-FDAD5942939A', '4053800083724', '  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82B977E3-DA93-43BC-81CF-AF8954D5C2CD', 'C9F0F080-D5FB-4390-A850-CF4B5E816C68', '4607106002127', ' 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BC1BE37-C1E3-4DD3-B8CD-8779BBEE5053', 'CC388865-78D0-418F-978B-2B0D5D4CF40C', '4620002182014', '   100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EB97BF1-7C85-436A-8850-14E08C7BB7AB', '616AD180-A094-4A01-823C-CBB034C32FC7', '4810155001960                       ', ' 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3C77F03-B3C6-4997-86E1-EEDD22352FB9', '37224825-11F3-4129-B085-D995093030C4', '4627115160014', ' E 350  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE840B59-5DF7-4B71-866B-C9207753D1CC', '317705A1-658C-444E-8239-9DA77733CE2A', '4610017750926                       ', '  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('510EB412-D98D-49E5-BF21-C10893584E84', '5A2C61E0-6481-449E-A5CF-F45CD3AB8B83', '4605658175092                       ', '  / /17509/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24E7B2A0-AFF5-48CD-8A1E-DC711C8171AC', '76F8EF5E-10F5-4BA5-BE8C-5743973217C1', '4607071771936                       ', '   20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55534056-59B0-4243-9ACC-30C6EF40067F', '7CE57427-4299-4998-A9F4-6C44DF6B900C', '4620021520446                       ', ' - omega 3-6-9   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADDF45CF-4A95-4E2E-8429-E33D0EDB41F7', '26391594-EED5-4674-9B9D-C517C85E9079', '6417150005528                       ', ' 4     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A366EFDC-38E9-476E-9583-E798227F95A0', '3F275F7E-6575-4B29-A6CA-BC036353140A', '6417150005498                       ', ' 4   /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E8B1650-E850-4ADC-9C79-6C0DD8861208', 'AFFF4EB9-BA95-4999-8C6A-68993CB7E5E4', '4620002185237', '   - /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F21624E1-AC3A-4294-82AC-ACAD5EBAE2F8', '3EAB4A70-2FCB-4B5A-A243-C87F76FC4E25', '4607086569399', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('175A396F-58ED-48A0-BBBC-E26C80696F70', '4E40DEEC-81F6-43DB-AFCE-DA81F1C2D099', '4601593001540                       ', '   /  0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('508FBF28-8059-4B68-B64D-EEB99B93E9C2', '3457AFE2-54B6-4CD3-A310-1D1B65098C14', '4605086011351', '  85   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD095079-3F46-45B1-B283-E79A7B6F4AD3', '5C49DE2C-0C63-428C-B4CE-4932CCC96804', '8887786200488', ' LD 23A   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8365BD53-ADFF-4AB8-A17D-6665A4098816', 'A38930C9-FCF6-4FA4-AFF1-95D0F95CA9AA', '4602565028251                       ', ' 30  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E988B6D9-8BA6-43EF-A132-ADB1BAE66648', '979672DA-0D6B-4A9E-BDD8-395A291D85AF', '4607041024062                       ', '    /  330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98FD6437-0F45-40E4-A5E9-B8B407BF513B', 'CA7A0ADC-097E-455D-A88A-DFE4D9505890', '4030539060639                       ', '  5% 500 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('707BA703-E029-469E-B765-B181972F1132', '96FA539E-EBC5-4A49-A717-53187CC56045', '4602212000999', '  2/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A44AEB8-6E27-4328-A299-C48EEF5C770D', 'CF2FE666-B38C-4091-B5F3-7BBFCE48860F', '4605579004273                       ', '   99', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A107549F-EBD9-4481-B678-58B9CBAD1A2A', 'E6F66530-5C54-4AFD-BE54-B5FCB3698281', '4049500952248                       ', ' - 4x10 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F9A0316-AA68-49AE-85DD-3D5F881D3E1B', 'D0281651-D2A9-4D11-A167-AF39342A8ECC', '4640001380075                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F275448-4A34-49A4-ABC4-2EEBC575D1C3', '77397787-9F31-49D7-BB70-2EDC78375B71', '8901148239951                       ', ' 40  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4B8152B-2493-44F6-A962-69C7A1838CD6', '51083C54-6B55-4110-9F21-B4173ED51911', '4620020890434                       ', '  home   460', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2434E395-CD7B-497C-B78C-AFDDB9C0067B', 'D3171A27-ED37-4C74-A6C8-4F300D1DAE5C', '4614171100191                       ', '  /     150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB9C86EE-C973-4DAF-91D7-8A42CAFE220E', 'D0A5705A-47F7-40CB-B997-3A85BF94B3DA', '4751018120384                       ', '  /     7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('467416CC-FDC4-48CD-93C5-8366B6282BA3', '5F415005-8EE5-4BFA-8F2A-E5B09C36E3CC', '4607174430501                       ', '     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E291F4D-6B23-49B9-B0FF-85E43E07188E', '5F58DF2F-0CA7-4859-B6C2-22400ED6592C', '4607174430518                       ', '   / / 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D75D0C8D-F815-4E47-9C80-1C03C5C3F287', '07FA2E2C-F8AD-4CE1-875E-7DD506A8E652', '4607174430808                       ', '   / 400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('612B088A-E43B-46FB-A97E-A40420069C46', 'E0F650D7-A8D1-4570-AAEE-46815DA16364', '4610008495348', '       40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E625A752-4FDC-496A-B51E-3ECACA1ED9D9', '67D79B29-CB66-4D03-8C3B-40D2BB96964E', '4607153456256                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB1CA75C-7540-478D-ABEC-6B9075F79889', '77C45ADD-841A-4A3E-9A27-EC61F1DD814B', '3282779206303', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07AA5878-98CE-491F-A934-7FC419AA9F2C', '0CEEA71E-FB5F-4067-B8E0-D9F9E3FDBFE3', '3800212712619                       ', '- -  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB656212-2987-4D91-A809-853D79D619F4', '2891B200-D316-4B98-BA31-EF337948E8D5', '4603014001870                       ', ' special     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6E45E78-927B-4CE8-A045-5EDA2DC833B2', '9134FDB1-ED22-47F0-A3F1-5F56AAA908E0', '4680005640812                       ', '  / 100  - ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7813EA62-B3E8-485B-89AB-84FFFE1AF5DE', '4A6A7F37-1C4A-4B1B-9BB5-66D0102CAEC0', '4680020180942                       ', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('263A08C1-23C5-4C3B-BC1D-A8679C4BA7A0', 'ED1E4C69-3ACD-469A-8467-098D0F4D85A1', '4603988015040                       ', '  500  48 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C390E761-6881-4C62-8F1E-9A576A431249', '411D3A71-5C13-43E6-9F2A-716A81E06FA3', '4627079640157                       ', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB548F79-780D-4032-B634-B32A2DB07FC6', '298EA8DB-8FF4-495D-AAAC-6AB7A82713B5', '5036519000991                       ', ' 50  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31F4460D-FBD5-410A-8AE3-43BDDA4FDADE', '34F2CFED-02D7-4706-A173-84EBFB16FA3C', '4607008960389', '- 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FB39692-86DD-42FC-B0BC-23463505BEAC', 'A4DEF077-B16D-4541-9142-ABFF7458CC1B', '4607061252636                       ', '      35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48269672-2C55-45F1-AABC-4652C12433B8', '184FB67F-D285-4BE5-A7D9-3405FD9A166E', '4607061252643                       ', '        35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17E9C75D-FB91-40F6-A993-1F55722203E8', '81CB290C-1A88-4A6D-B162-B197A32BF019', '4607061252667                       ', '       35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E42CC79-0B0A-4B83-BDC2-57E7B2558642', '89AF3DF3-6A7B-45CE-A149-7C9A7DFC83DF', '8030009762113                       ', '   .6211', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AE9F2A6-6DF4-4636-837E-904BB900B77A', '90A2A26D-7093-4632-A804-1C9AD55172DD', '4601969007497', '- 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E47CC71E-DE08-4C27-9D3B-A02B5F3401B8', 'B7EDB5B7-8739-401F-8FE7-04E13110D927', '4602676004878                       ', ' 0,25% 5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C64936AE-40FB-44DB-9A46-DD05E76C1260', 'F58F1ECC-01CD-4D89-8A65-044CA89AC022', '4612613500141                       ', '     2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0BD3EA9-060B-42AF-8A92-A9B1C6CC270B', '68707436-4F25-44B4-B602-DFB19D598E1B', '4606711484731                       ', '      140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFE60541-9602-46B4-B0BB-3887122ECCC9', 'BD12FF8D-FF7A-4FA0-9F30-8044D2324850', '9001505002163                       ', ' 400  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8248614-69BA-4822-80EA-DB792260C8DC', '3828914C-C256-49C1-BE0C-376450E7754D', '4627115160069                       ', ' 21  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04EF8C08-2694-4F59-BBC8-2FE8A6B8CA7D', 'D1FE45BE-37C2-48D6-850A-5184BADBAEE8', '4601835001604', '  /. 17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D752C44D-CF91-487E-A9F9-4EB33F1ECB31', '81A7053C-9894-4E17-AF1F-9D84766ED02C', '4607094170099                       ', '     6+260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50AF6D8C-AB28-4413-8195-C952D576E8FF', 'AEC0AF1D-AC9E-47DA-84DF-C43EC13832F6', '4601498002017                       ', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF84A995-4ABA-4A24-A139-FE174B962082', 'A38FE5A2-C104-40B7-9C2F-3D8A418A4EBD', '8600698007569                       ', '      15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9AFB823-E067-4E68-9358-80F6E7A32827', '7194B32E-FAA9-4515-B57A-B56DAE6D4D57', '4660000410368', '  . / / /..99-109/ 6 // -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0B1EE59-6812-452E-812D-4FB4DB437DB0', '8788E1CF-34C4-4FA0-8BDA-6500662FB3A5', '8850567105319                       ', '-   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDC3785D-89E8-4D02-A778-4FA2EE0F4D8D', '96C7ADD5-D73D-4D96-821F-5EBB11F12C8E', '7322540796582                       ', '   pure  42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60DFDCE1-508B-4015-862D-F548E2859435', '5FB706EC-9801-4A84-83DC-F8F4B4A5C1E2', '4053800411435                       ', ' /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27426212-3E8A-4AAF-857B-4C979566AC0A', '42DC3C89-8868-4A0E-B1A3-3277524A8EAE', '4680007630477', '   20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8FBAAE3-10AB-4544-AFB5-A8395FF022D5', 'D723AE1B-7C52-4170-8417-F3D00FFCF70C', '4607014000260', '    26  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E8ED4A6-1C18-4A79-93BA-FC10F14E583C', '47F733F3-8F97-427D-8352-702ABB0B324F', '4620002185602                       ', '  miceclean  / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA8568EB-40B2-4769-8FF4-27BC8D57F8C7', 'F0C1B152-26E0-4415-BB7E-17A4A1FBDE41', '2000103611750                       ', '   animals 6-18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2218FC35-5F0A-4A49-B679-21F26737F4AA', 'EC3A7684-3DC3-4965-8AF0-49281F35E413', '4640001381881                       ', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BA95B21-6E66-49A5-920F-14950353DF61', '37281F0A-7A54-4642-8084-4CAE2ECC7D15', '8594737211416                       ', '-  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65C8337D-9FB9-47CB-9429-75167062A95D', '006F04BF-8877-416B-8BB7-B47D7C6C871B', '4600828000365                       ', ' 2% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBEBFCB2-30CF-481A-B36A-E0B71BE4B3B3', '832FBFE0-130F-4FB6-84BA-14F67092C563', '4049500952125                       ', ' peha-crepp  124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C2FD77F-5B43-4BAD-9EED-DB85438A5548', 'B8D53A62-034F-4B87-AD63-D5DBD6C06CDE', '4605964004055                       ', ' 100 0,02/ 5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5ADE8882-CE30-4CAA-B8E5-E915D4D63EDF', 'AFE37CFD-B387-4193-BF72-542F1FDFCDF8', '4607156611096                       ', ' .  //+//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EE43AE6-8BB5-404A-94BA-85FF4B7C134D', 'D9D5AFC2-172B-4FB7-9BF4-0EA7FD0B7D5F', '4601907000665                       ', ' 100+25  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42941DB8-6DED-4C27-8499-46BCD93F0A1F', 'E43A8517-1B58-4055-BB05-19ADEB6357E5', '2000621489572                       ', '   /   (   ) 8  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BDE5EBB-FAB5-45F4-862A-4D1809AA93F1', '267D0251-D51E-41CE-BB09-0A6D9F8ED6EE', '4603631002069                       ', '     3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A82611C4-245B-4CC4-8867-A091444A0CDE', '1DC6EFF4-5828-4BCA-B94F-05568F12C318', '3282770037364', '   /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F2B8D61-C9F7-45CA-9959-1A0BAB51F927', 'B7C0534F-0556-4097-A488-630FC9632236', '3282779350679                       ', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9229A114-9F0A-44E3-AAE1-F7BD2BFB293A', '95D59733-9253-46EE-9C8B-918BC8F95D2F', '4606033012049                       ', '  /. /zo-b-158-fd-sh/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28CE43BF-821B-4D90-A280-68495A8C2155', '9A76D84F-D0D8-4E5D-8C38-AD8974934DFE', '8887786200464', ' LD 22 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32592A9A-2D2A-4C96-BE11-CE2DFF0DEB11', '800A1566-166A-4E2D-99BF-D5A3C8CAA625', '4601017477708                       ', '   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21303BC2-C212-499E-8978-DB09C6666BE7', '42888055-DC69-4926-9FAA-2241E6E0B33F', '5060038500205                       ', ' - Medium(2) 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83229AB2-1489-470A-9290-A4BC403B02E7', '04E321A6-8DE4-4D6D-BBF8-AAB1CBEEE244', '4627079830442                       ', '       250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DA111A9-AEF5-4A29-A31C-713E6B2A55E6', '04BE7189-5496-42D3-AE02-51CEC1E33417', '4260202923477                       ', '    L', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA7F2ED0-77CF-4AD6-8A6F-BA560AE4F1D6', '720A017D-A34A-4E1D-A720-A7D520D006FA', '4010439203602', '   4    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E94D0D5D-77AF-4E19-9C3F-584BDF5A55AE', 'DFA671EE-0E04-490C-ACB2-3310258784B2', '0837524000380                       ', '      150 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB5DD244-6036-4BD0-9968-3BDAE1FB1D6A', '5EF21B99-778A-47CD-B1F8-4E2BE35B79AC', '4602866002059', '-1774   (S)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14883491-94D2-4EC7-BA31-84D6206C56C2', 'AF6D2DBD-6965-46EE-8FD7-BE47742B52B5', '4607078976174                       ', '   -3  180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BC3B36C-DC29-4B16-885C-FE31BC65BED0', 'EA10E663-AD3A-4277-A7B3-AB9F54F10502', '4627129212631                       ', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D51BE24-8769-4D31-AFD4-6472B6C25E2D', 'F26B2AF9-EF1F-4D61-96D3-65D73A9A56C7', '5903407183176                       ', '       /18/317/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('150287AD-9301-4D64-B010-DCBAEAB0140F', 'AD5BA6B1-7387-4A3F-AFBD-2AB312316DD4', '8901148035010                       ', ' 10  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30B52077-0511-4AB0-AC6B-92CE38EE7CB6', '7C59F896-744C-4A40-B177-D983DECEDB69', '3433422403765                       ', ' -   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43167CE1-973D-40E8-916D-CEAAE90ABD58', '6DFCF6FB-80B6-4D5C-A1D9-D631F0A83081', '4811124000922                       ', '  /  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65FB6A14-3023-4559-A718-94F8E4C79973', 'EFCDE149-B841-4527-8BF6-8D482ACA0394', '4612751230115                       ', '  / //   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('889189EA-3CDB-4CEF-AFE0-935B0FD11CE3', 'D478D74D-848D-4F32-97E4-E6CF8A125F97', '3760102850473', '  /   spf10 7,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C2A20AD-F8A6-4B83-80AD-491595912B1A', '36BAE275-C492-4558-8216-3F8D658BD3F2', '4606677128779                       ', '     21 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B52B20A9-8FC1-4E5A-85F9-4278EECB85AA', 'A340FB48-D5DB-4DDA-9765-9B1DF5F48B4B', '4650001790804', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67B1C5F2-541A-4347-9339-D8B17CF2E5DF', '0D20BD75-BB14-4732-A2CA-0BB32E64ACBF', '4607027219949                       ', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72068F3B-2873-4F60-9007-386263823A35', 'E813461A-8B1D-4A6F-B3D9-EDF033D65B16', '3337871324346', '   - 10  &  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBCBCEE4-DD59-4399-B7B3-22F63E4F4522', '07A6FB2D-1EA2-4E38-9C8D-F991427CBBA4', '3337871324629                       ', '    /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F844E77-40CE-496A-909E-82541D2939C9', '105B1687-BD67-4126-9047-20297F347A70', '3433422404403                       ', '  lrp 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('668EC734-AC79-4BCC-A7CE-F837C152D329', '602366DC-15C6-413C-8422-3E2087A94888', '4607051798199                       ', ' /   /   530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28013111-02F4-411C-A9B5-31FF367D5AEF', '147509A0-BD4B-41A2-A50C-827238A60BE6', '5900095002956                       ', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F218C05C-4DBE-44EF-9048-55421E564331', '9BBAEFEC-8D42-445E-A6C2-1D4574A6B74A', '4606486011132                       ', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3219F10C-36FD-41BF-AF2E-9E2368EA9DE8', 'A7D9AD65-BDB0-419F-A51C-CD96167FBCB2', '4602689000553                       ', ' /.  . 10  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('172A6CB0-790B-406B-9E8E-88A3B7EF35CD', '22DFD31C-1BB7-4C9A-B55D-97627B1344E1', '4607068620421                       ', '   20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4CA553A-ECDE-438C-BC37-D0F5D3011D5E', 'FCEDB9BC-AA61-4930-A5C1-BA30AC263DBF', '7290106065116', '  500  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70C41CCF-33D9-4BBB-A5C7-371777D7AAC6', 'F089AA4D-C6DE-43DF-B3E8-1DEA1BC90AB9', '4607015595697', '   6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CCBB040-90E7-435F-ABDE-08306A1FB949', '856DB716-FD28-4DCE-AAFC-CEC782B9B7A3', '1626918020917                       ', '-131 //  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9382BA3-4AE2-406E-A720-12FAA150800C', 'A90D42C3-984C-447B-9F56-061683BCF30A', '4640001380303                       ', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA4F7B22-D3BB-414A-8415-EFFC530EC02F', '4C902BFF-200C-4C0D-ADFF-AE392DA67CD7', '4607118050208                       ', '  ./ 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF5B88DD-FBEB-4921-81FB-AEEEF2357930', '0BB68BC2-B0DA-4511-A339-A49A197E78F1', '4601164000859                       ', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52907BFC-F2E0-4716-B740-8DC594CF8F22', '3C2704E3-4C05-496D-B77C-5B6708F10C3F', '3574661287539                       ', '      500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E9B8DFB-1A04-40A8-9C38-BC513E0C0226', '165F791C-260B-464D-A809-BFB0C8A573A9', '4981046250153                       ', ' A&D DT-624 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4753A674-2412-4723-9106-0543B86076A9', '8B9C4392-7521-4768-9383-DF4ADD681DD3', '4601969007480', '- 12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFB4DEDC-8883-40EA-A411-5869B1DFA7C1', '98E6AACE-AB14-4C4A-BAA5-C3379968B1CD', '3014260094584                       ', '-   neon  40  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC2324F8-062F-4535-93B6-3047A611498D', '7A129C51-B277-4794-9E9D-5B5CD43E8D31', '4607009581194', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDB144F3-81E6-498F-9510-5A4D3EC45DDA', 'D9717667-DCD8-4FC9-B4A2-43F286188ECA', '4650001793706                       ', ' E  200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08EA441D-B221-40C7-89D4-6410BEDA072C', 'E5FF5FBF-547A-4E52-B997-C4439C9BB681', '4605319002606', '-  204  / 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('478ACF15-0AD4-4A74-95B7-11EEBC1E89F4', 'D054E0AB-22C7-4CE9-B09F-057FC1AE868D', '4049500585941                       ', '  .  7,57,5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48C512F5-1C4D-4472-B6E5-0067640D9506', 'EB9F0532-D9AE-45AA-ACB8-6F0F4EA5A0FF', '4627074841542                       ', '-    1,3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('989817E0-BEE7-4DC1-94A8-CABEE9CA23F3', 'FB460F3E-6892-483B-AFA2-9EEEE832B6C8', '4049500340823', '    6060 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8645B594-AA11-47ED-9B63-C62D6BAE7AB0', '90E306FE-F820-471C-96DE-F4563589FAB7', '7322540369335                       ', '     l /710333/ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A417BD9B-BDF3-4DA2-A617-C41F5B60F73C', 'A82B0B42-2CEC-4523-A2FC-7EEE53EC452D', '4607027767600                       ', ' 0,5% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62CF2A3D-4670-44F1-81C9-0E387383FFE0', '597A65E6-2D57-4B6B-A577-53A98BB3079A', '4600999012143                       ', ' aura  bio  /  +/ 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('527D9F06-0A4A-4B48-9A07-D0A0FBBB005B', 'DC4DC0BD-E6FC-4855-BAA3-3384546811A6', '7090014463888                       ', '-3   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('022CA884-7CD9-4F28-86B0-E2B1FD4D9ACD', '1CE813FD-2A3D-4DC5-BBED-DDA0DDF7EAC6', '4605658175054                       ', '         20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9808E128-1576-4338-BD3F-2DFCAFAD95D6', '7619DDFC-72E6-48D2-8E87-80A83DFB3FAA', '4601164001504                       ', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5546CC7A-AE58-4CD1-9301-A80E2E53AA21', '7D62CB33-B33E-43CC-82EA-B98418CD1038', '4680002554112', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8572367C-4C90-4D93-A128-9A48E3F9D97C', '0ACCA2D2-6F83-462F-88E9-5B49F3D2A479', '4601661000666                       ', '  50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('474A2083-3D57-4F21-A4A0-8072085FEBD7', '3BB75824-FD19-4F67-993B-1BA5CB698842', '3574661345369', '    /   300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2618B860-7844-4E74-B9EE-D1078C929304', 'CA3772B8-31E6-4C40-A817-7AAA86FAF750', '7680153989006', ' 100/5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07324F34-3B4E-4979-B4D1-FF8B80A99E35', 'E9151393-3758-4731-A6CC-27FA29FE006A', '4600665205169                       ', '  6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3943983-0BEB-4CE1-8850-C25CA9806476', '54F7E4AA-47F1-431F-802F-8864FA1B0BEC', '3662042002779', ' /  0,15% 10 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AEF497A-FCEC-4311-AC07-4A39B4BFD884', 'A0430653-921E-49B8-85EC-92FDB69D01B5', '4607111278746                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34D75A53-0B37-43D3-BFD5-3E7533653AF7', '57217E4C-D04D-452C-8817-83311E6E46B6', '4607152730166                       ', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0DA1A4C-88AA-4844-9116-A47B2A9ABC5B', 'E48D6C61-C445-4AD5-BE17-4DDCC7FFDBC7', '4640000902988                       ', ' 710   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69EB0187-B440-4DAB-A890-D9F513C56B09', 'B84AB9DF-FFB8-4EFB-B310-42998EBCD223', '4602656000708', ' 100  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B067C2F-F9EB-4490-82B5-616EA19071A6', 'FA231F69-DBC4-48C1-AD61-8DF96111B367', '4627079640119                       ', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB218C4B-8AF9-418C-8564-9504E553A3FA', '03FDE2B0-A44A-4A94-A91E-C2280185115D', '8901148239401', ' 10  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08EE62CF-C1C5-42C1-AB2E-1AB0F99B258F', 'C910C498-0A0E-4BFC-AA9F-740791FE3910', '4650069782032                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('356E7EE9-1CAB-4FF2-A643-A56531ECF6AD', 'E505A136-FEC1-42FA-9449-C1D1FF127203', '4600702086621                       ', '  IDILICA  / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E6A863E-B637-4A80-8FD2-B8B3ED04DE4F', '009DD8BD-B8DC-41D6-8033-3345EE172AA2', '3800043010403                       ', '  2%  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99345D24-4781-4AC7-97A7-13E75C6A0855', 'BF62BD50-D181-4E9A-826E-CB7B7B81234F', '4607027767570                       ', '   2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33569761-C999-4F66-896C-0BAF2098913F', 'CDDCF743-DB51-45CA-A3A3-99BE065C637E', '4823006302819                       ', '- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32C2AD51-AA7B-4DAF-B1BC-6A4111CFFC90', 'D21FD173-F12C-4BC7-AF10-5964E1B8AFDF', '4602228001997                       ', ' Silkofix      810  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DD080F3-4C59-446F-9B5A-916ABA6BCB51', '84CCFA84-2E03-46EF-B7C5-09934B9CEE40', '3800003303538                       ', '  C 850   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1ABAB2C-50B1-428B-A9FD-0DF21C1E9649', '68A468FF-40B7-464A-9EBA-8FEB884D9C8A', '5944728002418', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEA8E113-2172-4185-BDC2-33235F55B99D', '7FCE4F6A-D04C-4AAA-8D3D-79960A83B51E', '4607027767181                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F248FA3-97E8-4AB6-8A04-E1076AFAA173', '272E9EB7-ED5F-4B3E-908C-87E69751F439', '4640017330361                       ', '  /  All inclusive collagen lifting 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49A1AD24-BFA2-4F10-81BE-121859BA420D', '12E27423-320D-45B7-98C7-1F21A74DEF23', '4606711704341                       ', '       70 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34F36CF1-7997-483B-B093-B4B76583E871', 'C147E23F-1372-482B-91F9-6E685D524DD9', '4049500952156                       ', ' peha-crepp 410', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('603EB559-0CC9-4362-819C-2AC015372E72', '49CF1AAD-E832-477C-8DAA-D5B30742B030', '4601764005452', '  10   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4F587C1-4649-405E-A2D0-0F94CDA50734', '4CE910BB-D1FB-43EE-87D3-00C53D67F8BE', '4602228002031                       ', ' Silkofix Ag      8,2510  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FED7168-6D9E-4497-A3D9-372AABCE301A', '0A8E01C1-B791-40A6-8375-60190D291105', '4607172376238                       ', '     395  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('867270D7-5425-4717-AD8C-F1A55B43E87F', 'BAA535DD-AECA-44A3-95DB-E42FE7E69656', '9006968007380', '  3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('288CD01E-C6E4-4525-AD23-5F7FAAAB0389', '25428434-7524-4E41-BB1D-3D7727AF8232', '4602866022866', '-513   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('397AF50D-1E95-48B9-87BC-A5840BE5C867', 'AC20323E-A5EB-414B-9E2B-5B8159DF9266', '4602866017824                       ', '-01  ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82576890-3837-496A-B194-3F0A016B0905', 'C302D756-7924-43DD-856D-AADC7C562AC7', '3574661172415                       ', '  pure protect    21 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1592F5C8-9D4D-489A-B9CE-4A8065AF15CD', '7833F8E4-97B2-4A51-9905-EA6D8612A326', '4603014004741', ' professional     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4641AF5B-9CF7-4FDB-8662-0C3D05180A39', '83C7FEC0-9175-4F2F-A27E-31ADDEC4076D', '4607155640073', ' leiko 2x500 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1858D5EC-111E-4EB8-91C2-200D90250F24', 'C7386003-8668-472B-8AFF-9D5FDA77865E', '6904566061137                       ', '     .  4. / / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9D44B9B-5F7E-4481-8DA4-C03DCDAB7A73', '15FB119F-7330-40AC-A9D2-30EABFD1CA5E', '4605658251321                       ', '   /  6+/25132/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('983DA157-916F-48B2-BB4E-F678748D055D', 'DBF9187B-6D53-4A03-B142-3835126CE842', '4606677082682                       ', '      - 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B620D67-F37C-416F-88AC-351E9F2ECCF6', 'D44C94F6-418D-46A2-9D72-E260BEEF1F9D', '8030009500975', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA8187C2-FD2B-45C3-9FD8-997625A7AAD3', '097CC069-2EF1-4CD5-9494-67F262328EF7', '3800002303072                       ', '   / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47F8A72C-FCC8-46A4-92E2-A5840F718388', 'A016E20F-CAA9-4777-B4A3-837FD6619DA4', '4601498000754                       ', '  3// 2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0F31203-5DFE-4DB0-91C9-539990C3E33E', '54DDD647-197C-4F29-9473-68A0861389DA', '5292452000805                       ', '  /    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59C846EA-E335-498E-BC96-CA8FFAD81599', '60C67899-212F-41FD-AD7E-1A8E34DE62BD', '4605126002509', '  1,5 / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6665A3F-1D13-44A0-83DC-C6748B680E25', '841FC223-0511-4753-B53A-A550B468FBD8', '4670016720191                       ', '      80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A3BFB4E-5871-4320-8F89-C0AEDC6A22E8', '58C42DFA-4D2E-43BF-A84B-6C9423968624', '2000621490448                       ', '  ws  /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('972D6A43-1888-433A-9844-5C9D105F9315', 'C2088454-DFC9-4B49-82DD-79FE7627B1A0', '3574661115122', '   pure protect  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4C6A6BF-CFD0-4B93-8337-6489383808E0', '8022A2A9-0000-463D-92C0-7D7B257DD82E', '4607018262121', ' 150+37,5+200  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6FE43C4-FAF6-4EDB-83C7-D102B35A2328', 'C0F364DD-9F30-406B-BAF5-226065B9450A', '5944728003286                       ', ' 2%   5 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB4E926A-1330-4C5C-AB58-23E45A545043', 'FC9AC4F3-19AE-4EDC-8966-4FC166BFD6E3', '3850104074981                       ', ' 0,05%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48A73D41-C80C-406E-A1DF-05A85E980BC2', 'E6399D54-423C-4118-96B3-253679DB2BD0', '5903407091648                       ', ' - 0+ 2/887', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53EDCAB9-C19A-4C56-A497-CDE869C31DA4', 'F19637F9-41CF-45FB-B84A-6460C119C977', '5900516695347', '   XL 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D27B7C14-D755-4DAF-9251-6C51B68EA30B', '835CE773-EE3B-48BC-A131-9F5429B0F606', '7322540545661                       ', '  /tena/  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7D3D3C1-68F7-4522-893E-9498FF8E420B', '4D8A89FF-91AC-4D77-996F-B08C46CFB926', '5036519001004                       ', ' 100  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('772E9925-A4DA-4947-A1D6-AE42235DE7F4', '15576978-6D68-4870-BC07-82F06ECE07CB', '3282779260190', '-    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A1C47A0-C95E-4F2B-8229-42E3F847DF4E', '05BD433F-42FF-46C7-B706-BE0B1B575BCF', '4610010010560                       ', '  / 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4C58E15-B378-4C27-9742-86D30D7FD325', 'ABA90933-DC69-4113-B9BF-1802856E7096', '4607020901599', '  9       2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8DE17F7-82C3-4D42-9116-693D784F579F', 'E36AD598-2612-4061-AB0A-AF911B82785E', '4602159015155                       ', '   /  4,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('967A5D29-41D4-4779-A46A-F2399FC824DE', 'BAA7B1DE-57B6-4DC8-8118-74BA1D4DD67F', '4602435006792', '    44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F00CB7A8-2180-403B-B1F0-076AD420F9EC', '2DC15C62-4C84-42DE-A3F1-BFCB2DCC9230', '4607051796560                       ', '   / . . // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDF21C78-1A03-449C-9480-5EFE5CCDD049', 'D2CC371E-9889-47A5-9736-7EF29398A89D', '4603014002150                       ', ' professional      40+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5BD5880-49A5-4890-8900-09A154D64D8B', '56ED7F0F-197C-4704-B1FB-94DAAB5E7E90', '4670017926226                       ', '    / - 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBF14AE9-F00B-48B4-84D2-6E1B3BF856C1', 'BE946833-DA72-427A-BCFD-1605260DED29', '5999518577577                       ', '   all angles ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('638E614B-157B-4CC2-BC42-2A4167D55B5A', '6785106B-2FB4-4F3B-A0CD-C669E81A741E', '4680038240904', '   - /    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1504BEAA-F3F9-4A5A-8F48-375DAE34B2D7', 'FF5ED2FB-CAFB-49CF-8CDD-92EFC513F5B3', '4680038240898                       ', '   - /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92EF7375-AB28-47A6-B5DF-177048CAF1B8', '166ED5E9-69BA-4D72-B697-0D090284E7B5', '4670017926806                       ', '   / - 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AAE890C-598E-4365-A216-813C993030A6', '80A7D0FB-ABA6-45BC-9D3E-7903BF049C75', '3800200961890', '    300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5F35437-EDB9-4D28-A9E9-0011874C4459', '1C459E59-EA17-4C69-9978-F2BF55163DE6', '4602565018467                       ', '  1  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AD78419-A216-4BE3-BA58-5C7567720FEC', '5EE33BF8-212E-48CD-B74A-7E39DEECFD82', '4607086568491                       ', ' sebum stop    /  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BD2D48C-1A95-45C7-BAB1-E36337710701', '838E38D3-5E3B-4E58-B384-654B960638C2', '4630009180289                       ', '  950    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84650328-E690-49C5-A22C-598163E19138', 'E106A137-5436-4687-A4F8-96699A22D5EC', '0837524001417                       ', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6225922B-0769-4D30-8CF9-799E2EA7C8EA', 'A2789E16-9591-4498-9601-8F3C46AE0674', '4820147512589                       ', ' 2,63  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8609850-E87F-41EC-916E-FD930F2BA43B', '7F14A1D4-18B6-4010-AEBB-DE4F3DCE1E57', '4606033040981                       ', '   / /zo-b-128-s-s/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED34B198-CDFA-4DFA-8D9D-990C5A67AB69', '3DF89DDE-918E-49F8-9E31-1E06FF89009F', '4607051797543', ' /   /  530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8350AB0D-E4A8-4D20-8F8F-FB757F35BC71', '08DD9817-F2BA-461A-A09E-F57CC34FF94A', '4670017926325                       ', '    /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DD6CEB0-AF8C-48E7-98E2-5865F939F359', '9A81DD16-7E0E-4036-8C8B-9D4F4A9EA1F1', '4660003580020                       ', '    /  / //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BEF64D3-8DBB-4CD2-9788-0B7EEC70B72F', 'A0750358-49EE-47D1-8528-ABA270250229', '4602159015117                       ', '   /  4,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E04CC562-1085-43BC-AC94-B416D9D5249A', '4093D60D-2EE7-4218-BCC7-AD17B4B007B2', '4602159015216                       ', '   /  4,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEBC21BB-70D2-49AE-A2A7-F9DB162EF3CB', '1B208C29-6B86-4F03-8F3C-705B1B99D453', '4260202926065                       ', '   S ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70EC68E0-BB3C-4A78-B5CC-B0CB88C2894E', 'DA5C1F79-973E-4340-84B9-D1F87654B2D1', '4607003244798                       ', '  250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E16D5E7F-D450-4C2C-ACFD-42EB067A8BEB', '9678F2AF-A220-473A-8DFE-BBFF44F39034', '4607027762155', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9494C9E-2453-4F35-AB05-6121EE44AFA8', '50DA4D7F-11A7-4FCE-9146-A4823C1C726E', '8030009749084                       ', '  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('985334C8-3528-4324-915B-56C48EDE1267', 'AC2214C0-64FF-454D-8060-366189647C18', '6941762681301                       ', '  1500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E76A61BA-2DD8-4B3B-9582-10C57F846105', 'DEDD0C10-B1C0-4E4C-A011-0BE1B1030B3F', '4602159015261                       ', '   /  6  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EBD9743-F72E-45C3-B6C5-67DB9D8C31A6', '3A805A5D-6586-4FC2-9B90-F5212A1CD9AC', '4008600147756                       ', '     /-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4873CF60-B099-4BC0-818B-94106BEE5286', '20C4746A-651C-4368-8C0A-41FC86643189', '4620002186623                       ', '  ./ +- /.  .    / 10/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FC95553-859F-42DF-922C-922470A93D0E', '0CB57B74-8991-4446-8527-420E4F52B556', '4690655009617                       ', '- 0,2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B0302F9-DDDF-4F3F-9238-17C734F99374', '3329C93A-914F-4FE2-A6B1-4E223B7CED85', '4607029296030', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E43CC0C-ACF5-4828-9631-13990D31E69F', 'BF62E983-FFA3-447E-B870-9F5DD458A5BD', '4602435004620                       ', '  1,97,2   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9220040-2FA0-46FA-99EA-1A95551E1962', 'FE31615A-6963-4498-AA1E-186DF15C04CE', '5060038504173                       ', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('900B9D1D-3689-42A8-AFCB-D7B703067A40', '4CF34E90-DED8-4049-913F-BF0D5D38BA56', '4607071771943                       ', '   20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC123278-7888-410C-8E38-772EE46C692B', '38BA165F-E669-4BEA-AC35-72F24DC4CF86', '3856013207007                       ', '   +     2,97  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A7D49C2-4AAE-4E0B-87EE-6B657BC73C09', '9C67F5E3-19E4-492C-A11F-D89D5B8E5ED8', '4607163095711', '  200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DC9B2F5-7027-4149-98B4-D72DDFB9ACF4', '0B58D8C0-7B03-4B6D-A04F-05EAB7959D2E', '4820008316066', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C770BD0-3A74-4248-B8B0-C6527D17F9C4', '8FDDA64F-DE7B-4BCC-9982-4A45DB3FD0DA', '8600097301343                       ', '  250   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEA53308-7304-4ED0-BB14-31254A6A7E94', 'CDFD52CC-B035-4750-B552-D37CA09AD0F8', '5995377611049                       ', '- 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58A11756-23F4-4C1E-8120-AD91C75C02A2', 'FE62C0DF-90E8-4870-B6FA-FA383184282E', '4690655004995                       ', '- 24  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5431D70-3A80-424A-B5B4-DC5E685F917C', '8550100C-A993-496F-A2E8-4FFAC4CC608D', '8718117605835', '-2      800', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7610356-C20B-450E-9BED-D642FE51AD8F', 'AB6E81B2-0A25-4562-8F5D-D5E7FF2509F3', '4607059540837', ' +/ 30+5 / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD8993D0-0ECF-424B-8E4B-857B517B111B', '4F11525A-C4F0-4738-A51B-E9F7DE29C3B2', '4015400203551', '      8-14 68', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E3CD320-EA88-4812-B1A8-6A65BEC50D5A', 'CCBCF8BB-440B-418C-80B6-8A21684E23EE', '4627113835075                       ', ' ergoforma / 3/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F72F2413-5E24-4A35-A3E7-E3F974A808D6', '47D898AF-08AB-4A57-B4D7-102189C690B8', '4670012610212                       ', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('690B874B-2714-49BB-81C4-B0C32A0D3F03', 'FC600DD3-7AA6-4E60-9171-29CDC24AD540', '4680007751189                       ', '   6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8181925A-180A-4C96-AFDB-789B786F437A', '31F063D1-9B9B-4D1A-B5C1-75E248328BF3', '5029053545288', '    8-14 19', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('549CE139-7DE1-48DE-8119-5F20A838688C', '21282726-962F-4B90-9726-FAED7E1CFB0D', '4607013792692', '    150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA4F824E-6C62-4997-9678-D336650C6AE7', 'AE50BF60-84F6-4FF6-9394-AC29292C7ABF', '4640013550374                       ', '     "  "  0./14069', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('075912F0-8705-4879-A6E1-17559CE64E80', 'CB96FE7E-DB14-4FFB-90A6-ED893FA14CAC', '4601834002039', ' etraplast    12 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('917866B9-8DB5-4CA5-AE5B-B35DA68C61EC', '84609AA0-B9D7-42CC-963B-CF37F660D81A', '4601164000934                       ', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF7BFD03-774E-4CFD-83F1-AEEDF2F02C31', '6F8CD6F5-4A77-43EA-B098-EAF0EA4D65FD', '4670017924345', ' /    51 4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45A16D90-1E14-4CBE-A13B-139E81A1CABC', '771E7D50-0BB6-4684-90B6-ECF1669FD7D7', '4606677023050', '      - 1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5392987-CE94-4535-8B52-ED42A6F86992', 'FBB03077-0B4D-4210-80B5-8E046C8275AE', '4606677023043                       ', '    / / 1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8846840-1B27-472E-A538-94932D8239DF', 'B4974784-B1F2-473E-866D-B1FB09381B64', '3282770038170                       ', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FF62F00-A7C5-4B44-B78B-9956BF305AF7', '1279AFF8-D251-42E2-8FBC-146B3FCB116E', '5903407225166                       ', ' -   0-6 22/516', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2D0A509-68F3-4BDA-828E-277EBC5018B8', '652DD062-C110-4916-9D55-1669393B1E81', '4607027765118                       ', ' 5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDC24E9D-45F4-446B-87C4-1E2E3D90976E', 'BEB963F4-5AA2-430A-949E-C3A1F231E472', '4620002184315                       ', '   - / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36965F43-EB2C-4168-A4B4-C17CCB9D9DAF', '59030E63-6E77-4DEA-8F8D-B3B6CCCAFCB9', '5903407131078', '     0+ 13/107', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D48DE329-CC01-4038-BA08-23B2FFFDCF2D', '1644A770-9973-4BDF-B762-6220B060000C', '4670017926813', '   /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FD95A2D-C4F0-4636-B740-47F933F7B9C2', '855203A8-A031-4EF4-A265-393064FBB070', '4670017926202                       ', ' /  /    0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D57C3C2-BC1C-4B38-AD1A-75992CB0211D', '246B92A5-FB24-4E7B-8515-99CFE836B0F0', '4607118050802                       ', '  1%    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC4DDAF8-7A57-496E-B686-E55E2808B5EE', '5C2639AB-CD08-4561-80E5-F671B4C22E7D', '7310791247649                       ', '   28  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDAD4A04-5C37-4C14-9A58-8F17D9931EE0', '8F77EAB9-9D9D-4764-9264-8648006C132B', '4690655004711                       ', '- 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('159EB3A6-F02D-4BC7-9978-3C6230B6D4B9', '11734464-562E-436D-8EAB-CA9FF647149E', '2910010450079                       ', '  50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA102825-F34E-45A3-B3B5-9566848994E8', 'A5A26224-EEE5-4ED7-BDEF-34881277D8BA', '4620016300275                       ', '  smart  // 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F652F87E-F7D4-4A15-A902-022EE8D75340', '6602A75D-0C43-4F12-BFD4-C68E8AE6BE2F', '4603276006361                       ', '   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('524CCFFA-52B1-42BB-9922-185B6D4186E2', '4104C655-6A52-49F5-A110-89996AD4C9BE', '4602884000594', ' 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('384E9E70-FD82-413B-BC70-DC1F89755824', '36838AAE-74C8-4CAD-BA73-9112F4F144AF', '3282779393409', '  -  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC27B984-40F0-4E6F-B15B-23C718FE81D0', 'A97DC74C-B381-4639-BEF7-32953A73A96E', '3282779392570                       ', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4658EF1-094C-4D7E-BFD7-EC87DE124C53', '13246121-6746-49DC-B540-FB661B88EEDA', '4650001790460                       ', '      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('285EF9C1-DD71-4FD0-BF12-5BBC7001532F', '43CE0C91-098D-417D-8FD0-B229E2443744', '4607013580527                       ', '  500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4810B115-45C0-45EF-86EF-AF16406F8D6B', 'C460D3AA-22C4-4001-986A-63980F91F6FE', '4670017924383                       ', '  /   / 4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8219AFB-4349-42DA-892E-562F7E075EF9', '7A93BC2C-F7F2-461B-A94C-F93D5F6D9A7F', '6432100003867                       ', ' 250  / 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('234CF3DF-B406-4059-8641-1A58BF300E78', 'D09062AF-2FDE-407F-9893-0C9A48E3A903', '4602565014131', '   600 . /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DE00F78-63B9-4C25-9EBE-48A49A506AC5', '6894946D-6C49-49ED-9E51-1DF271CD921E', '4601835001369                       ', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13EC1498-6A6A-4A40-AA4D-C7E9166396A6', '188B6BE6-B739-4FBC-8542-118B731A5C6D', '4036534496251', ' sfm  /  s 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A42FC516-F358-4803-BED7-0A7B3A897FC3', '565D984F-35BB-4160-9415-2E190FF51610', '4603679002144', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C160D50-4CFB-411B-B0E4-CBD006318B29', 'AFFCDFD1-D519-4C6F-8E10-82C4A8BD1151', '4602509000619                       ', '  0,9% 200 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C07A13B-FFA6-4345-B6A4-769CE2035147', 'F2BB5307-4610-4478-89A2-D6CCB33B2BC1', '4607092930121                       ', '  5% 500 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27EA63BB-3B8F-4844-B922-F995DD0167BB', 'C8AB4441-84DC-4DC0-91CC-D6A9DD3D82A0', '7290004798079                       ', '   Mineralia 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90073876-3931-45FD-A0CB-79B3BD3BE53E', 'F6B799AA-56E9-4A55-BBD0-87ADAC9A4245', '4680038240881', '   - /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64BF742E-E296-4A17-8011-C9CA8ED600E2', 'B24C4625-0549-4387-A672-B97567BA5D7B', '4680038240867                       ', '   - /       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2D5478D-2237-4E5A-A0C4-C4D2C8109B87', '73FAB882-164E-4078-872F-654360E49683', '3337872413537', '    +uv /  . spf15 4808100 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF0E049F-406A-40ED-8C6C-59B3883FD88B', 'B5357118-D229-4666-BC14-728D48E61824', '4605738005776                       ', '    4  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEC7CF02-83AF-454F-9A8B-BEA351E6CD4C', 'C91515DD-FBAC-4E0F-AF9D-91206F7B6580', '4823000804852', ' 0,250/ 4  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2136FFF2-DCD5-419F-A03C-F3E812B12FBE', '15D52A75-FA71-4F41-BDAB-6500E241CABD', '4605319002644', '- 205 - /  450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78878DEC-323E-4C2C-BB07-0074B548BBE1', '100BCEBF-EBC1-400C-B6C3-B17741D6B6D1', '4602866063739                       ', '  BABYBELLE  BBN04', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D604A52-32B7-45A8-8E51-F5D83329ED79', 'D7619575-9E27-44F6-BFD2-C5E5B2C6782D', '4602159015131                       ', '   /  4,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C036BE3-5A56-40E3-8906-2D75A973F81E', '7F5A5BC8-AE00-4153-A2C5-AC02877414F6', '4602159015124                       ', '   /  4,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67F3A151-487D-476B-9423-27FD63F76ECF', '03817A2A-971D-4F4D-A080-C895B9834165', '5702589927192                       ', '  2,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('977EC3D2-EDD9-4C11-BBC6-C0BCA85EC982', 'E3BEFC0F-1729-4480-A3E6-2AF9D63B8DA9', '6224000132828                       ', ' silkofi   5500/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CFA8651-4B1D-483C-B1E0-AF60E6513EFD', 'F2E0C081-321F-48C2-BEEB-5D03AA2BBB05', '4630000893782                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB4A98BC-F8BD-4868-9E39-F5C994EE0F42', '4E2729BE-F6AF-4BD6-8BCD-117BEF7EA0B2', '8030009701082', '        50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB105483-7D68-41AD-A590-EE5BEC575B1A', '5730B2D0-C39A-461F-B53E-C44D1CC47020', '4612729880175', '    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08D1F2F9-B037-4670-9542-E403604758F0', 'C36B26F1-477A-4DC8-96F4-A40957E52C5C', '4650069840145', '   /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA41FB2B-61AA-4237-A5F6-81EA3EE695CA', 'BC7C6D78-4C74-4B77-B5AD-DD17714EC89F', '9088881345534                       ', '  500/5 5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3BACED3-CE8E-44F2-961D-C3113B216056', '9DB65CF0-73C7-4D24-90B8-A0BEFDE8D60D', '4602866023863', '    , c  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3FB84F0-4831-4821-9D0E-2560207C8A1A', 'EDDD45DF-0EAB-41D8-BAEA-B4CD411A95E9', '4607020903678                       ', '  24  2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21DFF07C-6556-4330-BF73-3818BC225929', 'B6B0B011-8D3E-4403-A8A2-D193B0000D4C', '4605370003680                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5771FA6-D955-4D21-9134-85701ADDE8DE', '1A1D4D10-2163-4FFE-98E5-39F88FB0B0B7', '4812845000956                       ', '+ 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7DE1A81-B422-4B1F-BE13-43C2745409B1', '21BA6F69-9F49-4206-B82F-B156AEAD0A8A', '6902088606331                       ', '          130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3405CA08-4DBD-4C17-80F6-94D7D0581DF5', 'E112DB3A-6A56-4161-9F3E-A46E1A002AF1', '8887786800367                       ', '  LD-211C', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B8F5F75-0888-4ED3-B34C-60297B451694', '53464175-43FE-4E46-A702-290409F5E8C1', '4620002185336                       ', '    /    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('241D288C-C6FA-40D6-8C13-470D3F957AEA', '6FA3FC39-7375-42FE-81E0-A37EFC43A68C', '3850114232227                       ', '- 15/1,5 1,5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EBAC794-FDBF-4E4F-B667-5E3E25C3C511', 'F96AF3A1-8667-4687-949B-5A80B6B18D91', '4627108140092                       ', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53BF6AB0-D501-411B-A46F-443E30E7DF10', '08B821CC-F4A9-41B0-86A5-F46DFFC47F5A', '4601836000019                       ', '  - 0,6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EFF1F79-08E6-40D3-8846-B26CACACA7BF', '575C0794-3926-4C0D-B565-68AB28DCA70E', '4607003248970                       ', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AA7B9B2-F30B-4036-8A62-37AEA3D6AA27', '09C3B438-4E7C-4C37-89BE-012487FD7E6C', '4391498005032                       ', '  3 2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A2517F0-C002-435F-BF6D-5DF003E081BF', 'EA30B7C4-BFD7-4EEF-8CFA-99942A08E3E0', '8594737172519                       ', ' 0,2%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88E9AEC4-B4BC-46D7-A17A-807124A32473', '920AA39C-50BF-41F1-BD44-3A98B73A3F60', '4630009620204                       ', '    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FC388DF-1348-4648-AD90-6F9B0C107318', '3F260949-6C95-41C6-9FA7-D0EE0CB6FC1F', '4605108001742                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3F7E666-99D4-479A-9F4C-87145B8A5EA1', '972E4E5F-C158-4785-91BF-EB6DDA97B992', '4660017520456                       ', '  /   . m   eam pp 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F47C2927-6D4F-4C1C-A58C-C41232F63510', '1849D605-98CE-4002-B27D-8D1A36932897', '4608816000458                       ', '    100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('172A28F6-8D5E-4B08-9D70-59898DCBF76E', 'E6E314C2-3B12-40DA-8103-EABDC1D2F828', '4670005860167                       ', ' Q10    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8FA3F43-5DA2-4109-9B87-A4972D3A94E3', '820FEAE6-FAC9-4CC0-BE84-F12C793093E2', '4607071772421                       ', '   60 /', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCF7D3DA-DC64-4A1D-851C-2A9F3AE2AAE5', '3B2D103F-E097-4B7C-9D3B-A1A0B2B80F19', '4627074810876', ' 3     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BA6F437-9457-430D-90E9-31CD65230AD6', '65576ACD-0E66-4965-BFBD-AC74C4B91FA5', '4640001382291                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D6C5B48-A5D9-44F3-8A5E-90E95F63FF57', '93CB886B-1A5B-456C-BF8C-DB3D39814690', '4627108140054', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC1A44ED-C59D-4E70-B306-F3DB52043F7E', '6268DD0A-21A1-47FA-B152-86438812E750', '4627108140115                       ', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('712FDA73-6E64-4D90-B196-8B3646D69D09', '42BE0D3B-AA1A-4E1D-AA7C-DB1A16A9303A', '3282779369084', ' a-  eomega d.e.f.i.  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7D6B739-7ABE-4A44-B5D1-99F74EA8995B', '857CBC7C-C477-496B-82D4-2ED3BCC340DF', '4620017360742                       ', '    16  14  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87F13ECC-7E1E-457D-96C9-15A1A425AEC3', 'A8AE559F-232A-437C-A2EB-429681895349', '4607022891652                       ', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A43CC04-C452-4655-8646-BF907C0ECA52', '30C57CD8-CC2E-4054-8F46-4812063D724A', '4660000640062                       ', ' -9 ,    2 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA43B4E6-B33E-4513-8868-C69662DF6B26', '040DF95F-8B3B-4448-AA79-45835C47F72C', '4602228002055                       ', '      pu-ag 1010 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2276661C-656C-4F92-8259-A6C390BE3901', '400C383A-A098-4118-A913-5E3818B903A9', '4605658251628                       ', '  - /  /25162/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('919550D1-81E0-4943-B032-CFB6C4A378E2', '39DFED8B-F483-4727-96BA-8076DA10674D', '4607172371189                       ', '  50   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D5D94AC-97E8-40DC-AA39-4818E0296910', 'B71611FE-58E9-4707-8385-D573789FB944', '4901301230812', ' merries 4-8 82', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF613AC9-2A01-449B-9572-3E13EA1C5B85', 'DE309ED0-FF20-4F43-A75D-146F812D84AF', '4902011851755                       ', '  4-8 /s/ 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55E2B6CF-A3AB-44F7-BEAE-394C65481D4F', '9EB294BC-6C92-4375-8ECD-C7DB92809F4E', '7906516690410', '     20 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B96DB6F5-7E19-4708-99AA-79C85F0CA965', 'BBA09AB5-7066-421D-889E-651A9C9CEC25', '4680004854845', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AC9024D-8229-4FAB-9EEF-F61D0C1C49CF', '21625472-62BB-4D1B-91EC-8A59A1A8DA8C', '4627114672242', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D849BB03-63A7-4D99-A9CE-759A6C4F9F45', '95467172-7426-46DF-B3B8-C30747BC06AE', '4627090498812                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC12ACD5-262A-48B4-84E0-606B0D95BA0C', 'FB1ACC93-69BC-4315-B63D-6F55A918B3D4', '4650001792921                       ', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('312A1A58-9299-47DB-AF31-C21DF0DB9629', 'CAA8F39E-E3DA-45E3-B2E1-EC380D7550C3', '4600702093810', '    1-8  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6BA6515-B5E5-42E7-93D9-1F779BFD51D9', 'E104C412-92F6-49DF-8621-6C4B02973C9B', '7622210739025                       ', '   9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C795C858-7BB4-47BA-8428-6B2B61DBB7EC', '51E66CCA-AEA4-4AAC-AF20-E0586910F929', '4690624016585', '   /  spoon', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2DE06F3-3D16-4DAB-9622-0363BB93089B', 'F1E38F19-382D-4146-BB1F-EC6413A34D6C', '4601164000767                       ', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DBDFD8A-BCAF-4FEA-A6B7-8C1D058B7D97', '8A632B5D-36F3-4B75-A059-B9BD7C857757', '4670008160622                       ', ' 0,1% 1 - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCB91398-CC9E-466A-AD41-DD69277AF4AE', '1512B478-B84C-481D-BAB6-0E1F929155AE', '4607118051748                       ', '  100 .  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D7DEBB7-8B77-4F3B-ABB3-027E955AD9BC', '11F55C4F-1701-4EC0-A0EF-005D56A4FC83', '4607027218133                       ', ' - 180 1955', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0D0ACBE-5C56-418A-8C56-C475800D8221', '359D0831-D5D2-4936-A25A-B6A66BEC57A8', '4603699000014                       ', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81F41714-8F5B-4018-8E56-025D6939B2FF', '3BBBF660-352B-460F-B6AE-B5A4C1668CF9', '4660011212142                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECEF0626-4255-4370-8735-9C7CEEF10142', '97042D00-55BF-4E9A-963A-315E87536EB3', '2059000000952                       ', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('055E16DE-F047-4278-9E7B-D979860A9CB4', '36966E58-45C9-4738-9A89-4275859136DE', '4600286107927                       ', '   0,35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E75F5DE-56FC-4E26-91CE-C5CBB5124C14', '6CDA9708-060B-4890-91FF-A515C1CB0A29', '4630009180876                       ', '     0,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A387AD72-9B46-4B05-8D13-767D93D77930', '493B0694-A7E6-4BF3-9735-B98BA51E7C21', '3594454400211                       ', '   5+1,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C229504-6976-409A-B99D-73DACA028B18', '8C76AB76-968A-492A-A21F-0B16099FB1FD', '4005808588824', '    / /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDF7FC92-506B-4A71-882C-6C9E7C22E887', 'D8D58BD9-B718-4B63-B3A0-E5A3B1B532E3', '4603014007315                       ', ' professional    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC79FCC3-2E40-413D-AC01-DFC15BD4D533', '8959765B-FB80-4654-89A0-307A08B15751', '3582910005391', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03ACE868-A05F-4D6A-8B26-9D32E9AF883C', '35084791-27B7-4DF8-B974-FA5E029060B8', '5907506237129', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B63840D-7E3C-4293-8F1B-D07213B3C34D', 'E0B7BCA2-35EC-49F1-B62A-27BE81AADEE9', '2910003910054', '  2- . -24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D90588CA-75DB-4D87-A3C0-AEF5371849D2', 'E5D451D7-8160-4ADB-B058-2DE8C8F08CEC', '3282779181600', '       150 +      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D526A53E-02A8-4056-AC4E-C63F5A683B45', 'EC4650B4-2958-4B03-AB04-9E88A2328F63', '4036534653227                       ', ' sfm   /  l', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDD32EEF-882C-4202-918C-11691FE3C120', '1625A732-3712-4383-B753-EE09AFE182B4', '4612729880731', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87CF7DB2-0B9B-4283-AB3B-AB29CA12C0CD', '106DBB73-8D27-440D-AA7F-F04F62AA0CD2', '4602159015148                       ', '   /  4,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7A522CC-5D0F-4E14-AF8F-6C26B1807DE4', '012BE3F2-90AA-433E-AE81-11DA16909907', '4607071772674', '   20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('289A101D-A811-4D50-B227-EC8550E6C6CD', 'C0EDFAF9-6B11-4816-B2CC-53926390C2F9', '5900516840174                       ', '  /   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('013F6270-22D6-48E6-950D-E5D4FA5F0A31', 'C9B8A7F3-B860-43C6-A4E7-B0AECA29D09F', '8901248101042                       ', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7A2B7C2-F176-46FB-8ED1-D3E011188B90', '436F94DB-D634-41BA-AAD4-ECA278B83808', '5900002071396                       ', '     // 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71ED39AC-194C-40A7-8364-43D10CB1039D', '0F637452-59B0-4184-9EAA-22BEE6A5EF7D', '4690419011931                       ', ' lab  / sos       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D6C685D-D509-41D2-BD02-CD59E6B7F981', '90D67D32-9B2B-47C1-A5C8-EEB9BB2D4CF3', '3504105024802', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DE57A93-A740-4B3B-B0C8-416D27637D03', '30AD6E11-3B94-4AD9-808F-F499B96D3382', '2000103610876                       ', '    0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE79FE17-5874-44D7-A3D7-F79CD3E4BAFC', '0EA55D76-30FB-493F-BA03-D851529ACC38', '4650001794468                       ', '   0,37  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('274DD096-CF25-4E49-B93F-F65BBCB9B63A', '4A07D073-7CF4-4CA5-8545-569D8EB141E7', '4603988011158', '  5/ 5  100 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4398CEF1-361C-4507-B44F-31176FA14692', '628B3C2A-79A3-4A16-8695-D4E96F090627', '4606144005374                       ', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09823F95-A7C9-417B-AB94-99B1B831961D', '932CA2EB-DB67-4C78-AD14-E7CCC47942DA', '4607017268797', '  350  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('777E59D4-008B-4FC6-BFF4-CB82A56E39CE', '73DF1FB6-A28A-447C-94CB-19DAFD9677D9', '4612730250165', '- ""  .  . " "/1201', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FFF17A1-E5DF-4C59-ACBF-7A5CDF7E9162', 'E2A9252D-2B29-47D3-B6A8-E9CE14BF8C33', '5029053543192', '   11-25 58', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23DC968B-CEA2-4A30-924E-FBFEF8DAA7E6', 'A8104E63-6639-49BF-B318-9DDCB39309DE', '4605370003451                       ', '    3-6  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8647B90-A733-4E1A-81DE-BB24FB93809B', '9DB081EF-0D79-41C0-BA85-58D61D5289A5', '4660019720014                       ', ' 0,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35BB6FC8-684A-4D0A-A089-289A3F2618C6', '566162F0-09FD-41AD-8A25-4438FFB02C46', '3574661128252', '         20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D9B83CF-D460-4945-B041-BA288065B0B8', '1A7D2408-F631-4AB7-BAC2-6ABC6FF9341C', '4680038240874', '   - /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81C2B92A-97D0-432A-B50A-23E10B324479', 'D45A20FF-1D76-4AE8-B7D3-D9A7648C4869', '4640014200186                       ', '    6090 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE874DAE-B1B2-4691-A1F5-868920FC29E5', '36B3A491-9B3E-4C8C-815A-6EBA549CFC7C', '3574660585360                       ', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E4BB67F-3A1A-4C1C-AD75-B3E2C5DD0A4E', 'BADF062D-4F84-484D-9D1A-386C73E23699', '4630007837987                       ', '1000  -    500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35D51196-2B46-4C35-915D-F82DEE1B1F78', '7FA64FC1-C26D-4A47-B048-962C85EC50A2', '4650070110374                       ', '   20   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('533A606B-1EA1-4E77-9200-0AD468B79A30', '5E6B65E3-5DEE-46E1-A493-EC1FB3D4D297', '4049500585934                       ', '  .   7,57,5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6D61ECD-1792-448D-873F-DD704CBC2A71', '9FC3B6ED-022B-42D7-911D-777F8B4C5DCD', '8009315901141                       ', '    // 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB8A86B4-9267-4003-A4F2-5E01A4E22CEA', '790F57C8-9D3B-4C58-AF34-548EEFB98F47', '4015630056392', '- - /Accu-Chek Active/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67035E39-539D-4DCE-BDF6-596C957A8496', '93C1197A-99BB-4055-A682-FFB5837B71E9', '4627074840248                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80086470-BFEA-462B-B193-E64F587BE767', '9E184AB7-5D59-4D73-8418-E26A4EAAA149', '3800200962637                       ', '    330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63F88798-C3A8-4C2F-BDCD-D088786B767A', '5A397950-2B99-451A-95E2-61C822920A06', '4607020904279                       ', '  26      2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FCD5866-D67E-4D39-B5FE-9971C2204ABF', 'F563C9EB-CE2A-4239-8B78-D3B2770FFF67', '8710103791874', '   free flow 6-18 . scf178/27 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C77480BA-FDC1-49E9-83B6-DCE0B7BDAB67', '636954B7-CA10-4B22-A169-E485F11B611B', '5411416010081                       ', '    4060 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74C9F160-7C58-4879-A621-80BD6C8CDFF9', '76D86BA8-9C81-4171-83DD-10B31780E207', '4607153456355                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A85EDB7-08C7-4909-90AB-949A55CC1686', '127C4F94-A061-4E1F-B8D0-C0F54D46EB17', '4607071772650                       ', '    20 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31BF7223-68FF-45A9-8488-4789F970925E', '5D991E1F-2FDA-4797-B749-4E517CB05595', '4931140061056                       ', ' NISSEI WS-1011   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74A86A4A-126E-4847-BFBB-5EAA62F1CECF', 'E2CD679E-7365-4551-8D58-CE3A6B041A94', '4810155001861                       ', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5E9C87A-E081-4A7A-A6E8-77FB313019CB', '80CCBF17-8559-481C-8EAC-5680B2359DAB', '4600416005352                       ', '-   30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('459DD74B-7F58-4C44-ABF2-A6BDAEAE7676', '30A12F18-15F2-4F46-ABAB-C631EB39B4EB', '4607069270854', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('885DB6B1-48D1-42B8-BA50-E02AAD4C8727', '482DCED7-631D-4EC9-94F8-10CEAF0BB009', '4640000903497                       ', '     159 10//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B9973B7-7DBB-4312-84A1-F83590BAD3C2', 'B917C292-2244-4446-B6B1-5C454213EF5C', '4607015890563                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C70F24DD-3B19-4D1D-888C-0E259EC09102', '22D6B699-A103-4213-89DD-D04D90E99805', '3337872413148                       ', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F588E8B-4B2C-465C-AEDF-F993C8CA474D', 'DE225EF0-30E5-4F85-B472-39D9CE447B8C', '3337872411595                       ', '   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E893464A-75F3-4DBF-9EFD-696956E8FC31', '16A9C406-5B35-4E13-B56E-5C1154AFFADC', '3433422406728                       ', ' -  , 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D14F2EB-866B-4D89-BEAF-F35B989D8BE5', 'ABE58D37-2F01-4B45-B233-5797BCA6A404', '3433422408753                       ', '   2*6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5081113-EE11-4A75-BC15-8FEA33EAD890', '7660F322-6D95-4D1B-BFDD-C711BA20B5F2', '8906046112726                       ', '   18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70D59345-86F9-4C12-B784-35231E36783B', '278CC19C-E854-40CD-9BFD-6A28E5BF12B1', '4600104030017                       ', '  125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33C1FC13-4E0B-4C63-BFC8-E93BFC39C0A4', '45BF91BA-2C53-4ACF-B406-C5095E5C5018', '8711141378232                       ', ' 50/12,5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('185027B5-B01F-479A-B038-D50F7601F4AF', 'ADEE3229-044C-42D0-A48A-C6F659D65D60', '4607051794085', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D4DF800-376B-45AF-A149-C6819B0AB85F', '8AC6DAF8-D97E-41A5-9075-1730BCC30A0E', '6224000132491                       ', '      2,5*500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('988EF9CE-2847-43D5-A7D6-384115A9C813', '16CB674E-949A-4AA4-8F41-F2BDF40A290B', '8887786200044', ' LD 71    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C359B899-481B-4821-80E5-B2F6134DCB6E', '7C1833EE-8099-40C4-A13C-150C852F79FA', '4607045500142', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('267E0835-680B-4907-817E-ECA14A87F03C', '9E604A46-2114-441A-83BD-2AC3DF360DDE', '4620016304624', '     " " (  , , )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACB06039-10F7-4D6A-8612-CBE88CE8237A', 'D535CA94-76F3-453F-B51E-170CEF0DC481', '4620016304631                       ', '     "  " ( ,, ,    )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33F230C5-5F66-4819-9358-8897F1E5A224', '05358F5D-3CE0-414A-A92C-4C2FD947E6E3', '4620016304648                       ', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31E46991-38E4-4DC2-9D2E-972108C681DA', 'E5A59459-1F9C-47CF-BA62-1E0F61FEFF2B', '4660007810437                       ', ' 5  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27B149ED-FB21-46AA-AB4E-08AAD502390A', 'E9A4C284-5029-45AA-AAD7-A118E095FE5C', '4650001681034                       ', '   / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BE47D21-48AB-47AD-B12C-A716E9309026', '8170B37D-C6F5-4F54-834C-26138D84094D', '4640001382918                       ', '      () 3 10 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5D8A441-0A25-4E79-88D1-44C2357D72B8', 'EEAADCF4-19D3-41F6-812F-32C6F291016D', '4602565011352                       ', ' 300  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('161C9211-BF3E-407E-AC61-7AC3C9DCFBB0', '293AD919-4214-44F4-A144-A0F9B4F10F2E', '4607001012795', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('169D7B38-1ECE-471F-896A-2844C39B1A10', 'C9CECC01-519C-4186-86C7-A02A9333F425', '5900516965709', '  / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35370E12-C676-428E-BAE4-13B491500FEC', '283D2E6A-20F3-4F58-8690-3B01EA261250', '4620760951280                       ', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D6A0952-4987-4CCA-A0D8-008CD57D07D6', 'F6CC620F-6F61-49CF-A63E-D372FDE0B088', '4603988006833', '  20%   1 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99E75007-9FF3-4774-AAEB-CC739C52A291', 'ABF1D9EE-6C38-42AD-8D87-6DB4B7066727', '8901138511784                       ', '        150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4F39F31-9C6B-481D-85DE-DFEEC2AE49B6', '71CBC8B7-B517-48B1-ABD8-F78043B65081', '8901138507268                       ', '       50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B200D73-0703-466C-BB97-24DA1B916C82', 'B98FB5BA-1693-4FD7-8DED-4E8D87EEAAC2', '4811248005698                       ', '      500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82CA0FE3-BF54-4F56-B920-D32702D7BE6D', '5440460C-335D-4C92-BC27-C8C98900D41A', '8887786100092                       ', ' LD-302   ( )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('559928B3-BD5C-4BAE-9C50-7C8F3EF856A0', '61BDB5F5-0DBE-4BA4-B8F8-1C9727E2D9E2', '4610008495324                       ', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('475A52A6-4ACB-4F91-93C3-E4EAE8A0D4A4', 'D5077E5F-9153-4783-BBF7-69FAE9BE9292', '4607073910067                       ', '  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A97D1A7-1BAA-4752-8A32-C0C9C6B3F439', 'CA32A9E7-E656-4E01-BC44-11CBBE9E5841', '5029053546148                       ', '      22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CBF479C-F057-47E1-B040-757126E312EB', '0D4203FD-0178-4093-B289-EF445CEC34CB', '4607101201730', '  Lubby x-    6+ 2 (4664)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A481782-458C-4A41-A02C-2F201D49629D', 'F32EEC1C-BE43-4D51-8243-01014B1A4CFB', '4602424006444                       ', ' 50  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B17F8D1-64B2-472D-AAD7-BA1BB2E940E9', '8E1ED312-79E3-4AD2-AFF8-B893E6D3D212', '3850114213646                       ', ' 4  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D615E58A-6209-4C57-A330-38FBB8A2E1FC', '34DCACB0-E72D-43F6-89FE-E52F6EFBC7FB', '4607163099818', '  950   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4DD9B21-EFE9-4C80-9099-9F610DBC2113', '3CABCB6C-8789-450E-8D31-2A625AF29E47', '4607141120855', '     20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CEAF80D7-5A7E-4BD8-8039-EFFE99914348', '14B1481F-C88F-4873-9B7C-2395470CAB63', '4601969007077                       ', ' 1000  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('580BFD51-F344-4084-8C01-F9C6657E3526', 'F771DC6D-4A8E-488A-B00A-8B5648DE6E6A', '4605370005202                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FCB68B8-7F24-4579-AAE8-8056BBC52B1C', 'C329D423-1043-4C6D-9E12-310FC81F9244', '4612613500035                       ', '    2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C733D24-516D-424F-9DC7-7C008EE92123', '233BC48E-8583-4432-817E-3B84B99DDEE9', '8030009522601                       ', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C20CA90-2A05-4E92-8038-A2570B2A3B25', '784032EC-C1E9-4988-8462-464100082BEA', '4607082851726                       ', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4C7DE96-A550-4188-8706-C35DF726A9AB', 'DF77093B-32F2-4DE3-926B-7439EFBC08BA', '4607040649471', '     spf-30  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77300036-8721-4A35-87BA-4ECE15620F96', '2C56D9A2-BCFC-4D5E-98A8-AE16C3417595', '4005800195761                       ', '         !', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F9B3366-3413-4565-8226-21EB6AFDB980', '3EB7726A-C002-499E-864D-CEE5609F3529', '4015672108356', ' OMRON M3 Expert     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9E1A8D5-351F-4E22-8AE5-0CF9D562BCC3', '22E18CCC-D91C-4BE5-9256-CE2C7108183F', '7640170370034', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69BE4B11-9E59-4580-9F08-885CE17D9D5E', '2D1C9D24-E0EE-43AA-8330-EDA03D510CC7', '4680007751127', '  6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('371C22FE-9A49-4783-B33C-6BBAFFF948E8', '24DD2F76-8BAE-4A1C-BB47-E6B52009F57E', '4670017924666', ' /      4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76FAC60B-5A82-44DC-8BF5-F2D5F07DE061', '540C4912-DD6C-43D8-A6A3-D7B0BDF075CA', '5900516720476                       ', '  S  6  10 1 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('597277D1-5651-4B38-B69D-1993C953DDF6', 'DA12A3E7-0242-461C-A7EA-CB918AE4E9BF', '2000103611729                       ', '   animals 0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCCDE8BC-CA7C-4A80-A256-85E64875ABAC', '84B74441-5F7A-4D5A-84E2-F2B1229A84B9', '4602242004363                       ', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEDEDB80-60CD-4879-9532-DF1CFF09E65D', '4EDB2E56-E5C9-46D5-9D71-C6B4CB485F71', '4820090051920                       ', ' 0,06% 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EAC5E44-40BB-45AC-A5A2-CFAAB8398486', '95B717E6-54D5-410E-A4DE-F3D973ECA7E8', '4607003240790                       ', ' -6 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBAA6BF0-11A1-4582-B246-B7513ECB2FEA', '9266BE38-E75F-4F69-81B8-87E21705D125', '4607021930376', '    / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C5C44B6-4577-4AD0-9FC2-E936E15DEC74', 'EA038D90-06EA-45C3-A570-CF087EAC760C', '4603762002914                       ', '    1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE6A3AAE-EB39-4B8A-8A55-808746124A2F', 'DC4F7FF1-5797-4B3A-909C-FB54A36FA738', '4606711702040                       ', '    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07816361-F414-41A5-A667-ED0A1E0EA1BE', 'ECABD501-4792-43B7-A4CA-1D13A2AF6316', '4612613500073                       ', '     2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60974026-F9CF-422E-9A46-9303CC84B561', 'CC876BF4-8FA6-45FC-86C1-1F8751E33983', '5060038502698                       ', '   /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6D7EFAF-9E72-4060-84A2-0F0794AF072A', 'D6A4661E-102D-4E00-AA85-666BFC3D9179', '4680002477206                       ', '     / 200.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1146F21-F1FD-4935-8BC6-3C67503AC6B3', '94118F97-91D4-4110-8B21-8E3E686203C0', '8030009400237                       ', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1D7F26A-8356-47E9-A1DD-EA1C06ED2B5E', '8720DC26-5D89-4679-A4D4-64ECA8C11362', '5029053546162                       ', '     12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F39340E6-7679-4DBF-B21B-93D3C8AD1F74', '293BC055-8F77-43BD-A04B-CF4AAEBBA7D1', '3800005321028', '      45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEB4E62D-959E-476A-B513-9A16B6143F56', 'F22F79B8-FB34-4C30-A53F-8DA6226F9422', '4600999004094                       ', '-       300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DE826B3-5513-4A7C-BEFD-ED2E0F6869DC', '2352B9C1-16EB-4A6E-B081-64797EFE4DC3', '4603934000779                       ', '    1,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FA42EAB-E27E-42C2-BD04-82C120C4665A', '178F2372-39E5-4175-9F89-91D8BC0490E5', '4036534470206                       ', ' sfm   /  .XS (5-6)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC0169F7-7AAF-4F7A-953D-71E4D0C714A7', '3A516008-5B75-4A8F-870D-6E78440C674B', '4607117340973                       ', '     1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91839FFD-2C29-4441-A0EB-C3D7B171E666', 'EBD98438-0085-43BC-8678-7CD720CB5C6C', '4610017500996                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DBBCC18-D20B-4358-99D2-F36D7EE64BB3', 'E223353D-2A01-4DAA-B248-54EE2374E335', '4607027215224                       ', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('995DC6B9-29E4-4D0D-8C33-8D8EADB740B1', '5F9BCB93-C213-466A-B8F6-F42ACE29CE83', '6920354818622                       ', '        75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E3346BA-56A0-44B1-B188-E78C19F91EE3', '30671390-46A7-4B64-9AFD-56218DD8BC43', '5900516720506                       ', '  S  10  20 1 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F20C1143-0268-49FC-9817-036ACA6F57CD', '21AB2677-C317-466A-BC04-EFD12EE15DCC', '5900516720483                       ', '  S  10  8 1 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41BD2B88-E5C9-4B86-B2C1-6909CDB2EED6', 'C3887434-82AC-4A3D-B8A6-EB695DB01924', '3282779323260', '-  D.E.F.I.   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3217CFD-2AD4-4FC8-9A90-3F6E16BC9681', '3670DF59-3635-4ECF-ACAB-AFA1C4A84BCF', '3282779244077                       ', '-    /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F76AFCE-F8B1-449E-8C79-636031EDC826', 'E8012D98-0776-4333-8555-9A7FCFB7B421', '4601834002947', '-  eroticgel // 50-60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0546FB9-00E2-4941-B515-A8A63732B137', '3E7DFB99-30CE-4411-A105-C9DC731CEC89', '4602206001223', '-4 -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6083D1D6-6D02-41CF-BC99-E42B5D2B63A0', '4F788A5F-4170-4191-ADE1-F9D3420658C8', '4690214166041                       ', '    + 75     +      100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46A80BF2-13E7-4F16-B875-25F3AA07CAAF', '672B0706-4B5E-410A-AC35-88465F6DFBBA', '4603014005861                       ', ' professional    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB7EB535-F6DF-4C36-985D-F18787DD02ED', '8179A8AB-9ACD-4D5F-86B7-744768034481', '4607051794092                       ', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A856A747-5A9E-4508-9F26-B64DFF60CA23', 'D728CBFE-D90C-4AE4-9576-98EF6D69A4AA', '4680005640836                       ', '   250 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD1C6271-C00B-40A2-9FEA-2F76C0F8694A', '8C348150-E39C-4A58-96B4-FCFD09EB372A', '5292452000768', '  /    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('910BB467-94C9-425F-AF1A-12E220B4299A', '76FA6416-9A4D-4D26-BEF3-E36052A405D4', '5292452000577                       ', '  /    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('031FF154-A0E2-44E9-AD78-2A4AD1DB99EF', '6868ECCD-21C0-43DE-8CF2-32D4F7A0E25B', '4600697193502                       ', '-   40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1BEAE59-052B-4D7D-9464-4A56B2DDA6CD', 'D55361F9-26AB-410E-8EE0-9AF196E476FD', '4032046002119', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA150C6B-A2A8-4B96-B375-4EED4EAEA139', 'DB890B47-B723-43CB-A267-CC0B94CBEFB1', '4607020642126                       ', '  2 30 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BD330D4-258D-4912-8620-8CD224347BC1', '75803921-39E2-4BC5-A189-8BD22E2010EB', '4640017330415', '    delicate peeling 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52DD30CA-B416-4160-8DBD-255AE9321150', '332A2F50-A261-478B-872C-9142D17F8BE9', '3574661017365', '    /   /. 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8955F7E-5AAD-48C4-8714-A18916A63048', '3C331154-8752-42B2-890A-6C2AF7CC0CCD', '4605108004538                       ', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E6D85A7-D006-4144-B0D6-C9637046C924', '60588DD3-F4E1-43D4-8E5C-AA60BA342747', '4606677134732                       ', ' -    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EF81C4E-F95A-467E-8E42-E9D1B2537482', 'D338707A-73B9-43B7-B629-FCF032DB67F3', '4670012298335', '- 3d', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61104F00-D774-4E13-A8CB-399472B347FE', '9B53E870-EA82-4832-A51F-3364AAA8AB44', '3838957080762                       ', '  30  60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('968A5389-6216-4B72-9132-A0373DB3EAB3', 'E8F222C8-6E78-4D46-BBAF-7DCACE7291CA', '4607012580184                       ', '    0,5  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76A84495-AA9A-406A-8FE1-743114762558', '448BEDF1-D871-4EFC-99EA-8B5BA444A460', '3574661064345', '     18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FB7AF0B-F2A9-4F7F-8C64-427469EFA550', '7B4A11AE-A01A-4634-8809-94FCBE3B4A43', '4009932554021                       ', ' -  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB924462-BA33-422E-881D-A4601F65AE16', '7DEC0600-542F-4DEA-92FD-964F721663FC', '4605738005790                       ', '    4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3529B57D-AB89-4D4C-A38B-B18693AB7A65', 'A78567F5-6FD3-41FE-8192-F11EFF9A23EB', '3800212712558                       ', ' -  18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE6C5692-713D-4F09-8E19-76CA25E7850B', 'C9577035-9624-4C5B-9891-4FCE5AA9D530', '4603988012735                       ', ' 5  / 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FA81384-CD1F-4F08-BE0B-C830667B20B4', '3BE3CA6D-075E-4C20-8AC1-71F09BBBA47A', '0382900910017', ' 1 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('386E1A74-A6CF-4D04-A42C-AE725555DA32', '35A8264D-3FAD-4FAE-9CA5-DBA4F781B9D3', '4601214001652                       ', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43F645D3-E7D7-4446-99F0-C8C35AB72538', '0C3AF8FE-6604-4A96-A0FD-5F6446B728A6', '4607005899781                       ', '- 5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F344F041-10E1-4252-A27E-19AAD82CE7EA', '404BD16D-5357-4034-A719-8B7861DD6BD2', '4620002185923                       ', '  - 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FD4DBC5-84ED-4967-B2E4-B00EB8C53F3B', '0BD6B811-FA4F-48D0-830F-E078B2837B1F', '4600697193496                       ', '-   40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C630FA1-DB73-4C89-AF44-98EE0381CBA9', 'F0B664A3-2E60-4AC7-8686-58B797DF6003', '4601811005121', '   /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7062413-B402-47EF-A0F0-1F01FB5885B8', '033C4472-10B3-46D5-98F7-E1031CE5139A', '4607077091915                       ', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C0F8957-779F-4B0F-9FBD-83569EE0C97A', '00D68724-64B8-4DC7-B335-5329549D3FBF', '3515451079781                       ', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66CFB821-2099-41FC-AB87-8FC3F2587C90', '9B06ED01-CAC6-46F4-B2CF-3C5AC730A3F5', '4600702091458                       ', '        100  N 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B576CEC4-D8D5-4C4F-8931-96C2A37358CA', '5F307679-B45C-4757-9364-0A1040D12FA0', '3534510000214', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9413EAF-0F44-46CC-8B3A-D18F2391DB6D', '1F855141-A4B3-480E-9495-8DFC068EA00A', '4607116944684', ' 5% 250 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43C9DC26-5A6A-41AE-BA81-3AEE6BBE432C', '62F5705B-0CB1-4FBB-8C24-F6DABED0A5D8', '5900095000327                       ', '     120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03EC9B40-4DB2-4C45-AC4D-C0B823E08370', '02E733E2-5587-4497-AE38-96BFCA7D89D5', '4650001795151', ',   -  / . ../ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6634474-1B77-4AB3-A465-E6EB11D8CAE5', 'D06568FF-824B-4831-8A34-0BC1BD637B7B', '4607039975987                       ', '   ( )300  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F2958AFE-3E03-4476-8FF5-C505DC5B1C4C', '9279B078-BC09-4D2E-890D-02AE5B9A0040', '4640003260849                       ', '    2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5B3DA2B-F33B-4576-89B3-D4D7F9B517AB', '59E06BA0-0026-4830-84D8-1CF006FAC323', '4607088741526', '   80    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D671BEC9-3676-4B28-87D8-6660FE396598', '97ABBDED-1F61-4E2F-9D9A-888C07469055', '4607088741540                       ', '   80   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0989765E-BF3F-4BFA-A98D-06E0F6675C0A', 'DCC94062-FB10-4369-8A79-693198BDE865', '4610012280176                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE1E064A-CA49-46A3-9EB0-C8C05FFC5845', 'B57302E2-3A24-4AE6-97B8-43BAC60A05DC', '4610013462168                       ', '   /     0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F57A496-761A-4E2F-B41D-0881BB79ED0B', '058E23BF-F6BF-4359-BEEB-E7362CA3BBF3', '4036534642207                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B109069E-4FE7-4EDD-989E-DF40A03C82D4', 'A749F2F3-DC63-4455-9E35-6F22E2CA6B27', '4640003260610', '   4   1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFF9DDC0-DA4B-4945-B483-A65B8C2DF38A', '497199D8-082A-4182-A375-5D2FF06C3775', '4606033047379                       ', '  / .(-F-6 emb.logo 3)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('213193FC-A9C8-4500-9447-D2B841E43C8C', '3EC784B8-BE70-4CC9-9D82-095425A8C3B4', '4601669006714', ' 4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90ED1CB3-8484-4B99-BA20-4E56925161B6', 'F5DA1259-BF37-4660-9EE2-694E4C6693DC', '3282770014129', '-    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83FC089C-FCBD-4556-AC99-476544198E31', 'CF20B9A5-6A7E-4417-8EEB-0EB547079509', '4620002180478', '  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCDC2EEA-5391-4DB4-8E88-B1905A675580', '15B906AF-1E3B-4FED-BFAB-D5CBC083D5D8', '4620002180485                       ', '  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93C6894E-D1E2-4D66-8EA5-20B700CDBAF6', '3A8C9882-B991-4799-84E6-CACA99796531', '4601764002215', '  500/600  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE5F6410-8222-4C8A-B5C7-05D7A06FB214', '0FFA5694-2F0D-4202-88FB-EBE55418CE2A', '4607131422365                       ', '    /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB2CB5EA-6C0E-43DA-A9D9-76645F4B203D', 'F13F8213-3C70-4526-BF20-DD6D2B27D56A', '4601798006326                       ', '  / 40  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41B36233-55B7-4355-870A-00EC798035C5', 'E1395ABD-0241-42A5-A6D6-729069D66DBF', '4607163090402                       ', '  125    /  6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D10235C-4FE5-4CB1-9E55-83A34541EDE3', '13F8D14B-7C71-4436-9128-4013895F2D2F', '4607011660252                       ', '    / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42A06322-ECC6-4ED4-93D7-6A26F304EBB3', '9D1F8A50-368A-4383-8EA8-6D4A6F0A7753', '4630015180044                       ', '      1 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('567F1AF9-7A17-4378-8DEF-2A2BB3BA3EF8', 'C8319924-5D10-42F3-9576-56D53DEFC85F', '4605108001759                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D86F528B-13A1-4108-AA50-5E2AA9011B56', '74732693-6E1D-4BCE-86F9-4FADF2EBE8C6', '4607163095780', '  200    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5A1857D-88A2-47C3-B9A4-58D837646843', 'AC986B85-45DD-472A-AFCA-F1320CC29B03', '4820121900302', '  -- 3. 20*22 1063', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('967D79BB-7E7D-4E4B-878A-B520EE54E1D8', 'C26A5573-1A65-4E96-BC3F-3B0C3FEF7EAE', '4605920000916', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A9609D0-63C1-43E2-AEE8-107F91E1FAB0', '78545A0A-505B-4BC2-84B5-9994C08757FB', '4605920000602                       ', '   / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F03DCD0-3ABF-4115-BCEF-B69AA2510483', '30BA21CB-452C-43CE-8D54-CBDE8EA6A2D4', '4600416002566', '-   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93A41745-994A-49C2-B5B0-F3578500D499', 'A5AD6477-B1AC-4A78-A866-5F7DC22B52C5', '4605581007958                       ', ' -    25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E74FAC9-B92F-4FB7-B4FF-1C9F5D96C19A', 'E705F323-61AC-4AD3-A3F1-67DF29A4D2C6', '4607086220931                       ', ' /,    350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('465A516E-13A3-49D2-81B1-8C7F9BDB4A88', '4789BCD0-2FCE-4CF1-88FC-A0166DB2A984', '4603014004925                       ', '   juicy / 35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1BB107C-87C1-4540-BB0D-83C3589A2D0E', '5482927B-CBCE-45CA-A59B-E4E194996CED', '4603725521070                       ', 'Vivo   0,5 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3BD7E06-B011-41CD-96D8-D45F510F93C1', '3DDEAD1D-FBC8-4443-A588-5172D37C6D57', '4607020903432                       ', '  20  2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF8865D2-1974-4DEE-9AA6-C4BB042DE687', 'FD40FE42-7E11-4661-B4DE-184320F9F9A5', '3838989514983', ' 1,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FF9109F-AB24-4792-A973-73DA96273010', '351D0C8B-5EF9-4E8F-AF18-C01DDB9F2F26', '4607086566619                       ', ' - /  c    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DB51798-3D31-4457-B623-3E97B1BD2153', '52733801-63DD-4DCE-9B61-B2502B6C6925', '3582910131045                       ', '    125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55B41154-F4C7-4997-8ADC-B3B5DDEE2126', '928A1102-07FF-48E2-BBB7-45A1D6493FD7', '0016401092377', '  - /   /137/ 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC26024C-FA0B-4494-91FD-6F19CC8A48C9', '94BC7937-78A4-402C-BE7D-EFCCCFB4682D', '4607002752416', '    340', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F61BB7E1-B928-4779-BB58-97CA998B6EBB', '8C231739-4CCE-4CCE-BA5E-4395535C7985', '9062300111627                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CBEB7D6-9586-4D5C-BEDA-EF33476FB31E', 'BFB6C5EE-C413-42BB-B7EC-DFE97F01E2BA', '4600936230692', '- /   410 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32467956-7450-4A07-BA5F-EB5DDFDA5FF2', 'A4543BA2-E9CC-4033-8FEF-F2BEA4E59542', '8714100713846                       ', ' Ae      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4E8F69E-1623-4A16-89B6-B6F79A0A29DC', '24479704-8763-484F-B6DC-8049600AAF1E', '4690408002391                       ', '     60 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D1833F2-C99A-4CB0-978D-492CF02361AC', 'D0BA8F9F-4654-40EF-B617-260ED1840756', '4607013792142                       ', '  - 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('054727B4-5D71-4B93-9696-CCBC0B088119', '6386E98A-D813-4CE1-B357-9876B067EB93', '4602884016182                       ', ' 200  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B668B8A-8962-4437-B4FC-E29FAC0B1533', '443F4097-3E76-4428-BF1A-5B210A87B247', '5903407225654', '    0-6 .   /22/565/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E39A57A3-305B-43D1-86F8-2403EBC2AFC0', 'CCEFBA54-727C-434D-B62C-40C25F45D7E4', '4607020904637                       ', '    1,5 / 26 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E359DE99-7872-4A06-B1E7-3CB0D536A54B', '8E2CAD20-DF3A-47D1-BFF9-E548F7C6C21F', '4640006304281                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55B990A7-3373-4FD5-83B3-93E526A4B001', '4DF61028-2EAF-41DB-B771-5F503C1B139C', '4607027217266', '  .  1807', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('245FBEF5-690D-4239-A831-357456F054B9', '9C330EE1-19E0-4274-A722-FDDFE63CD049', '4650001797117', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('589770F8-4931-457D-8B43-F5B92C6B8D22', '63DC7154-B7B4-4CEA-BF5E-66532BA842C9', '4602329001346', ' 20   20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F0AE1F5-CDDF-42F6-B87F-1D33827DF0D7', 'E059389B-FC91-4A1A-8BEB-A0695C1BF408', '4600999018756                       ', '     spa secret 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8EF0BF4-545A-41B6-A73C-4EFFA7CB4698', '2903C941-8F18-4C0C-8F33-031C31A8D3B2', '5280127480021                       ', '    120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D03E470-92A3-4BA6-B44C-8EEC757EE8CB', '9655E33C-E268-46A1-A27A-64C41BBCEB61', '4005808158003                       ', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47B059E6-6BEE-459B-BD74-3C440A54260A', 'F3774504-A397-4FDF-9ED2-7A1B812E0479', '4600702077209                       ', '      80 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57E0DAC3-E1AA-40D9-8520-D75875FB22B5', 'B7187D4A-47B4-46A1-A2C3-16CE8AB3D13F', '3282779184137                       ', '      30 +   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A05A6DE-ACA6-4164-8083-82354CE8EDAE', 'EE8A4DA8-D365-4B04-8800-9DAF914E859F', '6910181210614                       ', '       8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2E087F7-0445-4CBA-9DCA-1F9675E83DE4', '4C54B676-23E2-4AC5-B2F9-6B3712E70EB1', '6910181210591                       ', '      . 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93CF0025-D4F1-4066-8DCE-6D01009CFE65', '3F1D4AFF-7753-4295-8147-41D0980B9775', '4603014001856                       ', ' special     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2537386-7A9B-4604-827F-503B4B898789', 'AE851E4F-93E3-43ED-A0BF-D7EEB7EB6F7A', '3574661136356                       ', ' ..    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CBAC4EE-83DC-4DA9-9B16-0877C0478587', '57C277D0-8EAB-4A12-AC0F-221A092161C1', '4607086569351', '        nutrition 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0EEF601-8B97-46F6-BAF5-8511A231C583', '9CB0B990-9164-49B5-B956-92B2ED273E33', '4607086569337                       ', '        25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13D7D1EA-B433-4D82-A548-7205AA297D4E', 'C47A1882-8C54-478F-8A1C-29DF8ED03F86', '5391520945007                       ', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E209C48F-9782-46FB-930A-C0597CE8D31F', '9828E50A-10FA-4E13-B765-843775C4944B', '4603933001692                       ', '  0,05% 100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40E681AA-73C8-4C90-9B19-99608542F3DB', '091D9263-6AA7-46A8-BF28-6D2386F76567', '4052199204673                       ', '    90180 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8352FB38-8ED8-483A-A94D-0214DFD3929D', '97E44E20-21A4-46F5-95FF-AB045EF04908', '4650001790323', '   -- 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E228476-BFCE-4C44-9CE8-D422E69B1958', '7AC0B9BC-6D47-4490-AD0A-CABACBBE1AA0', '4601808005035', '  100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4024D3EA-4012-4157-BF80-2B3782344420', '2814BA64-B2BB-47D0-A108-51CD3F54C236', '4601808005011                       ', '  100   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D767F74F-301C-41C9-B672-1E5062FE7B2A', '9A249C90-231A-4D40-8C18-061C0D3B7E34', '4660011212227', '      10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAFEC769-3F24-4D30-AA13-232E029E2B75', 'B7666E44-BBDA-4E57-B3A8-79F87B4F18BA', '4660000410337                       ', '  . / / /..76-81/ 3 // -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4D0B8B9-CE1A-474C-9916-C8E29D503613', '7EFBD91C-6DB8-45B6-A6DD-9D96FD90C374', '4600689601619', '  200   /  4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70E5363B-DA6D-43BE-8B46-246C53B0B809', '311BA589-353B-456F-B67C-28B9964F5DCF', '4607163091409                       ', '   500    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C76511D-AE10-45D0-BCE1-B2DE88E8C1C5', '00264A19-2CC7-452C-B161-0C99111250BA', '4607131427599', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('657E1B02-FBE7-4A91-B67C-F701534AAE88', 'C9AD0762-75C9-46F8-A6E8-4196AA745176', '4607131429951                       ', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EC9103D-D9B7-4735-A1D6-1375E9E3C1D2', '7BBC8D48-5453-4632-B1A2-AC7627DE66A2', '4640016742059                       ', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1141DE38-3754-43A2-BC59-CCAFFDA02E0A', 'B246F412-8401-41FF-955F-0BA40C883C4B', '4627129211153                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD14E6DA-10E4-4527-9775-9B555E346505', '882231CE-6EE9-4469-8DCB-2A9C33C8571E', '3282779039499                       ', '  /    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F44E583-2D0D-4FC1-A264-CD80A70E94D8', 'ABA6A628-FBD6-480B-83A9-68A26934B318', '8030009522304', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BB8113C-C181-4629-860E-1A3E46B1D29D', '9C4DE5BB-4C26-4A91-8D12-1EAD1FC70C9D', '4607118050024                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9ADDF92-66B5-4134-8B5B-662FBB11A24C', 'C47929DF-8DCE-44D7-B95D-9B58D56FCFD4', '3760102850664', '  /   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60CFFB92-6630-4813-96F6-86DC957A547C', '73234268-1E98-4E2A-9018-2DB6B6C425CB', '4612739990031                       ', '  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('785E2DF0-D784-4D5D-876B-B798E35319BF', '1F5898C1-4A68-4721-B9E4-F0F0E9CFAD7A', '4607008960518                       ', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E22A259-295F-4195-8E0B-C8A1672989E0', '0C87CFFF-50A5-4927-A86A-CFEC1A850300', '4260107478102                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C85E3152-2DC8-4B85-8093-F788038DCA64', '2068D1BB-175F-4899-BF91-158A4A951F92', '4820121901224', '    225 124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3660DE02-F002-4FA5-8347-E6BEF534676F', 'CA637BB2-06CB-49E6-8B6E-9CA130D9CB12', '4623721921858                       ', ' - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32F90864-03BD-4C43-8B5B-A27269D0BC17', '9DA9E11A-202B-42E3-8E3C-C49E0A2F577B', '4607051797536', ' /    //   / 530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F1B28D4-FF5F-4B1B-8BD7-2427F5812E19', 'DEBD83A1-A7C3-4FCC-9231-F59F1612A76A', '8887786800336', '   LD 1 (3 )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F645F4BD-20CF-43CF-A44C-23284D63B33C', 'C464DBD7-DB0F-4AC2-9F8D-66F39E4ED4D1', '4602521007429', ' 5/ - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('665E8A19-5E02-4DF6-AE58-ACC3C30B7343', 'CE7B22D4-943F-4677-BF16-B13B8F0DA69A', '4607153456300                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('858E7E62-AE40-4D22-BD05-BF043AE126E9', 'C2A66831-0F35-4022-B2EC-4B390C33A257', '4650069782124                       ', '    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AAFE992-7C77-471D-A97C-579101CF3200', '6AEFDA0D-A02D-4499-8A7A-9166CBDE90F3', '4823015926457', '   /  // 42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09FD511D-A3C9-4539-88AB-6A93C4ED7B0F', 'BF2CECFD-F48D-4393-9AE8-C83084AFE312', '4605658110284', ' /     6+/11028/ 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4837CAC-B8C5-4B18-9B4F-77722EA8F604', '7B4917EE-D59B-4DCE-93A8-3DEC2E98F380', '8710103787211', '    0-6    .83511 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BE2837C-38A7-4F7E-9064-42C69C6B49D6', '46157102-7463-4DA6-86E3-FEBC6406D89F', '4605658121280                       ', '      0+/12128/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B4C6FAD-8833-44F6-8DD8-CBA03D8A618A', '4AE879C5-0F54-40D9-8B48-D940811A4F9A', '5900273150011                       ', '   360   /fcn20947/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57068EEF-D71E-4039-B0F1-149CFB404B77', 'FF2D406E-ABC6-47D0-8B66-F2F46728B9AA', '4601808000214', '  60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7716EE23-6147-4BB5-B5AD-4F00C25246AB', '99D28BA8-7D10-478B-9B41-9A22E56B7C42', '4650069843474', '    11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F7B189E-FB8E-48BB-9B20-4A16D8E8DE53', 'EBCB7AE5-7AA6-460F-B752-B9845DD223C7', '4620002620097', '        600', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE3FC4EC-8DEF-4E14-A6B9-5C90AC8BDEC2', '509D59BA-2B84-4F98-A1CF-338E1380A12D', '4670008162619                       ', ' 4 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34EE87E6-4699-4E25-AD2F-1DDAF3AB406F', 'B46E4B95-3011-4849-BC23-04E153D2445E', '4605370004205', '   /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('942BEEDA-73D1-4D53-9909-51D95397BBAE', '577BFDB2-18C7-4990-A51F-A2E6FF7A159F', '8606105662048                       ', '     18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E879CB36-D0D9-484E-B1F2-88171F9FADE0', 'D54B2420-652D-47FA-8902-8EC0EB8322EF', '4603256005735', ' 0,25% -  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89598C5B-A6DF-48F0-883A-F782CC3FC88C', '7CBF6B92-B418-428A-9CCD-01CF42A328B6', '5903407565828                       ', '    . 4+ 56/582', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0E1ABE8-5159-416C-BD02-DB333F158A6A', 'E5064EE2-1FEF-4DB3-8227-D62542E33D4C', '5903407131191                       ', '   13/119', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E91EE19-BC72-4FB3-9D37-D31448B97B47', '65AB6B96-0B93-40B6-B384-AC947AB2213D', '4607097011610', '  100    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59F54DBE-7DB6-4E2F-8E04-4F5AE4132C2E', '54E37BB5-A35D-4796-BF33-F7254BD321CD', '4607010248130', '   /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60E42C6E-3F83-466D-A532-EE2A59DA36A4', '1461C684-DCDE-4637-A67F-D45EDB7D5EC6', '4680013242787                       ', ' / 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2729BDAC-9EF0-4DE6-9679-A784EB218553', '3CAC5AFB-DDC4-479C-96F1-219A99758722', '4670017926288', ' /   /    0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F1D734C-AB17-48EA-B159-8FD9D8C34893', 'B7B46EF7-488D-4371-91AF-35F0E99C4BEB', '4660003400021', '-   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B909AB1E-2649-48BC-BB6F-515B91136BF5', '9E360955-5BE3-40D2-A193-8F1B58DFCD08', '4627129211016                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0CE4B6E-1F83-454E-97CB-BEE37448A2BB', 'C4D222BB-89C6-4911-97E4-011EB5DF26D4', '4602876002520                       ', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C9DDEE4-3316-4EA1-A1AC-1690362E7576', 'B2D8B348-72D0-4DA4-8DD9-A125C3E21145', '4601372000191                       ', '   33,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70F55659-0F5B-4001-95AA-80FFB4A7586A', '9BC90CB0-E602-4E21-8323-9E5509DBCE43', '4606144005381                       ', '       50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('265B33BB-A21D-4004-911E-F53FB2A075A2', '69D41C0B-41D9-486F-BA37-3CF4BE976CF5', '4607010247232', '        50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6E17CA5-4A45-4788-8BF1-E6AA7CE0C8D7', '65182F12-1D3C-4213-9BBD-C29414BF6B1F', '0837524001776                       ', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F76DE17-9E4A-4996-9E43-4894746DCCFB', 'E79FA358-4F85-49B3-9E37-6AE370E6E796', '4603014004918                       ', ' Juicy      35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56E9A2B3-F4EC-4577-A71B-179364214A4A', 'F152CE6A-CDF5-4211-982D-CC8200135B21', '3582910067351                       ', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F262E4B2-2CA4-4145-A73B-53F1BAFB60F9', 'E39FF5CC-C658-456B-A6EA-D692908823F4', '4620000431886                       ', '    / 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86B9F600-0BEF-499E-8C93-C71F55C7D615', '7379F642-17F7-4D3B-AC93-CF6521F59039', '4607017643266                       ', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C88F55D1-3A44-4A86-8380-88D636373D92', 'C5821227-36DA-47EC-837E-B6E42F784588', '4607008360073', '  / - 10 /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F9F700F-25ED-441F-885A-266981671C17', 'C0CB451A-1F85-4F95-9373-2C38B134623C', '4607078971155                       ', ' -  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97506F3E-8749-4AD3-92DD-BEC0E4ED4AE6', 'F13688D2-C73B-414A-817A-36B54BA66AAE', '5060255350706', '    +l-  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('338D0F45-DB8F-4F01-ACEA-A848D47B95D5', 'FE3BE33C-4817-4922-A595-F25AE1B22176', '5905179570130', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84F1B1E0-60C4-4CE5-8937-638B0B8287D1', 'EDF5002D-611E-416D-BF21-A97A17E1BD7C', '4605446001886                       ', '  /     21 350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B184A678-A128-49E3-928E-1AE8F331B2C4', '8518A408-EAF0-43C3-AE26-389BB4A50DDB', '4600936241285', '    124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5532B2F6-2A95-4822-A343-C9C87835E643', '4F54852E-02B1-4BB7-9B14-B1755F6F8CE6', '4600936241322                       ', '     124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59576473-055C-4BCF-9822-F929E2431C78', 'D995360F-91DA-4414-AB25-EA74A52F1164', '4607020904347                       ', '  30    2 / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47D138E6-38F4-4653-8C0F-8C1FB4F235D7', '497FB882-595D-4FA1-BFA4-A8FB8A02C2C7', '5029053540061', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04B24B42-36C1-4837-AC92-8F9890F4F6B2', 'BED9AB58-B362-4931-A357-889D499ED999', '4670017923096', '      155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('556F678D-5ED0-4C84-84B1-7DD0DEE5848A', 'A2863CEE-D720-4A3B-932E-00DD431CCF81', '4670017923065                       ', '  /    155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD5F75FC-B72F-41F9-BBFB-085873BE098B', 'B4B1D4BB-B821-48A7-B4F4-E96D8723E746', '4603500042752', '   . 100-104 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('072C3275-9369-42B1-953E-CF32487E1310', '139CE0B4-C4A8-46E3-8E93-DFB9D51B3D3E', '8901148239425', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04998FC2-6588-4914-9E52-68F9C1664A07', 'E1597F58-CAB8-4B7C-B095-454D5BE6EF7D', '4607118050819                       ', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3641E149-763D-4EA9-BC9E-33BCF29A5275', '00E3069D-0345-4F34-94E6-537B713D92AA', '4680018496833                       ', '        1,0 1,4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02A15B45-C8FF-4E21-80FA-E9AE6EEF2DA2', '08CF7129-0F3A-4FB5-9D88-EB43CDAD2DCE', '4823060802003', '   0,78x1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9971780-5E6F-4592-8F1B-2C3EB21D0CB9', '57556593-6CEF-45EA-8F39-E5AA7D03664C', '5900516894276', '     matopat plastofi2,5*10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AECA194-DAEA-49B1-94DC-F1C1BB3C155C', '9256B36C-5577-4BBC-9DF2-28D3D03DA371', '4602072021592', ' 5   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C979EFE-00CB-4600-A625-A17F3D72A0B6', 'F1205EBC-0737-46EE-A0CD-2D81700B57D8', '4623720904876                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FDF4219-B555-4D53-A594-CC190FE326A0', 'FF521A00-2BB6-4C9E-867A-AB1B2E02C510', '4607146822013', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1137CAA7-CFED-4BF4-B1EE-E78EACE23950', '6116054C-FA00-483A-AFF9-93FCE439464C', '4607086568484                       ', ' sebum stop   /  70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDBE074C-3037-46E5-8BDF-3E39A5BD0B62', 'BB27B2B2-EA3C-47D9-BF29-34D4BA889989', '4602509000565                       ', ' 10% 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1859F18D-5B4E-4130-B261-D6680829B379', '3B023D17-CE80-4162-AC88-D8F248D1BA70', '4680005640775                       ', '  / 250 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF6E7484-C67D-48E5-87E9-65F5C5C42E7F', '18F5A66D-A181-4872-8E24-5F69DB68D0CB', '8032568302359', '              ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B91CF387-EA17-493B-A148-A1AF4D364C6E', '939E7B8C-35BB-4DEF-B0F1-7D6D0B1CE030', '4620759290260', '  3% - 250  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A408296F-AB69-4D30-A939-9D4013C0BB1F', 'F1204615-E8D9-4029-8A39-53FE55081ABF', '3504105022648                       ', '      hydra 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51EAB742-C75D-4459-9BDF-A2EF07CC77A1', '2A09C541-C8EB-4F42-A18C-B5589BA5BCC1', '4630010960412', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AB98AB5-CD1D-44F8-B8AE-DC9EE61C6E28', '176EA45A-12B0-4CF3-AA06-D5FB67F374CB', '4690419007484', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E6D7F48-240F-4F83-957E-4603AB145EF8', '79508CEA-D027-4449-8DF4-9ED69669BD9D', '4620764310090                       ', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84BB6EFB-2ABD-4CC9-A1FA-5ED08DAADE5C', '8FB15F20-A674-48AF-B98E-9E6C9FE575B2', '4627108140153', '     80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99D13A88-03B5-43A9-BDEA-108FBA60E106', 'B5CF6D19-3B82-444C-AC08-D591408B15F5', '4601772002085                       ', '    40  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94E9C994-8456-453A-9E53-9D3E667FB7A1', '5F153118-A8EA-429C-8207-70E7A67A51E9', '5900516303181                       ', '    10 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6C4AC87-657E-436B-964A-62618349CA0B', '87DA5EA9-D235-434A-978B-31D079FB3268', '4607018262107                       ', ' 100+25+200  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75AE7C58-E2FD-4878-B625-89C8BFE2028D', '00A1A257-1BE8-46CE-90C0-D8A3AEAF4E21', '1950112580923                       ', '  () 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4ADD3A87-B67F-4C0B-8ACF-C88F01762AA1', '841CD302-4487-4552-9D13-1257E2040215', '4607027764890', ' 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('658C6CEE-D793-4C19-B848-7108B97AD15C', '6F744D41-5A67-427B-AAB3-0475A0467943', '4607086563205', '    -      300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AC588B5-1DB0-45F1-826F-61951524D646', 'E3F01DBF-27B3-4DAE-B8D3-90DE0D03F884', '4603423003106                       ', '      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5A59324-F7F8-4DFB-B034-30669F85FBE0', '3FAF7271-2521-4ACC-B3B2-7092349E3F47', '4627090498232                       ', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BE2A935-7010-4E9E-B5C3-152BA181EEFA', '6C36B7CD-7E22-4B57-B0CE-0A1C44E904C2', '4627090498133                       ', ' pellesana   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCC61FEF-3F6F-440C-BC83-9A3FD565B741', '447A16C5-5FCD-47F0-9EE5-4F526FC910FA', '4607174431744', '     / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('653BA2CD-8BB1-471F-9B65-1D55425F4E52', 'BE35E389-96EF-41E0-8FAB-D489120AE7CA', '4630015180303', '  1 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18F87E86-5ADD-4D22-95DB-2E035B98BEE7', '3DBB81C6-3EE8-4AFC-8F24-2921D8F1860E', '4680007630453                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E032BACB-548E-41DD-BED7-2BD4647C90C0', '2D3EB8F1-01D1-4A2F-821A-A1A947ED5A86', '8030009741231', '   "Medium" 2.5  . 4123.02', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D5E42BF-0CFD-4BC6-A4E1-EC5ACDEEE07A', '20F8FF9E-FF50-4F1A-AFC8-CD3B74394BD1', '3574661073316', '   - / 50+- 4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A04D2E5D-CE7F-4568-AD35-5B8239CA8F30', '73B74ED7-BD4D-40AA-9052-6DB81EBEE588', '5944728002302                       ', ' 3,6  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FDF35BA-30CA-4FD9-96CF-D1B4B054E271', 'A61F5972-8A74-489D-B029-FF3B8EE90697', '4600702088953                       ', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2933D921-2F37-47DC-8891-856768C623CC', '5FC2F4F1-19B0-42EC-9961-5816C74B4B3A', '4823015918858                       ', '    () 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBCF979E-4901-49E3-B8F5-96DC7DA67B5C', '60748410-1BD7-4492-B265-130008757EE2', '4603014001979                       ', ' professional       30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C149D77-C708-4AF0-8D7F-B4AD1B463579', '8A17A308-6CFB-4E1F-8199-F765E96EB04A', '4627074840521                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48BFA07F-52D8-4F17-A9AB-E3F004813D44', 'A49FA572-9E2F-4C8F-B4F7-1AED5A647B49', '4610008495362                       ', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D74AA86E-CE9D-4CB7-A823-4F54390C6189', 'CDE3D992-CE78-4CC9-9048-933AEBE8CB65', '4607039975970                       ', '   ( )  90 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A2BE98D-EBA3-4666-ABB2-C90EEF1BDD73', '4E8D64FC-032E-4B6F-9ED2-2F1AB35EE727', '4607029040091                       ', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6EE8909-D163-4E52-8E19-AC8AAD116E92', '5999E804-44D3-4673-B548-6E0491D41415', '4606033038636', '  ./ 2 . /zo-fg-02-12-/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E19674EF-5B3D-40F4-8F18-6CDFF4D550BD', '50FD89C8-E8EC-4167-AA04-C23C766A8CDF', '4600416002580                       ', '-   30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E70F8E8-66DD-48D2-BF36-017CD7517C38', '7275E545-DC5B-4590-9DBE-72BDEEC83F83', '5900516401412                       ', '     100+20% TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('827230A3-37DA-4BBF-8CFF-70AC9EBD3574', '1D7EDC9F-16DA-44D6-8B20-A69CC02E7D07', '4605319002620                       ', '- 200 -  /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8D16A81-D2B8-4492-B796-01372D4F095A', 'AD449245-9460-481A-BFD1-43B96D99918E', '4627108140191                       ', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87CD10CB-11F0-4F14-8209-CDB6CBA31365', '7DBED97E-F31E-404F-B10F-957EDB44548C', '4627086802371', '  .-.   . // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F480C61-F4B0-4F6C-97D8-377C5FC6F7B9', 'D9367E69-0097-454A-8AF4-FB20FC41DB9E', '4600665204919                       ', '  6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C2DE9CC-028E-4EBE-B139-ACA05129FB87', 'C3BF29BC-018F-45BA-A6C5-20B718A6D9C9', '4810910001433', ' 4   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8235A1B-D430-43A4-9561-A950C6D8D8F6', '37473EA7-80FD-43D5-ABA0-7412E2A22622', '4607174430631', '    - /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE355FAC-45D1-4D2F-86A7-D7CB6FF94EBC', 'F3BB5ED0-8266-43D3-A66A-90550ECEFD9A', '4602866021920                       ', '-1778  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2003B548-5A30-4822-9969-07F2F2ACD137', '207BB873-755E-4330-8902-E47207A68220', '4005800189579                       ', '   /   4+  4+   1+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E121FCC3-3DBD-4823-AC34-ABC92C0F76CD', '431AD2EA-6E36-4A1F-A708-8B9BA8BEB497', '4607020903562                       ', '  15  2 / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCC57CBC-E51E-4FE1-9CE6-8D157409EBDA', '306CDB82-AE94-49EF-A89E-D7841B22C848', '4627121880012                       ', ' aibi  3  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F094AB20-B8EF-4BA0-A315-796EA8F008ED', '4204118C-98D0-4948-AC17-5B53F738ABCD', '5907724574983', '     3,5 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42599AC0-AAC3-4796-83DA-B8EF1BB587AB', 'D2F9ED6B-69A7-4AFF-9DC8-849E3E8B702E', '4607041069988                       ', '   30   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0B0FCE2-D0E7-43E5-97C0-0276A1F17908', '3BF521A0-4195-45F5-83DA-12514C4F23FA', '4627129210989                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('975F1E7E-87C9-490A-BE48-65DA7D764C57', '791B2FFC-6C09-4A1D-ADD1-BBE14704BA3E', '4670017923423', '       270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB89327F-8FB0-450F-817D-1EEE5CBF1D44', '1A5F3198-764D-4B95-9429-5D40953DDC6C', '4607051797505', ' /   // 530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D8EC18B-8F5B-4169-B436-E40ACD08FD31', 'F9239904-4617-480E-A079-1CFED2B5D284', '4605658230944', '   /23094/  4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54CA1E60-B3BA-4469-9E23-4BFCAFF48AC5', '2A09513A-8815-4E71-9A7E-657410006AE9', '4601313012092', ' / - 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4EFAED7-0B5F-4E87-BFD4-5E8C4EF7EC0A', 'B17D4A3F-6EFE-446F-B855-BB3C73EDFA81', '4601313012108                       ', ' / - 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8352559E-9020-43D5-8810-0241925B8764', 'F3D645C1-270D-43F2-9B2A-104E5988FC95', '4607131422891                       ', '  + 30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CE378AC-3EF0-4B8D-9CBC-C3D5777E4648', '60BF86EF-A532-4013-ABD6-E7D1C87A262B', '4607068884069                       ', '    1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF4A3E52-B00B-4965-B05C-708D49BEBC59', '9830B487-7C36-40BF-B936-2826BE601E9F', '4607003246129                       ', '  8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBE079DA-5FE2-427F-B912-3E4D68674E8C', 'DC11DF8B-5E21-4428-940A-BD5C58BB2513', '4607155641360', ' leiko  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FA1AE27-FFE0-4494-B6B9-85F5B91AA7DC', '3076BC63-FA8E-442B-8A32-C4D32CA57CF5', '4602210001059                       ', '-  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('175548C8-EFAB-44E0-B1AB-E92D04EB81B0', '14D9455D-FDE6-4905-8FE5-EB7009E8E0A7', '4670017923409                       ', '  /     -  270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F85DE58-0612-4BD6-A4DB-A209F6365DD3', '3102366E-1FC0-4072-85DA-B4AFC391ED04', '4605021002970', '  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4ED5B3B-446E-45B8-B1A2-7DD6079D1120', '514563D5-F00A-4BB7-BA9B-61ABBF3DE2DB', '4660009150029                       ', ' 1,510   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABDDCB42-B65B-4971-927D-EF2141273FCF', '7EAA350F-4A03-444E-AA51-E52B4B71A8FB', '5900516892814                       ', '    - L     1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70ECE0D4-DA2B-4F29-B4F7-566A74387D9E', '4D7CFF00-E9ED-44C7-8147-30CB3D3A94C9', '4620002185282                       ', '  -  -  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33F171B0-E248-4D4B-AB65-64BAC0C89DA0', 'A7BFCA6F-8DDE-4DC2-A8F3-7B3D2CF70149', '8030009570879', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B65408E-6EA6-42F9-979E-09BA7EBDFDA3', '4399F7D7-4AAD-4BF8-959F-B7D74899417C', '8030009570237                       ', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E6001AE-36EB-4F85-8B5C-300BA911F5EA', '7E5A179D-47B3-479A-8C53-0E3D63EC405E', '4680007214042', '    /  // 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D56996C6-978D-4709-861C-C4C25218FFB1', 'BFFD8583-42C3-43D1-9143-B80280EF6C7D', '4680007210587                       ', '   /   280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FF60C37-B1D4-42C3-B5EE-2B5BF9EFB1D7', '4ACA4A96-F45B-49CB-848D-2E5BA66913D2', '4601772002481                       ', '   40 4    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4D1C2B8-70F6-4539-996D-DEDF7D37F38A', '833EFB61-ABCD-491E-BB74-9487EF99FE1A', '4603014007728                       ', '    6-11  73  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('758A7C46-5D46-47F5-8EF7-6D57CC3EF9A0', 'A2E5CF59-CDDA-49D5-ADFB-4CFFF006A2CE', '0382903205905                       ', ' -  /- 31g /0,255/ 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCF20398-6B6E-417A-8665-F1ED64D53724', '882DBBEA-0F0B-44D3-8778-EA7D63183354', '4015630019724                       ', ' -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B125FE38-92C5-4729-B85C-7AC47867771E', '5FA15024-4D82-4A96-98D9-3AB9385B7957', '6948209678344', '   / /    8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42AD480B-4552-40D6-AA5C-E00BB8B357C2', '25721A46-2799-4A44-B907-A04441B92B12', '8809052585266                       ', '         23', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD35AD1F-657E-4189-9129-D5EAAF20DA36', '989B1E98-817D-49AD-B3F8-114A7B02A0FE', '4009932004182                       ', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4516CC20-119C-4FEC-928B-D2F81741080A', '3AD3CE33-8317-46B8-916D-891FEAB5A80C', '4627129213157                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC8D4F95-BFA3-4299-A75C-661AF6F8C0AE', '6284C600-8E50-4A5E-9818-5AF6B1ADBA3A', '4016369668245', '   4  8   +  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DE34192-248B-462F-A902-D61A2DF8B749', '42178B43-FBD1-4846-B6C0-4550508F7946', '4602159015100                       ', ' // /     4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E35486C2-DE59-42E7-AF07-42A849C28730', 'E059BE51-F97D-440A-B595-71ECC58B907B', '3585551855745', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8E9EC7F-81C5-4A52-ABD0-E54DFC2EF448', 'DF6134FF-E01D-4FE8-85EB-5604FB0D098C', '4030855507528', ' 0,2  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D1AB2C2-CAAB-493B-8137-BDE92D23B77B', 'D097822E-EE27-482A-B99E-87841C62D805', '4607163095919                       ', '  950 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A0D46C2-BF41-4817-89B9-1FD3FEF3BF88', 'BB8725AD-EAA6-4DD0-A4F5-09104B7B3747', '4607068627338                       ', '    /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C4A13C5-755E-43BB-B062-C647A50E08FA', '52AC190A-19EE-4DC7-8131-D608D586D646', '4600697111391                       ', '    180 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3DF52C2-0600-4851-8559-C00B6A322BA7', '2FC06D2D-DB2A-437F-9500-8AC8B919341F', '4600697040516                       ', '   750', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0470B52-72DC-4252-B915-0A5E95570428', 'E7F91FBB-DD70-430C-9E98-01A3D3E154B7', '4606711702118                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67C3946F-5055-4F79-822E-346955E9D34C', 'C5626200-D744-47D7-9898-65BECE2F8C41', '4600702093124                       ', '     . 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2B56C0C-DF68-418F-B649-F024FD1E21A2', '79A5A00F-7BA8-4781-9B86-3890F8644C6D', '4620006946179                       ', '--   C   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CA39A69-30DD-47DB-A2BA-33B3418C726A', '06E9D7DC-D8DE-44CF-B6A7-7DADE61D1E4D', '4620006946186                       ', '-- +    D3   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4994C82-657A-4484-AD9D-F168FAC4809A', '294ED536-6076-4C11-8C4F-E758C398DCCB', '4620006946346                       ', ' 10 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36C503BC-9F4E-4F76-80BF-DF47BF0DDEC4', '183439AF-6A43-4BCE-B218-58559E25D549', '4640003260351', '      2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A12AFFF-F8BD-4009-BF5A-5E80630201CF', '8EA0A021-5ECF-4A6D-90E3-2659EA7701DB', '0000040114880', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C94FAF78-7172-4565-820C-047E2E0B9E56', 'B708186B-9140-40B9-B7DE-95A860103B84', '4210201049616', '  oral b    for  d10,513 / 3757/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('031CBE36-C6F6-42B1-AE6B-2AAC44F8E74F', '48967221-D82B-4A5B-A92F-94858F369977', '4620009500637', '       190 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('351CCC77-EC40-4628-A232-EBA384F1416A', '2858905D-1EB8-4FC7-8A74-308F94692D2D', '4601498006947                       ', '      2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59E1EA33-0C3E-4651-84A6-C056CC62486F', '437D950B-E0E2-490A-98B3-A3B5179BD07B', '4620001091300                       ', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9881580-F8B0-4507-8D38-503DD5590BB2', '2EAC261C-8442-442B-87E9-5C59D3DB470D', '4606486026839                       ', '  850  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('517655DB-EDDE-40A2-957F-3EF42A359438', '6711B9CF-E42C-4B46-8657-3E85DECE9FA4', '4250369505241                       ', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39A4DC48-92BB-49BC-A77F-76FB9615939D', 'B884ABEC-3F84-423D-A431-C9F1EFE3101C', '4607013793507                       ', '   - /  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('294CC2AD-954A-4C63-918E-E36D8137D848', '4EED5714-BE0C-4E40-BD88-CEA6386B336B', '4036534461204                       ', ' . /  . / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A590B22-3626-42FB-A5D5-78DFDAEB626F', 'A69A259B-D479-4FCD-AAC9-381124C3C835', '8588000133710                       ', '    1,25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91F79269-AD73-4276-9F63-88B96D7E6FD7', '1DB8AE78-A56B-4A5C-94F8-2E21535AAD5F', '4031881871294', '  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D2A54FE-8B1B-438D-AB5D-37585B3E9108', 'CA223784-515D-452C-9E80-3B5A7D7C52B9', '4620001090648                       ', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEB1A5AC-F3B4-42F8-97BD-32D2F13BD7F7', 'C3DD4182-AD3C-4F35-95DA-D544F4FC6057', '4680038240317', '     155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F66833B-7ECB-438C-B856-0DF836F8DC3A', '89ADB58D-A4DC-4E12-BFF3-AFAE61DE1EE2', '4602565024215                       ', ' 1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCA27E73-E0B8-4DEE-B917-8302A6D66A34', '681B4FD9-3042-4857-87FF-25A5E90F1C16', '4607152730104                       ', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4DB0D79-73D1-439F-B483-AF7CFA3FB003', '7AC42BF0-69AB-43E0-B622-619B8DB71151', '4607020904408', '  33     2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('161AF78B-ECE6-4EFA-90AB-2E9C527C35E1', '097968FE-015A-4020-9A6A-70028DCA7CB7', '4670017926301', ' /   /    0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10608EBB-A504-4676-AF29-DD0C3BA0EB9B', '4560D6C1-C578-4B72-8064-B714C5858978', '3574661288666                       ', '   cotton   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08706657-38CE-4903-B0B0-5BBF78AB37D2', 'A7E4EBEF-6A6B-4E34-93B3-0EA6A2BFF297', '4605446001619                       ', '  /   50  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EF0FD32-CC0E-4477-98D7-E917E19290EF', '40783272-D7FB-4BD0-B93B-4775876A36C7', '0027917104010                       ', '       60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B35A2797-8250-4AD7-94F5-3C6E59ECB1E7', '4740D16D-F8EF-4204-B6A1-5C6F740CCD49', '4680005640768                       ', '  / 100 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BF49906-FC37-47CF-B16D-08A3E2B8E852', '0C6F25EC-BC46-49E5-98CA-5465CFD34F95', '4260202923507                       ', ' vm   /   s 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12BE1E0F-F00A-49D5-ABE9-4DB70FF03C3A', 'D51E0CC5-EE81-4EDB-848D-35758D5DA9A1', '4602435006822                       ', '   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68F3180E-E5E6-4894-98B0-ED7DEDF5909F', '91ADF515-AD65-4E61-973D-6910F49107E2', '3337875474344', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('170D23AF-5F3E-483D-A2BB-96B6EF34F074', '2DF76A58-01E7-4AB4-B7DF-F1C0093161C4', '3337872419522                       ', '    20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E5E3E64-8A4A-4CE8-B872-F910871470D6', 'A688A122-9A14-49E8-A10C-FF2F5337A5F1', '3337872412264                       ', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6BED452-4493-443A-BCB6-6837D73B6F21', '21A1AE5C-FDF7-4ACC-9E46-7C846703DCF0', '3800200960510', '    ///+ /+// 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B722B53E-A0DD-4F0D-B7D4-49BA5103CE5B', '68D963A2-5A15-4C25-99A2-E29805611DEC', '4607163090334', '  125    /  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07880168-FF70-46C0-BF2E-A82321D0B11F', 'EA711569-A147-4A1B-81D7-976E56AC4C55', '4260205870013', ' 20 - / - 20 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11786670-FFC3-4A60-B194-4A29C923594D', '2CD49C12-BAEE-4E0E-ACFB-196AEA99F51B', '8030009700658                       ', ' + 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A828A4D-003A-411D-90D5-50D254D04673', '89DF8E08-08C5-4072-915B-79E7A16827F4', '4603149000311', ' 1000  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04636EFC-65F5-4420-9DC0-5B68450D126E', 'F5575C19-4249-43AA-8D05-0C128F271072', '4690655009273', '- 8  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D43CFC0A-F015-43B4-84D0-58D188B9B36B', 'B4FF57F1-A5E1-4916-9646-0D1330E71DFD', '4607101209781', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBDC9794-96D4-4BD3-954C-2F962BE614FA', '80E06874-76F0-4FE8-98E5-896A79ACC3B8', '4630018880064                       ', ' /    900', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12AFE0D8-B726-465A-8CD9-4314E5A9DD2B', 'A0BDA13B-9709-4B1C-A64D-F89C0F91CA59', '4600488003805', ' 1/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('019157CE-D686-4610-94B5-3064738B66D3', '6F078FCC-F325-4AD4-BB87-2C920F2A9CB4', '4607074610317                       ', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DECDE469-BB84-4592-96ED-C3F9FD349F51', 'CAF47299-DAA9-4781-8F7C-32D8989A1BE0', '4603905013401                       ', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F5F484B-90E2-4695-A59D-1B0C4ED288C5', '0CC3B11F-138D-4754-B1CB-1476C789A91A', '4607086562901                       ', '       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3865466A-68F4-4758-ACB2-812E81C8E722', '9CB8323A-C756-4021-9040-C031AC8D6F49', '4607027766542                       ', ' 10  30 1+1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35040662-CE6A-4322-ABE6-7334A79C603B', '27BF5862-146D-40AC-B360-F2AF1638DD6A', '4620021520231', '  clearasept coal/minerals   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('260AEB42-0F17-44BA-A50F-AA1F2354DA8D', 'C5AC91F3-68CD-4625-A248-398E924B1A33', '4210201757757                       ', '-  3d  /   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA62B57E-6A24-41C4-BA64-545F9B065AFB', '59A2E8F7-2D27-43F7-A942-254C4AD0D266', '4601214000570                       ', ' / /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D853AA8B-1521-4FCC-A408-06A9BC606CAC', '9B471DA2-9D01-4B0F-8D9B-D0A66373C7E9', '4607041024208                       ', ' /    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9ABAED09-B05D-408D-9D96-D58A877899C0', '05E2ACC5-4A9B-4ADB-96A8-DBFEA2F13DD0', '4605370004014                       ', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36974019-95D7-4982-B86A-7ED382EADDE0', '4792BCB5-02F7-4469-BBA2-FCA40F0389A1', '4605370004281                       ', ' -    75+ /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BBC3444-70EF-40C1-BE43-160807FD1910', 'B60ADAEC-8D2D-4073-903A-03E2AC40F732', '7640156393538                       ', ' wn-114 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A91B24A6-9733-49F7-9D9C-88D6B13F41E3', 'F9C98862-B9D2-4773-A3D1-917EB69706E9', '6223003732257                       ', ' silkoplast comfort it-hemo 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D83F757-2F6C-4D3E-9D5C-FCA6C2A7BF17', '3A7F1766-79F3-43B7-928E-39F7392D7FE0', '4607101209019', '      ,  0./13628 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFE1AFAC-C94D-4BB2-9A77-CC9413F2ED80', 'EBDD4C20-4F8A-4125-BB7F-BDF885B46D07', '5900516861308                       ', '   "matopat"    8X5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2A48AA7-4976-41F2-9DA8-D553E5F4575F', 'A2DDD43A-DFB3-4215-9644-94DA5F7B71F7', '4607051280021', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('471635E1-CAC8-492D-AC77-B2E6455099F9', '66AA8F14-70FF-451C-AAD0-2BA3A5B3D525', '4603014002518                       ', ' professional    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B2DB523-C0CF-4B4C-B7FC-50926F551836', '35AE4A66-45CB-4E31-8DB7-16B02D9F5797', '4650001792976                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B040836-2F03-41B8-90EE-9FEDAD3A9B4E', '494AA773-AA60-4695-9D0D-AD8859900E35', '4640003260276', '       2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B16EA00F-EB4A-4295-8DC7-5E7D06F43E5E', '2687CF72-5B46-4432-B054-D5D287CF28DE', '4610010012120                       ', ' bionational 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5F77CBF-DCCB-4453-B279-38300BB23211', 'A7254C69-A41B-46DD-A15F-BBF09344654D', '4627129210743                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57F5477B-C549-454A-A7CE-8550A6D140E7', 'E6F25EC2-9D89-474F-968B-55A5B3E9B27B', '4602565020033                       ', '  0,9% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57AEAA2B-B791-4004-AACC-6137F013747B', '3A5BD0FF-20A1-4C00-852C-5CC93371FA0D', '4650069840169                       ', '   /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8DA8853-D287-47BC-A9A4-EFEC6A67C375', '02B7877F-DBF8-449C-B5BF-EF8D3BD7BA4A', '4601764002284', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('355BE788-0FF4-446A-9175-42D97DE396B4', '869F72B1-0AA2-4867-9A03-010A36698078', '8001040097656', '  340   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A08A4B8-C335-4F32-B5A7-5DEBD90311AD', 'E2D30579-6AD4-40DE-9147-6C93C08C90F1', '4603583000137                       ', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D40C671-75BB-4C1D-B0F6-521101B4DEC8', '0F4072F2-A517-4F3D-B774-3A55C4DE62F3', '4607097013089                       ', '-3   Q10 0,7  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81378185-80A9-4340-AEAC-421F9B52F0CC', '045397E7-EE0D-4553-9ED2-13732822A44A', '4607121690897', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2764669-B397-433C-A41D-41ED25BA4DF3', '8FF03145-2B39-4BAA-BBDD-4CB2CF15ED8D', '4607025201564                       ', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBA496F7-42D0-41D6-86AC-FE76EEF0C329', '8AD49DA2-59FE-4D4E-AD3D-CD14B9B370E1', '4630000893423                       ', '    / 1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('004F029A-C3C1-4B67-A9B9-79B2F7C01775', 'DF8F7C75-D8D1-4F06-9AC5-522485D1BB5B', '4670017924864                       ', '         /  270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0266CFA6-FCDD-4E90-94BC-944BBB1F1DD7', '3D3A7F33-9576-4DB7-AF03-AE7CC7DF4C0A', '8716900553820                       ', '     125 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79BC07F1-B6D0-483F-966C-07FBC90029E0', 'C9296512-A36F-428D-B365-555CDC5848E1', '4607051797499', ' /      530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF434BE5-D5D7-48F3-B2BA-6876658B25C4', '7B39DD5A-110F-4DF6-9F8A-4A234EBB4293', '4607051797529                       ', ' /   // 530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80C020DE-EC37-4048-8BBA-44855B32F3B0', '15081298-67F4-467F-A6FC-08AFCAE4E026', '4030855467242                       ', ' 0,4  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C75B6628-D207-43D5-A020-4F1FC7299E0B', '8463A519-CD49-4D20-9D55-067B20EF7868', '4607027218355', '   1701', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C3D4D8F-114F-48C6-B047-048E87B4CB14', '4BC2B912-A096-4208-A2F6-FA457B36FE18', '5900516602925                       ', '    6090 10 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02B7230B-927A-49FD-B825-A7FBCE6F49E1', '328C25C2-3E65-47E2-A446-D14FE4FFAFB3', '3800200963542', '   /  330', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32F5D85A-A3EA-4ACD-A2A8-D4A849195C9C', '83D9796B-3CF4-4EBA-8C86-2FA50F3792BC', '4627131981082                       ', ' -   0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63AF6E36-4C51-4BE8-BE88-0A0C66F157AA', '61581CE4-6CCC-432B-BC39-FA7E377B5818', '6941762672552', ' silkoplast  10x18 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C735A24E-A561-4D02-87D9-D8DAF27DB012', 'A7761939-71F0-43DA-B049-32AA15F024A8', '4607039975925', '  9 ( ) 0,2  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81FE6809-097A-45D2-AB03-1DD9CD7B4057', 'CE5248D7-6AC0-48B5-B65D-EB8C13673135', '3574661163468                       ', '      90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C5DF5B5-C056-46C7-A623-6C98DE720AB4', '8C4B1E27-1D79-46BF-A5FA-05EE4050781C', '4607027219307', '  . . m 1208', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('233EDDBD-F11B-45C1-896E-843C5E7A845B', 'F76CB161-6BA5-4ED3-BD33-CBCF7E58729C', '4605658195564', '    /   2 /19556/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A49484CE-4E65-4FC5-99E9-0CE2B1FB7A8C', 'B2307EBB-3DD3-450C-ADCA-2CB8BCA4DC57', '8700008290510                       ', '-3    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10898393-3302-43FD-B0EF-2F6A5D08D9C7', '65F0CC45-47EE-435A-8FFD-B70B4DB1686A', '6430046751088                       ', ' 3   viavit  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC060D12-5F02-4B6B-8670-E82684D57195', '38741B7C-80EA-4C3F-A26C-F32B34DB148F', '4607027211257                       ', '  -  /,/ 6-12 . 21711', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A16C739D-5067-4D91-B515-D5383A3C884B', 'BCFFE17C-A043-4155-8C11-F02C4BD8C639', '4607027210168                       ', '   .. 0-6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE1A8D87-1A38-4FF5-BFFF-0BA29807968E', '066F96FF-32AD-43A3-ADCA-6E0AFF60A121', '7612729000235', ' 400/7 -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47ACCFC3-A921-4177-A585-B04A0C87F368', '5C06090B-2DF7-453A-BB0C-19CABAC3C616', '5023497781912                       ', ' - 0,25/  2  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98881E6D-1721-46A4-AB63-155AADBABF82', '51F5CBD1-0231-4543-93A5-074E49641E63', '4601164000446', '   60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60A12EAA-1900-4F62-8118-D6AA515F24D2', 'BB2749B9-4538-440F-84BB-FA98EFA9BD37', '8030009500173                       ', '   20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F470762-A216-49D1-82C8-D3C175965159', 'C2743105-E8CB-4734-81B5-B065F893FC63', '4605185001345                       ', '  / 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EECB1F2-7120-43DA-8137-7B581458832B', '9E8D1F73-EA6B-4799-BD24-8C6C59706BB5', '4603720937258                       ', '  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FC6479C-D1D1-4CFE-9DE9-F41D34A105E0', '8639E388-9539-47F1-AD1F-B4A10C5FA67C', '4602784003534', ' 10% - / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03043D0D-1108-474F-9D17-C067557F2B58', '11F590B2-79A9-404B-ADFC-423E8D80D695', '4601532104202', ' /.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65906699-934F-449F-9BAE-374247C28A98', 'D70C614B-B09F-4CC0-B907-3C51B973F978', '8901138512811                       ', '       150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA90BA79-A457-4CA8-90BC-D67C4A55095E', '7AD9653A-8E65-48E2-B666-DCED39733526', '4602884001553                       ', ' 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F451915B-BCB2-4D5C-8699-DAE2A25322E3', '96210A37-4705-4089-A42E-9D0CC91CEEF2', '4607051790766', '   140', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84BE7779-C0BE-408D-9532-10A831EB2170', 'B86847C4-2D58-47D5-BF46-1EE3D5253084', '4627074843836                       ', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C3A7B7C-2E61-49B3-A3A8-0BB343B6F410', '2BC81AB7-767A-458A-90EF-A1C6BE7BEA54', '4602210001622                       ', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A208241-9C76-4CF1-83C1-91C8451B08CE', 'F34D86DD-39DD-440D-B2DD-F8E4F6675CD3', '8001090170316', '  60   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD4704E7-62DB-410A-8D69-173EC934B908', '5DA6291C-2D31-4511-84AB-2CF18924681C', '4601910000133', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D1E41D4-778F-486F-AF50-8D54D9AE82B0', 'ACE4011A-3D78-4B38-AAE7-DB4A17B9DE69', '4607174432383', '    /   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CCF1F08-0DBC-4C5E-81B2-B869541C29E5', '5249A1C7-AE01-43F8-B2CD-5848D4C0FE87', '4607174432345                       ', '    /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E1193F5-9116-4A76-B55A-062476FD4DF1', '51D06A08-4849-4D33-BEFA-D65B97E0C505', '4620768760198                       ', '- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20957D0F-D1CA-4F93-B79F-02EBFB1EDEC5', '898E4C76-42B4-4A61-A163-12CFE12B4C24', '4620002185718                       ', '     /  30 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CFEB8DF-7BD5-410B-B69B-C2A20DA13E82', '1AEA0896-9C57-4113-98AE-0830B37FC324', '3838957494408                       ', ' 80/ 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C2E7947-24F4-43D5-9E5E-C815522CBAE6', 'CBD8DA62-20FC-4D46-9DF9-EB77F5124B60', '4607002056699                       ', ' Donfeel " . . " 350 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBA27511-96A2-42A5-A74F-0C120554DBBE', '99607842-62F2-4861-90CC-4FC7F06855A2', '4601811011542', '      b6, e  c /,     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0848B6D5-D51B-4D4F-A4E1-5DCC4C3D94C8', '915D4203-FA10-4906-B896-DAE8ACD7FB0E', '4610007620567                       ', '    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CFBF007-7091-4CCB-9BD0-3475046AB731', '2C6E52E3-3400-4ACB-B678-8F22AB07152F', '4009932551556                       ', '        15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('229350A6-3273-4D33-8AA0-1C42DEA6D67A', 'E4D068D9-80B5-4FD2-972D-5A4F4B15DFBC', '5900516892708', '   -     1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4906641D-5AC0-488E-958F-FA432153A73C', '6DF9EAAF-5DAF-4C5B-B0F1-02A5A3D9A706', '6978724578980', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A304850-26B5-4A71-9036-BEE142A7E9CB', '7DB2C8A8-3D3B-4045-A4BA-F19ACD39922B', '4046222751098', '  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26FEA06C-FC38-47B3-BCB8-2CCE058D5015', '1B7E47BD-B5DE-4087-821C-5D9DB0FAA97E', '3800200962644', '    /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D442A119-F164-482D-A669-4E7894BDDF78', 'AA532389-ED9D-47B5-BCC3-64B310C75515', '4607027215873                       ', '   7013', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3879357-BCB4-4959-A814-9EB43626AD32', '6417F8B1-2326-455D-9E47-2A651C9631D7', '4640017330408', '  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28C33C41-0972-4079-B1A9-F9CA6B7D7883', '47DCB2F7-F497-4B5E-8AF4-8918198D4C1F', '4607010244620                       ', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3FBE2C0-B8A4-4A1F-AC6D-CBA67F5D5EA7', 'CDCE9FEE-1184-4DE8-9DC0-376D54D772E5', '4751018120650                       ', '  /  15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB090EFE-8DA8-41CF-B679-378F8CE2CA64', '0814573A-29C4-4BF4-B799-D931D8739604', '4627090498270', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4A0A53D-9838-4D79-A96D-69BB2DB7222B', '8133B68B-F3E8-4638-AA24-D98366EBA5BB', '4670010370637                       ', '    3 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F2EC14D-9739-4425-B7A2-71031EE81AB7', '5B0EFE4B-7DA4-4CD2-A72E-4A3CACDB3CD2', '4607131429937', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB725C79-6D51-4D89-B92E-A549DCE9AAE7', '45A3020E-77E3-42BE-A77D-7BF4DD4E4CE4', '4603014005472                       ', '      275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F831B1E-3663-476F-A0BC-5DC921CD92CB', 'D560DFE6-27F9-4CE1-972A-0309F572BEC8', '6432100011695                       ', ' - /. . . 50 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A020EFD1-B61B-4490-8C52-EF9F593D36AE', '745C63A8-FF42-4BFD-9479-C0ACC16AA113', '4620016303221                       ', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FC80969-64F7-473D-B54E-44487FEA51CB', 'CF5911F4-F8DD-4E10-8C96-ACEAA0904C2A', '1642011565209                       ', ' - 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBA8A0D5-2324-44A6-867D-3217E546050D', '9BE62EEB-E52C-4134-8DCA-B58A571AAFF0', '7322540034936', '  Tena Lady extra 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFCCCFA0-0E74-476D-AACA-D4B0914C5486', 'A39DCADB-4AFC-49FB-A037-574EAE523C72', '8594737222214                       ', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CF1C3AA-3B7C-4863-B249-2BA5667F730A', '621DBC4F-0B3E-4BEA-87A6-87DEBB723D7B', '4607014000345', '    34 / / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF45E1FF-0927-4EA4-AE10-07D70623FA44', '5409FB7C-BCAD-479E-9101-6B5BAA66AB91', '4602206000011', ' HM  100/ 3  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('438E7B5B-45FC-4B74-9788-5931258E5A8E', 'DC5A4F62-658F-4A85-ABB7-06FE4D989FC3', '4600338005096                       ', '  112     6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5CC8FC9-8336-42E2-B338-B107D127D3C1', '513F7BCC-05F4-4EB6-809C-60E34ECB0ADE', '3282770132434                       ', '    150 2 ( 50%   )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB21CF7E-DA9F-490E-A7DF-A802C28A3D59', 'DC3A1D5C-BCC9-4319-AF54-8432B23DA9DC', '4605169212774                       ', '  - 35  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE3E1CA9-3F05-4C6F-9A12-ADC6291EB637', '5393F681-FD66-4F05-8B51-30E3DCA31152', '4607051796812', ' /   / / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BE13FA7-BCA7-493F-92D1-E9820FC09D49', '4DE0B13B-53E1-48F4-B574-A9A954E6497A', '4607041067021                       ', '   slim- 375', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F731086D-CD43-4471-A3CC-80BE2CC42C4A', 'D2588EB1-D5C8-4033-A73D-B49865C5732D', '4607019010202                       ', ' 100  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37BE3A99-8472-42E5-A304-D1C2608A0FAD', '4DF0ED58-97B8-4EBC-A1E6-57156A34DA0D', '8714100713693', ' e    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('006F7576-6C40-4FD6-824B-2234651D714E', '019CECAA-29AB-44D3-B31C-C0230E3155BC', '4670024930186                       ', '  Veiro  12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CD0AA3E-14F4-47A9-AD07-819879000CF5', '35BEE3A7-42B3-4152-95D5-C6757D7DF8B3', '4607075797734                       ', '  Veiro   8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('929B1C89-22B5-4283-AF48-22B906D6B314', '36D0393F-95DF-4028-9A60-3983A2340B53', '5903546001591                       ', '  75  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('282641F4-91B9-4C2D-92AE-771D0826143A', '08046574-F891-4D2D-BC50-01A07B8FB30E', '4680012950027                       ', ' 500000  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('769B02AD-4CED-471D-BFA1-1A11D91C353D', '9382AE2C-3430-4CD1-B752-1C3D03C7C3D0', '5903407225869                       ', '    0-6 . penguins /22/586/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04D05DA7-15E0-48DC-934C-B6CD4B88FC5A', 'FDB964A8-2CAE-4C90-8B2E-7DF0EE690B4A', '4607013861220                       ', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72D7DEEF-AF5C-4E58-AF13-C63ABDF8CEDB', '6AC872DA-3321-4FAE-824C-DBF96A149E24', '4650001793669                       ', '  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92880722-4DC6-43CA-A503-7680AE4349BC', '932F60DD-C12F-4C5A-AB9F-5ECF153B1572', '4605113000808                       ', '  2 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A434EF1-A00C-4C4E-96E0-B6715D8545E6', 'F8948561-8707-4D7A-824B-DC55259793DD', '8003445801043                       ', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5309F851-1646-46C4-B5C7-4BF5C1347422', '81E72916-76CD-42F1-91C8-A12731B07253', '4008233103990                       ', '      400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27AA4A9C-0487-4D46-979B-BCF68FD2862C', '1FE6A680-58EB-4225-8413-F216BC1A579A', '4614171333490                       ', '    /.  /   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6E92BA6-273D-444C-901D-C51185A7090A', '1F7DC172-E6B4-4F2C-9A2D-C79A8718B1ED', '6224000132514', '    5500   tls', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CA9E849-9919-4B60-A140-67BA944A7209', '6C7B12BD-AE76-4B04-B787-C3560409279C', '3850114213608                       ', ' 2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F32FEFB-8722-4091-BDE6-B18B6EBEF580', 'CA396428-6D09-4CA4-BC94-1123BF124F89', '4029668000760                       ', ' 3,9 12,5.   4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9213533-9914-494B-9BCF-FA45B0B316C0', '0D5E6874-FD5A-4419-8DBC-D94E5D75F508', '4016369666920                       ', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F082FEC5-0DC6-4675-A72F-E02E6C1B59F4', '3AD87A39-9AAE-4DB5-BE77-EBFE564C4F0D', '4607020901438                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2734E34-5745-4D41-8346-C9F3E199BECF', 'ED760A94-33AB-413A-9FBE-0D35484EAEBA', '4603988009346                       ', '   40/ 10  10 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2973E75-9C43-43CA-9806-123D585C67DE', '6396C887-951A-4063-9611-4E5ED5AF7C82', '4650069843498                       ', '   -  11 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05202A28-B031-4921-8647-4FC35565DA82', 'D608F5D1-9B98-4DE8-814B-8E022EA71323', '4602824020330', ' 5/ 1  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3540B5FD-8F23-4AC6-9A8D-04810F594385', 'B4435AFC-8E34-4283-9A0B-AECEFC58E33D', '4607174652514                       ', ' / 7580      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A34A313-1FA4-4A72-A8EF-CED7CA3E3D7F', '447955FE-2A78-4D01-AE42-D538960218E3', '6904566030829                       ', '    1. / /  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('409F9258-D374-4873-9199-739B74BA6697', '0CA6D63F-0C1F-4AC0-986C-035F53BD9997', '8717472293701', ' /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BB999A5-93D8-4624-8D77-6D2846CA545D', 'A33080F1-CC32-4282-BBB1-C1BB8D1C04F3', '4690624009594                       ', '    330301', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29A45B56-840D-46F0-B6A1-35C8F0721BE7', '28783ECD-99F1-48E4-98CA-66798466E313', '4607106001380                       ', '  38', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22A8D9AB-A8FC-46BC-B98A-8B5D12222C58', '07E54911-7CB6-414E-9B80-5B955243DBC6', '3577056017858                       ', '     2+1//', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECE2AC74-EC4C-4CD7-BEE2-98E5A0FDE328', 'FD263691-B85B-4C3B-83C7-19BE3B07CCFF', '4623721564949                       ', '   / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15C73932-CE99-450D-B56F-AB0F01DC7297', 'EEAD08CF-7DFA-40DF-8AC7-4A135A2C5F05', '4603907003035                       ', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B339B96-C146-4BE1-9641-6646119EF31D', '317A0BC1-53C0-4137-B721-10EA6CDD3CED', '4607075797970                       ', ' Linia veiro  2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1DC716A-8D1E-45CA-A5A5-C8337F0D1675', '740A40D4-31CC-40CC-898C-B9A35F54CAC9', '4008233128214', ' /     80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5686C4D-B5E9-40A1-840C-D3EB24910B67', 'BEF7334C-2B5E-4503-8DFB-9F0039CE4FEF', '4607078790756', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D741E7B-63F7-40E1-9562-A8F1D7279E09', '74D12213-BE0A-4161-84F7-6A9D3BC7CB2A', '4670000471610                       ', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C44D7B8-7E80-4A95-81B9-952559DCC206', 'EAF69FC4-9512-4730-96FB-601F7F891DF1', '4601061101123', '   20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05B83D8B-5C44-46E2-B31C-F3124D20211A', '814BFEF1-2C94-4497-8B44-FC22BEDF2BD6', '3574660483499                       ', '  reach dual effect ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A6FB4B7-3D5D-407C-B4B7-1B79F04F2329', 'AEC7FE0F-8AEB-45F2-A3F2-59946773C929', '4605658251338                       ', '  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7CCA561-BB51-4C80-A2EA-2FC7333DEE11', 'D2E9525E-658F-4833-B61C-21740218D055', '4605927001497                       ', '       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6A6077B-479A-49B2-8276-96D0E9923978', 'BAC3AAAE-41CE-45ED-8EDC-0C2BEA03BB28', '6942895980132                       ', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3DC3494-3FDB-4758-802A-E1FECE27AC7A', '8093A0E9-9C6E-48AD-9BC4-65F219843674', '4627108140214', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FA1E1DF-E81F-4282-937A-D68F81F72DC5', 'EE5369A1-0DF5-4CBE-B822-F3CFA51E3D4E', '2910007970054                       ', '- 23G', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73288A9D-1C39-457D-B2D9-A76B83AD9006', '81701314-3925-4BE9-96DE-9720EBBE70DC', '4600999010637                       ', ' /   /  /d-/  45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCC6D9A2-2B9A-4AD9-95DE-A091EF331798', '20121C3C-9C91-4270-A5D9-2FF91372F4B6', '4620017360667                       ', '  1010 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1960F9B5-20B2-4E4B-84E9-C0646D533DF2', 'E111334F-A478-43C1-8096-E1B212612015', '3282779035576                       ', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52955686-7E43-4CB6-9B59-8B30B172A19F', '16D92C9A-2644-4AF3-8ECF-3A0E9651D071', '4606666078108', '   / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A24E83FB-10B1-49C5-9A41-BFAFA90852AB', '2C318693-197D-4C9C-8949-E3A87A65895B', '4627090491509                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDCE23B6-E506-4F39-A10D-EA606926967F', '78C3E85E-FC07-4C55-A3FA-C9F6F36FE4C6', '5900516895945                       ', '     2,5  5   TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E84DF5BC-87EC-4220-BCCF-B4E1458C1C5B', '4DDE6879-8B75-475C-828C-675D14D9841F', '4623721564956                       ', ' - / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3617986B-7A93-4B2C-AE13-90CD2684E009', 'E77C555B-D180-4507-BC0D-4126B11DE663', '4607043671042                       ', '    461', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF7C00A7-1184-4BF7-BD88-309CA3DBFF4D', 'B7A854CC-DBA0-4159-B79A-AF6F904D7EAF', '4607029295279', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1405A514-5DB7-4A2B-BB4C-38414E04DC3E', '93BAA47A-C81F-438C-B116-B011D1B067B7', '8717627106320                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B8E897C-2C31-42A9-8A3F-220E3C5109B3', '3052F072-D00E-40D0-A0A7-89F023AC3D1F', '4601661000598                       ', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50B49B4D-2487-4C7D-A60F-89516B599D52', 'D3E71235-42B6-48CA-8B11-8454891CEADD', '4690419003578                       ', '    / spf 40 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('723893C6-C19F-4410-A202-FD50ED561EA4', '8DC5A469-86DF-4862-89A8-62E65737487E', '4627129212235                       ', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C562B7F5-7EBD-465D-BFCD-487B1BF11B8A', '9E865DF4-98F5-4E59-AF97-2BA375CE9277', '4607102130916                       ', '  /117-s-sh is/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE2CB5A1-5A0A-49F9-A02E-09103E486E64', '30F56B8C-908D-449F-837A-65C92B254315', '4612613500172                       ', '    2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52BD170F-F3C2-4309-B916-9E5394674178', 'D545E38A-2FFF-4622-96A6-A5B495223592', '6904566030522', '     . 5. / / 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('889DDACD-E91B-41D3-95BB-CB231307316D', 'C5B24C01-B0AE-44EB-9AC9-67F60C2CBC61', '1977793420003                       ', '   - 7,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('669B2083-C830-488E-A006-5F803C898C90', '8FA14D2E-8828-4D80-83B6-B55845701959', '4601498000020', '  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A005CB38-74DE-49D8-B70A-E42542E7B8F4', '9492411F-B3B2-438A-90AC-50ABA3257F2C', '4602435007812', '  /even lab/ /   / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F7F83BB-1FFA-4650-A025-84B3F35927E7', '8193A0DF-5C57-4989-BF90-CC977C61382C', '0837524001257                       ', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75EBA73C-6B74-4D50-81CC-27CF10923421', '0FE1E9EA-9892-441A-B5F7-A80106AC8B29', '4601951000864', '- 100   +', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CE0F640-72E4-4E90-BF23-3E7BA1485577', '64E02CB1-BD0F-4A96-9CE1-A3334F948BF6', '4600890000096                       ', '     / /././ 170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D6A440E-092E-44A1-84F3-6E3898662032', '31774AAE-E811-4A72-B920-D9D99AC86EE1', '4600890060038                       ', '     -   f 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('083DD697-5DFC-4054-9C1B-541EE84EB7F6', '0CB23DE2-7754-4870-B030-13B9DA605EFB', '4600697192314', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB42B389-2281-4850-B6F6-6F3502ED4A72', '89F73590-B6AF-4157-87AF-910935AE6845', '4607025710011                       ', '   /   240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA6EEB59-075F-4B1F-A193-52D7EBF4552A', 'E55E7338-B151-48F1-A47F-E500566DE404', '3574661189826                       ', '     6   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C11C77B-8937-46FA-8995-88C16CA21F89', 'E012224A-451E-422B-BFC9-9BC90BF0283D', '4602196004204                       ', '  30  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('925E109A-AE31-46BD-B9EB-F4989AC17F5B', '9EDCCFCE-382B-46B7-A59B-49DF5A8BF1E3', '5900516722333                       ', '  "" Fixopore S 10  35c', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEDA0703-6E99-4B5F-AE2C-57432E0CF77F', 'E8F936B8-6ED7-4EF2-B606-D89BA58F219A', '4607163099832', '  950   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CB3CB81-C056-4E33-8064-2370591727D5', '551E0FAE-9C3B-4DF4-8F28-0F3B7DA6D182', '4601774007798', '    / 2/ 3//505', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A650D3B-5E77-4FAE-AD15-0B158BFE53FF', '3A867BEF-0CC0-4DB5-BB63-1B37B087B322', '4627074841573                       ', '-   ff 1,3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0D7779E-C28A-4D66-AD97-16A779CF6A6E', '8FE7A374-1751-46D8-A94B-6BB5FE09B56C', '4607024944752                       ', ' 2  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B9C87D4-D033-4E13-B661-0A49FFAF1162', '4D5FB440-BB58-4C13-B792-752EF62B75E6', '4620006500913                       ', '  100 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44E2929B-FF95-4378-B1F6-E32247F3EABA', '47B309D7-9457-441C-B03C-B78B9211A4B3', '3282779285216                       ', '-     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69D5962E-E7C2-49AF-B05B-9BD74DAC3564', '7F70847B-5049-4F3D-BC4E-D7F88024757D', '4607172371356', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71413AA6-F364-4595-B31C-A2565D98D8E8', '63D930E0-B123-480F-B0C5-A68135730F60', '2005657030828                       ', '     c   +  / 260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B402406-8C09-4151-804D-311098F8685A', '2D6CC714-8DA2-47F0-A7EC-D3E87AC2A307', '4603726763004', '-      A  E 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D41FE8E-290E-4EF6-888E-BEDB2B4C072A', 'EBFB14EB-5F97-480A-9B5D-C6EE1CA8FA7B', '1977507572011                       ', '    20 0,3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8D1376F-E70A-4AB8-990B-4AD55DC20B3B', 'BA76FBC2-80F3-460D-AED5-14C9F7C8C19F', '4640006300771', '   -  44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('114C8F36-8F33-4BA6-8F33-B677945A67E1', 'DEF6AA7E-07BC-4308-832A-85E7370181F6', '4607163095834', '  950 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('790DC8F9-475E-4F65-9AC2-082F254BDE90', 'B515F850-F461-42B5-98B9-54A04F9D47DE', '4893949250744                       ', '  /   /25074/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5075414-644D-49F7-A826-88622F2A15FB', '1A516D86-D020-4041-8BA6-655689426CA9', '4607153456140                       ', '      14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA029B0F-69FC-4AFD-ABF4-8567BF809F7E', 'F1164241-DB3C-405C-8E94-36C37B13928F', '4601214000709                       ', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('017A6C66-02B4-4ED7-B336-C534DD527B53', '4526867B-FBC4-4862-A016-EB3326485093', '8470001789334                       ', '  700  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C32D6301-EDF6-4032-B317-B99AE56AE2B8', 'DFADD514-B13B-4ABE-B7F8-DDC2D7A81FA6', '3337872414084', '  [+].  -        ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D3DD2FD-2C38-44B7-9261-C1BE54FC02CF', '968A33B0-1D52-4C1A-B334-BEA7594FD183', '3337872418587                       ', ' , +200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('294C8E06-342A-4FC9-B599-9C962A14C3A6', '7D1C8B88-6220-452C-9CCD-BDE480975B49', '5000167094923                       ', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF28AC19-4EC7-4CDA-957E-0C0E40EB8C5A', '51314A9B-64AF-4CD5-8008-BD09402A6CD0', '4607131040316', ' 2/ - /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D40430C6-DC1E-40C6-82D7-93DB889BB402', '4690327A-3E4C-4CE4-B13F-3BF7229F197D', '4397020901612                       ', ' 11       2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65B062EE-86CC-4946-8767-DEEDDED80C0A', '751C6EAE-4B7D-4499-8482-78490A1CE5E5', '4036534452219', ' SFM    /  - L  N 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4155B1C4-4D8F-4B7D-ACE8-F91ED648AEC6', '6B584451-C5B2-4097-804B-2C4F0A0B21F3', '4607152960211', '  - -...75 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C384EACB-16E6-40FD-BAED-2AC04F538221', '463D68C5-4419-4C73-ABB0-337F10B1C2D4', '4620002181635', '    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0EDAB27-37E9-403C-9A27-FF6F689A36A7', '589F8656-51EE-46D0-BDFA-BC4D6AAF443E', '8904004850017                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16665F52-E03C-4865-9E01-4C696E688195', 'F159EBCD-8BFE-451A-9223-0718BBEB4EAC', '8806695013842', '  100   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B47A6A7-F564-43D0-9FFD-A807E9B9EE53', '73650A47-1E17-4FBC-932D-730109E56A82', '4015400203520', '  sleep&play   3 /4-9/ 78', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86B49F91-73F5-4563-8406-0A8BFA868271', '367EB920-7046-4881-94D8-EDB4BEE4B06B', '4015400203582                       ', '      /-5/ 11-18  58', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B9A51E0-5FDA-408C-9E28-A2AF1E4A94E5', '8F36ED33-89A6-431F-A39D-04E9EA5D730C', '4660013570950                       ', ' /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('795F0A19-2CD1-46B8-8FAD-C07C8DF53D26', '37DBE4F8-B2A4-476F-8FB5-B33F3B09F21D', '4620764311622                       ', ' ha    3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4E22787-4F56-4882-B72E-E225E1DB8AFE', '5E132B96-CF77-4061-A990-BD8A6AE9DCDD', '3282779246064                       ', '-     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DC36AF8-D5D4-4886-8A07-F8C98999B216', 'D3EF4EA1-B1CC-4C04-95AD-6548A704C2B4', '4605658112127', '     125  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4AFEDC9-05C7-465F-9FE0-0EFF2ADC73AB', 'BAE4361A-1EAE-4803-9A53-8141D7B6AEFA', '4607069271035                       ', '-  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE93DDC5-41AE-41CA-95DA-0116DF5E1F0E', 'C9EAB865-CC9A-43FB-B82B-B1760A8238A0', '4627135780025', '   12x22 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('482C7D39-4BA6-40A7-A96C-E5242DAD1593', '8EF52915-2774-4425-89BD-8356BDB912C4', '4605391001337                       ', '  1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0A49F53-3F8A-4BE2-ACF1-A71D147175A5', '43E6023F-98CB-4BD3-AA7F-CB41A479B17D', '4607085860640                       ', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53A8D3DF-845C-49B5-8167-3292EDFA264D', '4C243F33-0E43-4579-A6F1-EDD42BF4D432', '4607010248635                       ', ' caviale  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7468DB1-E1E2-432F-BC87-3A4F5874D120', '9CB8C083-0496-4C2D-BC34-72E670FD9E28', '4680004854548', '  2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF48F6F0-5626-46D0-94BA-BC03C85B7E06', '47928C6C-57A4-4966-8421-18D2622A5FA2', '4602509008790', ' - 400  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02E5592A-778D-4D06-899C-4EFDCAE23423', 'F281CEB9-4425-47AA-B32F-564B3BAE7A6B', '4670000470552                       ', ' -   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED269611-C1E8-4099-BB27-C3D978969B9D', 'A0CD8337-B8CB-4068-B41F-1D17FBC7F1D0', '4630009620143', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC51C0CF-DA8A-4CFD-9911-77B28E490B65', '1B8B3E39-2FEC-4ADF-96A3-17338F80F716', '4605658250829                       ', '   /   6+/25082/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CA84BD0-1FD9-4372-B2B3-9EBBBF22031F', '80B381A3-35C2-4224-A3BB-723AB7117261', '4601669012111                       ', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A695A63-7EC3-4450-BBCA-1C3DF538CBFB', 'F4283B5B-8471-4C13-9ED5-50C5CEB61F1C', '4607086564585                       ', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDF2ACA6-9028-4031-A0F2-8B2B74CA8BE2', '13E45093-1AB4-4DD6-9F57-C56CA7666FA8', '4605319006901                       ', ' -     450 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1C68113-9963-4D34-A223-F6039C2F6EAE', 'C34F135A-96EE-443D-AB2E-ED095FAC6031', '4600936310325', ' -  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02D80E43-14B0-4BFF-93E0-AAD75D6AC9B2', '707A1FDA-CDD3-44FB-BDC8-5AA1C24E58AC', '4605169212781                       ', '  - 35   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7069D970-CE47-4235-9E7D-3D8FC519E87B', 'B90FC377-8037-4C41-A472-F86973454D23', '5900516892807', '    -      1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('731DE108-5A72-408B-9E3D-F53791A98762', 'C07BF2C2-CB1A-4AA7-83F0-514D3B7A5A75', '4607174434592                       ', '    /    - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F115B6EB-E9B2-4507-9C84-8AB283CCCE4F', '0676EFA3-8C65-48E9-A975-F0CB0C46F62B', '4640003260290                       ', '      2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C005C280-3FBB-4125-A73A-81D563E460C9', '3D57C87D-612E-481C-B5FA-E07392A13C5E', '4603713000563', ' 400+25  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4960D07-C6AD-4674-B71C-23E1895F0F5F', 'E287009E-AE67-43DB-BDB4-B12979B8873F', '8588001193638                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65325AB7-D867-4FE2-814B-4F5E0416AF63', '6EDFF110-0C62-49F4-AD61-80BC8495BD73', '4600936182038                       ', ' /   f 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DD57320-6DDA-45FB-89E9-CA2A409A7978', '1691F021-CCEC-40DC-9F5B-94586D90CDF8', '4607128160423                       ', '-   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('965654FB-9710-4887-9755-9ADD9CE71E7D', '2DC1FB06-FA88-4A06-ABB8-7E563C2C91D6', '3574661207025                       ', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4360A90E-1F64-4865-9E77-9FB58F3D1F85', 'ABF720AA-7081-45D8-AED8-4E63454C87CB', '4603720177050                       ', '    5 / -  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5B06D3C-B49D-4CAC-BF07-F973CEBDAB5B', '457B6B20-717A-4DB6-BF7E-FD7E572C3261', '4607068628427                       ', '   /  / 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C6AFA5B-1A90-4280-B915-8061A56C9EB4', '237BB45B-7390-4F61-BB16-7F60D621D884', '4603933552798                       ', '  20% -   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('596D4308-9E25-40ED-B1B5-3197B09E5A9C', 'A2695BBD-2818-496C-8032-BFA61933CD7F', '8030009500562', '  /. 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AFD771B-F166-488F-BDD6-A3722A6410FD', 'DE4A0B88-BBE6-462C-814D-721C1AD581D4', '4607051798687', '    - /. 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F47BB985-5C4C-419B-8EB3-F3A8CDB2F4DC', '70D70DB5-D3C1-4ADA-B4F7-DBD6C498FD14', '4607078971575                       ', ' -    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC38851C-D855-41DE-A3DE-52C9539C3D43', 'BD0C3447-D3DB-4C4F-97F4-8E5545D922C9', '4607071772667', '  /         /  care/ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F55260B6-94C8-4DDA-9D2C-E2576B7E4390', '89D467DB-0F29-4ED6-ABC2-5ECADDE4DCA2', '4607014000024                       ', '    2 /  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE521F40-C3CA-44C6-80FC-11DE252EF928', '07886CB3-C12F-433C-868D-6AD1663DD4E2', '4607014000291                       ', '    29 /. / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAFA88FF-EABF-4AF5-AD16-85D1C523FEF3', '9BC51D88-33D4-4033-B724-BA142B9F7CF8', '3282779310741', '   -   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7B65A31-9E0D-4870-819B-6334EF57AD4F', '67887243-781F-4482-B4B3-FFF6219E1896', '4607094175643                       ', '    /   6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('037A610A-0E7A-4F6A-BF47-45E07F7E7BE3', 'D30C95C9-DC2A-478E-B4C1-1B3C310E02DD', '4607095330072                       ', ' 50 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A75478D4-03F7-4B9A-A42A-1C57E9B785D1', 'F73058F8-A733-4544-8F50-00CD8553AD72', '4607027218256', '  .  1806', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14F59881-10E9-450C-BB03-5D0D9D1350A8', '7A51C5CA-088C-48B0-859A-FDEED9342939', '4607174435919                       ', ' thalasso - /  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA26A6F5-D695-47E5-8853-32444DAEDBCF', '597B6B1A-90AA-463B-BF6C-4D567331BE1A', '4811248000402', '         150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50447B26-4063-4DA2-918A-47F8415794BC', '522CC3BB-4FF0-4150-8F86-2F688911D50D', '4600702092394                       ', '   /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9466A84D-1C3C-4A30-B21D-366BC1942E40', 'D0DB278D-46D6-48D8-9C9E-FA377869F915', '4670000790049', '    /52-56/   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45A02F27-1A1D-468F-AA66-4AEB056F95DA', '953A2318-097B-41B1-9D9A-94DC2C0166BC', '4670017923041                       ', '  /   155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C4B6E6E-8360-4972-8443-586018FB1469', '4E7BD82E-932A-4871-82EB-1EBC045C1386', '4680007751202                       ', '   6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB0BC7AD-F9EC-4304-824A-984760AEF159', 'F5226765-3872-47F3-843C-865012C41161', '4601654003155                       ', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08AC09EC-87C2-4DA8-A810-371147EFC7D7', 'EADF15E9-FD7C-4F62-832A-13AF23F7CA18', '4601654003162                       ', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69FE90BC-D468-4B07-87C3-03CC0E406F15', 'BB75A083-CF9F-421D-9B76-CE22E68536B0', '4601654003179                       ', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA0DDF6A-4582-4CEA-AAF6-35C32C88F342', 'A0528DAE-A4A7-4C23-A19D-D18197F49DE2', '4607021930123', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57763AC8-CB4A-4EDE-AFD6-8FA1974E4F75', 'CA8FE2DF-A547-473A-9AB5-E0E2D667A678', '4680007751172', '  6090 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('308DF3CA-9939-4B8B-91F8-53D1E4047C83', '76E8C92E-F21F-4904-9706-088C869F3774', '4660007703166', '  10+158,5  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FC925BE-AF07-4A66-90F3-3FF718506C88', 'C7897E57-116D-4899-B452-44C8034081A7', '8901138511197', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('062ABF8C-096C-48E3-9F70-EF9193726AAF', '50EBF962-B01E-4F3F-95CB-BD383460777E', '4602355010848', '    spf30 /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80B3B062-EA00-437D-A429-3D1669A1F196', 'ED806FE3-EC13-49DD-9D76-1169A21EE7EB', '4031976500337                       ', '  - .S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16DCEF75-4CC3-4E1E-956D-E7D55ABF75E6', '649A28E0-9EB4-43E4-9294-3F7A20CFB312', '8030009701297                       ', '  high tech  . 0129,02', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE14F66B-56AA-4BDB-9293-31BB9A16E90B', '12F50BF2-ACD7-44DF-8209-BE76DA326A05', '4605180005706                       ', ' 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7C4D4BE-17BA-4A96-9380-F97D6C77B583', '81A18F7C-AC3F-4302-8387-28BD101110B7', '4607004770050                       ', '- 0,47  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEC91F44-7BC8-45AD-886B-C63558E0DEA9', 'AFED8A69-FA3E-4239-9B83-BF9B558F4648', '4607152730340                       ', '     1+1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4995C406-0F28-411F-B6D1-B4742550D8D3', '55CF9E4A-8465-4BDC-8FCD-600F70653372', '4600689603408                       ', '  250 5    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACB10F3E-D6E4-48AA-B96C-C02559610004', 'F3522917-1B22-4F80-9940-221B374448B3', '4670017926240', ' / -     0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12E6E01D-42B0-40F4-ACEF-9D474C37A198', '5DAE9921-B326-44E2-ADA7-0C6C39BD6F70', '2000103612481', '   13/109/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F9FDA53-F1FA-4490-A6A2-1FA2F7BB0520', 'FDF115DA-A284-4070-A42A-383283606077', '4606677128809                       ', '    21 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C0845A4-843F-4662-9F4F-BA90DDBA87D5', 'EDD0591C-83D3-423A-AE85-795979CBF55B', '9120029750487', ' Manual 809 . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDC4B6B1-107D-4FAE-A9FE-9D09BB07C971', '1F9574EE-2EE8-41BC-82D6-70F5084D5482', '4607088741557                       ', '   80  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BF27AF8-56D5-4330-90E9-4887227E84E8', '30AE83FE-987F-442F-BCFC-2032C7C8C3B6', '4650001793546', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AD13968-4E10-405A-BC63-548C128BB482', '9F753B91-AB42-4D24-ADED-6AB9A6EDCDB0', '4603679000409', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6957778-499F-422D-8F31-03FB8B1278B9', '8FA62CDD-C3B8-4C1D-A2F7-E117F1DAB749', '7290102061525', ' 1  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('779FA910-AA71-41F1-8E77-A684C7C8A3D9', 'A625BB5A-562E-4A04-A49A-605DE5F83C76', '4601861000589                       ', ' /  0,01% 1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E1D36AE-ACA4-4C84-8CAF-6A4533340BC8', 'E247F5FC-0B99-40B9-8B78-AA79A034D7B8', '8009315041175                       ', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEF63F90-4574-45CB-8A59-93B51E8661F8', 'D5FF5FB1-CD0E-4019-A124-47F332A12F93', '4601808012569', ' 500/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BF36B7A-82B5-4C00-986D-44090E909095', '70B9FE68-748E-48A1-A4DA-D4E824F7203D', '4607005322166', '      31 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C85A78FD-CAAD-4FE6-A180-6B11AF86B972', '983660D5-D52A-43E7-8F49-D8429F019559', '4680038240911', '   - /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3883C5A-1133-4D3E-B231-087B92207EE7', '5A8B402C-9C63-45B8-8017-FD27715F4123', '6950570782537                       ', ' Arlette  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E29EB74F-23D4-4383-AED4-6B783A905340', '40E7A82F-CBDE-485E-8B3C-F30BECFD7B57', '4607101203703                       ', '    /5525/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08F0253D-ADC7-4028-A8F7-018250793DDD', '1D7FEAB8-828C-4D83-AB1A-22B1C633798E', '5060038504159                       ', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('635D084B-B857-42D4-A1E9-1873A1AA45B6', 'B85E17C0-F885-434A-B1F7-6B2D8DDCFDF1', '4605658403263                       ', '    /40326/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DB6F38E-6F2D-40C4-AF4C-66BA8CC4E10E', 'B388F21A-3352-4651-9F9A-7164071E7816', '4630017310326                       ', '  6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44E4EE7C-BE3B-485F-93D4-F4ECD1B1F922', '6EDAE08B-96BB-4245-8073-362B503B82C7', '4607017940969                       ', '  - /   70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEA61255-F6C0-4A28-A26A-441172620A97', 'D11EEC7B-1746-48C4-ADAB-49F11E0FE412', '4607082850149                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C4C1E89-1C35-4074-8382-4A894F89680C', 'F87BFF66-5CB2-41FD-B540-DA04F99F8AC8', '2000103611927                       ', '    6-18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D112E4F1-B680-4395-B712-03EFD8A9C6BD', 'D2F60D01-7DF2-43DA-961D-07A2D2A72480', '4008600129837                       ', '  /.110+ . ..1,10743403 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2518C2B8-7C09-4F05-97E1-70D71A4A750D', '7A3E1DF2-FDB6-4353-850D-D70F9C21B4C6', '4600702098488', '. - / beautology 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36DF29B7-4520-4A6E-8DF2-C408A3777789', 'E7CDE2F6-6579-4815-8E9C-35ABFA56E9FE', '4607034473648', '   /   3    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1AD3B54-0A21-43DE-8A0F-F5A7ACBAA37F', 'FB9F4C60-2E67-489C-B505-B82AC5EBFB41', '4049500952132', ' peha-crepp /. 64/ 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64A96093-0F7D-46F9-A4E6-D82DB4CFECE7', 'D55CACF3-1FDF-447D-B191-303DCF934949', '4601654000581                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A827D40B-7078-471A-96BF-BED047DC07FC', 'D6E5C68D-951A-4CEB-B224-A2EE2C0F6977', '4607012580689                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('705CBE72-A03C-4EB1-B4C5-4B4747AE2188', 'B9CAB514-DF36-45C2-9DF4-F21D3071E1C5', '5292452003004', '  /    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94A96549-5AF9-490E-92DE-82E69E9D8C73', '523492C6-41AF-473A-B01F-20880B05BF7F', '4607163095735', '  200    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC2A673F-B6A9-4EDD-8350-7E34E3199288', 'BFBF4694-42C7-49A8-A67A-FE919D66C1B8', '8030009401098                       ', '  0-3  30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A07C0F4-8893-4D4A-9969-D401272F511D', 'AF571389-316E-48B9-92E0-FD144F6D297F', '4600338007793                       ', '  200     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BE3E571-DA24-432E-934A-B42699CC6E40', 'F465E918-77CD-40A2-87DF-5F31D07E372E', '4650069845997', '   /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66E8F517-A09A-44FD-B885-7D389BE8CC0A', 'E76D7E00-C33F-4D9D-8D8E-6AB726ECFE49', '6417150005467                       ', '  4  /, ,   215  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5113A7FC-1216-454A-98CB-841C4CCA3C00', '97201F77-491E-4E51-947A-A41EE07C449F', '5413973261319                       ', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B5F0178-3DFA-4DA5-B4DB-80BFFDDDDB7E', '70DA914E-3AE0-432F-862C-A4D34E1C2E2A', '4607027410148                       ', '      1010 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79334E49-2D29-4B04-B427-B339F6AE8766', 'BBD7C7FA-9C93-48DF-8F4A-F13AE855DCFC', '4600999012266                       ', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C5826A0-965E-4F60-B112-F474F7602478', 'F5EA5D48-7519-4484-AB3C-11B81BF85F1C', '4601811001550', '  8  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F2F80F9-18E3-448F-8B35-57B449E26407', 'F3D383DD-E6F6-4AA2-A90A-59B99916E66B', '5900095003106                       ', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('537C0757-7AE8-4D37-8C11-8A2669E25412', 'A271ED30-66A4-424C-8B17-603F5AB5DD6A', '3800002303041                       ', '   /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72251456-AB06-475E-A028-14C2DB1115F9', '556B9523-F3DE-49BE-A6AC-5A41A00046EE', '8013240401201', '   wf-2000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AD6A9C7-36A2-4218-AEFE-16F6D0A8908A', '5FFAE4F3-D8F4-44F2-9587-1230E4E3E050', '4820065531112', '-  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7688C291-96F7-41D1-8F32-16C4850DB52B', '90E76A6A-63A6-4353-8DE6-FE113F142DD9', '4607118051786                       ', '     /  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DC5F76A-5D21-48D2-8332-3733C9068C6F', '4B538D4F-48EC-4906-85B8-6B3B457AC746', '3582910020363                       ', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('797C00F3-2BD0-4422-A3A6-74C3223D6F69', 'E933F935-FE29-4A88-91CF-4DAD65512A63', '3838957051533', ' 10  7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18F08345-0AFE-4B63-9BAC-57372F3551CD', 'B8414D04-87D8-4052-8180-7EDD5539FDA6', '5292452000850', '     //  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76CFE5AD-111E-48E3-82B2-0A9AAC230E73', '9BD4E7CD-3850-4437-834A-1881AD215EB6', '4603014002167                       ', ' professional       40 + ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAF6BB3F-6122-4EC7-B392-00B9961B65DF', 'F84A5833-E6FE-43FD-91E0-7A2AC8305B82', '5903407095837', ' .  , 3 . 4+ 9/583', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7944C0FE-6F21-420B-99CE-2CEBD04D20EC', 'E03D327C-996D-49E2-87CD-321C857DA330', '4602565020361', ' 250  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F164C176-76D3-4099-AB5B-E6784458485A', '74ABF6D3-675C-4433-84C9-7113D4528327', '2000103614331                       ', '  0+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3902F5EB-15F7-4FBD-9459-4FB63BBDC3E5', '4784861C-298F-4529-9A29-C09A2449F80E', '3858881059870                       ', '- 5%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A037144-71BC-4059-BC5C-9A88DEB86BD5', 'F5A4BC9B-0EDE-4255-8B58-6A3F04665B3F', '3870010010194', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E2E41CC-7A64-442F-941B-EF662BB6641D', '5DC687CB-FCF8-478C-A607-1A46DE8AAC64', '4630012463485                       ', '    . /.  .7 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E83BB89F-BF50-4945-84F5-4E84DB5DF1D8', '819AC33A-DBF0-4482-BD8B-353A27F35A9B', '4627086804054', '   080 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4702A255-6369-4691-95AE-11F50485147B', 'CD758371-43D7-4886-8B5D-DE0FBB9FDDFC', '4607118052783                       ', '     150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5018FB54-2861-4890-96D0-3BADD22652CD', '1B168005-FFCB-4057-9AD1-35C6253F6217', '4601498006145                       ', '   1 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A979D1C6-38F5-431B-AE0D-0A4210C365A9', '31094E51-F5E5-49D2-AFB0-C4C7853724AF', '4640009710065', '      500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF7E039B-4258-48A6-9C8E-A4F36640BB69', '08470926-888F-4CAD-BB7E-AA9EB9C032CC', '4620016240281                       ', '  -       500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D966429C-331E-4273-87FF-ECD8F2F74086', '89305C88-0D30-4E01-9510-7009F6C85B9B', '8030009749015                       ', '   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D4AB35A-436A-4BC7-ABFF-5E514AFC671E', 'C5E1534A-2649-41BC-827B-0DCE56A81582', '4008600162841', ' -      0-6  . 1      1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E525028-E688-4E83-87F3-7123590DF980', '2B773D93-BCD2-4A06-8E1C-5D51BD788856', '4607021271264', '     1010', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99DF2663-36BB-4FED-8129-3EDF406B5B2B', '69AF0CA4-E789-478D-8C52-C0FBE510F21E', '4260202922166                       ', '   . VM 22G', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B740749-BA9C-4D03-905B-ADEF44A1215D', 'FCCB75E3-EC52-407B-9137-D4D360F8BC81', '4670012820918', '- .   2 / /350.*2/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3095C4DE-EC16-459C-B2E5-E2DDB5A84DBB', '7734B29D-E6BC-4817-A372-D7D1E5F58541', '2000103611897                       ', '    0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA403278-260C-4F0D-A51D-5E74ED067AFB', '370E60B0-CC04-4526-8750-D732AB5EAE6B', '4640001382857                       ', '     () 3 10 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36208AF8-8435-4104-9FFE-32DF503F0A00', 'FB1FDF1A-3697-4BFD-83C1-86BEDD31245C', '4605635003677                       ', '    1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('301352B0-2CCF-4371-A306-5B71313CDF1F', '63691C8C-D912-4688-8FBC-21BB2513D43F', '4607071772438                       ', '   60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5D9114A-0FCB-45FE-B9FD-B26113EE5F2D', 'BB1AC979-0807-43E3-ABEC-FFF567177292', '4602243001750', ' 8  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DBB5E71-8BC7-4EC1-A3F3-C0BEEEB192A4', '2D7C4C1A-296C-4A93-9031-9BFB57A85C55', '4893949120450                       ', '      (12045)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE9BDBF4-506C-4BF2-93D6-EC6422ACEFD0', '718D546F-412E-449C-9DCA-3BFC56B25092', '4015400435839', '  7  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('417EF8EC-5F53-4BCE-A1FF-2B66888E978A', '80047336-EE67-4C42-9330-896A787C6A26', '4601772002078', '    40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEBBAC75-2679-4E78-AA5F-12871010E0AE', '3644A19C-2525-4AE0-BD50-390B8FF8F874', '4605658130374', '  -    /13037/ 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31371496-4AE2-4230-98B1-6F9911D9F06B', 'BE5E7531-470C-4707-8B3C-528E07EAA2E9', '4630030920212                       ', ' 400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('412C3352-C089-4E38-972C-3EEC9C48E46D', 'C2C17B24-1DEA-4B4C-8C84-5641919FE422', '4620013400084', '    +', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31D2B4FA-E542-4E8A-977F-39F3E81C2661', '785ADA61-B6E5-4DBB-B448-600219B78DD5', '4605658120177                       ', '      -  2/12030/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F78A4C91-BEA0-4DF3-B129-A153FB9DD151', '48908DAE-F777-4B6F-BB9E-6F3A5F02BEED', '4606556002534', '  40  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D68EE8B8-E55C-4215-9EBE-73F562484FF4', '7F18CB93-F640-4755-BF9C-C7F8F6B6CE26', '3760102850381                       ', '  / 31 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AF480BE-BF14-4D0D-9A2E-A6669AF47105', 'E08E4A2F-1EC5-45D9-BB11-6AE8343764B4', '4607004500725                       ', '  600  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFC187F5-7F76-4FD0-A76B-4F2E51DF7F91', '74EE731D-4381-41AD-8D50-D0651A296413', '6910021100174                       ', '      //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA3AE7A9-B782-4971-8C1D-C4B39D0D25CE', '235E026B-A8EC-4D8F-9335-62D7D779040C', '4627079833054', '    / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53BDFAB8-B380-4952-BB2E-F4CD3A1C92FC', 'D7116ED6-5FB7-4083-906D-0AA10581C8CD', '7611800073816                       ', '    30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63507F94-1F45-42E7-AE65-ACCE1AC198CF', '52DB122E-D701-49FC-A1DC-77B9416E7634', '4823015934353', '          350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DAD027E-610E-4A81-ADF2-978C2F33DA87', '0FBD716C-5FE5-4789-A4B3-56E09FDB17FE', '4607068628489                       ', ' / aura  .   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E4CB903-093C-4BA5-9A24-ECE28243D2E5', 'A6CB152A-17A4-4BD0-869A-4C33CD7BBEA9', '5997001360507', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B9680F0-6CDF-4DA9-AB5D-64537C43C032', '09E22AEE-ACD2-489A-8DF9-65AE10A54149', '4627129211078                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26334039-6549-40D1-A139-6DA6BC6BE41D', '17186F6A-747C-4DB6-B5CD-3642F3349BAD', '4627090497204                       ', 'Pellesana biohyaluron gold    -     / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07550574-4DBD-419E-9957-EEA1F5B2FD36', 'B77B77E2-267E-4C41-8EFC-E677C0B07D0E', '4607045500135                       ', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA9C01C2-6CC4-4A1E-B447-872709B1D8CB', 'E5994B6A-4D85-4895-9038-A7BF2E82D286', '4640001381737                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00452054-5573-4A57-B5E9-D4C8EEC26039', '926D3E7B-6EBE-4CFA-9D73-C6457897359A', '4650001793935                       ', '     ,, 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A905D87-AB65-4F28-B2BE-FB73FE6429BB', '2FCCB548-FBAF-432D-8FF4-11364038FADD', '4630009622666                       ', ' 2   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E206201F-660D-4AB4-8433-4F446249EC74', '14E47745-5C32-42EE-8871-F8243591D617', '4605994031267                       ', '  /     /  160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4AF040F-4957-46A5-828C-D605E0C0332B', '48815D2C-A9F5-4186-987D-AF755C07285D', '7321838740504', ' 50/5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86CEEA61-0A6D-4139-8B8F-9C9FE523ACB9', 'F6BE29FF-7BD3-4551-BF47-80BA91AC5C5C', '4601774005688', '  / - -  .8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFB8B8B8-C523-46F6-B622-30B1B0C32708', 'ECCAF08D-565E-4308-9899-D7083A63C429', '4620003221934', ' maneki chibi-neko- 6-11 56/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BA291FB-07E5-4F67-B8F1-77D21E737B9F', '6B2D0619-52E7-4A37-B323-B6F0C458E73C', '4005808203680', '  - / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('788C3EC6-0F8E-4EE9-A573-AADB0A3F7D59', 'AB42CAD0-B3FD-4A2A-85D4-28379AFE3414', '5413787003440', ' 100  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('446B3EA0-800C-4A86-B7F2-C29A344F5873', '87F3764A-8DE3-4DE9-98A0-907691958CBC', '4606486023746                       ', ' 8  56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61A66FE9-3536-4A78-BE48-F099F813CC4D', 'AC1DD627-256C-4112-9E03-98FF7F974B4E', '6223000172667', '   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('962B4512-C94D-4522-9506-B6DDF7E44D6B', '3B86FAF0-5E51-45A1-A2B1-02A4FF2AC190', '4601429003731                       ', ' /  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CFD0F22-0716-4DB3-AF56-6A94556F7D11', 'C872E9FD-8FE6-4D94-A2AF-319270D9F884', '4823015910814', '   /  ./. 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8282E219-601A-46EA-BA96-E7D3370ACEDA', 'DA89564B-6ABE-4A97-B93B-6489641C7B47', '4603171102557                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF2C3C87-F53A-481E-9E48-F7B6E869404C', 'C33BF70F-DC2D-48C1-9208-B41059A6C1E6', '4680005640744', '  / 250 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EEC0702-A43C-4A48-A228-E7157EE5B5BF', 'E9846B4E-4416-4B78-83B2-6EAD7A79A17D', '4606272033416                       ', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BE13398-D017-4B02-9CEF-005612386939', '696F95B1-93A7-499C-94E2-209F4F4B2F05', '6946469488475                       ', '    /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('219F4DA8-FBEF-4861-AE4C-73059D221F5D', '88227A7B-AEA0-450E-9574-FE8F318E7241', '8710103671602', '   scf618/10 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA72B918-C73B-411D-BCA6-9FC93DE1714F', 'D1ACF801-9D9A-40D4-81C1-A4385C91D906', '5012909012584                       ', '   via .84480', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EDCAD55-3334-41EC-B253-B7809DCFD42A', 'D2C6ACB1-3899-48EE-86DC-64444433B61D', '8806695013057                       ', '  50   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58930928-DDDE-4585-8105-7C2C2E674950', '4EB6C562-B2EA-41BB-BADA-3C82852C4317', '4607027216665', '   / 5106', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40E60518-8BA7-4AAA-9D31-5A0B76056A00', 'BC253FAA-72CC-4ABD-9F70-A033AD264A82', '4607086970010                       ', '  - 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6611E78-6BCA-412A-8586-C4F9655EFEAD', 'D9B333E6-4B9C-4E94-86C4-0B166C645665', '4260202922449', '   . VM 20G', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98210667-989E-41DB-AA6B-E77D38DEB540', 'D91DD326-F3C0-40E3-8D7A-1D558D56740E', '4607034472832                       ', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('575815F0-AFCF-419C-9371-C81E26C20E62', 'E29DDB93-3B7B-44AC-8BB1-4CB21F9D66A6', '5900516892715                       ', '   - L    1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('569A3C3B-5366-4991-95FB-A387CB5E290C', '5B29BEDC-D5E4-4C02-B088-7E49D9068671', '4605342001843                       ', '   /   150 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB0A54BB-9ED5-41CC-BEFB-F0F6EECCA243', '88EA30B1-1231-4F5E-8A83-3917907F23F4', '4606272002016                       ', '  /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85643DB2-13BF-47E7-8525-1A397CDB9219', 'F10A8BB9-DDDC-4406-9852-C1AC6C711D68', '3282770074239                       ', '-     21 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CBB415D-016C-4D63-9104-098C6F63226D', '8D3B2AFA-5302-4D78-810F-A514EAF5B1F3', '4650054820787                       ', '    10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('843CFB77-A570-4161-8725-887E0366AFE9', '9F359BD7-976E-4746-ACFE-F1AD59865CF5', '3594453800210                       ', '  2,5+0,625  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE1C8702-3E95-4DB9-9222-2DE53C2159AE', '05F3929B-6662-4210-B192-F663F41F0FCD', '4607174437210                       ', '   /   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35157E98-EE5C-4E36-9F73-74F1E524A256', '9359BCEA-8365-4F3F-9052-3E01151061B1', '4607174434530                       ', '   - /      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F34F30C-D200-4C7C-8B14-C377A692C630', '01271FE5-FF3F-430D-B511-E36956821FD3', '4605927001503                       ', '    3  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EA6F7A4-B0E5-4CA7-84BA-B47A5B2354C0', 'BAE2EA2A-B00E-489D-A4A6-41076039807A', '3504105028442                       ', '   /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AB69088-9AA0-426E-8CB4-E0462220116B', 'EEC87864-55D4-4295-85DF-0AD6C949BBF1', '4605927001411                       ', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC0B6ACF-8B1E-4286-81EA-5217EF0C36B1', '43905636-CE75-4562-BA5E-5666ADD4F929', '4605059000313', '  500 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('306C029C-64B3-4E19-9289-3920195AC625', 'A2848628-827A-45BE-89BE-1E36B072B6F1', '8030009040020', '    . . 75 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5367286-A53B-483E-923D-64F2CB8AB593', '9EE26DD5-821D-496C-B6B0-95B381C45760', '4690419007460                       ', '      /  28 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F715D1E-E999-4E31-BDEB-7298FB33BF7E', '1BEF1CF7-728A-410F-A3F0-1F3D64EE7F6D', '4605738006087                       ', '     /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BA22E77-F13C-4508-8674-FC4258E4E84D', 'CD62CFAF-DA61-4C0E-B2E2-BBC365759634', '4607101209286', '  240/250 .., . 0./11466/12021', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('611BBD64-87E0-4241-AF63-99120B044F5B', 'D54EA5D1-2A8A-4218-841F-FDD2F1C80233', '3282770082418                       ', '   DS      100 +    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7897918-0FA3-4D34-81EF-5ECA4721C7AF', '4FFD3FF8-2371-4364-82A9-A1A5373A4283', '3337872414527                       ', ' XL    , SPF50+ 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E57197CB-660F-4375-93E1-C61475E90F7A', '9ACB4A25-3A35-431E-8B44-E2A5E414D421', '4015400278788', '    /7-14 / 24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DCB5CA4-3761-45AE-81E3-B9CEAD949D8D', '055C8E91-6C86-4F90-9299-039564235BAE', '4620002186159                       ', ' Q10+Hst    anti-pollution / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6393E1A1-AFEB-45BA-80D0-E4F8B52241BB', 'FC41E2E3-CAFB-414D-ABA8-3B02E4A5892F', '8716900569500                       ', '    - 125 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D469F90-48CF-4DEA-901F-E45A7484D65C', '2675B6D4-DF46-4D3D-AEC5-3DDC1705D1FC', '4607045500166                       ', '    2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51A1B37E-731E-4E7A-891D-52AE577CDB20', '5C6845BD-D740-47A1-9A61-9578481AABDE', '4607101205479                       ', '- Lubby  0+ (7284)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('349C160A-41D9-4FB0-84BB-82D9BC5F8048', 'D13A12F1-01C2-42C3-B5EE-8C71BA724ED8', '8009315001162', '  7 /d 0,3/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('091D1236-AA2F-462D-ACFF-2D5DD7B5AB1F', '1157AEFF-EF88-4091-B1CF-E8904A171B6E', '4602435006020                       ', '  5x500 ( -)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31B0D201-45E5-4B71-AF76-E00B227B52DF', '909136D7-5180-412B-AC5B-CD2DB0A92C68', '4627090498195                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36C764AA-1D11-4234-AFD6-24D16FF7C60E', 'B7AA6141-3722-4DC5-99EB-0015FDCADBC9', '3850114237055                       ', '  2,5%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5BF1840-2E1C-4149-8449-66811B897594', '351AB25A-ACE9-467B-889B-2323B6C4A129', '4820121900487', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('481C0252-6332-4AFF-85EF-4FDDB25C32F4', 'D86A3BEA-D879-497D-9E2D-416A277499CD', '4016369662618', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B10311AC-59C8-40E9-9026-117BEEC13C8F', 'C53E8315-99B7-4426-98B5-5FC78CCA4412', '4607086566589                       ', '          75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48C63752-8A27-431E-AA3B-2EEF162C07BB', 'D19CD5DC-C03C-48C7-8DE8-5EF5ABE2821A', '4607061252353                       ', '  yes 25   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC409820-131B-469F-8154-B06A95E97373', '2F817DA9-D22E-46C4-AC70-C1793B9BFFCC', '4627131981105                       ', '    6-18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7981EAC3-A801-47F6-8514-0F3957ABCE8A', '00C36943-E9C0-4A85-B0DA-F55B53ABC155', '5900002071365', '  /      15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D29948E4-95B7-4B80-9E12-8A72DE4F0CF4', '7E1AC720-35BF-45C3-953B-369548A044B8', '4640013559001                       ', '       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9701974A-2D18-44A1-B18D-E6A8BCDAC67E', '628DFE65-8C88-472B-9D25-2070A0DE7B38', '5292452000652', '  /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8AF107A-0C1E-4772-840C-781ACADAA8D5', '9FF29B69-1C52-488A-AC2F-ED0A40555460', '4820121900050', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('754C7BF0-40CF-420D-8E22-5BB195C7EAD5', 'E1503C6C-BDA2-4F0E-9BF9-E55A106030B1', '4606272002023                       ', '   / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD5BDE5D-7EA4-45FC-A75E-B20D4956B183', 'C8E49A5D-B451-4025-8B8C-AD44A92E2E39', '4607021930130', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E12E73D-109F-4A50-BD1A-DB809A354B7F', 'B618AE67-F0FA-4964-AFFC-7A3B6B756030', '4607077091724                       ', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C5220B1-35DD-44EF-A7C4-4EB86492B9B6', 'CF13520D-042B-4347-9D7F-0CD6B902AAAC', '4607020215504                       ', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACA47736-B808-4F5C-9842-EE751B3A58B8', '22651853-F537-434A-A677-B66ED04A22D3', '4630004180116                       ', ' Handy 6060 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E9C743E-9BC0-4C9F-9C90-C7F8CE2D9E94', '953BA62C-4E3D-4CF3-B975-EFCD8F03A223', '7613034778628', '     25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A61642F0-0F33-43D7-AE3C-76893AC31745', '307B49CA-2EFA-4F97-A215-D8787871C25A', '4603679002915                       ', '        20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('913C8B04-843D-46C7-86B5-E5E734E07981', 'BABF0250-C736-4DDE-9303-AA0F22335942', '4603679002908                       ', '        20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('508D6935-B5F1-4CFB-AEF7-7824F68CB6E6', 'A4B580C5-A88C-4BC7-9543-0EB59D045D47', '4603679002922                       ', '   -     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F185E1C5-9849-4E2E-9BE5-6FE124CDC25F', '21FBD60B-61AA-49B1-88D8-1223974F2287', '4612746210641                       ', '       /     15 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('120A037F-80FA-4246-B8CF-B150FF29310C', '5C99A7C4-159B-46F4-8066-F75641E42BC1', '5012909007184                       ', '   /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79654B65-9653-44C8-A9C6-4FB7C8B38498', '2E2D7DBB-B852-46E1-98C0-E34C26424B0D', '4605738006575                       ', '      80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE1C95A5-AC32-47F2-9200-027788FA694D', 'B97C2E79-013E-4518-B7DE-1B6CE893D5EE', '4612746210610                       ', '       /    15 7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06BC9778-3B34-4B7B-A3E3-20B888557FA9', 'EBEABB1E-F192-4354-B33E-016BB2594DDB', '4009800007123                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAD3011A-90FD-4AC2-8A7E-A491AE8AC385', '6F134ADF-4AB3-49B7-A55B-6F8245B43625', '4016369660447                       ', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4024F25-137B-4D9A-9D58-16E9A2743B60', 'CBB6DB16-9825-4D2B-8EAA-E5A4FEAC923A', '4670012610229                       ', ' 40  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E48116A-3C24-4EE9-9769-328F325D586B', 'D49EBB3E-3DBA-46B3-BC60-57047B974B27', '4600697193489                       ', '-   40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C370EBD-8DC9-48C9-94C0-FABD48B7DE88', 'F916A733-E8DB-4E80-B963-10EBE0921906', '4605059004564                       ', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43161759-C96A-4280-BEED-74BCE55F18CF', 'BB9ED7CE-7834-4804-877D-A2E6427B8F61', '8887786100030', '   ld-301', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2689D189-5BB1-45E5-950A-7523AC8AE9E7', 'A7957778-CABA-4777-B711-D921DD3A1E57', '4620768760129', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCB21A31-B9F3-426F-924D-736FDC923E71', '46888249-6A47-4CBE-818D-38836E1FC96F', '4036534471203                       ', ' sfm   /  s - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F928994F-6A91-4FE8-88B8-E490C61ED752', '7F60D5A7-80BC-4BC3-A6DA-7F71B2C43C97', '4606033014012                       ', '  . / /ea-307-150-220pettern/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D216349-F66E-471D-8E0E-E4C40DEB1755', 'F2483FED-4AA5-4560-9F2D-DDE7F8EDB6A3', '3577056001314                       ', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E076BDF-1609-41AD-8476-2A356DD0FA9B', '9D1977AE-255B-4E23-85CD-6C1848E30611', '3014260248642                       ', ' simply  2  / 2 /  care/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBCB3020-2159-4B06-8956-09A410D249F4', '704F9FC0-B022-4513-94DF-4EBE9246E055', '5900161004440                       ', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15966B8B-70AA-4824-A71D-FFB5DAB28A9A', '7BFA7A9F-94DF-4678-9606-BE0B26AE22D8', '0837524001356', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7C44815-A0F7-4227-9A86-DFB7F047E333', 'ADA62D80-FE90-487B-98D6-7FFB50B3229D', '4650069650454                       ', ' 0,05%   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3FD64D0-B17E-4758-B440-B9994965C00E', 'FA8613F6-C459-439E-9315-2305037F4A83', '4610013462151', '   /     0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21114CA0-17C3-4542-9B6E-4753621D49BF', 'E1885D27-F8BA-43FC-933B-9C9F821C9956', '4607131427438', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('796FAFE9-B7D8-4243-B63E-1E02FD9DF095', '49A071A8-F072-451D-8B47-4A4EDD8CB525', '4607131427612                       ', '    45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E25A2ADC-457C-426F-AC28-57D6F60984C4', 'C0B95655-6B57-49AD-A6D1-F772A3973A9B', '4607051796096                       ', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16458265-4985-4B34-8FDF-393E60C46C54', 'BA8DCFF7-BE76-4EC5-96D4-261C26AA8102', '4601201008794                       ', '    1,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CF6CE1F-7C4D-433D-87AC-842961E5B842', '3EC83AD5-63BD-42C6-8546-F175A5888531', '4603014001184                       ', '     3-8   55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4DA6843-982E-47FB-BCBA-135A2F4B3921', 'E6C824E5-6693-482C-8341-81D55D6819C1', '3800002305670                       ', ' maternea   150+ /  210', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B6D5933-9783-4377-BC70-60EDB6E7BC44', '14F41D14-A1FC-4EF8-AFBF-DFAD8C1EEC8B', '6916119020294                       ', ' 0,5% 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22B3EBA3-D48F-4281-8C66-5237DBF3A6CD', 'B7CA7213-7671-4920-9042-CD1BC89AE19D', '4607106001557                       ', '     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89C30987-BCA0-4F0F-8682-BBAD7C1C747E', 'D26E9419-ED72-4629-9D84-9C61D0663202', '4607163090235                       ', '  125    /  4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('619A7B1F-F351-465C-9FFE-A2B0569054D9', 'AF83E3B8-C0CB-4CEA-9708-769846396823', '4015400125051                       ', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5505887-E624-41F8-908E-CA09BB731E97', '776C5F40-C0A7-4D5A-A463-2815896164B3', '4607163095810                       ', '  950 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CBE7412-1FD9-48C1-B39C-7A6B3298907D', '4957C420-1060-4415-BD24-67068B239D35', '5292452000911', '      / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57050E78-FD7B-4BB9-A13C-564829A77E32', '7465DA88-7A5D-47FD-9F12-CFA294D51F9F', '4600488004048                       ', ' 5/  /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97B2BEC6-0CDD-487A-A8BD-B03DDFC2A089', '8C3DFBF6-BB60-4239-93DF-ACFD5448110A', '4607020904903                       ', '  36     2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('677E473D-5959-4FC7-9908-25EEA0C9BF19', '44EF7111-57EB-4F51-92D4-0CF05DCE565C', '3582910061076', ' 3  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36A982CA-2668-4091-9767-E8E68C7062BB', 'BCE655D8-60D6-4834-9974-98C3FE31B86D', '4607101201679                       ', '  Lubby    0+ 2 (4651)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9814A53-617D-4E8F-BF8D-744C13B1B497', 'E48ED48B-DEB3-4B62-8FD1-F4469CD47B9A', '4602809006120                       ', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89136719-E016-4069-80FA-3C314F8D67BB', '8F649D77-464E-4AB5-AB7B-3C0916613B05', '4630006000016', '  -01 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5720FC1F-DEBB-4C42-95A5-BD3534A4E4E3', '2EF2EC6B-E033-4AE4-AAFA-D02BDA1EF5E7', '4602242003397                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52458EC1-1BC4-4C1F-B3A8-0271010FEE32', 'BC2C262C-4945-4490-A3B2-41AA4DBF145A', '4612613500110', '     2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EECD6DD3-2E05-4A72-A529-7E264DD67CEE', '848F3E17-CDAC-4C02-98B1-353DA7381315', '4260124360015                       ', '  300 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FAE74B95-07F6-41DA-9F00-23E910241938', '659B88F1-9FBF-4E28-BA56-91AD28444D19', '4605086006340                       ', ' 2 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5742A3F4-FDCC-49C9-8910-99BF9B411D30', 'F54624ED-0396-46AB-B201-19E33194F705', '4602210001608', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D77F73B4-0021-46F4-A2C3-166AEEA03519', '05C63358-9716-48A4-8BE9-0C8FD592D8E1', '4820121901286                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B19E8466-7F44-4A56-92CB-4F7DC542D6F9', 'F5DAE9AF-F3E1-4BCA-AB7D-1935DDBDB5BC', '4627129213218                       ', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('673E43D7-2BF2-4BD1-8E67-7E56425E3186', '77F140CC-874F-4B89-84D2-BB56196DAAAE', '4650002440111                       ', ' /   170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBF751EA-BF8E-4E44-A135-4C8963EE0F18', '7E9392F6-583A-4E3D-B027-8321861C1AD9', '4607021709965                       ', ' /   170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('297E2FED-6C1B-485E-8DF9-B45357048D65', '92377375-42E9-45FA-BFE0-02CD581FCA3F', '2000000013435', '  2- . -26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58655233-744E-4AD2-8F37-0DE031BFEC0A', 'B400B67D-7A5B-47D3-8863-E10F7550C8A5', '6933298600321                       ', '  150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33F3F090-1BA6-4A2A-8344-B0A7AC0A47E1', '3EBEFCFA-42F4-4040-9C03-D635E95B9BE9', '4614171337573', '    /    150  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4E0FC76-D597-4FC4-BE1F-914A5338374B', '0EB5806B-AEFF-482B-81B1-9CC3C61CEA64', '4607174430624                       ', '     / .30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1219219-E96E-4AA8-AD21-C2E76D9800E9', '0C19DC98-CFAB-45B7-869F-90182664C330', '4605342000525                       ', '    Dr.Aqua  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A254ADA6-E7EB-4886-90FC-92ABFC90DD9B', 'F8D7B74D-3517-419D-B26B-BE036AFA2CF9', '4605319001364                       ', '      .-32 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF4CC13E-766A-46A3-BD48-DC78C1671989', 'CF3AFC62-FF23-44E2-92E8-BB4194B0FA1B', '4610021170154', '-   / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99E0CABA-16FE-499A-985D-6D73EECB8440', '04633DF7-6A5C-43B5-A733-16512B746153', '5900516691721                       ', '    XL 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88463B30-71C5-4CEF-B53D-F5E907D551F7', '3781DC76-C4DA-48AD-B8DC-6D06E0BA3986', '3337872412646                       ', '       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7DB4876-8132-445F-B4C2-1C40FF200C0F', 'CAF01D8E-1B11-41BA-88BC-67244A949F75', '4605258002460', ' - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3727988A-BB3E-4BCA-B06A-FEA7C0BE0931', 'CF7FB287-101A-493A-AB23-45A8F030A5D5', '4002857009409', '    /    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('057C8FA7-63CD-42BF-9155-CA1A0E0AF54F', '32ABC6CD-28F0-4D2F-AF91-93A46D25D522', '4210201154730                       ', '-  /   stages  eb10k 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F28577F-7A4A-465A-8367-1A0971384AB3', '9CA0AFC4-6502-47FD-82B2-9E07D6CBBE7A', '4037353010307', ' 0,05 0,2  / - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1C09814-79C8-4AB0-A3F4-15A901586356', '772FD54B-1128-4A97-9348-B870ADC4B071', '4104480463327', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4DCB6C5-6D6F-4DDE-8A3D-1077D3A18637', '9774EBB4-891A-4C70-BA69-D5D0A7FF2434', '8034003210014', ' .   5 - / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45ABBB1A-8105-4DA5-B8D1-67EC904D5801', 'D662C6FD-A477-4596-A528-2DB3D58757FE', '4627108140078', '      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DA8A51E-B947-45C7-8528-57751F631E10', '4DA92D66-B56F-44D5-985F-9D2BE86F2D75', '4604060082011                       ', ' 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('341DAAC6-5858-464B-A86F-BFBCB5692062', '2740CB15-A889-42DE-ABE1-5A95D45E1FA5', '4607008160048                       ', '   20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1FCD3E9-131C-4E8A-AE4A-DC24696D878E', 'D055743F-F0D9-4313-ACEF-610851DC9C70', '4607010248659                       ', ' caviale  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F05D4B8-66FC-4A4B-AE2F-395C39A7F3C0', '3128AE9F-82E3-4A0C-87C5-85C000E87F28', '5009612911242                       ', '  7,21,9 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DC845A7-1C7F-43DF-A9BE-7349D816EA00', '645AB206-80EE-4BE3-A043-5DD0FACA62F7', '4620002184773                       ', '     30 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('806AF058-5AAD-4EE1-A584-0E96F0A3FFD4', '12FA982F-75B1-4C4E-9A77-EAA057EB1194', '4606666021531                       ', 'Patricem       2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F882D723-8F9C-4C47-93D5-1ECDE61D746B', '740FA90D-497E-4B8B-95EF-495EE3D46896', '4607155641377', ' leiko - 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9786FCD9-6548-40A2-A9A6-9DFB5E399580', '55B1506D-5323-4E28-85AA-9401556F4B76', '5016533647433', '     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD0D56F6-637C-4BBB-8769-3709283F1B94', 'DECB2E5A-680D-4546-AB1B-473C9EFAE70D', '2400002035365', '  10% 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4147E489-DE34-45A0-9F90-B66040BF00D9', '7D28FD31-9792-4BFF-8435-715CF209D3F5', '4602329000653', '  2% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4A5AEEE-7329-4DA7-A7B2-D142AAEA6C8A', '38555C79-A7DB-4A72-8ECE-9AEAF4B212AA', '4665273150041                       ', '  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('307390E5-BFF5-41FE-BCC6-7D77BF5D0556', '1157A2B1-1118-43D1-934B-361E4BD2FAB2', '4600936183110                       ', '     240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D55D8093-C66F-4DE5-8987-A148BD2B06C4', '48AB6331-4C50-4DE6-86A0-80885A4CE2EF', '8030009502368', ' / - 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B759DD29-5240-4337-BA4B-098854FEDC81', 'CF4F79C4-A45B-4909-B855-5E410DE321E9', '4627079831326', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3405A4B1-823A-40B4-9887-706212C508CB', 'F059DC4D-F665-49DA-A29B-024A28A09F5E', '9062300104285                       ', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37D51C3A-83B2-4FE6-83D9-7ECF8F943EE4', '33743362-FCEF-4E8E-8E1D-0DEA9F5EB47B', '5036519000946', ' 4  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD59D863-21F4-4A45-B67A-91276A0E40DF', 'A3F0DE8A-A250-43C0-BAE1-390DB1FEBC04', '4680007630460', '      8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A6CB68B-F3BF-4D9C-918A-45011F574025', '01A6E710-24A4-41D0-A519-E60EF8691DCD', '4607075792982', '  Veiro  2  24 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79708AD9-9250-4269-98E2-C495D5608083', 'CFAC942C-94DD-45FD-BBCD-6626BD2FA83F', '4612735970617                       ', '  /   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF21EB68-F897-4925-8197-CC806A3EC0C5', '93638932-9256-4BBA-8222-3AB49D49AD21', '4605319002613                       ', '- -  /       .400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('905CABA7-5BCA-4378-BE27-1E70FF375082', '64C97A1D-1E63-4628-B961-CAFBF9D7BAA7', '4823015914690', '    /  / 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E066758-2749-4301-BD0D-D38C9404FE24', '9ECB210D-527D-42DD-8648-133AFA64C5F7', '4600999008498                       ', '    120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4EC2E3A-CB6A-4955-A456-0BB658E50900', '6D7B5812-DDB2-42A1-B476-7BC6345C784A', '4600999008207', ' / 5  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C73EEE29-FB56-4AB3-83C0-690F007D97EB', '5C37A5AC-7E77-4145-8CCD-477EAF0B2D3F', '4600936241926                       ', '    124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09CD8368-FF88-4806-B9DC-572F0AD7D0CA', '955A455D-3523-477E-8DAF-98D436B822B6', '4630007834412                       ', '  /     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FC82DF3-4D58-4D38-AEDE-077C197613F0', 'EBDD4342-B109-4290-94EC-69863FB9A596', '3282779181570', '  .      150 + .      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DDA07A2-7E13-431C-859F-3071FE6BE8E8', '1635311F-9784-4BD2-A7D0-20C112767815', '4607021930109                       ', '      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B728EB50-14DB-4189-9DCC-5DAAC0F4AA4E', '3260E1F5-30C4-4800-BC16-9CE4EEF1EBEC', '4627128156110', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('895B1787-B32F-43AD-8B45-098906587C94', '7D818A27-47E5-4BA8-BE63-F8B2C8D8232D', '4029917001951                       ', '    150 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7BE1BC9-AA3C-4195-950D-ECFCD1930986', '1A75080E-84D8-4A63-A59E-A84B73D38848', '4779033720037', '    24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78745BF8-0699-450A-99CA-BB5534C809BB', '7A629C4E-4234-4A0E-913B-DDF3865F95C1', '4605086000232', ' 48     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32472DEB-2742-4444-9CC7-1218EBB2821F', '09AB95EC-1B3A-4FEE-92AF-6F2CCDE0A2D0', '5900002071372                       ', '  -   /  / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('727288E0-A04B-4F49-BCA1-96B64365F0CD', '4401EE9C-A8A6-49F9-8769-F9D09A23E888', '4607121694147                       ', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1CCBE79-8E5F-4052-8FFB-530A18E70779', 'E356BC2A-EA72-4706-83EA-4887A0D29134', '2000103611880', ' -   0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9256E003-E586-4F97-80E1-E51295A80F2A', '4E5CE945-A71B-4080-9070-4E0178E083C7', '4607013790704', '     350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D638ABE-7E11-4717-8E9E-2A309C751613', 'BC312A2B-D040-4AAB-A165-4D11DA7FEAC9', '4607027219659', '     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FAAB375-AD54-4856-809F-E0CAEFE241DD', '95955719-EE4E-456D-BF62-2B6B3E1BB4F0', '4602159015094', ' // /   4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E65611E-79E6-453D-BA4A-2840B08354F6', 'F39BA528-F463-4A3C-8642-7A9204E04FE0', '4607174434912', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B859DC77-2C30-405D-A322-5B3E2D7B3F0A', 'F6C3ED82-71E8-49FD-8917-1D6D4FD4E410', '4627114672266', ' pellesana    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3199072B-6CF7-4E03-BE6B-CC36C05E216F', 'A69CB86B-4E9E-48BF-AE37-54C9950F6633', '4627090498096                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9435B9F1-1028-4232-9EF5-2697FADCFB83', '91B9D227-B039-4902-A8B0-E7D7E06A51AD', '4620006110099', '   .  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D96343C5-9532-4C4B-806E-616C66B9F04C', '56181BC0-7E28-4CB5-96A8-3C211F6B7795', '8594737170713', '-  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C281791-55E1-4D1F-8059-8D48A0132604', '532D86E3-5FE1-4C7A-BC98-030C4894FF07', '4032855840155', '  2- . -22', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4610AB9E-CFE3-48F6-860A-82B77944EE72', 'B123D162-B4C3-4831-8026-1C5289479F67', '4032855840131                       ', '  2- . -18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29066091-2B73-4224-8224-7CB999940E76', 'A243F3B3-035F-46BB-84D5-37A5C1724178', '4627074843928                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B406A61-4318-464E-94CF-38AC2587EBCD', '773C19E0-76A8-47CD-8140-F7620CD6598C', '4607014000246                       ', '    24 /  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('215EE815-6C1E-497A-A257-40097343FFB1', '60BDD72A-571F-4122-B5F4-9B1DEECAEE80', '6297000713007                       ', '     / / / /71300/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16FD5420-3030-45C4-99C9-9F66534AA27D', 'E8FF97DA-5C81-41D3-AEF0-15150A66A059', '8901138818258                       ', '    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF7E992D-E59F-451D-8F49-FF874A5FB44D', 'F1E754C4-CE4D-4E98-9DAD-9F876890D16D', '4602676004687                       ', ' 0,25% 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B43358B-8330-4BDF-B75F-D1504D5E9609', '66854EC0-F923-4BEB-9D3A-8872DD8CF32F', '5900516992743                       ', '     15 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBBAA831-6726-4E7E-88DA-A8193BBAC544', '9A497CDC-50B4-4E8D-9B6C-EC67096476B8', '3629002792064', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EBB3FEF-DAA4-4A9D-9204-3DE49C38A30D', '17818971-7F87-40E8-8AB5-35035660F5FA', '3574660444346                       ', '   / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('314B14EE-FD50-4990-84FE-AA2245611E8E', '4E687E0E-1292-4EC4-80A5-B8E8D82385A5', '4690419012754                       ', '    /   3,7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E35BD84-71F2-4819-98CA-AC44BBCEDF1C', '0759D114-79AE-4253-BF9B-0801CCC900ED', '4690624018190                       ', '       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BECC366E-F0CA-44AA-A29C-6862DA67051A', 'C79A4A40-9EE3-4DAF-9FFA-4E96CB3D0F06', '4607061252308                       ', '  yes 25   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05CCA38B-A5FE-4E7B-8002-D9185E5F7619', '58485A8E-72EE-4435-8D81-739608C8F8FB', '4602210002575                       ', ' 200  140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D790C02-832A-4C9D-BBBA-BAD96BD025A5', 'F386B67C-0859-4DE5-B2A4-67FBBD90A098', '4601808001808                       ', ' 100/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3494317-163E-4B50-9887-562C8EC4CC03', '4A909278-4C40-4377-B972-2BBEA9CE210E', '4605658230418                       ', '   /23041/  4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60D17ED8-F68E-4EDF-81C5-AEC7556853C5', '2DB611F5-21ED-4EB5-BB36-C490D5604F7C', '4680013240189                       ', ' - 0,9% 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75EC9FCA-FC8F-4DD8-9CF6-4E58C85BE06B', 'B9ACF0FA-7479-49DE-B0E5-7B510C46E492', '4607086562796', '   sos   /  15 +.  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D916895E-A3DC-4CC0-A85D-D3889F4908A9', '6AA26DEA-374A-409B-B879-8F2408C543CD', '4606486005230', ' 600  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04890CDE-A9A8-49B5-BFB4-FE1745CB0EB4', '93CDBFEC-0532-485C-AE85-357DD75CCEFD', '8906014101646', '  / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C923EB3-4E63-4CC8-9B95-1FFE8E8282E8', '77CB2873-7C89-4C84-B6F3-FEF1FDB8298C', '4607101203413                       ', '- Lubby  3+ (14784)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3F17814-4492-43D5-BBBF-3BDB9E10C195', '59EB0F3C-68FF-4B2D-AE87-351B114A263C', '4650001791320', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B760723D-A645-4181-AA3F-25EED98A32AC', '314D4BBE-3ABF-4989-A14B-BEFBE449CFC2', '4823015918582                       ', '   / / /  42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50B9BE2B-064F-466C-A9C9-B567A8AF63FF', '42F3A23C-F40A-4CB8-9BA9-D26A2297160E', '4052199237817', '     51,25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5482314-B744-4C48-9351-E666917DB4AA', 'B075AFD2-AED2-497A-8FF2-100B44732F57', '4607024970539', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60606E6A-381A-4E96-8B1F-260989C8BDA1', '0643836A-D35B-42EF-93FE-E4F4F3CDAFA1', '4670017924628                       ', ' /     4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A736A94-259C-4260-99FE-2EDC338D4236', '167888E2-49B3-4075-B34D-DF80838BA0C7', '4640017330286', '-   -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3769C6D-7E2D-4738-B452-D5F26C8D742F', 'A61A7929-04F3-4D7E-A5E0-9F4E6693FF10', '4640017330392                       ', ' all inclusive collagen    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E7D8589-9FCF-4834-A8F1-C2B4A55F9524', 'F0899823-160E-4646-822C-921884DD19A8', '4640017330293                       ', ' all inclusive collagen     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8CCFB77-8BEB-4E3D-8F3B-A119136A689F', '4DFA6E67-8CF2-4C70-B4DF-5B3959A3ECC7', '4640017330330                       ', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BACA624B-E606-40B1-AB04-92A73BBC8C6A', 'E1D2C374-398A-4941-9212-2079709387BA', '4640017330347                       ', '-      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9463E33-43A7-4DD9-8697-09E93778DCB1', '2E1E190E-10BB-488F-BD00-FFF60F4AE2EC', '4640017330323                       ', '    /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A484E64-9C85-4EBE-A565-03685EFEDF18', 'EC1B40CF-2517-46E5-B47B-E7E9824AC4DF', '3337872413711', '       ,   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFDE83FB-BA51-4615-952C-1D423739F05E', 'AA266887-47FE-4C13-95EF-B6234197FEAB', '4751018120469', '  /  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF23E48D-F706-4C09-B998-790DDA5132A0', 'B14A5B5B-A4A8-482D-ACE5-FAB9B152DFA8', '4605738001457', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98452D22-8099-4811-9DD2-2912444F518C', '38441498-5D76-4D04-9F13-AB4BD0DF7B52', '4601654000444', '  2,2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B39455B-40C8-4078-A7C5-ACBD7BF4FB79', '4F574B8D-4422-411E-A6B4-48D5747498E2', '4601654000154                       ', '  2,2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0078AD7-2759-4AB3-9391-A301D2AB1DFD', '5E514B0F-5EBA-43EC-9815-CA5886E53BD7', '4607039975529                       ', ' 0,5  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09091C4D-8E13-4660-962E-1BED82618A5E', '586C0300-4725-4321-9DD0-4EDCA448CA8B', '4602329001483                       ', ' 0,2%  - 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6CA340C-BFEB-4E63-AF01-58D60790FF8C', '50B1E278-9C62-440E-8A97-B95A75680A45', '4603720177074                       ', '    7      / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7447EC7C-3E64-4C9B-A19A-4821A4428C91', '43990486-33DF-43EF-89C7-4535C73A0461', '4620002185268', '         10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('442438BC-8203-4913-A70D-B875F1F4B33C', '050FEB3D-209B-433C-A616-F9969767D1E1', '4620002182724                       ', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4539EAB-AD71-4955-9B9C-8E282541E527', 'AFEECBA5-6085-4296-8B6D-A19A6033E12B', '4607141997600                       ', ' 5  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E11A07F-072C-498E-8581-BD904E6E0908', '49796DE5-1E6E-4B8D-8941-DE887765B783', '4603469000077', ' 150/   17,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FE195B9-F0FC-423B-9946-E203A59D8FFD', '966BF045-6509-45EA-B4BF-5CDD715492E8', '4630009186441                       ', '  80   4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B9846B0-1F93-473C-B60F-A53C5CC0BAB2', '443D1361-239C-41B2-A816-7B1F7E110BF3', '4902011850635', ' goon- 5-9 62/s/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('589CD38A-BE54-4258-9154-B127E5B5E06E', '1B224772-1AD3-46FA-B431-FFCBB940EB65', '8585000208745                       ', '  60   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8D2B2E4-450B-4816-B6C8-6E07F369E8A8', '4B4E0E17-1E28-4075-BE29-9BB9A02CE0FD', '3574660482850                       ', '    ', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E95D3A3A-6502-4CC5-AB2E-5B0A811227E9', '5C8A3AEA-DD97-4E30-9506-5424D769E9B3', '4602509000527', ' 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4FA6518-D52C-4404-BAB1-B57FF402C2DB', '0016A4F9-3E50-4DD3-8978-0EA6224C6F38', '9021600168090                       ', '   / C 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB7F1523-FBDB-4464-88A8-ADF1EFC43D53', 'A104FC3E-05A4-4DA3-B749-9B2B577EB73C', '4607015594010', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDCE01F6-ADEC-4F1D-8EEF-9F8ABF643267', '8CCDB645-1EEA-4CB9-AC0F-6750D5A58F91', '7322540456004                       ', '-    l 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11A917FC-6A4D-45D5-943C-F48E25F9826B', 'E9069672-C3AD-40C0-BD7F-194E146B6938', '4605949001215                       ', ' 100  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AB9A1DF-CD86-4917-98BF-CEDDA09386FE', '3C3D28BF-CABB-49DE-9B58-EFE9A70928AA', '5060105140310', ' 1% 2  - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A3CA3EC-F527-4166-AB87-5FC45F4A4406', 'E4D7AA98-87FE-4363-AFB4-2BBCFEE06850', '8024790101053', ' 600+1000  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49740902-74CE-497C-9AB2-376030499731', 'D2DBC144-465F-4C49-889F-07C88CCE6701', '3518646023606', '-     4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5A8C8A6-FB53-4E17-884F-1DE21E13E91B', 'D88795EA-888C-456B-92C5-73E6188F1DBB', '8009315062118                       ', '    6211', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2BB37F0-CA27-4F7E-A3AD-A067193CDB65', '50D87D35-BD92-4B6C-B466-8D8767E21B98', '4607174430372                       ', '    - / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A6C8EEF-177B-4EE5-8257-FC804CED65B8', '9942D6FE-E0C7-4F13-A12F-9104CCB4D7CF', '8030009700054                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41F8BFA0-21AD-45A5-9D2F-F2C030A071F5', '6A8279D8-6F30-4599-95F2-7754F9A44257', '4606677021414                       ', '    /   /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AE40667-498B-486A-863E-D436417A8316', '35D40866-A662-48E3-B0D6-8596A9A1CC9B', '5900002071389                       ', '  -   /  / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F451E022-3DE3-4259-9540-7407DBE793EA', '0506EC7B-E3EB-45B0-A3D9-FD8B1533F3A1', '4680007212734                       ', '    /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EB50388-3D3D-4D6A-BB1D-4156E0A2F78E', '55513D02-C76F-4775-BC5A-AD333CF5AA0F', '4600951001147                       ', '   8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A10E65F-0E87-43BA-8A95-28A57CC8C524', '8D5ACA9D-D259-46F9-8855-14660DD3199A', '8030009570046', '        250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFFC87DB-2EA2-414C-91D9-24BBAD2094EC', '74A9436A-95F6-4646-8879-7A29787E7027', '4600702094831', '      /.     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85549415-4EBA-4E85-AA33-280F46BAC9DC', '127A41F6-F4C9-4D0F-BBA4-534F4398991C', '4670017923430                       ', '      270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE211357-A2A7-4A86-AA9F-4E8C0E5FF123', 'E1821A96-2140-4688-85C9-FD1EF9227F78', '4812845000949                       ', ' 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A19178E-2166-40F2-B838-5D6C68B09AE7', '7EE522C6-D0EA-4D73-B6FB-BEB9D2508FA3', '3282770049312', '       30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57A9CB49-EE80-4FFB-9A14-7C5D74C8EB50', 'E7B768C9-6262-4043-A33C-20A74993C8F3', '3282779405485                       ', '   A.D.  - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF486A30-6225-44D7-83CC-F4079EE41DD1', '964DCB5E-F46E-4ECD-972E-C3CD63C98E7E', '0837524000052', '       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FAA1DAD-9BF5-4A1E-ACB2-8D39EC6A5A77', '950AD3A1-696B-4158-9318-F4C846DEA369', '4620009500590                       ', '    4.3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7426236-0F45-45B3-8BD1-127AE1483D4C', '4FEC2679-3D18-417E-BC56-EDD4D2BDBA58', '4607055560075', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B22DE925-DB9B-42B2-A21E-E19BCEA90608', 'C4E69324-C963-4BB0-BB92-77194B53E6C1', '4607013793446                       ', '   - // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BDC9560-787C-46F2-952F-6A362BC837FA', '3E8EBC27-72B4-4577-92D6-6882116771A2', '4600416011896                       ', '-   100    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80534BC8-4D49-45AE-8F40-E28241C94AFF', '8B487D37-9629-4536-A6DF-B8313C32826D', '4607153456676', '  500  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A20914A-E3C6-42D0-825F-6E26DEAEF79B', '55BFF51C-44D9-4C4D-9ED8-3AD6C62A49CA', '4602242001973', '  500  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A439B8DD-2390-46F2-9347-6F6789C38CF3', '3A141628-9836-4038-BA9B-245F75BD545E', '4607008160123                       ', '  10  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB7EF8A5-3CD0-4EBF-ABDD-6699E6F80BE2', '48EE0AD6-831B-49C8-8978-415EBB514098', '4650057001299', '  / spf30 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('979C15C7-0E90-4D82-B722-0D4997D8528D', '8DC81531-42E6-4B91-9136-4BBF12137E0C', '3401579205778', '  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78D40489-82AD-4E82-BBC5-B9590AB630E3', '627ED8BA-63B2-4BF0-8515-06B47C7EFA25', '4823002228915', '  7/ 1 /   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76DB6C8D-0B32-41A5-879F-71A00769115A', '4627062F-C7D1-4117-87FB-D946021C9B7F', '4670004410219', '     100 3 -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('726693B3-ABC4-44D6-BEFA-6ABCC0C6DEF5', '667C7E4F-6245-4A3D-A36C-F8A477A21B31', '4008233109916', ' -  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5C766CE-30E3-4B29-B704-586B1F54D817', '48A2E100-D632-47D9-90D1-95834417CE74', '4008233049779                       ', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E8655A1-7531-4E71-89C6-3F2F227BFAE0', '817A243A-7D58-43BA-ADD7-67F444853D50', '4008233118451                       ', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9650EF87-551B-4D8C-B360-51E0ABBCA865', '1F2078F7-D7CB-4A09-98E6-D4D62A52BBD2', '4813870001062                       ', '    65', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('273EC1EC-5EA0-4F8E-98BE-02A70CA64FE5', '41A815FC-6872-47D4-8C96-0101DDA30F44', '4607061252339', '  yes 25 -   + ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E1B7A38-14CE-4DCF-9E2C-68BEB68BABBE', 'D6B9337A-7DA6-4D54-8B4B-174A03E6938B', '4607019530014', '  0,5 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74316B6C-833D-4F1D-B903-68F8FE9CEEDD', 'D26B2492-5EE9-4E3F-A29C-0CC4E300C17B', '4011548010556', '   4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E63F076E-2025-4519-AC62-205B8325651C', 'ADE22CA0-4545-4BE1-8D30-2716711B659C', '3760102850015                       ', '  / - 7,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7ECFF6A6-9249-4B4B-888B-3520536DDF39', '82300147-B542-42DD-A7CB-A6CE1E3EAC2C', '4680013245467', '- 20/ 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1A5D7C7-BDEE-4A02-9844-F3D56CBF99B8', '4DB02FAD-B02F-44CD-A2F4-AC1C0E8D489C', '4603423001034                       ', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6833AEAE-A525-4126-94BD-329A480E26B7', '2360F7EF-4E86-4C6B-B5F3-E2189D5E9FF4', '5292452001574                       ', '  /    8    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC443EBE-A653-499F-B2CB-328FB084097A', '168E2D68-7A6B-4934-ACA5-A26A1CF4C86D', '4670000471139                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65C375D4-F2AD-4CEC-8D4D-0954A2E7F9AE', '1340F2CC-F8BF-4155-86E1-4B0FD78D039F', '4751006752733                       ', ' 2733 gemene /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16B450BD-4D6B-41AF-8250-1309995D3DB3', 'CAE725EB-09C2-4429-9055-532C2ECA0367', '4605446000636                       ', '         70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC0967A2-3035-425E-A98C-F33E1F53623F', '1BCA7EA8-1342-45D0-A1C7-7F660DEF84EB', '8809052585983                       ', ' - - / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('949AA6C4-7C04-483B-8BBA-C48E5BDB02C5', 'AF33B698-39FF-4B9F-A343-4740A2767B7F', '4670017923058                       ', '  /   155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C24C374-334E-4850-8CC4-CE4AAC02D296', 'E72AC180-45B1-4A68-8BD5-7A565E2CBA71', '4680038240409                       ', '   - /   155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F2280DB-08D9-4040-86F6-1B4713672EAC', '9CE05E6F-54E8-4A9A-965B-B280A6831CD6', '4670017926745                       ', '    /   / 155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EE6672C-34C4-419C-88C7-060AE24B573B', 'E4E32C5A-EB9B-4FD5-9ECA-1D303165F92D', '4029438001522                       ', '- 600  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0DEA065-CA92-4F16-9EA9-5A8922789A2D', '9209BB44-B935-49C4-B118-DB06DEA434F8', '6921570922070                       ', '     /    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94EE8B2E-0427-46D3-ADC8-F8E19DB3C7E1', '5BC0A95D-1B27-410D-A519-6E254C56E028', '4602103003177', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22EE3181-FA95-4F01-8836-F5D1FEEDDCD6', '7A342DE1-9387-4508-BC55-8E952FF0635E', '4605342002307                       ', '   . 300. ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D4240A7-8D3E-46B7-AC69-D85E66F896CD', '8B1E7E7D-E6C3-48B4-887F-920FF4927F34', '4605342002376                       ', '    300. ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55599155-8031-46F2-A51C-659174F0AF94', 'E0338EF9-8EE8-4DC4-97E7-7F2DA194F490', '4605342002406                       ', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29822621-D76F-45A7-A568-B5E536063A1E', '1FD4DD05-CADF-4112-AA9C-200D4576700F', '3282779254878                       ', '     - 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61DED814-5845-4550-87A2-9F9A12F794FC', '39583253-34B5-4955-9E1C-F6527C0135B4', '8030009570206                       ', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32AC1970-AEF6-4BB9-8E2A-31B21B45208C', '0515BFAF-AFAE-4A39-BADC-CD17CCF8FB32', '8030009570688                       ', '  -   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1813D035-7695-4AC3-A93E-C30C84ACE85A', '96D04279-730C-481A-A6C9-33842A950BBB', '8030009570633                       ', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67BFE895-EE1B-4472-ACB8-314A1A0D1A37', 'AACDF4CE-4A62-4599-A46E-738A1503FF29', '8030009522502                       ', '        150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90CAEDAC-679A-42CF-A311-C8CF16DFC4DC', 'BB0C94B8-F93D-4995-8DA2-293A741B3B77', '4607008160239                       ', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8574B4DB-76E3-4FB2-99FD-31EB81514D9F', 'B3C7965C-5919-4E17-9F66-9EB8B7280B2F', '4601811011238                       ', '   / / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C0EA827-E4E6-41E2-9B8F-27ABE7271DA9', '4EC35539-21CB-4F3C-87D7-6502CCD328BA', '4823060802799                       ', '-  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55163A67-91BF-4893-9A69-6C4F35F5174F', 'DD70C651-2010-4954-B1FA-4826810C2EAA', '5060255351710', '   90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FC29E4E-6FF9-4A2A-9B63-EFD43D541B0C', '61CE0A72-E939-4F7B-85CB-A6AFDD14BED8', '4612730250141                       ', '-       /3611/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('570AE8D4-4E5E-45E8-9101-8CCC179A6F29', 'C564961D-DE11-4E01-A41F-DCF856C2CC23', '4650001795168                       ', ',   -  / . . / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF74EF6F-9B5F-4677-9004-ED4E4C45BB62', 'AC04E076-4AF8-44A9-8236-9B2C32ED02DB', '4607148222668                       ', '       -2 5,6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09C78045-F4D0-4850-A95A-0A79A4252C4D', 'C0FE7219-1F20-40A2-BD5C-96A4A0FC09FD', '4607010248642                       ', '   / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B802D5C-9F8E-4E63-BC74-528875B86B13', '79D2E187-1822-4B3D-9F36-344A08669F2C', '4002221001176                       ', '   suss 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBFC5F27-B775-4E21-A5FE-308FE3BB5DC5', '632AA8C5-C90B-4AE3-86C8-272738682D42', '5060068526367                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A31B667D-D8D0-45B9-97D1-CA385D76CE37', 'AF8399B8-0F11-48E6-869C-0B37D0A1C465', '4601313000082                       ', '  90 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96E68324-2DB8-40FE-B7B7-AA6BFEC2F65D', '7A813830-66B9-45EC-99F7-73F59E36EA78', '4607176004656                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF0B384B-9457-4155-B5FB-6F5F0036E259', 'E7708DAA-01F8-47F6-9A83-57FB6F889800', '3800021150060', '  -   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17142760-CFE3-41DC-80F1-D07356B51B9B', '995C90FC-D059-4D83-BD91-DAF33FBB98C6', '4601498000716                       ', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1097E2D-4E18-482C-878F-BBCAF887F44A', '4B9192B9-302E-41C7-8BC9-80F19868A358', '5900516311940', '       20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A28D0BBD-AEFB-44CA-BBFC-EF583D7D59BE', '0EBF7AEE-3D24-4ED2-8899-02C38EADC953', '4607086564042', '       160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BDA7A74-EB2F-4528-97AA-99D3D7E6DEA8', 'C31AB43B-BA96-4FCC-A378-4CD76010AEAD', '4660018603172                       ', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A5D6148-FFCA-4EF8-B953-955C86DC574D', '7E07A77B-F323-435F-8E4E-67A70CC28E4D', '4607086564462', '    /   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('309A9A29-2119-4729-B71B-425FA18BE6CC', 'DF6FAB4A-A6DB-4AE7-AC62-DA920219516C', '5900516310417', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C2C94F6-367D-4E02-BC05-99453C011A58', 'DE112BA4-0491-4F64-AD51-0295A000C2DE', '2910014230240', '    / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('638F6580-3D0E-4970-950E-B3413F45A2DE', 'B6F11DAD-F857-446D-8F17-32491B9010E9', '5903407022079', '    - . 0+ 2/207', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EB8AB88-A37A-4E7A-BEFC-989E9B92E37B', 'D78610D7-8807-43F3-88AF-01F586C53D34', '4607024930199', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2600933-71B3-4E34-AB31-157673F7ED80', '3E791EC9-374E-450C-AC74-2983D3E0F438', '4690655004919                       ', '- 16  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEEC193D-9A68-4469-8919-E518679312C9', '42BF863A-91EB-446A-93C7-9560108490DB', '4603988014357                       ', ' 0,1%  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2196964-DBD5-4F62-ABA2-474195745E7E', '1EDCD054-88DE-4B0B-A129-2ABA2BA09E8B', '5029053532677                       ', '  16   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91B69543-DB63-44E7-8CF4-C0E026A4C762', 'DA9A06DA-37F2-4FD3-B5BF-899E94264CBB', '2910014230073                       ', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7051ECF-D59A-4B30-9647-D04FCD973C09', 'CCC86057-C6EF-40F2-9BBE-75A1D47242F9', '4602212010073                       ', '      72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C2596D2-B68E-4F3C-88E2-66F2F06A6187', 'DABA4C82-8B85-41B6-8C46-FC5CD33E715F', '8901138500078                       ', '   /     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64644192-2290-48AE-B508-1E0412E6DEC8', '62F525BF-D0DF-4EC8-ABFF-79A8403C9D9D', '4606033075129                       ', '  /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50605A49-18CF-49A4-9394-147E16387FDE', '28FAAD1E-D18E-4CA3-AB9A-10C661AC7701', '4690655008351                       ', '- 10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DDD3749-BE5D-4299-A8D9-ABA246BB9FC7', 'C96287B8-29A9-410E-92D3-6C55421D1C66', '2000103610890', ' -   0-6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('946D8704-3E4C-4373-B7E8-9D72B97D5C03', '8449DC03-C09E-4380-B17C-816B13572C48', '4019338601526                       ', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('538D212D-F095-4FE1-8D9C-F445C3A8660A', '7B34F5BB-96C3-4977-8D1F-3E5B51E85756', '4607126030926                       ', '  1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5118781C-31F1-417F-9987-E3EA1D5465A1', '5910ECE1-2F28-45E8-B839-BE1264123458', '8584005717344', '  100  / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EC68D5B-D21A-46C4-83D4-568415456CC3', '1C1C7394-CE93-43BA-AA3E-C1A70E29C061', '4605658213732                       ', ' -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05536254-A45A-4740-8DD9-460635673ED5', '2B0CC164-096F-4DAA-A6C5-3ED05E744F1A', '4690419012761                       ', '    /    3,7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC26BD26-94E9-4139-A18B-FD28D17B9523', 'E0E9E2C0-F1E5-421B-B26E-E929E92A0634', '4605962000011', ' 1,5% 5  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43D38D8B-4166-4A4A-8132-530844E9542F', 'D8A77130-4AC7-4485-A2EB-08F7D51C2D9E', '4607158910074                       ', '   / 100 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C233660-9DEF-4662-AC7A-511FE0DFB308', '6D12C3A7-23CC-4FC2-9B9D-787909D0E123', '4015400265054                       ', '     /4-9/ 62', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F985CFED-2581-4869-A86B-8DDD635951F9', 'BBA22EF8-0E2A-4D5B-843B-FB6E9A277E1C', '4250431900073                       ', ',20   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0F93639-1908-4CCB-A833-FA35ACC95458', 'A363CAA7-29B2-4DF1-B770-59C759D2654D', '3337872414213                       ', '   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2531071-839D-4C0B-A204-ACAC6638C367', '00291425-9C94-4AAA-905B-D1E5149CB8E7', '4605370003444', '    3-6  / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0172CD8-4195-4D31-B0E4-F81E895E6CC7', '95BC0D4C-1768-4436-BCFC-58EF49D9055F', '2000103610906', '    18+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2FBAE17F-80A8-43CE-A0E0-889C437F516A', '88A749F9-AB7F-4C1A-A0E7-6677B89BD564', '4607013860131                       ', ' -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36783D9A-3269-4C1A-AA3C-41FBF4FF8365', 'E1DB1CAA-0062-46A9-8EF7-99D8B866A159', '4627129212143                       ', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E053CC98-4D43-4C6D-9647-11791D9283FB', 'D65D91AB-AE75-4680-AC93-6AC96D7FDF3A', '5060038502766                       ', '  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('799EA5C9-393D-4C7B-B90A-B58E96BC5B39', '72E04DF6-3622-4168-98C5-D0A7CD096B0C', '4607071771950                       ', '   20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E51E719-85FA-4039-AB21-19E4202C220E', '3B54E3CA-D99F-4DCB-9267-64FCCBB505F7', '9062300114604', ' -    1,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6ACD6A9-0779-4FFB-9EB8-C2C6EFF2633A', '1D822D7E-2569-4C9E-82E4-6DF176212CE7', '9062300127772                       ', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('685E3F90-9175-407C-BE63-30318BC9991F', '3A6F708A-4C9B-44C3-A376-68261FE55A89', '3282779043861', '      2-   -50%   /c78587/ 400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D46E3BC6-1434-42FC-A837-22D659A7ACF9', '386EB827-B4CF-45A3-B191-B59CE4B351F3', '3282770100259                       ', '    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1924A8D8-5D58-40BE-BA56-FAC79ADA8FBE', '3053C0AA-F469-450B-A41A-3C3FA058D58C', '3282779022859                       ', ' +  -       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA7D4C55-29ED-4AA2-BB7F-E1013EE9ED24', '8EFAACE5-5E87-4050-A5D4-F370DD158FAD', '4607014000062                       ', '    6   1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE1C6F5D-730B-423A-A379-998AFF374A5A', 'DD563BFB-0277-44D2-81F9-0BCD57BF4E6E', '4015400095088                       ', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8269CAAF-1804-444D-A633-0AE85C25C680', '7944EF75-B0F3-4215-9868-14274EA173E8', '4607055074619                       ', '  074619   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('471DAA3A-0038-425D-8464-416FA647EF7D', '6CFCCA22-B7F2-4F55-BE57-E0B24C4012DF', '3337871320980', ' .      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2023D3C8-4E30-4A85-ACAB-2DB86F0E921A', '0B8A6EE3-72BD-467F-BA5C-CE2E045F1559', '3337871324902                       ', '    -      75  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('897E4F13-6595-49CF-A1FD-FD15FD23FD20', 'E1AD4D31-25D1-44EB-9341-4E5F2DD4294C', '3337872411083                       ', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA8BD7C5-646B-4879-A7D6-7E02AA9107E4', '41BB8584-FB37-4DD1-8875-1CE2F6E1AC0E', '4605342002253                       ', ' . . 250""', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CB4BA49-242B-4E91-9B52-19F9B6A1D02F', 'D1D8577A-DCE3-4167-BEBB-6CE62AFAF8D3', '4751006755024                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0BDAB42-8174-4790-A79A-33CDC45ED5AF', '50463185-5867-4F6D-AA3C-5178A74C4688', '4607088741663                       ', '    /     70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1136506F-4C70-48D7-A87E-CBDF46437BF4', '62B946A7-6B8A-4BB8-8872-14F288C665F2', '4600286100447                       ', '   1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBECE0FB-3663-4CE2-AC1A-16750E8FB437', '4E077162-09F0-4C4B-A1CD-974647C90E84', '1685926563052                       ', '         250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7569FB65-4235-407F-B577-9BB38AA9AEB7', '403FACC8-5A84-4F6A-83B5-FBC6A464ABAE', '4627114711705', '  . -   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('426B3D96-1465-43C8-921C-A5136163F4CA', '4732F1B7-B416-4163-AE4E-7401786D371D', '0027917101187                       ', '-      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('280ACC69-D4B5-42A3-BAE2-AEEE803385F1', 'CC4B09DB-FDF6-4AD2-8A53-BA1AAB730638', '4606157001172                       ', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF41B2D7-39A5-4590-8FB4-6B1C258E9634', '52A46C5C-3666-426E-8AF7-5D9F4ACDE049', '4630010960252                       ', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7802DCB-FF05-4E70-8ED8-926CEF4B08FE', 'DC72ED7A-2871-4832-BEC8-BD692F2B7EF9', '4600338000398                       ', '  500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0F29080-FAD6-4895-8225-7468E14A0AF1', '2730DCD0-EC4F-4065-9CF5-0B46F8CD0600', '4627090498577                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9925344D-0233-414B-87ED-3083691ACB44', '5CE788CA-BFB1-4074-8CE7-DC04D0A0C44A', '4607078792422                       ', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01235653-B1DB-4CE5-B12E-3DDB14AB54E3', '8EBF6FB8-EFAC-4E9B-A025-EA7E112A1FEA', '4601654003056', ' --   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B414EDD2-EAB5-41CC-AF46-ACFABBC0BEA8', '91A1D697-601A-435E-A411-3B817F387621', '4008233127958                       ', '   -   /    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4891A5C-64CA-487B-990C-9A9BBF1F9FDC', '47AE6623-2915-4955-AD90-F69F0D2F7B3B', '8030009502283', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BA05977-F1FD-496E-8B9F-795C093A2C40', '2AA8DDD8-E4E5-4591-ABC8-DED9D4088CB5', '4005900008237', '   /   4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C5CF7CB-E5B8-4595-9225-007C672CFA43', '8D520417-15AB-441C-95F8-735D4CF8C09E', '4601654000307', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('009168B5-7F86-41D4-B134-AB4ABD43D6E9', 'C6DA88EA-868D-4AB6-AF10-E99098D8CBA1', '4601654000253                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD244150-248B-4833-B366-201F601AACA5', 'F31AA4E3-4E06-4A42-AF18-003E0BCE6692', '4029917000220                       ', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B15B0CA-93E1-4DC2-928E-91D7C30A1576', 'F209572C-05F6-49FD-A0C6-314400B18949', '5292452002915                       ', '  3d        5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52E04B9A-4D27-4A0B-BBE7-15A92DAC810E', '027BCC7F-BDB6-4E70-8A7E-897E323EBA24', '4016369666685                       ', ' TEENS  8  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E601CCA1-057F-4E34-BFFC-73C9B2267DA2', '89EEB808-46C9-49F8-A30F-147A7441A940', '4601654000482', '  2,2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C7684C6-C6BE-4856-B27E-1294FA1E0527', '0E5A75D7-20AD-4029-97F5-6647DAAC1B0C', '4605446001473                       ', '    ca+  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F96C792A-3D1A-4BD3-8868-2BCE6431AEEE', '00312347-18E9-409C-B1D6-9D23D779109F', '3337871331948', '      /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17616EEC-37ED-4409-BDD8-1CFA6020A77F', '2EBE42FB-6133-4842-BED8-396E2A45E4A6', '3337871325060                       ', '    -   , 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51D67601-1F75-48CD-B3CF-F43859D20C8A', '05D1388D-4717-403B-9388-5B8346A94162', '4750282912169                       ', '   - 3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D440124D-91F6-4588-BE2C-F595B4009C72', '60CB2507-80DB-4578-B00D-3F45EF42CC7B', '4631140314793', '     , 0,8 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D044D378-7D03-4B4A-BF12-DDFB0FB3FD6C', '20AAAE50-75B7-4013-9A3A-FD3E9DD90362', '4631140314809                       ', '      0,8  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88F2AF47-6EB1-4D30-9274-B355871F9C88', 'DF086B2F-B4F4-4F0D-A22E-159AD3D99BE3', '4600936241292                       ', '    124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3A3CBE7-4CA6-4542-83EE-741CE4E0D44D', '5C48811F-D0CD-40A4-B730-1CB1DE90299E', '7702018849031                       ', '  blueii  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AFB3E4D-9FC2-4FBE-A1CD-E10D3129AC41', 'E02D73AA-27A4-4B69-B11D-D14E6988FDF3', '8901148216471                       ', ' 2 4 / / -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D374E095-3216-4975-B3E4-49416270571A', '8104E63A-F417-4852-BE5B-6281E1108FA7', '4607054703114', '  soft   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50912CB2-828E-477E-AC14-1D4350D07864', '735A12BE-AA59-4280-A48E-BC83C5635148', '4601429002727', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D1B2A0A-99F5-48A6-83C7-C35E0C3AA692', 'BC1590C7-2C1E-4D38-8864-E152DB479222', '4690419012778                       ', '    /   3,7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C9AAD13-ED5C-4B9A-9E66-DA716350F77D', 'C0F430D2-DFEC-4184-87A0-C6727CBA1988', '5900516421038                       ', '  -    1:  1 80 +50%.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDB3DF76-18B0-4F9B-888F-A71D8FFE7B8C', '31251ADE-4AFA-4426-BE18-DBA6EEE1F205', '4603804000168                       ', '  / 50 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('709A904F-7715-4325-A1FC-16224262E23F', '3190C11D-39B2-4A41-B27A-CEE5AFB25BCF', '8718164965586', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A5A63708-6435-4D0C-99C0-51DAB2103E01', '438E7ADE-6D6C-4C55-9370-26D8F526AFC4', '4607055136683                       ', '- 25+10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22080A02-3C3A-4530-B8F5-B61BC7166467', 'B85B83AE-75DC-45B8-AAC6-E16E67168139', '4607011665264                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65D07BD3-2CB5-47CA-9E0B-6A39CEE50CFD', '4BE60130-8E71-49CA-9D9D-C66039A39D95', '4601654000598                       ', '  2,2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('643C007A-7CB7-4307-ACD8-518A8B5D3728', '99CD7B22-D108-4BBA-9761-BA6F7F467496', '4612729880052', ' -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBA35275-864D-464C-852F-265BEBB6A809', '01E41FE5-8440-490E-9A63-BE5ED0E9FF06', '4601808005097                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04C034D7-4949-4664-8E8B-408519634D46', 'FE5DEE0A-94A6-4BC8-A7E8-4025FD6CB903', '5038483745977                       ', '   /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5060F51A-D2E9-4534-9763-66111858E103', 'D2D81903-682C-49D9-933F-3C0CCD78B294', '4620760951808                       ', '    C    17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5EDAE25-356B-4C82-9DE2-328F0F8320F6', '898F8048-31D4-48B4-AD4B-7C85079FE70B', '4620760951792                       ', '    C    17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64A2A997-22C5-49EB-9F3D-E1FF5109ECD8', 'AA6811D9-B4DB-4C9E-8CD8-2701E1C9FC93', '4606486002246', ' 50  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A503AB19-8B2D-473D-8BDF-E94EAC5A845C', 'A2FBCA8D-DE40-4091-9FC1-4DF4A73F17D6', '6921570932406                       ', '     , .  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84B5240B-81CD-4646-A65F-CC8AD54A8282', '3B976DF4-D982-4486-BE63-29E185431DBE', '6932511207453                       ', '   /   .   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D568ACA-E723-4CAA-93C5-F18F88A8F2E2', 'A03D8890-D729-48EE-90FB-9895A47B0EBB', '4602159017074', '    4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE55528F-5F91-4E3B-BB7F-B45AB937E2E2', 'E482BAB9-9232-427E-8063-00C2F43AB544', '6417150005511', ' 4   h /     215 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DEF5A82-42DA-4841-938D-429A28BDD537', '138FB0AA-608F-426E-BA58-B8F0097FE21C', '4602509009735                       ', '  1  1+  /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FEC3980-ACDC-4A94-8F1F-A05DCA8BD8EA', '7727BEE1-691A-4D46-9A50-BAC5553BC32B', '4602866073677                       ', '  . .   .   -003 (8,0-50)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F12AA68-BA91-4F86-8633-DCC2AD06CFE2', 'C2F92F40-D29D-49DF-9C2F-CD378DAC6689', '4823060802720', '  3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2036467F-C322-4661-84AE-823A1801D38B', 'E162096A-8659-4733-87E1-1FA4CBD98E92', '4640006301730                       ', '  - /    70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A500CE9B-5F8A-4017-8C48-2AF62ACECB09', 'E1BA6629-B8D1-45A4-B2C5-21B1E0EE8C13', '8901783010106                       ', '- 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FEB8C51-0237-4B08-9AC5-68C4D1B1D351', '52BEBBC3-2DD8-4CD8-883A-99276E973744', '4612613500103', '     2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDA2FFF0-F698-429C-B43B-C5541AD4AC48', 'AF3968C2-33D2-48F0-AB0C-F492D8393018', '8030009502450                       ', '      6  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58EEE1CA-0E0D-43A7-A544-B7D6C8F7D93D', 'DAAA515B-8271-49DB-A9AB-8FA1FD9A32BF', '4627114670033                       ', ' pellesana     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD964365-6908-461B-860C-6EAEAA4A9EBF', 'F5525338-91AA-4512-8D69-7A4386443C78', '4601214005995                       ', '   3 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('175E38AC-3AEA-4A7E-84CA-577FEB2CB1EB', 'EC936487-C7E9-467D-8E84-5A9ABBB7DC34', '4620002185541', '   /    spf 30 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF34B263-BDBB-44E4-A20E-FA03910CC936', '4DB82747-A42B-46A7-BDF3-BF49E5CD7A07', '4005800195747                       ', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F14480CE-8C82-4AC4-8691-99BF9C0CA998', 'BBCF40B2-A4BC-4CB4-9FC4-04686A5F2459', '4690419005688                       ', '  - /   spf-50 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C86314A7-BE0B-4B2D-995D-79B6280576B9', '4EF6776A-E1CE-465B-B7EB-4E9F864CF793', '4607174435254                       ', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E0CAD0A-C318-4B8C-8FE9-F8C6D1742F45', 'DED9398C-7F7A-4792-B16B-5CB846BC958E', '5903407225623', '    0-6.   /22/562/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4778A243-FA7C-4F5F-AE12-3CD0F076FD78', '58764CD6-7D9F-4FE6-B2C3-35DA88EFA6E7', '4606033047409                       ', '  /  /-f-7 emb.logo 3/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A238476E-DCC8-44F5-943F-574710882EB6', 'ABBEB429-1D3B-4D91-ABFB-B27E0661BD13', '4601774005824                       ', ' - . -325   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F177AB2-E653-4D11-BAFC-74F2E20F100B', 'E7723432-0733-4494-A285-876D84FF20B9', '5000174647839', '  380    / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BF78EED-C191-4741-B025-DD979BF07D76', 'EF367B31-1122-461D-9415-2ABDEB8AAD77', '4607017643259', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('815FC908-E9CB-484A-B2B5-FB79DA8DB453', 'EC2CD470-8948-423A-8F36-3DA8DF2A75BF', '3282770122756', '    spf50+ 200+  /c62551/ 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46E423C2-8948-4972-A8E6-69F228734DF2', '78E05D18-E139-4816-B99F-EC3AD74A2AC0', '0856920000497', ' narcocheck  / 5     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF70312D-1D2B-47F6-A82B-8B034983E6E6', 'BEE39406-CA67-468A-991A-43311DA5B9D2', '4607039973792', '  1 ()  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BDC2ED0-ACF7-45D9-AE6A-4A901386776D', '3248DBB1-54AB-4D9B-8373-475D2CF33007', '4601450000020                       ', '  - / -   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20719F07-672C-4684-BACC-DC757E4EFEE1', 'D881BE15-F569-4DD6-9E3C-1164461522D0', '4603679002557                       ', '  -    300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72A2D398-D237-4623-B5E2-4361FEF9FB59', '4EC91F8E-C285-405D-A4E2-174F080FF9EB', '4603679002533                       ', '      300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('540FD5D4-2F3C-4582-B7B3-7BBBB9173385', 'A7B44BF3-4CA3-4172-8230-1CB13D028DBB', '8032779759720                       ', '           500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD154FF2-82D4-4951-9A25-B0B363E7916D', '79467481-7031-495F-9A4A-F72D7A44F679', '4607017264621', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B64E795-C8EE-4143-ABD0-1B6D7B0106C9', '709CC30E-452C-43EC-974D-DF9992827094', '4620760951723                       ', '    C    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A7CA552-4AE5-4F26-80E1-37EE764CF279', '2584B3AD-F84B-4755-9E7C-6055FC898EE3', '4600689603255                       ', '  200   /  4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A58F747-EB62-4D96-AF33-8B15022C9123', '99DC7990-0C7A-4C36-B15F-4A40BB145F3B', '4627108140252                       ', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D81CEA85-3DEF-4EB0-97E1-59E966010073', '738B3DD2-6C19-4323-9B77-CFF4167A74BB', '8710103618348                       ', '     , 0-2  .81520 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DBD4F61-8C07-4B37-A124-8E383815DF55', 'BE6CF507-1DB0-44E3-BA52-81B450FAD065', '4603728322056                       ', '     -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AFE1E33-03DD-4CB0-9CDE-D16BF1A554C5', 'BDD3BDD3-ADB6-4DEB-89EA-DCA9676B2B5C', '3337871328399', '      , 150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92A048BC-1670-4E1B-BDFF-A2B4EAB0592B', '658F8BFA-0569-4F59-8837-91392DE3C46B', '3337871320751                       ', '  ,  .  3  1,  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2638F66-4F11-48AE-9753-388DE4AD5B76', '03837E66-4EDC-4A7C-A14B-9323FA78CE43', '3800200962859                       ', '   /  rose/   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28E05CAB-0D87-4DAC-95C1-4C47368EDE10', '6019143C-90BB-4370-A105-A6AF6C7371AD', '8901138511012                       ', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13804F1D-2EFA-4D4B-9161-7FE7743376F4', '755C0F3F-CF2F-4B70-8B10-5BE627371F09', '4620020891615                       ', '    //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AA23F9B-1DE7-4970-BB83-8383BC7DAFEF', '75AF06DA-96C3-4744-8B36-8AADDDE70C53', '5900516695385', '   L 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF6FFFE1-34A7-4ECC-96EA-2EC47B3DA489', '2F686337-E678-48A1-A05F-2DB64B51CD9D', '4620020880329                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('365EA10A-E537-4323-941F-D8601EEA5CFC', '47C8B6E8-0340-4924-A343-1BD036A77655', '4640008530480', '  1000+2,5  / 56', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA3A06F6-C71B-4FD1-B9A4-1B3322C306E6', 'DEEB2906-B520-4A20-8304-9CDF914CC75F', '2012042000502                       ', '  -12 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('550B8A9E-19E7-46CB-BBEB-889C6D9ECD40', '4281807F-ADF5-416C-B6E2-0DEDBC2F7B41', '4607174653795', '  60100 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92A64C23-96DF-472B-943D-DF3BF5B6A23B', '2B385CD2-7E5B-49EA-911A-A98C01675A24', '4620760951747                       ', '    C    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A38E1E27-F789-4CA6-AA83-378B3C39F222', 'F5B0551C-CB55-4052-B6D5-ADBD6AE85847', '4607102855970', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87AF4296-22AA-4B00-99A3-E9286E39F966', '8164A51E-912E-4EF4-8948-CD74BB1F5D18', '4750258202416                       ', ' . - /.  . .   1 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E6A93B8-0F0A-4E4B-A9A5-31688849CF27', '9D520431-744F-45A0-ADE8-57015AC5CCF4', '4602159017067                       ', '    4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1071C154-1BA3-47F7-BFCF-22480BE239F5', 'BAD5D429-2EA1-4235-A241-A310E9A0B5C0', '8436531910709', '  pekatherm f-70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE6C11DB-C70F-4C24-AE63-D5AEFA135ADC', 'B5C19D1A-A191-4BB8-8F68-BBADCA149D9C', '8436531910204                       ', '  pekatherm u-20t', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('511D4CE1-A467-471A-BE23-EF0E701DD976', 'B5295529-366A-4216-8DAE-7D61B9B41AB6', '4603014004758                       ', ' professional    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('902DCD17-5336-4F17-AFA0-4758F9E7430D', '004260ED-EE2B-4193-A84E-EFD76230B2E4', '4605059012705', '5     120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2468F6EC-7CCA-4B82-AD51-78A3AB83FF27', '3FD3EA4A-D323-42FF-9977-72C152BA9272', '3282770037319                       ', '    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2222D94-21D5-4A47-AAC4-0B24B0AD54E8', '894967E2-2A58-464E-9CC8-DB142F45B55C', '4606677015598                       ', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1CDA62A-F378-44FD-9994-CC946A1CFFF8', 'CC96D267-1C1D-4AE4-9E7C-700CCB9FD3FF', '4032855840148', '  2- . -20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D2802C5-1D52-4F70-BDF4-C1F46D614B39', '578FF289-F1F3-4B69-9B5A-4C88BE6D5F76', '3337871324582                       ', ' - 48  -     ,125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADB49988-2EF4-4EC9-B3D0-F6D78625D29D', '76C9A9B6-76B4-4FDF-93A4-9A016E49C5D7', '3282779254984', '      /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1D97BD1-EABA-40EB-818F-02F00131CF38', 'D9F1C1FA-A0B6-4CA2-8329-E47A740DA8B2', '3282770038033                       ', '    / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39084ED3-4CCB-4F2C-BB6B-F299C6AF2A09', '95821BB0-D1B2-4DDE-B19C-C87D7B0910F4', '7322540574777', '-     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD273082-A218-4347-8725-55DCE3F66500', '6CDF5AC9-8BF4-48FC-9C57-FA15171B76B7', '4607106052580', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('338B567B-8527-49F4-AFAF-B927A2CA692A', 'A82BBA2C-31B7-4E39-8240-BF9C10D05480', '5060038503664                       ', '   /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4990F23-EC0B-4D91-9312-EB232088241D', 'AC1022CE-9DC5-40D6-BC69-AE9A84051F6A', '4602212000463                       ', ' 24/ 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05F9F9CA-D727-4CDD-8D4D-6A0EF5CCD188', '8D9A9ACF-240A-43B9-B62E-C126C4312C58', '4605126000451', '  ()  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('254D124C-D782-44A9-B959-B45507CE711E', '9AB79635-2283-4D78-A4E8-63590EE1CA50', '4607086568750', '     / 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B96221E9-3BE4-4846-B646-FEAE65FF3E9C', '0A387999-E350-4A4C-8817-31EA39B24DF2', '4680013242800                       ', '  - 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF55BDCA-0BCE-4455-9B24-225E423DCABA', 'C9E0EC9D-9FED-49AC-8BE3-F4D8C65B811B', '4627129211030                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D916E08A-AE7E-4013-8D69-0155ACB3186A', '0E44856E-AA2E-49B7-B928-382EC7738A79', '4607064299232', ' / //   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('142FB1F5-2EAA-4B96-9C14-6302F9439035', '01543594-E0EC-41F7-8F76-B2FF4E6757C7', '4607102855956                       ', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FFEA374-7C26-4714-BAA9-06524268991F', '21C98D2A-FA87-4902-8E1E-D8C95573F2E7', '4620002180461', '   /  1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F270BE4-163E-4BA8-A300-4491C7B75211', '4F64C2FB-A376-470D-92EF-BF74A6297B04', '4602159017081                       ', '     4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAB41ABD-7F3F-42DC-8DE0-E6BB608FCB19', 'D947D1B6-1DE2-4C78-9230-6E73BA998650', '4607102855963', '  /   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A29182A8-47D1-48CE-88A7-F29B546C7D27', '232C49C7-2884-44CF-AAAB-6BA3654B95E8', '4650001798350', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47A731AB-D930-4684-8E71-CDEAF8BDDF2E', '4591BC43-F9EF-4ABB-82C7-6A1B652730F8', '4620760951778                       ', '    C  17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C191A453-6630-4117-9279-67A8C9ADA30D', '340FFE05-9CCF-4707-B9C5-939CF7E911A0', '4751018120339                       ', '    8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2826717E-0829-4C04-80C7-FCE9A8F9524E', 'E62111AD-CC3E-457A-9898-94CEB25288CF', '4602159017050                       ', '     4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD0EB33C-CC59-4697-B255-714164F3CCD1', 'CB7E2761-6D96-4081-9D10-9129A9F0131A', '3337871308612                       ', '   ,  -, 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA2E20EE-55F8-4476-8B9C-67EACE0F1E65', 'A7DAEDC4-038D-44C3-B0EA-4B016A239F75', '4605658401597                       ', '    300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC1727F8-F7F4-4C22-87A5-982AE985EE90', '13945BD6-548B-4D5C-A065-9A3A2C5BA5C2', '4620760951785                       ', '    C  17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15EAA3A1-E8B4-4568-8EA5-5B09EA1561E3', '515BC9C0-E793-46B7-9853-9C53FBE18820', '5903407181172', '   2    12  18/117', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('976C4D31-ED44-46BA-A76F-D528D57DB1CA', 'A832F057-53C2-4982-8581-31D967939918', '4610010012113', '   bionational 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50556BBC-1C77-4F07-B2C2-F2F261F1EFEF', '9FC788B2-4B9C-4426-8957-D841CD653C56', '4607114290066', '         100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('904E2D84-6B9C-4B59-82D5-832F96C5865E', '6CD411C7-4D2E-46CA-9C52-2A2C559FDB9E', '4605797000200', ' 100 1 /  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92A7FF89-ED7A-49EE-9511-33129869D632', 'E90D6081-2FF7-4932-9725-12A21CA4FDC1', '4049500340199', '   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32E44E0E-876E-4057-BF19-EBCA2E292F9D', '40162BE0-5562-4409-B86D-3F7CF8973DA6', '4015672109384', '  OMRON C21 Basic', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B5B0BF1-0B43-4B9E-9CD5-873DFE28C7B7', 'C1DC96B3-32E7-4854-AE30-C75D3D4545E2', '4650001791252                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('585246FE-9D4F-4D8C-A410-7EB3DD128653', '890E9B7D-612E-4ACC-98B3-4E48095C155D', '4605658213138                       ', ' /21313/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B95B28B5-3DA2-4489-A7B0-3362498C1F5C', '00F756C9-08C6-4C2F-984A-48F165921201', '4607102856052                       ', ' /   /- 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC948A5B-BC67-486E-92EE-4D160696F2DC', '8D3C9D08-056C-4FF2-A95B-8EF5C0332B17', '3337875533799                       ', '. ,      26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8048754-7E3C-45E7-B9E0-6F5C17344230', '98148D17-9E67-4E16-AE44-A78467374AE6', '4603569721698', '-  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B34CB68-F947-4900-AA95-B3950BCDB895', '9DD66151-6D5E-4AC7-9022-3A57B35CD52B', '4607061252322', '  yes 25    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8453707-FF3B-44C5-B45A-C9377FF2605B', '5EB62CF3-CFBE-47EA-981A-1110AE203EC9', '4605108004835', '      -    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB50AD3-69A0-42A1-BA35-2D4CC8357C7F', '0DE2B9C9-39B6-4ACD-806C-B9CA3B628843', '4603728322070                       ', '     -  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85486484-2911-4C31-9ECE-9B2B8EBE2B64', '3FFA33C1-D3C8-4E9C-B9EF-00B7BA3C2469', '4607051798526                       ', '  / . / ./ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0602D43-6BA3-483A-AC37-51A5477CE3FF', '6B9093EA-8EC8-47A6-A996-49576AB8589D', '4650002438958', '    200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DF4FD62-B5C5-4BB9-9D3D-EAB02D053366', 'E14A7875-0400-42F7-A570-EC6CC6DDF6C0', '5900516988623                       ', '     8+2 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65D0F737-4297-4E8C-A24D-4CB2D10470CA', 'FB6E5937-AB9D-4B92-8053-424A8455F564', '8717627100328                       ', '   33,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D65167F6-850A-4185-AC36-0D3EB1B8B79C', '2D84730B-44C6-4E7B-9A18-EB81E4E5CDED', '4607003247201                       ', '  4  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9051C511-67E4-44B4-A0DD-857461C44FB1', '3EFE8BD8-5EF4-4F85-A86A-4C3580432260', '8588000133932                       ', '    / 0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('862DA43D-CFE0-449D-AC7D-5EBE9C38FD9A', '81466112-E739-41FA-A993-CE2370582668', '4650068532959', '   - S  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('121F7D84-1505-4D6B-9575-D941230F0578', '5EDF836D-B7D9-4E09-8748-4BD6775F4CB9', '2000103612900', '  2/207 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C85AA9E7-2006-4764-9A73-65F05EA9B64B', '06181302-E918-4912-A17B-E090AAD8C301', '4607017267769', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8736AF94-2601-403B-8128-78D68F5FA02E', '5855A2FF-A35A-4657-9BFC-D7E36D252149', '4620760951716                       ', '    C    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92531CE4-2566-4027-9C2A-E4D72AF6E962', '7ACC0111-951F-40C3-BAA6-83BAD0FAE6AA', '4610010012090                       ', '  Bionational 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01D54794-D827-4573-9F25-6F2475FBCA01', '9080AD35-3A6F-4896-B98F-E39E0738B1AD', '4680021330032', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C651E91-A8C4-42DB-8D4C-77A2B3DD260A', 'F269A344-8F67-4A0A-B7F6-5B50FF2A277D', '4005808884247                       ', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FF769B9-A00E-4B60-9426-7A6BE33486A0', '9AA5CC3F-5A49-480A-BB7A-E9AA0670BCD7', '4650002438965', '    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53837DFD-049C-4503-A1B6-A9DA5A47A068', '5A2D3697-BA64-4AD9-B6AB-DD592C6B0A98', '4607174432567                       ', '   / /-/ 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F908D1A1-9026-41F5-90D7-6DC8788D0949', 'DDC83625-7DF5-456D-B287-7256DCEA39E5', '4601654003001                       ', '  2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('343B4EC1-BE1E-44A2-9243-1BCAFCE65A7D', 'F1B065C1-6D43-4684-BFF5-221A9FFE49E9', '4607027213558                       ', '  -  /,/ 0-6  11609', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('508D49E2-3911-4EF9-9366-5F0ECF95B11B', '5811BB2F-586C-40DD-8833-29D0C2D013EC', '4750283039698                       ', '  - 4 /43-46 /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCDB0FC4-AD0B-448A-8910-01927E1BD949', '0B933929-0A56-4A4A-87CB-AE1C8BF22F1A', '4660011214580                       ', ' -  /      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43DB9492-8462-45C1-9BE7-B05DF6319AB5', 'D16576EB-C7FE-4E67-9EDF-BF6144EE39B7', '4009800001220                       ', '      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B67C7E1A-89A3-4E37-A306-73E634C54BEF', '6D523170-A9DA-45AE-BD16-2FA99F8BF041', '4680021330018                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDA0B83B-9685-4F1B-AE2C-AC6EE932D27D', '36A5A499-9043-4F31-BC05-F92B154CADFA', '4650002439009', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EAE578A-09F3-4E28-B4CD-87C83EF507BE', '6D9A36D4-8E29-459E-80FA-2D983C3A912F', '4631136460992', '    / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5DB494E-85E7-4015-9013-C67E956277EB', 'A2694062-9F7D-4701-8BC2-22497B2AA751', '4650002438996                       ', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EE4EF90-7F3D-457B-9D68-0E71583D77C7', '3BF6922A-705A-4F82-BBAD-D88A111010FB', '4620003221941', ' maneki chibi-neko- 9-14 42/l', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B52FA08-6265-4C57-832D-40C481B027FE', '502E164C-E872-4271-ACE0-BF5F47AD6FFA', '4650002438972                       ', '    200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A60267B-B726-4298-9215-08E42F73A48A', 'F96A1784-AE4B-4555-8418-E5DBB101AAF4', '4680007632907', '   60x60 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2A66DBF-17F9-44C7-A389-3E32FE3BE01A', 'D18B1576-5317-416E-8F57-67BCC8D839AE', '4607017264584                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E88371D-0649-4642-88FD-FE917C6A93E3', '1A118A1A-4E57-4CBE-94BE-CEDAFDD99EA0', '4607017264577                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87C6D51B-9BA4-469C-85E6-993BD5E9F211', '9A897D68-8D1E-4CE6-99E4-1DD135D0E270', '2466350402457', '  6% - 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF9C0DE6-2A68-4CE0-893E-E1BAB1FC9F97', '7E8D09CF-16E8-4E9B-8F2A-04E84BEC2862', '4602206000127', '   100/ 10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4CE0D94-0707-46FE-9D8F-2FDA92266645', '69DD11E3-737E-417D-B2C1-42BBA362AE6E', '4602206000080                       ', ' HM 100ME/ 10 - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9104567B-DF98-479D-9E66-DBA94A7F13AC', '2C65A518-EBB1-4E97-8D7D-3C09C1C00D9D', '4607039971132', '       50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D829DBB8-3608-405E-BDC6-5891426A8860', '5C2EF925-0389-41B8-8468-05E205812BC9', '4606711703993                       ', '  /   50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36A56E93-01C6-44E2-81DD-270297B00EC3', 'BE507FEF-9CF0-4589-8CEB-A80191152C44', '4630009186403', '  80   6  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F19E42F-187A-48BB-A426-CC03FFE869F9', '5AB6C9B2-F463-4E25-BDA3-2A82F9863BC7', '4210201746553                       ', '   /   precision clean eb20 2+1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1033ECC9-EEF7-4874-BC44-AD5979638491', 'EDECCCD1-74FE-42C0-A544-14CD59E8D64E', '4607051795501                       ', '   /.   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA36F9A7-BFE7-4893-AD84-B442AD55F06B', '036AD4A5-FE3D-49B0-AB18-CF8C0E3057F2', '4710614722750', '- easy touch  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80235E19-9C3D-4CD9-977E-A5789AB102B9', 'BECB8559-F46B-4D87-8848-3229F92CB785', '4602228001492                       ', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0154295B-8697-4C45-9BA1-40235CAA1581', 'E6A29CB4-C243-4AC7-8264-EC9250560A07', '4605319011707                       ', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4939B01-7F29-4174-BD7B-A54CFB6CCD98', '39B94107-827A-4590-A429-0FFF8597B12B', '5900516420345                       ', '      100+50 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6881AB64-0AD7-4C6F-AA4A-33A9DE67B11A', '3F974248-3852-4B64-8901-106D60869BFF', '5900516420901                       ', '   100+50  TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD923618-AB9B-4FD8-9465-03F4C748A2C3', '2B910AE7-E424-4309-BD08-B83565093571', '5900516290900                       ', '   : Dr MAX NEW   () -"classic" 750 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DB71647-96D9-4E2A-872F-32846CC6FEDB', 'CAF2F090-D397-44BB-BD12-CCE0B91356F9', '4607029291684                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC461AF4-F515-416F-BFF9-00B54BE6EB52', 'D776C062-2CD0-4269-BBC4-4AC63D8C6651', '5391523120036', '  160+4,5/  / 120   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72049D56-C9D7-47AF-ABB6-DA51A7978417', '554B15AD-0BBE-4126-A7FA-936198ED004E', '4820121901200', '   127', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56CBCDDB-6A8D-4862-8877-6ED0DFF84614', 'C598E686-9DC4-4F28-B1D0-BFCCB0F6C613', '3337871325565', '     ,  , 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDDE2815-2F14-4F14-A962-D4CD26E54CEC', 'C54A875A-9D88-4371-9B50-3ABD4821EE45', '4601214004905                       ', '  2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5305E6C-42F6-4A8D-9182-03A4547C482D', '9CEAA81D-1E11-43AB-AFF0-CA10811EC408', '3337871325558                       ', '    ,  , 40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B17A4DB-ADFF-4241-B0F0-24A01DA03090', '4BE1330E-3369-44C7-ADEF-5DABC36F4A63', '4607174437302                       ', '  - /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('086CF3AD-DC47-4ED0-9EAF-243DC2D06B6A', 'ED54146C-127B-452E-A445-ADE948043C58', '4607174437203                       ', '   /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A73EBAB-5E0B-47CF-A47D-B25D3B228AAE', '5E2662D9-A611-4338-8949-848858A82E71', '4607174437081                       ', '  - /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('712C8CCB-0570-4DB3-86D0-B990A47151E9', 'CABCCFAA-05DE-40FE-8420-0561A93AEE31', '4607174437104                       ', '  -    300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A4D2F32-C1B7-4736-9C1C-9ED594DC4D68', '07320759-6374-4132-98BE-7CF876D86EB9', '4607174437432                       ', '  -- /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E9ACDF2-519D-4C51-A97C-FE1A0C00464F', '9EAF942C-CE2C-4B41-9F46-4DE6429FCA34', '4600951001208                       ', '     1,75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5A18431-1C93-4662-9CBB-07261527FCFF', 'D2ADAE25-3F34-47C8-A6E7-443BAE92596A', '4607017264652                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C77A7F0A-6664-4F1B-895F-ADEF0ED0391C', '580FEE47-95E6-4CC8-9B41-125BB8F01DBE', '4607017264607                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('005AC1FD-708C-4FD7-9C28-81AF50AF3E59', 'B28A19EB-5156-4954-9CF6-C75A6114DECB', '4607101202768', '    ..  0./13565 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34B86AE5-66BD-4D05-B373-263FD0F1B3CD', '250E5F03-8FE2-4351-A4E5-53B9FC911C7F', '4627084350157', '    125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62465EFA-2350-403E-8D40-0FFDB6307DC3', '476609DE-98E6-4F20-BCEC-060729329345', '4210201104773', '-   prof care+mickey f/kids/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('861ACD2E-3A2F-46EC-91E8-0B8D07B2529B', 'C1829BDA-E692-4F2A-B855-0A9AEBA45EF8', '4607034472955                       ', '   Black Edition 400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F430511-2AE3-4D6C-BBED-3DFFE189BDE1', '31808CF1-578B-48A2-BD6C-3A0B54D68AD8', '4602228002017', ' Silkofix Ag      8,256  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11AA1CE5-74F0-4123-8033-3938BBEACA2E', '02856C8D-4882-4B13-B61F-57B59D7550D7', '4602565013707                       ', ' 200  /  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CBA1FB6F-773B-47F6-AB17-1FD8A55653D5', '0D7FDA49-019E-4E56-BF0F-D5757A9F64F4', '6941762681127', '  5500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3166C874-1E29-4C3F-BDD5-EA4B9CE8337B', 'DC961E63-F5B1-40B8-B22E-493910763A47', '4620760951761', '    C   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('134E1DA2-99AC-4018-9BE2-74E9C35BF5A9', '65AC054B-8DC5-4819-B248-1952BBCCCC99', '8806695013811                       ', '  100   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1E97830-8914-427A-9E62-6B77F6791B9B', 'D11B1222-D25A-4A89-86EC-25D38848AA72', '4650069780724                       ', '    /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6898271-088F-4903-90D8-C5EDBEDC69BA', '989D27BB-1401-4FFE-A6E0-6AC6B4CF8702', '4607023329154                       ', '    10*10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C03ADCDA-E37D-4F74-AF05-097446AB2423', '372D4393-3800-43F0-8E74-C5C67AA3AA1A', '4030041000161', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09BDF0EF-1169-497A-9EB7-0F46BBC45CE5', '63C3E256-8AC4-4E88-A66A-63DF5F100BBD', '8585004503006                       ', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49477F71-C8E3-4ED8-B165-B3369E685F8F', 'B4924BFC-5891-4102-A007-85DB07C837AC', '4607131040309                       ', ' 2/ -  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('438CCF44-3232-43AF-BA5E-8E5B7FC9E95B', 'AD61DF2F-8FE5-4574-BADE-0B219F08888C', '4605962000202                       ', ' 15/ 5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5752604C-4123-40A5-969D-AE11BE45B905', 'B210D695-7F30-4865-BE97-2F3FCE4F81D3', '4041336800045                       ', ' /    diagnostics 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDBA9E2D-A3AF-4E88-93E7-AD5CD568C812', 'F36FE244-1749-4F69-B1A8-516B9EA6D15B', '8718951098756                       ', '    12   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19C32CFD-0ADF-470D-BF9C-60861BDE28CD', '9CAD40FA-827C-43B9-AFFC-2D4B89B78DB1', '4650001689702                       ', '  - /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B50230B4-A414-49CB-874A-A550D8886EE9', 'C5990D8F-0D1C-4597-9FD7-BD30C01E89BE', '5700666011581                       ', '-  -   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB78E739-2050-4EEC-8AD0-8688F0CE143D', '02C48BEA-E1E0-436C-ACCE-A1196C0759B4', '4607091483451                       ', '  6060   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1888C182-5D0E-438F-8682-DD56BCE3F36D', '96D5C61D-C548-48B5-8D0B-75040A99B67E', '4607102855925                       ', '  /    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C7A3A2B-E9CE-4BE2-9490-95FB3F2705E7', 'EE42D5FD-CB88-4B56-B6ED-4F3FB1B3D8D3', '4607172376306                       ', ' 6 600   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CCC83AE-4E6D-493D-9E0D-DCDA8D897930', 'C2A22AA1-5396-40F5-86A8-15E10EC58D52', '8901302092149', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E735A25-AB39-4278-A72D-32AEEB4288F1', 'D2D4F6E7-C6AE-4AEB-8E10-D5332FB9A109', '4607010248109                       ', '- sos / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F93FC515-C06A-47C9-91F8-429C583FF262', '5EE9941B-EE62-4670-AFA5-0A159EB86C96', '4600689604788                       ', '  250   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9450857-4A65-4DA1-9E38-DF4889A5247E', '6DC6A21B-B839-44AA-8B14-8DB111C4B093', '4627129213355                       ', '   (25 %  "") 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37B60C6D-E194-45B0-964E-E3E6850C261F', 'CDC73E6D-6A59-4A37-8735-F2904403093A', '4670017924680                       ', '       4,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59E708F9-A111-4B33-A800-9B7AA4CF784E', '15CCC9DE-537B-40EE-AAA1-5C81792033D5', '4620760951754', '    C  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E56C951-8B31-4E92-9B0E-7C8C442B49AC', '0144D50C-014C-4B8C-BA90-23A885B5C946', '4605738007435                       ', '   (150 %  "") 30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FA27A0F-7908-4733-B20C-83CC404CBDD3', '1161C3AA-DC45-4FE4-869A-F55F66734460', '4620002185244                       ', '     - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9200D299-EC77-49E6-879C-29B2B24E3CB4', '0B61FF1F-2C53-46A2-A57D-B6516BB9528F', '8585004502993                       ', '       30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C2EE5AF-44D2-46D7-B4A6-C9A5297D4835', 'E6D6BDC0-E782-4709-8A80-524DA078DA55', '4607174437265                       ', '   /      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF7E6C2D-223B-4B8B-B31C-EE79C60A483F', '692B860B-2C33-4427-8E59-C6011251A610', '4660005620212                       ', '+    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43E0D72D-167C-4499-8739-3454EA329408', '1630D33A-F357-439F-93FD-DF8B94226CD0', '4680007632914                       ', '   60x90 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05425524-5D03-49E9-8466-4253D153C54C', '6A6CF27F-4016-45E5-A686-2709A4D689FB', '4607102855932                       ', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('706FD39A-DF74-425F-AA04-77F6B901B7A0', '4B5AC702-D3DE-49B3-9884-35E907EBEEAA', '4603728320588                       ', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FC85EE2-3B0A-4F1A-9E27-753D51BDB58F', '2A7C44A3-9ABC-4132-942B-E843B94A6B1C', '8585004502986', '     / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7647A81C-D293-49F7-A19A-F176CFA046E6', 'F8491134-879C-4250-97FF-19E842534DD9', '4650002438989                       ', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B84C002-4C37-4F8F-8AB4-C0C95E2E99B7', 'D9088628-115C-421D-AA03-C647147159B7', '4627090498850                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8416FA2E-B9B9-434F-85B0-936011227B23', 'AF9300EA-2165-40CE-B571-6F4FFB56699B', '4607011667138                       ', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B28CF958-EAEF-4ADB-A61E-2289789AD4CF', '5A92EDBE-B7BF-407B-96F0-34BA5939CD96', '4680018496864                       ', '      1,01,4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('420EF576-E051-41A0-B791-543649801A8C', '1AD61243-5782-4E0E-BDA3-B4D531ABFC8A', '7391899823980', ' /     240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACFE8CE5-674D-4422-94A1-81C10136816C', 'A8BE76C3-14AE-4B52-8ADB-C7FD936468AC', '5700666007508', '-  -   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3CAAC5E-E8B1-4CB1-83CD-FA74ABFDD4E6', 'D0AEC495-FDC0-4BEA-BE57-598F2A1F403C', '8904102204347', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('424A233A-5178-4B30-AAE9-BDD99E2B7036', '30C2C359-8813-4589-9CC4-D976125B735E', '4605077011469', ' 20  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B38BD67-3798-4023-9146-DB239818ECAD', 'A419CD7A-B6CC-4BC2-95C2-F9E0CEC43F7B', '4680381010568                       ', '  45x29  5 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFC08B1D-270C-4939-821E-59CEAF81A150', '51EE304E-CF42-475A-A862-796836BEF7C3', '4650001798114                       ', ' 03  /   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F04A71D2-FEB7-4550-9156-007D979BC068', '84BC1D23-9B9C-4BD4-BFCF-1974C9185E53', '4607102855949                       ', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E48EAAD2-2497-4BD8-9C3C-9B3EA2F31D86', '1D17F04B-A146-458A-9B6D-DDBE56B4EFBC', '4607017264553                       ', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC31497F-861F-4C0D-BDD1-F69F8374C16A', 'C24BF98A-3EE9-430F-BB2E-B9BAACF03D47', '4607017264515                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DEC9574-BF6A-4338-AFE3-396BE7199AC5', '10DB89A9-7348-4B95-8194-A86F28C36332', '4607071772834', '   60 /    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('426FF0AB-1E19-4A0A-8CFC-EAB3DB7290FE', '486D9161-4AA9-4429-9827-B80F45800850', '4607136210042', '    240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDACB8FA-9C11-401F-B07A-D86731EE3A99', 'CE14EE59-CB1A-4CDB-B767-1C641FDACA66', '4607061507132                       ', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('056B0D07-8B6C-4682-923B-8D74EA1C792A', '5D7E569C-74F2-4767-B84E-8A12D465C644', '0016401008217                       ', '   /     125 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E66294C9-8CF8-4EFB-8B81-D9945E39D622', '44AFB8D1-83AD-4F4A-97F3-CA667C83662B', '4607029296061                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBF03DC8-79AC-4BE3-98FA-53ABB71CEEDA', '0D4084E8-30CA-4033-B47B-64F310249492', '4690419012235', '   /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CEB6099-5830-4895-A42F-EA18525F3CDB', '3DDAA7FA-0F32-486D-AAFC-886FED4E3949', '4607017264706                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8750C7F9-5105-45B6-ADD7-03120EF2262A', '20295217-BA10-40C9-A141-4B5D31BD2557', '4607131043836                       ', ' 50  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CE4D96D-FA9B-40F0-93A4-55EE3800D36D', 'F3BD74B5-9D9D-45F8-9C66-9BE4FBE07D4F', '4605108006006                       ', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6268D1E-B8AA-4D3D-8573-33823D6C479A', 'B4E50DC2-E8E3-4A84-9A8B-7C9949BE18F1', '4607102855918                       ', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C2A74EC-B620-4AD6-938F-B76DD12E90D7', '67FC4106-D30E-47A1-B5DC-CC43F7E9B416', '3574661161426                       ', '  /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('739F0763-C9B5-4D06-9302-D3B0B8B491CD', '8FEBADF5-631A-4728-B78F-482399CFD0D9', '9088882428229', ' 300  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCF36A3B-23AD-4AF3-9B90-CBB27B9FF3FD', '43D8DBBF-C5BD-4895-AFC9-6690BE5EEBCE', '4600286103783', '    0,33', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B5ABFE8-6FBA-4AE6-A4D7-22B0A21E8BE1', 'B430D62B-EFEB-4DCC-9F7E-0DB71A1A5974', '4603726763288                       ', '-       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E642BDDB-72AA-4F20-BBCE-8AA8A211A21A', '820090E6-0427-4937-B16D-12AED45A495B', '4605086011375', '  105   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBA46B70-1AF4-44E3-8572-EC45E0EA2878', 'D7268167-480C-4CBD-9D04-8D04508D85E5', '4650001797292', '     7 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9A60A27-55DA-49F3-BC7B-7378E8AFD814', '7C322A25-0B3A-49A0-B217-57F0C181A252', '4604060991825                       ', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85A938B0-977E-4BDD-998A-FFB0A67DDA64', 'B53FFB7B-ACDB-4582-9ACB-1EDDB207094F', '4607163095827', '  950 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39F71391-E2D0-41CA-840C-FE504135127F', '9D594E1A-2301-431D-A02A-C4E6085D919B', '4670000790087                       ', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C06F3602-3CFE-4AAB-B6BB-57C2F984775D', '8D010562-B40A-4BD4-A5FE-89E2BC5234AD', '5903407028040                       ', '  - . 0+ 2/804', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('603F7686-E1D9-49AB-8AF0-9C53BE3EA489', '924C001A-AAE8-445C-AB2B-1215B10143CC', '3337872420696                       ', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22FBA13C-07AA-435D-864C-191609B24361', 'EB1CA34E-438C-49ED-9917-B7D485DFA41A', '4620760951860', '        9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65DFB395-23EB-4B54-99D9-40192642567A', 'D379F703-BE80-4734-8BC1-04116A410659', '4603907005350                       ', '  0,13  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('839F0AA8-8949-4CA1-B1CA-7BD8901BF7C3', 'B88062A2-ED56-4F3B-B5F4-39B04EA7CAC1', '4627129211108', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C751A5D-1368-4A8C-9F50-2EBD61A3A900', '1956DE4E-04CF-4031-A0AC-38DE13766CDE', '4631140314816                       ', '       0,8  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E2C059D-5CFB-49D1-B296-05641DCD5FBA', '49E18687-E673-4C02-B89D-F26CE75A1B7B', '4605126006026                       ', '   2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F340EA1-146A-4448-B282-AB3C4B5D5048', '4551343F-A22B-4605-A16B-32B8D5CE1B76', '4640001380235                       ', '      10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('060701A8-496D-4D3E-B639-981BE9578EC5', '540E3AED-4D3D-4EDA-BD9E-2308DA6F357C', '4620760951730                       ', '    C    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('44F10B50-E871-457A-A491-CF1393469B21', 'AA4A4B64-B29E-46B9-99F3-B228A8297018', '3499320007634                       ', '  0,5%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84898457-38CD-456E-B092-1E40B2FDA475', 'A4F0AECF-0E30-4D74-A764-4502FCB2629D', '4751003441104', ' 3  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7AE69D1-8B7A-4A71-9B17-AA306149FB93', '04098472-C435-49BC-B585-E681E201E00F', '4607101200146                       ', '     .    6./905300 260', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FE9251B-C06B-45A0-A5E5-0458AC51B1C6', 'D4C9AAD9-17D3-4C20-9F5F-76070DA469C7', '4751023292021                       ', '       /  0+ 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6B99D47-77E1-4CA6-9989-3E86F4FA2545', 'E008F619-7022-49E2-9F48-434DD1BB334B', '3700281702682                       ', '     40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08BEAC0B-8A87-4ED8-9D10-6E378DBB188A', '7CA01A6C-C1C2-43A4-8217-634592F169CC', '4601969008135                       ', ' 1000+50  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC0B447F-A6DE-4931-B11C-AA8A3C359E43', '73A4A44B-002D-4A8F-B649-201028621548', '4602424007908                       ', ' 40  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57EBAAB9-F002-43E4-9056-5738CE12D0C5', 'EE7E912F-21D1-4184-85B6-29FAEE03C105', '4680007751165                       ', '  6090 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B5C98C1-5913-4C72-8C88-257E276C28D7', 'E13D6D7A-B028-459A-9E8A-F606D3C0268B', '4605021001836', '  5   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4C00612-B4A5-407D-A037-7D7DCA5A1B85', '4ACA969D-99FA-42E7-A4F2-41DEA16AC85A', '4751023293974                       ', ' 7000 aura    . 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D83B7D13-2C88-4542-B81D-BEDEAB9DDB9A', 'D7992103-854D-417C-AA46-9FDED67CF608', '4650002438941', '    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CFD2F8B-72CE-45C9-A258-BEC6837CAAD6', '062F46CD-833E-4203-8732-19117E9C8507', '4607011664878', '         75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1A6EB39-E1D1-4E28-B486-95323387FF32', 'E764170E-09EB-471C-8F01-FF974C543F11', '4620020891646', '    // 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50A228E7-CAF5-422E-ADA7-E4C2F1FB0207', 'FC1D8748-C2CB-407C-85DA-F728281173F3', '4627129213348                       ', '   250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF9AADC3-B58A-431E-901E-8C78A1BE7243', 'CA858A06-557A-4CA7-B4E9-440D353C62A6', '4607155210078', ' 0,15%   3 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C39DEBDE-C2F0-4DC1-A0EE-1A6D1D5F158D', 'E5D2750F-DA5C-4EE9-A4B7-506521A9E512', '0083078006976', '   spf 15   4,25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ADC5078-164B-4960-AA99-F5BD081C777E', '518C4B78-7F82-407A-BB53-99FA18F21383', '4750283000018                       ', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1A7C5BF-BA7C-4B29-BF0A-C16FB281C3B1', '766D346D-9587-43D2-A7E3-450E92F47CE5', '3831016750019', ' BREMED BD 5001 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A3BAF73-CD01-4D50-898A-3B5B2FDC56C9', 'DE6DF0C3-F762-41E4-8FFE-BA67173E23EB', '4601969005226                       ', '- 1000/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB13C648-81D5-4BB3-9194-857A52B713D6', '61E2D806-D87D-41FC-BFF0-53C0C8515ACA', '4640000901073                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B8920ED-935C-4C5E-A10B-E17CC6A4DF30', '59D6B1A3-0E71-4AF8-88C0-909A5300B55B', '4820160034174', '  /.   40+25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14E0A765-E357-4793-AE81-EBE2B11645C7', '532DC556-E6BF-4A23-BDFB-06910768C7E1', '4605370005011', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7AE1151-8C88-41A2-BAF0-DD6B0BD62AA7', 'A95DCF90-0250-4BF3-89F7-3B19DE2AC4EB', '5907996093199', '  .    25g 1,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDF349C3-5F71-4F0B-8E28-FDC476F825B1', '64C45DB7-D159-4E94-A7F2-110BE74B21D4', '4605658195571                       ', '    /  19557', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92E8964B-D9CA-49F0-A7D1-1EFACEB03B60', 'E3D002D2-54BD-49B1-9DBE-42E2FF8FB5AB', '4607055563373                       ', '  -    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EF1FBF6-451F-48AC-9D3F-BE19BC962D34', '9B3260DA-3FDD-4F80-A05C-7466C62DE106', '5021265243969', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A448198B-057B-4B4C-84C2-DBFABDE1FA56', '4DFE4830-F008-4592-B8E0-46966B18AD15', '4680021330025', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F0935DD-EB0B-4405-8445-FF56AE73FA9C', 'FFBD20FA-3740-4667-A674-B67AFFD38943', '3582910002796', '  10   30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D364F788-27AB-4770-B706-714210241B64', 'ACA80785-90D5-4276-B863-7CD91DF5CA25', '4607102856076                       ', ' /  /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79FBC2A1-4397-4C6C-8D4B-F3065FECD07E', '31F469AB-3D64-4319-B320-F732DAF83F46', '2910029290291', '  8 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43A1AD09-9964-4411-B269-BA5377673A32', '0A37D13A-505D-4AE3-840F-751A90D5A0EC', '4607017264638', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2125739D-06F2-4C1F-80E8-50325F376F37', '3EB0A988-92B7-40C8-B99F-ABAF4260E890', '4607051798212                       ', ' /    530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CFF75D0-C1DC-40E1-8A81-EBDB6410B81C', '38C7E34D-8FC1-4036-8D49-37A0D31080B8', '4607153456669                       ', '  500  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('858E3E7A-66FD-4308-B9BC-EFA2B1B9869A', '34E537DA-474B-48C8-B217-88A303C92C0F', '3337872418785                       ', '     400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFEE8CE5-9531-4FD4-AEC1-703F2DA37043', 'E31DD25F-DBD6-4822-B3DE-DF1DAC3A091F', '4603726763035', '-        E 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('078BAF77-0A10-4C44-825C-066C8B836DC8', '3A2DA016-278F-4FD9-9974-06F13133419B', '4605658195465                       ', '   5070 /19546/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12A4DB69-EDC3-40BE-8FD2-70C81C0313A3', '08C71923-DC13-4D91-8790-9026D1344C8C', '8906036182524                       ', '    .  / 4 ./ 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED3242EA-3CD1-41A9-AC6C-F8717A3ABEE4', '574A29E4-61D2-4DC8-9161-262D09BCC928', '4602849001536', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B9900CB-13FA-4D97-A99A-F6E1C04A27F7', '596A843F-5587-49D3-B0E9-FF1C23F1F362', '4823060800085', '  3 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A1AC7C0-5F54-4C49-8171-10A5AD09A80B', '609E633B-0A4C-4565-ABB2-9B4EA7D59933', '8584005716958', '  600  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B147C050-15F2-46BA-A1F9-193795D32BEF', '218D1827-15A9-45E7-BF65-FF1344D5F6B8', '7322540369397                       ', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FD0814BA-CC44-48D8-8B0C-E8774432BCE6', '34ED1DF8-0267-4337-919C-6FB7191B5C53', '4823015914683                       ', '   /    /   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9EF9674-1011-4D23-B15A-4F2548D41E60', 'AB8C0C11-5BB2-4B10-9544-72E802FC60A1', '4627074843935                       ', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61821A57-2D7A-4625-BB66-8E695E4DAB32', 'C1E6C0DE-ACF9-40B6-AE1F-195C89E0462E', '4005900012883', '   / q10   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58AFDEE0-6604-451D-93F1-1AFC29C7CA6E', '02D33CB9-0479-483B-BFA2-6BA15A6220D5', '4606677009566                       ', '   -   / 175', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C52D75E-4364-4E97-A96A-348012C67573', '1FF4EE61-F44B-421C-8EE9-1D3961E4773F', '4607027213572', '  -  0-6  11709', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43FF6E77-3AE4-4137-BC26-C0B8D9CD699E', '4466E04A-D5F2-4B56-92C4-78E9F5C33A8F', '4607017264560                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D2F5840-64CB-4EB8-B0A6-4BE109DEF269', '2AE0D423-0A40-484C-BEFF-5C9007F5A2BB', '4607013793422                       ', '   - // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAC43712-4A19-4D07-85C3-0E19A6CBF915', '6DB336E7-097D-4D8A-886B-176DA58B5C04', '4607027410032', '    / 1010 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCAA30EC-09A6-4146-8F1E-848C136E484D', '6E069C61-AA49-4CDB-A7F5-9B5C37A877CA', '4607086561546                       ', '     /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26239DD3-FAB2-4163-BFE4-9A06F10C9080', '330E32D6-AC9E-45AC-8271-2F53E82CF17A', '4032651214891                       ', ' 250  -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('024D7896-4675-4976-9411-F4088755C3DF', '3184FD8B-6563-40CD-81CD-332E2F9192F8', '0027917101194', '-   -  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7A21885-AED7-4C97-892E-EE55E1DE3A00', '9EB4D14C-3B43-4C2E-84D7-411F624D151A', '4036534474204                       ', '    / l 45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('862D5A3B-4E4D-4590-96E1-47D0AF634DD6', '2D7D244B-35C1-4D05-8367-68865234B6EB', '4607172376214', '-     zn  7-14  900    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('858B6EFC-0596-454B-AA94-42CB5C35BE85', 'A2488639-CCEF-4C2C-A747-AB22ADE89EA1', '3838989559113', '    27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22286F75-0181-4013-811B-9D930198DDC1', '3F78A1DB-A7F8-4027-8B2A-B817A9BCC197', '4605126005982', '  / 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BFDC118-5FAF-4DC7-9D9E-1B57798E348F', '1D5EE89A-657D-4FB8-A112-C40CE530B252', '4751006752702', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EFE763CB-220B-4F28-AF58-EB1C4909447B', '95308083-7F41-40EB-AB47-E1936937B6AA', '7613031583348', '-2 400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D2B9647-1A3B-4D3D-A359-E9CDFBEF68AC', 'EA2FD5F5-2E27-4B3A-9EEC-255F0D50FFDF', '6940079069680                       ', ' 7 days  / /       1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FDF6CDA-408C-4997-A7FA-E7A0081825DB', '8F7A1A9F-68C6-443C-B771-B2CACCD5FC2B', '4627129210804', '   - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6E30F2F-FBD6-45FB-AFEA-93CEABA1E1DC', '43BC84A7-B01A-431D-B1F1-90FF20F48FD3', '4260412324767                       ', '  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAFEDE34-2D78-46E1-9694-2277850A80A3', 'F48629C3-5200-41A9-B9F7-ABD578E2177F', '3504105017200', ' /mustela/ stelatria -  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E6BB389-C0CC-45EC-904D-B6A86CCA4E1C', '1AA308AE-C0A6-427E-AEC9-E76AA45FCF81', '8901138506384', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A6DA588-C029-44D6-AA65-8161AD01FC38', '3894A287-844D-45DA-9E5A-7BB994D672ED', '4650001795373', ',   - // 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BA0BA02-18DF-474D-85AA-570195A57DBB', 'E3211F69-80A9-4F1C-8831-203F76BC46F0', '4610010010201                       ', '  / / 500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7A5DFA3-D1AA-4434-BD19-1FA2F8B1664D', '865F3A4C-63EB-434C-A880-D9D79203500A', '4607015591279                       ', '  2 2 / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF98CC10-AA46-4DA6-BA58-16F204407F0C', 'C7817BED-2033-4FFD-8823-C6A72AF31EBA', '4750283006317                       ', '   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F568641-D51B-4B4E-BF2F-BFA13B4A2610', '17FB06A3-4824-42A3-9A01-0EE6633083B8', '4601969008104                       ', '- 50  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6462A4D7-139D-401C-AFBE-63AE0D804048', 'DD45C1C6-67A8-481C-8A53-E7088DB9807F', '4605658230920', '   /23092/   4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80983BBB-629C-4A4E-9773-A3138DA7B607', '1C09499C-8229-456C-AE2B-33C9837CF95E', '4660010100341                       ', ' -  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC54D88C-612D-4AF8-92CF-91FCB88C522D', '41B0D7F2-F6B7-49D8-A6AC-E8BD9D7C01A1', '4605126006019                       ', '   2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C250F133-EB26-4C50-9DAF-28A466358665', '320CB68E-4A8E-4C49-91AF-0A31D98A0B55', '4260107478058                       ', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20D2DA9C-ED55-4AA9-83E8-E59F4894E290', 'FEC702FB-FCC7-4B21-84A1-F620C3A842BD', '4607174431546                       ', '    10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB84D24F-510F-40AC-8B94-FC0AA8E6C8D6', '648B86C8-5C2F-429D-A234-44347205021F', '8712400360029                       ', '     1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3767E3C-760D-4EA1-95EB-46D1E936FC0E', 'B3164143-BFE0-4CA9-B401-E074DC3B64E5', '3337872410765                       ', '  ,  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C078AD08-A6A7-4334-BE92-A30AA267BA3A', 'C1595DDB-E92E-4DBC-B37C-5DCEFFEFCF71', '3337872414039                       ', ' r / , 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69A0C19D-3E7E-429C-AA9A-1D8A501736D0', '0A82FB03-29A8-49F8-AC2A-D483A07A402F', '4627129213232                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5898DD8D-D3E8-48A1-A217-F4661E14D9DB', 'BA212D67-7FCE-431B-822A-BF0097B7857C', '5410076893423                       ', '     75 3d  lue   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA22D840-CDBE-4BB3-8027-164A87DC8202', 'C62763E1-BDBD-435E-A555-29F4EA1DC6DC', '4603907004292', '  0,18  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05321C89-0BAC-4372-80F0-0987C42EB52B', 'E5E6D345-CEFD-4578-BD65-C5DAB0AB3E14', '4601669000477                       ', '   60  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB21D9DD-8D5D-401F-8F57-33C0EE75B7BC', '9BE5FDC4-4CD6-4CD6-8FD3-088F49DEE42B', '4620760951259                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9E5B808-153F-4D59-A2A2-06F5FAE4B5CF', 'E698A96E-5BC4-4C2C-AE2C-00B7ED915BB3', '9002260019861', ' 500+100   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ED398E5-1195-4BD6-99E1-04B7FFDAEDFB', '17258FEF-9C1C-4865-AD5B-852DE8A70723', '4607014000147                       ', '    14      / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('480E69A4-D319-4471-A310-E6416BC9FA7B', '0BED4DA6-4FF0-4668-9298-28061AE6950F', '8710103578550                       ', ' -   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3D9A342-584D-4622-9E3C-4A3832062606', '4C4E97FB-DFAB-49EE-B90C-521D399A943D', '4607019390458', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0018534-C511-49EA-BA89-1072044EFC50', '0837F67A-D758-4791-82F8-321CCAF31E3E', '4607172376269', ' 110   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D30B907-7F96-47AA-9BC4-12E5D401F29D', 'E549D6D1-33B4-4636-B9A1-8FC1C2E8D9F9', '4607051795938                       ', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDE68EEC-848D-4371-BB04-B51988CF8C63', '9A791DB2-CAE6-493E-9831-0ED46F755D4F', '4680007751196', '   6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('418FF72C-B75C-445D-BB8F-D7A5BD90F0C0', 'AB6B500E-81CD-4A63-9D42-46D12C6121B1', '7622210506009', '    9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35B1327B-8855-44A7-A355-114B5452DAE2', '94E26BBF-245A-4D86-BA7F-068E61205BD6', '4620764311851                       ', '     3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31D20987-BDDA-4D18-867D-9CCB0EF296BB', 'B7DA6CAC-1DD9-4CD8-9BA3-9CE4BFBC8727', '4627113836102                       ', ' / - 3/-604', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F08F4136-3911-4893-A43E-2D845B1C03BB', '5524A199-2E7F-4A2A-BECD-F7957927D8EA', '4680013246297', ' 100/ 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('442082CB-5D7B-4EC0-9ADA-154B4DA6CBC7', '0326977F-DA3B-4626-BC1A-A4E54FB404B5', '4670017924963                       ', '  /    270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB3AA952-E810-48EB-89AF-C97EF7B01877', '1C27C5C5-416B-4397-A905-A2088C720D01', '8901302123966', '- 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9015944-2748-4BB5-8D44-BC491881FB52', '7AD3849E-87CE-49BC-AA16-8A99930D5929', '4670017926721                       ', '    /   / 155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D91DB521-6AAD-4E74-BDC6-EE5C4FAB9197', '2A61BC51-FB30-4E78-A691-B3F47E73E39D', '4607174430563', '      //..400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6729CE1-E5D9-4A89-914C-506A93D48019', '563B367C-7FB9-4C6B-9405-43237E6AD113', '4607174433939                       ', '   /   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5349791-7DC1-4B31-88DE-9AB6E884A071', '57588E24-177C-449A-A163-62BEA3DFCDD7', '4607174433908                       ', ' natura siberica   400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2B844BC-751E-44A4-8C0C-9594CF1E80B0', '9105D3EB-6E62-430B-AFC0-26A0DE077B55', '4640001383496                       ', '  -3    350  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B46EAE90-E29B-4809-9798-15C5ADA1E852', 'FC75AD7C-79DD-4DD1-9085-D4141F60525F', '3838471022002                       ', ' bebi    6  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BF19DA0-0CF6-44BA-806F-2003BE6C3B13', 'B5183BD5-E962-4A57-A1C9-53F2C667371B', '4607071772698                       ', '         20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7A84BBD-834D-44C7-9519-9802366E5E60', '309B68E1-C792-4228-A288-533939293B52', '4607102856069                       ', ' /    ,, 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0073C93D-4D47-4BC3-B642-B2009FB9C92A', '86CAED0D-62A5-4451-AC61-6B6E430B8522', '4612738370018                       ', '  81 /./  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC01D419-FF1A-4675-A43D-DF8EE7830EFB', 'EE8EE54D-BF47-4D3F-BD69-A7D9F33BF11C', '8032578474510                       ', '   / /.-  ./ 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26E039CC-4D71-4B70-9712-2AC8CC15BF4A', '8C8FCC98-D508-4AA9-AFB3-807040D79665', '4016369669143                       ', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA240F47-8547-4650-A024-EE2176B4A508', 'AF94B138-1D56-4F15-9C93-14EEE26BE1D8', '4680013246839                       ', '- 100/ 5  10', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25B8E1E4-8AFD-4054-89DC-0C301CD68CB9', '276C868B-A325-41E3-80DC-56A4249E3AA3', '4607001340843                       ', '-   36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39DA88BC-5747-4F36-9FDF-B15195D32A46', '2EE9E893-E1CB-48FE-A2E2-77D96AF4DB63', '4603380001061                       ', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6447EEB-A352-48F0-B7A8-968F3B93CD67', 'F8740955-2D01-4784-9A56-7B648E89A85C', '4606453043333                       ', '  hair lab - /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83B72801-24AE-416B-9F6E-193A76B4EA91', '446019FA-51DF-4625-AF68-69BE00418F94', '4606453043326                       ', '  hair lab -     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBE44152-D706-4BE9-ADD7-6F1D337E8050', 'C4FA1B63-4ACD-4520-BC35-7C6B8D9A44F1', '4607104130372', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('360C0528-316B-4963-839A-4004CEE3BC72', '611F882F-EE1E-45BF-B65B-80AC4FE8A91B', '4605086014437', '     8x300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CAFA1F2-F49B-4B54-8545-0A51F57D715F', '8F823557-F178-449A-961E-B8CA6AB1064C', '4008600211235', '      0-6  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4607A69-99E3-4C82-9D0F-4E136BDCC08A', '53ECCDE3-7BF7-4A3A-AF1E-4B07F34DED50', '4600209009758                       ', ' -3  1  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACAA20EB-988A-4886-8C9D-F1A08B5C9D9E', '5B17FA02-390F-4B14-8191-D1D93D0FDD2B', '4612734910263', ' 101,5     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEFB3141-60B5-4B7C-AA2C-A4CAFFE8D91B', 'A486DD5B-DA1D-43B7-BA97-4D905F528604', '4602435006716                       ', '  3x500 ( -)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2A248D9-3364-420A-A3EC-D4BA30172175', '5C06B1D5-938F-4240-8B61-462905FD7A38', '4627090498119                       ', ' pellesana   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB982CE6-214D-407B-8BE7-2C01B8DAE8FF', 'BEBB5C77-9710-46F9-805D-A5EB8F67C92E', '5413787006441', ' 50  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('237EC17B-8AE7-4ED0-BA34-C0326D9657C2', 'AA0CBB98-C114-4734-93BC-9EE4F6C72CAC', '4600702062687                       ', '     50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('990B38CC-B726-49D2-AABE-9054FE34318C', '8495DE58-1BD4-4891-B84C-BE74B68EB3F6', '4650069781660', '     /11007/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E0AFE93-68B2-45BF-855D-6214F12E7920', 'BF2E6FED-35D4-4C10-94D3-252498ED0B16', '4602565019044                       ', '  0,5  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE9EF1B1-E689-40ED-B513-8DBC99FE0608', '502F7A42-1D2A-4AEE-B6B6-4F35CD4ACD06', '4605370003246', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B7C02A9-D41A-425E-BA91-D2B57D018605', '13E394E3-CD5F-49D2-8AF5-6FE4743DDD9E', '4630007837208', '1000       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BD65CFA-70AB-4790-AB36-B48D9643B88A', '8126DA54-8879-409A-A985-A36E71163517', '4640001382215                       ', ' 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2782C3F7-3962-46D6-ABD3-E5A20E1B75AB', '11F9D634-0646-45B6-9A48-4F1D20D98043', '4607101205196', '  /13837/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E80AC595-6D47-48BE-AC5F-3AE6F84B25F6', 'D82CE978-06FC-4ECA-AC88-4C035FD34A0B', '4010439201257', '    /   32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABDC7BCC-41C7-4E3E-BA8B-8771F1A406E5', 'E7D34F1E-3509-440B-9664-4A2C9E3643FE', '4690655012341', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('354A093B-9C97-4F44-A8E1-74E6D2B3B950', '4BEA7F85-C9E5-4901-B05E-CC5219C350B0', '3800002303959', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0185F3C-10A8-472C-853D-8DF3CDD622DC', '2237475D-091E-490D-98DA-9ADDDC352CEA', '8001345036022', '  / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EF3D675-C5F7-4D44-823F-847CECBA630E', '19518F4E-2268-4283-A262-408CBA1FDCBB', '3337875583589                       ', ' b5  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17427522-4826-417C-A57F-B87E5EF9070C', 'BF6FD28B-9881-4F24-83C7-0C593787BA21', '4603014007735                       ', '    6-11  73   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2AB10EA-0ABB-4134-82C8-16D929A3B8ED', '75C79467-0173-4471-9B57-C7BE36768F57', '4603988014609                       ', ' 1% -  25 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D584532E-092A-4BBC-8698-B765A0F58258', '2893BBDB-5B52-4963-9DCA-F5283A05A96F', '5036519000953', ' 6  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0994E97B-1E6D-4354-9634-A256260326D2', 'B7FE6F0C-5E94-474F-A185-7FE3DFC8BD78', '8030009502030                       ', '  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('734F983C-E24E-42B4-AA7B-FDEB9A23474A', 'D4D79452-FE8D-4F0E-96A1-A20EBF57C5E7', '5904913544109                       ', '     50,0  136', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EC9DF2F0-E7E6-4E9D-A29D-A47D4FB94FDF', 'CDBF9267-078F-4F37-A25D-89B6AFEFA91F', '4600697101538                       ', '  140  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F69917DF-F07D-4FE4-ADC4-650E64127291', 'ECBD8F57-94F2-43EA-9C5C-C901977D3F06', '9120029750371                       ', ' .. /manual sv 609/ / / s 50 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2432C2E-135B-461A-86D6-DCC390EF9424', 'D33C2320-9674-4D4C-9404-C717BE2A59BB', '4601164001337                       ', ' 3%  20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0AF0DB2-D86E-4AC6-AB68-7FA1567E5168', '2F97F665-4988-44EC-9BE0-582D4A3ADDF9', '4607083728416', '   2,5x7,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1D4E004-6208-41D1-8251-514C87A0D66C', '12BAD033-171F-42BE-AA00-34B50812581E', '4607010089504                       ', 'Filorosso      40/70 den/ 1/ 4//velour', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCD77B14-C012-4FAB-8FD1-E6C08B14FAD4', '931556BF-AEAF-45F7-ABBF-023BB58C48B2', '4610017194171                       ', 'Filorosso      40/70 den/ 1/ 4//lift up', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D10A7EE-8835-456C-B6D3-96DCF2ED8868', 'DF33A49C-9148-4D04-8BF6-23E838172DE0', '4607010086978                       ', 'Filorosso      80 den/ 2/ 3//terapia', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61132079-3179-4D8D-B7D1-748DAF70C7FF', '802271C7-66B8-4A42-876A-E525516BD756', '4680381004147                       ', '  1010 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1452D1D3-666F-4C6C-B40B-03E592FF445F', '0B2A5DFF-4665-4517-B991-AB65530C798E', '4607025201274', ' 0,35  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBFBB3D7-17B2-4A28-81DF-8A6DDDB48E7E', 'CE57B1CB-AA3F-41B4-917C-3C118315D2B6', '4750283010048                       ', '   . 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47653ED2-F959-476F-BCE4-DBBE5E73D117', 'C311912B-EA39-4100-A216-16282307A5F9', '4603988014142                       ', '  200/ 5  100 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53F964A0-E981-468E-9A86-DC180A53B0BC', '994F9473-92E3-4553-B6B8-66F44A7147DD', '4607027218072                       ', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B26CC23-53A3-477B-9A8B-6B392C09291C', '9F1E242C-571B-4AB8-B0F2-8D8194BD5ECB', '4607017264591                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F99200E3-948F-4E00-B0EB-F479B46F3AD0', '0F6F414E-56E5-4F5D-9393-170567C1FE4C', '5000167094930                       ', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F251B33-621D-4447-BBCB-1C715BC601DB', 'A4CAF962-223E-4D04-9508-89E901924277', '2000103611194                       ', '-   owl 0-6/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ED9C846-5B1A-4DD8-A3D5-01469CA67756', '8C0A65BA-2DC2-44D3-8E3D-BC341BA1EF6C', '8030009522205                       ', '       200 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE9922EF-744B-4C8A-80C3-0AC217E98006', '2F44480B-13E2-4551-88CC-E9ABA3400652', '4823002000276                       ', '      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6427986-6A24-4995-A441-6E45358B0507', '4401EBD9-1314-4E22-B707-848BA64C98C0', '4607003111175                       ', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F523850E-356E-4A6D-98B1-C63ABE8D1335', 'EDC50C8D-A52A-4440-BBD2-065D2E19ABF8', '4612613500011                       ', '   2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A1208C8-C723-425F-B4D8-7D3A1DB1AC5E', '7BA7F252-17EB-42CB-9DA3-6EBD2C8256ED', '3282779361330', '    40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D784726-C05A-4365-BF5D-F577BD16CA53', 'FA511BBA-FC17-4D7B-A880-255976D6A66A', '3282779361286                       ', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFE8C10F-7B8C-4796-B39F-32082BC1AF01', '3F1D3E02-82D5-447D-8A76-A431E7D5863B', '4600488000101                       ', ' 100   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9302873-08F9-4715-B5D3-32722A7A896D', '78E7E85A-0308-4162-B3D6-F1940D9DCEB5', '4607010249151                       ', '          / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9F28CB5-8F45-49DE-B02A-70CBBF5C5546', '462A6D42-2625-4D16-956C-B8F037995345', '4607172376283                       ', '+ 6 94   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A589F41-736F-41CF-A854-3AC27AF2CF3B', 'B3BF3FAB-B10D-4AC9-BC1A-CBDEA4033CAD', '4607043670243', '   S-1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB951575-7288-43F9-B412-733A2DAD82B8', 'E5F3DABD-0839-4496-B135-1333CD77FBE0', '4605086014413                       ', '   510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49E16967-0B93-4053-B8DC-CDE14ADBF42C', 'BE0D15DB-A569-4E16-9B19-AECF5BEF9FA7', '4607051797512', ' /   .. /// 530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5315F788-553B-41DF-974A-FEF807683456', 'D68F240A-4286-4CD5-9F0B-21826BAE8313', '4810133005355', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2677C15-9858-4E90-B56C-899FD446D6F9', '4B48F77B-B010-491E-8A1E-17766FB5B7F7', '3282779310628                       ', '       spf20 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15BA0477-3E42-40A2-9AE7-95B14478E58A', '5AEFC2B9-02C9-4E42-AEA8-E1A0F2E1033A', '3282770072365                       ', '   /  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43AA591B-6A10-4187-AC0D-09D0F1E30753', '036F6AE2-90A4-4CA4-83BC-8CC0DD4B6399', '3282770123609                       ', '    spf50+ 200+  spf30 200+  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A4D0377-59AD-44C1-8F73-C513741D0650', 'A1BF9112-384E-4CD9-8FF0-D02E302D806F', '3282779181617                       ', '        2- ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('376458E1-CF90-41C1-9C86-A6467D483730', 'BC2FAE91-5EC8-47BB-92C4-15B3385B3F43', '5029053543659', '    /. 3 /5-9/ 94', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B441F060-4A10-4AF5-AA52-882C85F67D5A', 'F2A50BCA-B060-4107-BD23-3B952E386EFD', '7322540764147                       ', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B0183DB-DD48-4539-B2F7-668044B26162', '2FE328BF-E7D3-414A-8336-EFBC15E63A8F', '4603988014616                       ', ' 3% -  25 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30E15D9F-3DAA-4932-B0AE-10904EDE5714', 'B0B432BB-BE34-4CB6-87DF-F875E2258D02', '4607027217808                       ', '     200 (1937)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DFA1311-0AD8-4201-8EF5-8419597A1AF4', 'F4EF25E4-C5C6-44B8-B4B9-48D37E7A5506', '4751018120391', ' - / //  7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1590C26-D2BA-4D76-9891-916F8799F6BA', '91FEAE75-9AF9-4F6E-A0DF-C95CBD3C2FA6', '4607100621591                       ', '  500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62C19270-8660-4F79-B8CD-D2371DCCF20B', 'F4988CBB-4EB9-4BBD-9249-6A62B42136AE', '4820090052941', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('858C2717-DF94-42D6-B49C-CF3930AAE5AB', 'FFEB7369-9F74-4411-A5EB-B43575141F72', '4823004006504', ' 200  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FF5AB1B-7975-4C53-BDF8-644BD0872808', '6B9DB601-6AD5-423C-8675-BE80D9280591', '4811248001867                       ', '     400   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52E533BD-CA27-481C-8870-CE4D7DF94014', 'CF38B5A7-D0A9-4ABF-B5EA-D3C092E2294D', '4009800004191                       ', '  -     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E5DBBE0-EFEC-4943-8152-450C43A3A93A', '6DE17BD9-D1BC-4C64-BE7B-72E94A1D0E1F', '7891024131404                       ', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46FFBBE2-ECB5-44E1-B5CB-F5890FADD512', '1C44D0E0-4289-462C-AA60-E774CADCAAA1', '8809383001442                       ', '    //  95% 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A30A916C-7B73-4B1C-8941-A38CB9078909', 'AD095601-150C-47E7-B357-CBD604E73FC4', '4627130223602                       ', '-  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DE21413-EF24-4D13-9E42-EB8B2685DF7E', 'BA21836A-70D0-4E78-8D61-BA965FC66589', '4610010012809                       ', '    bionational 2 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DE30DAD-8113-4991-A962-059B906FA27D', '26CC9578-DD88-41AF-8A07-EFFFE912FFE2', '4627129210897                       ', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78D6FA2B-6560-42B9-B473-1CC580384C57', '5292B996-8AD3-4A22-AE17-5F0D75746B89', '3337871323332', '   / / , 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2C03A5E-E0FE-4A7B-9E0A-9E27EC8DAB59', '3E648FB3-210A-4B2E-9733-6DF3CF37EEA1', '4690214211208                       ', '  (  50  +    15     30 )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D05C6CFC-FB23-405E-BF15-284F48B923EB', 'E95FC095-1E78-4848-BC67-3DA0A5443BC4', '4032717000239                       ', ' 1 7     14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCE6D10B-042D-4035-B2FA-F7F0D7798798', '17515425-692B-4111-A948-772E149E826A', '4680381004130                       ', '  7,5 7,5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F29252FA-1E45-47F2-9483-43A1DD001DAE', 'FB05A336-320F-4E3C-B479-E8CA70DE3371', '4605370003468', '     /6-12 / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('079B2260-0769-4237-A3B4-CD7824860372', '459B763A-E3BC-42E1-A029-DF242E2EBC29', '4607131043997                       ', ' 60  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('612D4F70-44FF-4853-9C91-03962A5D104E', '5ED353D6-4644-4F19-9F4F-83AC41D79F4A', '4607100621560                       ', '  500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ECD13AB-BAF5-40A4-80F6-6B010618B43F', '5D6A0E4E-F4E7-4B1F-B1BB-E42B838BAE52', '4606144007552', '   360    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53E7B1A5-6102-4DD8-AC60-F4DECE217AA4', 'DD48599F-450C-473F-899E-28F412DDA72E', '4605964005915', ' 100/ 5  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23D17466-07DA-48C5-AA2E-83F7A65F35C7', '18F4CD9B-7B73-42D2-8E6B-B19B1DCCD9D2', '4605126006002                       ', '    2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45B52398-7FC5-45D6-B3E5-5848E933BB5F', 'BB7950EC-ACB4-4885-9A9D-B8B363F10852', '4680018496857', '      0,71 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F503363-20BF-4EA3-AA53-1B23C6D03ACA', '09E49921-CD04-43F3-A409-4B8496A531DE', '4605310003077                       ', ' 100  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11F62C98-78F3-4BC5-8181-5A2C33AABC17', '81B573AD-72C2-470B-9552-3B91AFA4C85D', '4601164002815', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD58CCB0-57F2-4AF3-81E2-7D53404B2FBD', '3090D3B0-741F-433E-8B1C-A4DA8DD9DD0A', '4602009005046                       ', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FC800FF-FA7B-46BE-9965-91AC79FF93D3', '80276A5B-988D-4CEC-A0E8-6A72C9F6F846', '8718164960376                       ', '  2- . -28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AB29A3A-180D-4A15-99B7-2772BC16FC67', '98A7C906-BF7F-4203-993E-30D7B8219D73', '4640021710098', '   /  spf45+60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('895C6AC1-FCDA-4679-B3EC-16AA34814077', '355E0FE4-5A9E-4AC7-8878-B2EADAAF4110', '4623720904838', '    003', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BE36092-0840-47C5-A485-D7A512564C9F', '79ABB595-5BB3-4B46-9E7D-EA5F5196DB80', '3282770037135', ' /avene/       40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1709CB26-7447-4C23-BF3B-9603E64B97EE', '73EC0E75-E693-4F26-867B-A150A4CE51B6', '3282779047838                       ', '   .  . 40+ /. 50+  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6971C4B-F972-4CE2-8BBC-4D0E458375D9', 'E5ED3C85-A6CC-4525-818B-8AD01630D4DC', '4620760951266                       ', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1A0F1CA-393B-4D6A-AD05-EF503D6FA604', 'CE139435-39E1-47A3-94E9-6BCFC2FBF154', '4620002186609                       ', '  /       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81210ED9-6089-4E00-B3A0-70A468CFD152', '3C7A574D-2CEC-417B-9314-C77DDDAF35A8', '4049500112963', '    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('222D7582-26EF-4C22-BAEA-BDB0D009033C', 'D2EC212D-F19F-4621-BA9A-36910B22CE64', '4614171337337', '    /     500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0B3AB9A-515C-4B55-8F34-4750BA6C4460', '0C046AD3-93DC-4AAD-BE22-BCA7F182BF78', '5391520948107                       ', '    /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA74E5C1-CA1F-4743-BAC6-C8B7DE48C65D', 'D86EC40D-C02D-4B15-9163-E0DEF74390B0', '3282770073065', '-  D.E.F.I.   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('183E6658-0A13-402B-B28B-F38B68A84891', '468167BB-FF19-4967-B7E6-070436B8EC05', '4607017264508', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1C4ED78-C612-472E-952A-9EEA8E3C208F', 'BAEAE832-4D60-4A0D-BDE0-FCC11EDFBD4D', '4605658271145', '     6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('227616C2-5A14-447B-A982-CC4927135BBC', 'DAE02F39-9D8E-4A6E-A16D-096448534C2E', '4607102856083                       ', ' /   /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91681D0E-3ABA-4FE7-BEF4-4472007B3F75', 'A46B0252-CFF8-4ABB-A587-E7A892787EE7', '4603256006374                       ', '  3% -  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB56702A-10D4-4D2D-8808-DE1E96F98807', 'F9ED9E9D-ED66-400D-9BCC-FE0043DF1D4C', '4602565019969', '  0,9% 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0292930A-E672-4323-95C4-95F8BB601FFC', '046D57CA-24C9-4034-A9EC-3369901435A5', '4016369618004', '    75+  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16BEC5CE-562B-4A4B-8F87-3199E5BAE1B1', 'F3DCE91F-A9BF-49B9-8A80-B8E2B8EDD8A5', '4600999004100                       ', '      210', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('640A8EC8-99ED-4150-B1E3-ECCC58D5D24E', '54A19A91-B2AE-49F7-BC2E-DDF1BBA47F98', '2910007970061', '- G25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B25425E7-A312-4F69-B085-C64ACAD056D8', '84265BD5-B452-4C9D-901C-0ED9BDB1ECC3', '4650001790859', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('424BD863-3604-4DFF-9AD7-1965FDCFAF70', '181D4353-B0E3-43D6-9941-55E057ED19E8', '4607061253466', '  Ego  25   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3124BF5-4314-4E27-9F86-2024905E661E', 'B5C78879-AB0D-44C8-9324-22E40F7FBFC5', '8600599000898                       ', '  g+  1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C994E301-CFDB-4F40-BE51-C6CF016F6DEF', 'CD1E5500-376F-434C-ACDE-62ED8275F283', '4670012610243                       ', ' 5  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('187501BA-12FB-4F9D-BCB2-5CCD5250F083', '7D0062B7-95C1-4EB8-9721-656C5EF8689F', '8850567163319                       ', '-      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF477888-0469-4353-B6AF-1AAAB5E27CF1', '4566B1A5-805F-4670-9F93-C181CE5E095B', '7613031575220', '    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0471462B-9A4B-442C-A1D5-D82386F1C63A', '0125917D-FEE7-4FB7-B08C-AC9DC46DECF3', '4607041065676                       ', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED0BFFE3-F14A-4C76-BBC9-6897CE106DE2', '91CE8279-ECAB-42F4-A75F-748F61BF709B', '4601892006949', '  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5566D456-54A6-4FEF-9199-65516FD79677', 'D95B6125-13D6-4B37-BE71-ECC25231EF4C', '4605319007489', ' 252   /  // spf10 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9EE43A6-4621-41A0-9ED4-DF02BE1B931A', '2A2663D9-F2FA-451B-AECE-2D2627D2C631', '4606677022121                       ', '    / spf-30 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFD53EE4-D716-4A11-9D40-ED8086765C3B', '68AE6FCA-155B-487B-996B-9BF5509E207B', '5900008011303                       ', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4913E597-5782-4BC0-AD09-E154289B8BBF', '1B1BDA75-E156-4AC8-8CBB-278A7BE75321', '4013006101035                       ', '   // 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59078C88-FFC7-4498-AC72-C50C3A4F0F77', '82941389-0B00-4FDB-B66D-2B9969E1DE23', '4627090860046', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0603C53F-5EEF-4314-8F71-59F47B1F3BFF', '8362D0C4-28CB-4397-8245-F7EB7B8BBF99', '4605342002277', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('412F307A-BC4C-4A54-A856-D181CE4FD582', '47B9AEAB-2AF9-4E7C-99D0-B14B1303EB49', '4607027218492', '   2256 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F77E9738-7D74-47F9-832B-DDAE1BA74BA0', '1EE8AE9C-2949-4DC6-9A9E-7D5B660C90ED', '4607003248949                       ', ' 100  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEE9F0A7-8D6A-4BCF-80D4-A812E302B277', 'FC65BAA2-2B3F-438A-A5E3-A401F737995A', '8002660019592                       ', ' 667/  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F317FB92-ACC6-45FC-B77E-00C83AF7C188', '17C86242-FE32-40B6-B403-BBC2A746D56D', '4607071772445', '   60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('994BA7DC-9EF8-45F0-9668-5E4B601C4A51', '4F861C67-8E60-4B18-A188-056D7FCB4A19', '4607101202973                       ', '  - Lubby  0+ (4697)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A8379CF-A8D7-4FB4-BC28-709F98CA0359', '0D44B541-7B6A-4601-9506-CA81B4A098AA', '4607101205264                       ', '      XL', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BD8A061-6F0A-446C-B0E4-2ACB1718F97F', '2EAC3AD4-9FDF-4287-9E89-97232EC33ECB', '4600702090604                       ', '׸    56+ / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6592F69-C0EB-4F86-BF39-C962EE51FB54', 'D656128C-9F70-41E4-B7E4-19140A8C9D7A', '4600702086515                       ', '׸    /  56  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B13286E9-278E-44B5-BDBC-E86DC5D52A53', '88CDA9BF-B31C-46EB-AE81-770D2843C549', '5900095010081', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FA18AA7-E6E0-408E-AAE9-464FD03696FD', '92E03E1D-4242-4D4E-BE4F-B1521C6DF9A4', '3850343001274', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('406B3E42-64D2-4C26-BA7E-926A6C12A34F', '4DA5F0DE-5BB9-4336-8F81-33448CB9C75D', '5903267902481                       ', 'Veet  /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('687B3890-54A2-47B7-9BEC-76F9B694B1F9', 'B10ED2C0-CD1E-480A-A09B-528AB546A418', '4620004740199', ' 0,1%  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6A857C4-BCA5-4DAF-8077-8167612C18F1', '7A4D380D-ED05-48B1-929D-93152B794D9C', '4750283046177                       ', '  .    .6 /9509-/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1367E56-3CD6-416E-ADAA-7676113A2640', '8E04B04F-18F6-41BE-AC6A-62A79CDCC520', '4823015918605                       ', '   /   // 42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4305B6C7-2CDF-4561-9050-0F0A75311E15', '818FFD05-B7A3-4D7C-8483-30EB51AC01A9', '4607008960228                       ', ' // / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9F01EF4-14AF-4C3C-B233-6F2CE82DA5EA', '2194594F-D8A4-478C-A9C8-D223A73DAF93', '4030031890116                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA845D9F-2B15-40D2-89BB-19F8C4508DE1', 'BA78EF4A-2010-4920-9BF1-AF3D91910FBF', '4605994029868                       ', '     100  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47BA950B-8315-435A-940D-DF6EA7A16BF3', '85651D57-56C5-4B70-9DEC-809C41FB2BB0', '3850343061667                       ', '  2  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59F3A3AA-E8B9-421D-9F30-3437662C22BE', 'F24025D6-93FC-4869-8FC1-81E9F1C08C84', '4607086566596                       ', ' - /          75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3154C3C-F019-443B-ABA7-E999570ABFE9', 'BF57C126-6A12-496D-A9E1-C9ED039FD2CC', '4627079833351', '       50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5809CF80-C07A-4E34-981B-82382E4F9C1B', 'EE8099D4-482C-4A52-B95F-951262AD71C4', '4640006304274                       ', '   100 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('739BE0AC-458A-4AFD-AB35-F611A66EF38C', 'FE3FD29C-671B-44A4-A459-F318786FF759', '4670016770233', '- 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('655FF0AE-AF24-42D8-97BE-0F3B94F6991A', 'E9D585B5-5BA6-4446-8F11-D42F659913F8', '4820160034150', '  - /   175', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79C484A0-C4D1-4310-9AD8-AF8AE1A6A5B1', 'E7E8D1E3-C61A-43B4-BE07-00DCEC331A6D', '4820160035331                       ', '     40+ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('612A1DEF-8535-4CD5-B4A0-14F4199A5919', '0F501DCA-2028-4AEB-96DA-4450D89D6B96', '4607020904323                       ', '  29   c 2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09206613-7D96-492A-BD6F-357AFC45C54A', '6CC3CA9E-6C1F-4D6E-A47C-A0F53DABA009', '4601654000543                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2DDAAA2B-731A-4DBA-A014-956EA826F390', '12206FC7-AD00-4131-9DC1-E16AB428928E', '4640021710074', '   /  spf25+60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51E6338A-765F-49E2-833E-8D6EFA9AD58B', '856709E1-17AD-4CAF-9602-DE9CDDBB31C7', '3282770000085                       ', '  /     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D1EC5D54-6825-4064-834E-4B9F977F6D35', 'DDDC31E9-7AD8-4F47-9B84-EBE884E9758D', '4607056520023                       ', '     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('522CB363-967F-42B3-A098-D1A4F235E453', '377DB67C-53EA-43A0-B609-3702CD6F7B36', '4607027769635', ' 3,5  120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F079987-4E1C-4EEF-9D85-5936A4C9E3FA', '8C8839F4-59CA-4B29-A966-618611BCAC82', '4823017805248                       ', '  2,57,2/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C872BC02-F24B-4A6B-86DE-3F594AEA7733', '48097D8B-BF15-4643-8F7A-59805AC8C41F', '4607155640950                       ', ' leiko  4x10 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEBE5037-EA92-43ED-BD31-D920D35684D7', '0A782D01-DA6C-42CF-8B1F-F2EEF65E4A0A', '4603014007308                       ', ' professional    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C9BA7EF-95AC-4C00-8333-E169D3BFC554', '4D40CC7A-0108-45CE-AB5B-9F82A8A85588', '4607094176503                       ', '     6+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62528F77-FFB5-4A98-AC61-F763E41A856A', '638CD454-6BDF-4EE4-B52F-87BB18D56C4B', '4028694000034', ' 20 2  - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2EE18E65-85CB-4D7B-AAEA-C55647A4B8F5', 'B622F5E1-8F1D-4664-A8AB-C93371386AA4', '4607121690538                       ', '   11   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6A43A97-9626-476F-BA0F-CFA407BB2CA6', '33197759-97C8-4FB1-97DE-7014E518808D', '4607071771967', '  /      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C46CFC85-7A6D-46D9-98E0-61EA256BC178', '3718A37D-8959-4092-B731-35F35F6D5D14', '5907996093229                       ', '  .    2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C729616-0896-4509-876A-9FC88964A85A', '04566FC3-B491-4E1F-A2B3-BB53357FA00A', '4605077003778', ' 400  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0BF4CC6-574C-4BB6-90AC-F2593C4B9F5F', 'BA4882B2-6EC2-4613-8E00-4EDFDE5B9FE8', '4605108000936                       ', '  /   10 8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08C2DEF7-68C5-4F8E-8F59-52672BEEA48F', '64CC99EE-D515-4AB3-8831-324AAAD2C163', '4602666730701', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('701BD33E-FB47-42DF-9808-4AB3C32E1595', 'DA8C1A23-E636-4CC7-87D4-EED61504E4C7', '4603276005043                       ', ' 100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('640BADAC-278E-46FA-A508-5F4FC0E19378', 'A6F1BD24-A69A-4A02-9F4E-49626DB79DF0', '4602984009596                       ', ' - / ,  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8A334F1-A041-4619-8436-828B354290A5', '26316DA1-C466-40BC-A278-A8757034020D', '4627129210767', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08CB1DCF-AA73-4A95-BF96-8BD4834473D7', '1B2084F4-DC4B-46D2-9FA6-180AB508B4F1', '4620021520187', '  clearasept  /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('725EE74B-E0E8-4483-8CC0-A26F309430FE', 'AEFD2053-3A0D-4EBD-A512-A64F3F52DF18', '4670017923850                       ', '  /        /   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67B74825-0616-487F-AC93-7131069A971E', '131E050E-D8FE-4903-9477-8CAD111A9FC9', '3800225901000                       ', '   /     12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFCD83E4-48D3-4358-A4BC-320A69A17481', 'DF5389B8-D544-49CD-AA66-B1FC416AA35C', '4049500971058                       ', '    20x8 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EE6EF5C-6B06-48BF-9BE1-6FE347C2C412', '7B4E5C2D-00FE-42F7-9DDB-A4F2A72813F6', '4607174437524', '   /     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C9892B2-AD5A-4B17-BB9A-C10B8FAB684D', '43403F2E-10B2-4633-A622-5B0853B9F235', '3574661128757                       ', '    - 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85E59807-17C0-4638-8B4F-03DF6E2EDCAE', 'E38D8340-1016-4C7C-B96E-62FEE5ADD45C', '4607154693353                       ', ' little rabbit        300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87AF730F-6D81-4D2A-B1DB-B70D99E5DC45', '598AF54D-FC57-4BC3-B90F-3515B6BD37E4', '8030009402040                       ', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEDCC812-AFE1-4A44-A5A6-EB6D2FB81E6C', '291C77E8-1CF6-4A0C-BAC8-1C666A598BAF', '5029053506203                       ', '  16 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('636DB3AE-1FC7-4E89-9740-76F63BC14B56', '5D2E4717-0076-46CB-9A07-A0147D7FDFED', '8030009701143                       ', '  "Sensitive"  .0114.02 25 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9873739C-D5D3-43A2-8B51-41E50EC7EA2F', '64B39860-C6EC-4459-A55D-D64B04091FBA', '4601498006022', ' - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4B1ED5B-C0B7-452D-9B94-94EC31F88A8A', '7FFC271D-A6CB-48E6-A449-8553B3F5B42A', '8030009705035', '  /  503.02', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E02273A2-1A37-4F9A-A638-D50A96836435', 'EA4F1C2B-D1BB-4685-A6CF-7AA2224677AD', '4607045190848', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3632A60A-5CD0-41A2-A7A3-AE63E46C4E40', '19F84224-D863-489B-89BA-443DE150B951', '6921904705904                       ', '   60x60 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8983AB3-5175-47BA-A3EB-37284708B4C9', 'F12A85B7-067E-475D-8D8F-CF5606F59F11', '3574661208183                       ', ' ..   +  16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FE2BC14-D46C-4053-824C-37FC4CC09E02', '628D674C-9C10-4B46-A3EC-70B4827DD0F4', '4607003247188', '  3  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('866B6709-3C9E-4723-81B6-03F8FD7F1F02', '98088C8B-5D89-4DF9-9026-E00030ED2DDC', '1094922319653                       ', '   1 9', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E36019C3-36D2-4FF0-9491-724C2A716DB3', '214CFC6E-AFFB-4552-94F3-A54AAE02CAC1', '4607122563770                       ', '-  /  24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FD5F391-AAFE-4737-93E5-9DD18D29EF8D', '8095924D-5246-420F-9548-B267CEE7C119', '8030009749039                       ', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DB359AE-D083-4FF5-9419-7599101B8B34', '6A092000-A46B-4AFD-8238-C95D1100BA82', '4650001794833                       ', '  - 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3B16396-14ED-4978-A3A6-7EF9779937DC', 'BBD9CE53-6F57-4829-9AFD-ACD39CE0ACA3', '4812845000314                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB5A6F7B-793A-4CB1-8111-A8DC6A913616', '98BA1569-F52F-464F-AB2B-6877F5B2415F', '4607037190887', ' 0,5+0,5 1  / - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('418C80C9-5AD9-4D26-ACC4-1D893A9F6466', 'E8C148F4-EB70-4478-A6DB-C6EB421729C0', '4607027210489                       ', '  -  / / 6-12  11011', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA92F1B7-96C4-4227-BED7-8A88BBF309AB', '497AD927-00C0-4E79-971F-958EBAAA785C', '5391520942822                       ', '  /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4BB9905-6024-4137-83BB-499F9D16E60C', 'B6880693-B64B-4386-A803-D6E5474A282A', '4600689603477                       ', '  200     /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F84766F9-FAE4-4860-82BB-880DB8209B9D', '64D2C4CB-8E59-47BD-9DFA-99E5C43C30FA', '4714204027010', ' -   .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20F6A31A-D4B5-4EEF-AE64-3B8626EA5B36', 'DEAD02A8-02FD-4CF5-BF23-56C8E26865EC', '4711014010218                       ', '    . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14C4516B-3131-46FD-98AC-5146E0EE392D', 'A7D8F5D2-7ABF-4D07-B217-76979DCEE498', '3574661314402', '      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A839ED7E-03EF-4E38-B8E0-4A76F023EBCA', 'E83FC5DB-1FAC-473D-B279-C3944F534ED0', '4601450000105', '    //. /// 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47073C53-D8E3-4823-80E6-DCB31320BB37', '27E13D4D-C550-4BDB-A755-CA273377E5B8', '4601450000075                       ', '  - /   -   170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B4234E5-1099-4B9E-B8D1-5AFDCF09A12F', 'B74731B8-BC52-4E6D-AA6C-E4722B4B3A16', '3282779369077                       ', '-    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F89D1719-1086-4EED-BCCB-6FEF78E9C2A8', 'F6D47171-B116-41C4-8C58-78F6B7745A93', '4607086566626                       ', ' - /   ,      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02D3793A-0633-44F6-AA7C-8988DD5A066F', '6A17F82A-8B12-4BF2-BD0C-13AD0447EFB6', '0016401012245                       ', '      -  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('525B556A-4225-43A2-B8F4-C586E3BEBD26', '4226D768-81E9-4B8B-A242-98088DDD2391', '4810797035019                       ', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5675F7DF-E541-4F21-B94C-787FE86C9706', 'A2C45A94-BA77-4AB9-A730-F260AD2360B3', '4603695001428', '  50+850  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8221E62B-1C5D-469A-93E6-DA1EC86C7A36', '681236C4-1F52-4BFD-8BAB-B69EB273BA2E', '4607141998805                       ', ' 10  98', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EE09BEF-7A4E-443A-9F3E-873A07B07100', 'A0870E25-8120-467C-954C-CC16BB1E5149', '3700971300617                       ', ' / -', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEECDCD2-AF2E-4DEE-92FF-C8924F489D67', '98BD5F9D-2799-4DBE-99CD-EA7067F02EF3', '5292452004582                       ', '      100%  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B41288F-304B-47D9-AA3E-D65987F52DB5', 'F17AD38C-48EA-4C1F-9518-99851D2403C0', '4602676004175                       ', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47CE7263-D4FF-4A99-B5C8-DCEC22527EA2', '55D86638-21AC-47E5-BE51-A05D409AA22B', '5411416045663                       ', ' terezalady    14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84CF17A2-BF63-4262-9173-AF088EB078AA', '08F23347-98C6-4B2E-B258-A695BADE87FC', '4601808000528                       ', ' / 50  /+- 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7804BAE-D897-460D-92B9-C805CAF0ABE4', 'A0A1A09E-B1E8-45F0-9988-5714EF0873EC', '4606982002726', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91E5830F-5AAE-4704-B16B-2A4E2652D018', '0B8D0C7D-3B23-43AE-89CD-CB3D0041DCE2', '4601907000481', ' 12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC3E9F48-0FDE-4957-8F25-73DC2B0B3651', '76A99C7F-3A29-408D-8718-FA8F40307C83', '4620006110013                       ', '   .  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3BD5ABC7-B7BB-4398-B189-666C678099F2', 'F7E74D5F-70F0-4F03-A190-0B02BFC45E08', '4640013559100                       ', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E09508B8-B495-4C40-9319-72073C6BC6D4', 'FF97087B-1D02-4016-8B33-A91891CA4ACA', '4607167150157                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CE6C9C0-9321-4093-9150-A1A0984D2F20', 'AFE43BD3-7085-4F21-B428-9CD357FCDD70', '4620002181314                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA43A412-D474-4712-8E96-DD889BED6DF0', '486B92CE-3BCE-4A2F-9B12-5BC6E6CD5E4B', '4640016741878                       ', '   /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E11ED06-C6CA-402E-B399-B5701F4BC427', '77787497-511A-4689-8341-A5904E14FD79', '4607017269862                       ', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F32863E-92DE-4ACB-AE3F-61D16265C5FF', '20799F68-1CEB-4A8F-9AFA-97A8CB6CDF78', '3574661221090', '   /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('865996E5-92C6-456E-BAF9-785A67EC2409', 'AA2FCBA5-4D4E-40C6-B742-B884BDED4C66', '3337871311292', '  ,      , 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8800D0FC-474F-448B-8958-F02AFEBE6265', '65E469E2-4F82-462A-9E74-E21ADFC05FAB', '3574660096880', '     18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80CFBADF-3BE3-4197-9426-96DEB719EDBF', '503183F6-2EAA-459D-8B3E-A768D9538DB1', '3574661047188', ' ..   32', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4797F303-6738-4A60-9EF9-8DA7864F7BC6', 'A5559152-F493-47D9-AA96-47FE4957541F', '4823015916649', '    /    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('562DBFCE-2579-4D93-ACCA-FB5742F588AC', '091B6381-84C3-456D-85B0-DE48F4334E7E', '4602866073066', '  . .   .   (3,5-32)-000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CD41C83-33D9-4467-8698-C803B27DF38B', '6EAB58D2-C324-4704-8169-590AE22A020F', '4823015916724                       ', '   350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D850666-BAF5-40C2-92A9-7080AED0286C', '1297954D-3D8E-4E5E-BEAC-FFCBF463FB0A', '4610012150356                       ', '   / 3 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDB1BF5C-6EB4-4CAD-A0CE-4808D2BBC6BF', '13F47ACE-27D6-4211-BF2B-500016FCBB7D', '3838989666262                       ', '- 12,5+10  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24FA48A3-0A82-4E58-8D54-01E1B54A8819', 'DAB4D439-FE88-47B2-AA89-A44EA986EC8F', '4009932558692                       ', '  -  /    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('20B39F6C-DE0B-4414-AEFC-D7C61FE2E80A', '6E13F925-E670-4492-956E-C9D8BFD7FBF6', '3337875550611', '     SPF50+ 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F09E2C4-E8FD-45E4-B9F6-DE1F4BCB1BDC', '68469EE9-3BA4-44F5-9908-13B1CB080482', '4607100622581                       ', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3F4141E-B384-424E-8EA4-57E49A0D2781', 'C66D5102-B644-4BCB-B844-9568C93670DD', '3518646671593                       ', ' 5 - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A56CD69-9076-4F2C-9F49-770E597F7A78', '22E74DF6-C69D-4061-AAD2-9E3AC4FDD109', '6946469488383', '    /      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12CCD861-1163-4D8D-80F2-684ACE95141A', '538E661B-1D2C-44CD-9431-42D926290DED', '4011548016688', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5A5750A-1081-402B-923C-20A4C9E30B3A', '02F8408B-22C1-42EE-AB64-EB731CC1CDA6', '4011548016671                       ', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62EA68D1-BF3C-4FD5-A5A7-F2608CE505E1', 'DC6D8DC6-CF92-454E-9FAA-29A0896AEBE5', '3800002302051                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DC43D3A-5ECA-4D91-9F18-5FED5E290F08', 'F212B90C-2F04-4443-8263-530194F37626', '8585004502450', '   30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFD4D5D8-55C8-4F06-B2B8-A921598C4EBF', 'C006BD06-E3CA-4841-9DAE-9A439BDC6F24', '8585004502436                       ', '   30  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6043E331-844A-4101-A789-735CA60A6701', 'D72E8DC2-FD31-41B0-ADED-F0AE38E81F2B', '8585004502443                       ', '   30   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BB9DB75-72CF-4F74-98BC-7077EDE36922', '0A00C34D-671B-443B-9070-ECB854C10767', '4607071772841                       ', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0476EDB1-2454-402F-B56D-BF935669C2ED', '18996CE2-1CBC-49A1-806D-F3648C782FC3', '4607101202775', ' - "".  0 ., ,  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C3FBAC3-C021-45A7-842C-BD7BA9FF495A', 'A7F1A495-7171-4018-9D17-9556FB99F26D', '4016369355367                       ', '   /   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42214C9D-3AC1-4BEE-9669-572AF75D8C75', 'AA35E21C-7012-4191-9B7C-98D1B760150B', '4620017180043                       ', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A88DD68-B164-44F5-B7A7-B2E28F9AC342', 'C3D532A9-8826-402A-8114-AC9D5062017C', '4612586500773                       ', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7685CABA-8151-47E2-91FB-7E230E4053CE', '28EB4905-C45D-4953-B75F-24EFDA7AA3F8', '4603907005312                       ', '   0,18  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B90FB37-FF1C-4FB9-999A-361B673563B4', '9E1B6F73-61A9-4CAA-B692-5853EFF40ABF', '4016369655559                       ', '    75 Dr. Theiss Naturwaren GmbH', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('133AB5B8-EE75-4080-85D3-DD3978FF6258', 'FC2CF5C4-5AA5-4554-965E-C1716A1BCD78', '8594739206007                       ', '  80  84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9EC1638-9DDA-4E19-A016-5264EB1742F6', '612D52B9-D5AD-4F6E-8E1D-8D333D2D20E6', '8801051068795                       ', '  perioe  breath     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AF25B4D-7181-42A6-9C00-07E7206E685A', 'DB9EC454-C876-48EA-A7E7-A79D38DA513C', '4607011667244', '  /   .    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9AF723A4-E761-4EDE-A4D2-9329A50999B3', '59A08351-746C-436E-A510-8448E17824F2', '4606486021407                       ', '  100  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('398D88E2-81A1-4F08-9386-4F4C3E181D77', '328669A2-4B12-45C8-A44C-21686B3D55A9', '4016369661871                       ', '     /33% /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C42EACE8-7195-4420-A106-CAEC798802F8', '9BA9E94A-B2FC-471C-8732-8A97D5F5F31B', '3858881059900                       ', '- 5%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0985FE59-4BE2-4A2D-A38D-47814975345F', '967729DF-5EF3-4C18-B6B8-8F717E117F3A', '4690214108119                       ', '. ,     150+ 150 ,   - 50%   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0307B015-5D12-4006-9785-52DA62BE24B3', 'F56D15F9-E9E5-4FD6-9B7C-5A07CE94895E', '4627090498355                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3ED893BA-6331-4A00-944F-E4EE19E70182', 'A6F3BE95-1CE4-407B-A59B-99321830F461', '4670000470095                       ', '  /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A209AC6A-4760-4AB8-8F07-964EA2373D29', 'A9ED7C38-B1C4-4A96-838B-850857FA9DF4', '4640013557472                       ', ' - " ".  0 ., ,  . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68CCA1D1-A256-4643-AB7C-222DB5972C2C', 'F1C7B1A2-CBF4-427E-99D9-A2A24928A476', '4620021520095', '   /     -  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE964D55-5431-441D-B23D-877DBB9CFD01', 'E2FA1901-775C-4E94-A728-1BB01FA2D69B', '8021961001457                       ', ' 500   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65F44FA4-291A-4A34-BED2-EAD8557E0A16', '62414AFC-7C0A-40DF-89A1-1F8D3469CAFB', '2832086943555                       ', '  """', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F57E35B-4970-4436-B1A3-340D0226BA84', 'CE3B2596-E815-40D1-9E8C-914B56F3C7E4', '4627129213034', '   /        500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37557B09-95FF-4F2D-8E63-56DC0931093A', '33A00565-0493-4ADD-9C7E-C29AA9906E44', '4607041068202                       ', '    -  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5670AF3-892F-490D-AB20-075A77D23D42', '1D344D25-F7EE-4757-A675-72DDEB49750E', '4627128156141                       ', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('301508B7-BA36-4ABA-B2BD-0F934827904B', 'A1DD4147-E4A8-4E9F-A93C-1A8578EA2B34', '4605526005469                       ', ' - /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82C7A522-83F2-49D8-9411-9234E3C5B4EF', '3FE45E86-08F8-407B-9098-F9B51DEE45AC', '7702224472702                       ', '    400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D80180E5-FB79-4523-8CDF-FC7D8F6B37DE', '19AFF452-E3B5-49EF-960E-130EEDDF823A', '3282779013932', '-    100 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93264ADD-2259-42DC-92EA-3215BA1AC7D7', 'F3CF65DD-44B6-40AC-BEFC-E2273887AFF9', '4607027210441                       ', '  -  /,/ 0-6 11020', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1111481-A93C-4158-8162-4883C5411E4A', 'F8DFCE9D-E61F-41F2-9784-81722606F111', '4036534641200', '  S /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('474B47AD-748F-4B08-A5B4-7582449F0C8D', '4F67AF4E-1462-4354-B7CD-ED566891AB94', '8887786200099', ' LD 71A    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6CA0FABF-2BDD-48D3-B0DB-D8D7E77493CF', '56E9F770-3EAD-48AA-AC7B-4BFF68EA6540', '3433422405912', ',     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('588FBDB1-4888-428A-AB30-3927D542F799', 'C1387970-4914-4B78-BCD1-C07585727618', '4605185000027                       ', '  / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E88B9319-6E60-472C-B3FE-86C7464E4AD1', '0E0D11E3-8A2B-48BB-A027-FEBDA58AB57C', '4607014000314                       ', '    31   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A3C8FAF-6969-4FF9-8EF3-32CE55B2E2B8', 'F0567CDE-1FD7-4F7C-85F7-4EC766BA4910', '0617015000200                       ', ' -20   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AAA0B363-FC00-4C5C-BB4C-D5EC9FF35CA0', '70922F53-27C6-499F-A10F-5FB7EBB2A854', '4016369666142', '          200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91EA6602-6D69-4696-A58A-C0991E0340CD', '0482E3BD-72DC-406E-9A38-A3AA349D11A1', '4016369666166                       ', '  /      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7527C549-36DA-4049-AF6D-6947464F3EB5', 'C45F51F7-19B8-4BAB-AEB7-0773E4FD4BB6', '3282779054232', '      /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('315A5AD0-0262-4FC0-95C6-74E6B748E5D3', 'B7052D0E-116C-43F5-978C-C05164677E48', '3574660571769', '    / spf20 4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85BD600F-8946-486B-A3B7-919C639BB5C2', 'C68282EA-1654-45BE-B708-01653C2B648A', '4640016741113                       ', '      25 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FE2E4C2-6798-4BA0-83E4-AC12AA55D4FB', '29480C17-D769-4671-B4F5-941D1DFCA8D6', '4607039971095', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE720E30-D384-429F-A418-1241B1C159C0', '7A1F1D92-1716-4ADF-B060-B22C737C3C56', '4607010246600                       ', '   /  /   10 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B651497-398D-4872-B0C5-0048D50575E6', '1F6DC726-9EA7-4E02-AFB0-66A2B6E163D7', '4601429001782                       ', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE9A5E0B-19C2-408D-9B5B-01F182AACDBF', '39F6607D-DEA4-4E5B-A3D4-1912CA8A5C1B', '7310790020588                       ', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('196D0E9D-DED4-4185-A5A2-9D6033B01B65', 'CCDF2E3B-467D-402F-9E49-B13BE9971D62', '4660000412195', '     8x100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5162111E-9502-40D0-8F7A-463DA28ED515', 'C686EFCB-236D-4724-9C6B-B185360F1BD7', '4823017805309', ' 410 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('828835F8-DFAC-4193-831C-4E89585685EB', '49477F69-AB2C-4C09-A8C5-5BDC84F8C2AF', '5999518577652                       ', '   3-way head ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA9F77A2-394E-4670-AB1F-6BAE8AE34021', '221A4EA2-D917-46C7-A2F1-D0B4E1B6268A', '4610006202757', '- 300  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E40721F-F2CE-4FE3-A073-CDAA932D169F', '1DFE7262-AC4D-481B-A264-B0C89414B164', '4013054024997', ' 5+20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('998CBA6D-341B-4FCC-A2D6-D66DA3C121AF', '4F559213-EF63-4177-A355-94F82AD5B8EC', '4670017926837                       ', '   /   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC9BDD3E-772F-4380-B390-6A1D6F228CB8', '5AC2D865-4FAA-4F53-80A5-6C92AC47CB18', '4250431900035                       ', ' / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('848C1831-DB07-4989-A61D-A3F387225D22', '7D1FEF36-7C72-4AC6-A7DF-822185C8C64F', '4607056260172                       ', '   170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9212C520-3497-459E-814A-5DDFE3B8826C', '0C530472-288C-441C-868E-91220D8E3F28', '4823006302949                       ', '-   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D533BE0-FB24-4AD1-8260-63EBDA850EC6', 'C8D3E4FB-7F88-4774-85BA-86C6C85F9239', '8809052590390                       ', '      18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('956252E0-D3DD-4DEA-8518-8E9E103632E7', 'D461D7D2-3927-4F5B-82EB-3D66C1F51A39', '8585004503013                       ', '      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('557AE177-73DF-4460-B0B6-B71099583DC1', '39CC35DC-786C-416B-AB24-64AE8E6D19ED', '4607174431010', '  -   500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A961EB70-C10C-4D03-9A73-017F1FC2CF4C', '655B609C-718C-4D8D-8046-AC5E03BED6B2', '4603276005036', ' 50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E451A21-D9A8-4005-9CBF-0CEE15A70538', '5840486F-1C99-4EB8-BACC-031B14698003', '4640013557601', ' -16403    4+ 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7361A268-D7A5-429D-BEE1-2846F3D3C627', 'B7A75A38-A411-47BE-A0E3-C353F13B278B', '4031083004629                       ', ' 0,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5AB5972-FF21-4812-8B9E-0A7D958DC4E2', '1CF34063-B79B-404D-A0B9-25AF39BF7371', '4690419010484                       ', '   /    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2698480C-1991-4863-AE5A-984B89D67FC7', '6B622ECB-ACFF-403E-BF76-41334243848A', '8901086040015                       ', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6F07403-302B-49C1-A870-DB60971C53C7', 'E43B6F11-2807-4770-B311-C94E309ADA6C', '8032568302250                       ', '    /   spf 50 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EA855F7-A594-4E8B-8504-11C7B1FFD460', 'EB8C3102-E62B-4EB4-8A7F-2566494EE2CC', '5009612911259                       ', ' 1,97,2 10  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D5C13B32-EF66-4CD5-8D5D-B67C3ED111D8', '944C068B-D389-4B99-AB64-71100E8D12D6', '4605658170325', '       200 /17032', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFF80909-E392-4E4B-8721-A98F9F35ED03', '54D50090-9F3A-4827-B356-C3BAA6547E6D', '4607006950122', '  10%  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC3431F8-265D-45CA-BB5E-9910F00F1B14', '01624D9A-389B-4F34-A5A0-39900009E132', '4602159017470                       ', '  -    4,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A331E93-6FC8-4C65-A4F2-4B388FD22A1D', '16FC28D9-C5E8-404B-92F9-85D55F450D6F', '4602565017088', '- 1%   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C85D6D4F-6CC9-4C1B-8CA9-729722909ADD', '528795B9-A62D-4869-85E6-777955FDCE62', '9120029750425                       ', ' Manual rn709 .. s', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13011AA4-CF16-4305-92E4-FD84A7EB8DE3', '05F5D19C-BCB9-4A7F-B9AD-E8907A971966', '6933315521998                       ', '  7  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4EF6774A-6FCD-4B91-80B4-248BE396CDC5', '67E71A84-DB87-4DED-BD46-83CE1D039BCB', '4607068628410                       ', '   300 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F71538C-ED86-4D9D-B648-ACB30D7E4591', 'A86A7EAC-912C-4F5A-BE5D-CC13D932DD62', '4600338007144', '   75    6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EE4CA78-CCB9-4C61-8888-044C26E2AD01', 'ACDCAA59-756F-4A8C-A2C5-3AA37EAA7B61', '3574660482799                       ', '  reach interdental ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('482A70D1-6BF9-4C23-BB5A-3B5B51ABE4C9', '43CCA60E-4B17-4249-B30B-313512A8D3E8', '6224000132439                       ', '    1,25500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90B65E71-C502-4287-98DF-501E28A81613', '23238A0B-D426-4644-B16A-09EF7ED5792E', '4605319002965                       ', '- -   /  450', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F14438D5-A8B9-4D00-B49E-A7651478FA65', 'E430E5F8-3C16-4DC6-8422-56BA3A4E1F64', '4607071772643                       ', '  +   /  care/  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2479831A-7FC8-4C4B-898F-C2F7EDEA33E4', 'D2EC3D3B-0A29-4480-8DAD-42B11D258C2B', '4601774007286                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D7ED0B3-0F41-4566-BD88-9D1BE5915518', '24A15919-BB8F-457D-BB24-697E35331185', '4607034470722                       ', '    74', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45DEFDFD-CC29-4A17-832E-4B5FE0BC1973', 'B01C21BD-A012-46E8-B2F5-E629811E00FF', '4823017802520                       ', '   14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('182F7E55-77AE-4EA5-B149-9A37504B37EF', '5B113379-89DB-445D-AFFD-D3ED5073150C', '4650070510389                       ', '      42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6021E8B5-8B05-4042-8404-6D7DD42C39EA', '014B0C81-0B8F-4FD5-B755-7F2F2495691D', '4811248005254                       ', '    /    ,    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB2C75AE-7CC3-4E51-A47B-5DEC1B884F78', '7678D13B-36B6-45E7-8BC4-8012E52B7832', '4607025200185', ' 350 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7E93678-7CAE-499A-84B2-A53ECB19DFFF', '15E96D2D-BCB2-465E-959F-133FE6B0C891', '5903060611313', ' 60  42', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F3BD208-4F70-4336-B0B3-5D7815934C48', 'A76E332A-C372-4AB2-BF33-AE2FE419492E', '4607034472474                       ', '  /     , 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4311A45D-0FE0-496D-9229-A70AD0362EC7', '5B1A0952-10E6-4D10-BBB8-C2FAE25E3DD9', '4607034472481                       ', '  /    . 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3961AF98-8512-4162-93B9-A92E3E42DB2D', '889E9D49-DADA-48EE-8929-FCEF81C24BA1', '4605370014594                       ', '    care 5% 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3B97083-65A1-4A26-B5BF-148776D7E76E', 'C82D7EFB-E93D-454D-B308-2E55ED548E60', '4607027219802', '   1119 240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFDBD0FE-C55D-4307-B00D-EAC9437815B6', '79A72518-0819-41CD-82CB-8CB943A16701', '4607101200900                       ', '  /   0  13697', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A20F039-3101-4A2F-8494-4536D9680E0B', '93FF3F13-EEEA-4CE8-BEC8-944EF4566AB1', '4607017268827                       ', '  350   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71E2564F-D3C4-4B87-A19D-065ECDB13D3C', '74645366-957D-45D5-B608-D67FA8AFF4FB', '4606055955645                       ', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5269480B-ACEF-4ED0-82B4-9349E6BB9892', '72771DDA-94FE-4EED-B3C0-F44B014EB51F', '4603907003417                       ', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC6B4521-6242-4B45-9EF7-B9CFA1A3331A', '96DDACAA-EE99-47F3-AFCE-E90D724EC745', '2910012070206                       ', '  2 30 /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F18305B2-47BE-4691-BBA0-F8E4EC9C2106', '6D7ECEB2-9AF0-4B5A-AF70-229B5BA4FD42', '4605048000690                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABB8280F-DA5C-4406-8A2E-1740569C93BD', 'BE9A826A-3EE4-4ECA-9465-9AF90DA0C9A8', '4607136210554                       ', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52454256-F4D5-4122-81E6-48C9D9985EB2', 'D3EF1831-E28D-4F44-B46B-001B1939DB8F', '4049500245210                       ', '  85  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('93E9C8C2-C8F1-4544-A2F9-06CDE8D208CB', '2E6DC501-E00B-41D5-89F6-E525B148E664', '4605126005999', '      1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65990AA4-D9E3-4A16-A5B8-DC2B8D3A5F93', '92CA8AE7-0579-4691-BB25-03B5AEF08A36', '4607101203710', ' -       "" /5520/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9A7509D-72E6-4731-95C2-6BF6B9370A5D', '13BD9050-1A40-463A-944C-E0A5359E46B3', '4602573030109                       ', '  -active 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB71CEFC-CF3D-4E05-A64F-6806AE5E8FCA', '91F6807E-C2D7-4F3B-AE7A-C447DB366F02', '4600702099188                       ', ' - 30+ / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1EBF7F23-B71A-4F11-83EA-F1E91F6042A6', '01F18296-55DC-420F-A525-94B1993B7E38', '4601892006963                       ', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('020313F8-489E-426C-AE47-088C6650315E', 'DBCBB731-CB36-4322-96EE-3D45479D69F2', '4607101202751', '       0+ 250 (13564)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('839CEC3F-4DC7-4A0C-8540-5B9A217CC4D9', 'A805A09C-104C-4041-B922-936C07C8BD7B', '4607008960181                       ', '   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EEE43A6-073C-4FEB-9C84-163662D6A890', '09C01321-FBA0-4EA9-A2C4-F8BBEB803D22', '4607027219857                       ', '   / / 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FA6F5A0-D25F-4095-AD3D-6A8DDA92AFCA', 'C51ACE9E-41C9-4327-A1A4-562731841FBC', '4605658110673                       ', '     225 /11067/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFEF808D-B035-478C-8FE5-965AA3F56A19', 'CB99A61F-40B4-4058-8217-88D1A7D5A37D', '4607046745368', '    6,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9C94BCB-982C-4B95-B4CF-F7D713ECD4DE', 'D5919158-BA28-4533-BDC3-EA197A6C9FB2', '6916119020355                       ', '- - 1 %  2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE5EA58E-332D-471E-BD6A-DE7CA680A986', '2996335E-6B9F-4164-A58C-F7E8E0354E45', '4603727300062', '  /1803/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C700FA68-22A1-4393-8D1D-3B01D327C934', '7E985DD4-39D2-4594-BC41-BA463C9EB763', '4603988012513                       ', '  20%   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C706176E-A78A-4ADC-B708-93F7E3AD1865', '0113A1EA-CA01-48A3-B959-6BD8E61D1718', '8585004502979                       ', '    / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06B8A56E-6BE7-4215-B85E-9687946BA106', '1013DD18-19F6-4A38-B389-ACA9B7559DC5', '4605658251765                       ', '  /  6+/25176/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FE2EB91-364C-4F88-BA97-7EF3AF32BC13', '64D1DAD6-C456-459C-B356-075AE5C95D19', '8710103486565', '    .86810 /scf310/20/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AC2A6EC-B1C8-4F3C-A269-B7A08B624BA5', 'CCE51433-D3FC-4A76-A930-AAC4DBA0712B', '8901138825577', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F60DC18-2F43-4703-9FA9-7F40132A9FEC', '6D692F39-C80D-4B26-9379-6C0431B5ADF8', '8901138825591                       ', '     /82559/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57FAC2B0-71A2-4903-AF82-9A6059BB015C', '6BB78833-E959-42CD-BCA1-50A710CB1252', '4606486026938                       ', '   500  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('542D34DC-EDD0-42BB-A2EB-527934547AED', 'FCA8508C-A9DE-48E5-87CA-36AEAF3CBA53', '4670017923386', '        270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E1991DD-9F8D-4DD4-94C6-FF9AEBDC8904', '1F070729-B76A-4858-BD4E-85C935DF767D', '4607086566671                       ', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F41A992F-69B5-4B31-995E-74640A917A99', 'ACCEBDB4-AE48-4C62-925B-ED657F4DF36A', '4260202924719                       ', ' vm   /   l 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66E3C083-D8EF-4EA5-86A0-CD7F69C8A053', 'A8484D6A-B8C8-4C84-94F5-D7169C2261F8', '4602212007684                       ', ' 2,37,2 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C4BA5A2-2CC8-4286-86BD-57C5D0FD7C10', '5DC16990-30E9-43BB-B275-A4E967A86658', '4603014001658                       ', ' professional    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('842A8E07-40D1-4A20-9432-C7F1227C4FAB', 'AB8C4162-BBA8-4528-B962-4F5B6C481B14', '7290102066568', '- 5  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88390B2B-CB5C-434D-86F0-9EDC3B889D41', '6232A0B6-DF41-416F-AB69-F7BF5598D901', '4660018601567                       ', ' - /      spf-35 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A47CC105-7801-4F58-BD5C-BAC8988E593E', 'FA71D94F-B883-4D02-9D80-7DD7FE923310', '3337872419638', '  [+],       30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F72BB6C-7111-408D-9AED-6AAB8EAF6938', 'BE05D310-2903-4ADC-B547-2095B6BAF59A', '3337875549486                       ', '   300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65629101-B6C2-40BB-88BA-9CB2F7247008', '538FD8C6-CCD6-4920-A041-D512E145008F', '3830029296095                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A8E42A0-39C4-4C7B-A99E-1020BFA714E3', '3954A881-1554-41C9-A221-8FCF5528133F', '4600416017355                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82939462-E6D2-4CBD-A47C-2C8227EEF144', '555B6874-C61C-46D4-A235-895A88B96AD6', '3282770037500', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F892E9D1-5B8B-477F-A65C-A1D20643F315', '0B6F6FAF-59C1-4128-96DB-F7DB463DA9DF', '3282770073706                       ', '-     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5498800E-3195-4D5C-BBD7-F9E4BF975CDE', 'ED5AF59F-CC5F-4B2E-B032-BC23E40D30A3', '4049500247771                       ', ' omnipor  /. 2,59,2/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E9E9421-2B09-47A7-80D5-9175C6AD765E', 'A5C15AF6-1197-4F5F-B8BE-E4E84F276A38', '4606486027928', '  50  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A43F49F0-C75A-463C-BEDE-8D7DC0AD533C', '4032A73E-9A57-4162-A4F1-A3802209DE2D', '4603014000606                       ', ' professional    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C54DECB3-BDD5-446B-85F4-C05C54A1DAD5', '5D19FC7F-05F1-4AAE-B867-75698CE626BD', '9006968001197                       ', '  100/  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51C9C9FE-1FA9-46AF-82FC-C0C115D4465F', '618AB9BE-819A-4279-878D-23627FFD8A10', '4600702096026', '      51 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A044308F-3555-4556-99AF-94B5A7F8EBA9', '09ECAE56-8D55-484C-8072-9561ACD83545', '4620021520156', '   / , , f  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7F83227-F71C-4298-A590-07D21CB55E96', 'A71D2157-0F59-439A-9335-D851902AF12C', '8809411186837                       ', '    &  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50C8B89E-0B4D-4033-8398-2AE8D03817C0', 'B9725193-6324-438D-B9C9-6ED26B1F1185', '0000000644600                       ', '   500  1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B0F94AB-C1BE-4B49-AD2B-A064A9B8706C', 'A2260F1E-9A4A-4241-A49A-78B2323510B8', '5060105142413', '  2,3% 3  - /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B9C58D4-BA8C-401A-9B62-888E38B03136', '8AACD820-B555-48E6-BE3C-D654392A305F', '4603988014258                       ', '    5  100 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91FC33E8-0850-4323-AA9C-6B2C86692B62', '1502F7F1-E9BE-4802-B74E-A056B6FDBEFC', '4602866040051                       ', ' Ar1006 /1-natural/ 22-29 mmhg', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A9C30544-4150-4B09-AEE9-40AB413ABE1D', 'DE0F245D-0240-4B4A-B058-0F97F13DFC12', '4013006092104', '-  aquagel  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDAFDFCF-A823-40D2-BE39-4AD4998263F1', 'A3F309BA-B4D3-4122-8845-6728A5549AD7', '4823015930423                       ', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('68F28FD6-8150-4034-B500-D40169797053', 'E3F49FB8-140F-4D18-8B3F-6F5DCC5BBA75', '4607051798540                       ', '  / . /./ 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E086D1EB-9F87-47E3-8287-A0244EB77792', '2786213E-9BF8-4CD1-A258-09E245D923D2', '4605059012576                       ', '5          30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62018923-CA8F-40C4-B1C2-5932ED35B201', '8370B333-4D60-49F1-AAA6-9447360F9A76', '4607061252889                       ', '  bona      . 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98537D32-3D6C-4FD3-87A9-6FBA1C0120BF', 'F592B2EC-19AA-47B1-80D0-7333AD58FC05', '4610017500804                       ', '  500  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EF48010-54DA-4EED-8998-6323BE68F725', 'F9061314-E52D-466B-B6E0-BB6390ADC4F1', '4612746210474', ' 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B320F7E-5287-4E79-8482-98DBCE1A24E5', 'AAC5715A-3B14-46D7-9D5A-E99F54354203', '4623721569272', '    96*96  206', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('786CAB0D-A749-4FF5-A784-A59AF7B69DBA', 'AD01EAAE-E39E-4A43-A4B8-25E153F8E34D', '4607051798137                       ', '     30 3    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32481332-7DF8-4D42-B98C-B9F5F4348F83', '27BD3D87-C432-4F10-B92F-80C910A20DE9', '4602228002956                       ', '  /  safe and care 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A633A868-4847-413D-9629-CC74AA50195F', '1B3D90C6-4EBC-4B78-9005-2AF155993314', '8030009700030                       ', '  children 6-12 .0003,02 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BADCF7B4-A664-4C69-BF8F-2C8DF0E1F5F8', '5C6E881C-B125-47C4-AA01-E63B70EE53E8', '4660011210377                       ', '       18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A3E7783-1E9E-4577-86CE-C1F8BB252255', '7A8662A9-4C35-4496-B1D4-DE6E94B72D08', '4660011210575                       ', '     18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13BC017B-958C-423C-9718-5A7E700819DD', 'A40C0092-06CA-4602-95E3-BD910E71E371', '4680007751141                       ', '  6060 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2B295B0-B92C-4681-ADDD-0B36CE34ABC1', '5C68A9CC-289D-4944-B510-EB2014BEA8CF', '8030009703000                       ', '     S 0.23 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3042E4F-4A35-4A11-A032-3F601EFCD089', 'F981BBC1-1806-430D-A0A0-BEFB483DA653', '4603609004002', '  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4FE1130-AAB7-4D67-BC2D-5076F100EA45', 'F27179A1-7CF5-4635-8FEA-2487D58B2320', '4607102856106                       ', ' /  //   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E8B6018-3272-463A-BF9B-8A199C124ACC', '028696C9-8C4C-45B2-9FDA-BAD22A96E495', '4607102856090', ' /   / 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B7382EC-3697-42F6-B0AC-C36FE6EA5ABE', '72056C29-8861-4974-9582-131509F7CE7B', '4607001500735                       ', '  3% - 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('604655E4-10CC-4043-9DF4-FE258A454521', 'E6ED2F2C-B5E6-4D28-BCDB-336DB7DDE566', '4710636640186', '-   td-4227/td-4209 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('687B8F97-6602-4CD7-95CF-C9BC3B3ACA65', 'DA4CA667-FB68-41F6-9A2F-D4ABDE78996B', '4607117341338                       ', '     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A91283E3-9338-453A-A602-3811604D0AC4', '91BE6E9F-B6F9-4B0B-A8C0-2074B6631079', '4607094177708                       ', '      6+250  4710', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CB93D84-2C0C-4EE4-B820-4207062E386C', 'C2196F3E-2C8B-40C3-9FC1-4BE2A655687F', '4603423007043                       ', '    35  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58BF007F-08D0-418B-BC9F-1C8C8EE0A7C6', '45DA55E3-819B-4FDF-92B2-4BA612539682', '4600665203585                       ', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A39B1A1-981E-40BE-8425-4700F5049C35', '4EB51863-5302-4AEA-B309-2A819C592924', '4607102131418                       ', '      -116', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4E62BE2-F7B9-468E-B954-2CEAA6B4AB77', '57BB6164-35A9-4322-B6D3-2C9F49935794', '4260090440469                       ', '- g21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58B5459C-5B38-4102-9051-61F678F29158', 'A224F7A6-A239-470E-9274-9BB4288D179B', '4605086011344                       ', '  83   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00DC9612-4CFF-469A-8410-098BA8B43412', '5D19B804-9FD6-4268-B493-1FB6F3CBFA9D', '4640001382949                       ', '  500  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDB8F436-0F35-4FBC-A525-2EA1D60BE621', '93100BA4-2B00-4F74-B1C0-E9A44D503E7C', '4049500630986', '   // 67', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79978C17-FA82-4167-890F-2FD66BC3B642', 'F6FDEAF4-8F70-4523-8B4A-3882ABC8D21B', '4610010012137                       ', '  130  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77831B59-1853-4B38-946D-26AF439AC76A', '4D1FEDFE-47BD-4D83-AEEE-F8D410AAF62A', '4607092830100', ' 1,58    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E82D37E-66EE-4D09-8C86-5BAD0DF8804A', 'D82EE332-4404-40E1-AD52-421BD191AB8C', '4660013570905                       ', ' /    - 18 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E5EC4C1-3CFF-473D-BD26-B67BA970A37D', 'CFD47FDD-D139-4F30-B6B3-8680149AD8CC', '4660013570882                       ', ' /  -  18 6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C78F3FE-8B5B-44AA-A3AF-D5F597D3DAB9', '6CF6B782-12A2-40E9-8DF0-1E52B14B974D', '4626016682717                       ', '   TL 201', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E25FD63D-7BC2-47BB-998F-ADF4CDEB4831', '2CC32782-A472-4574-A722-2EFCA2B2D65A', '4605581007965                       ', ' -    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7CB88F3A-4179-42FF-8B3B-C1F951AF2714', '59EAEA79-6321-4617-8060-D293222B9B66', '4605581007972                       ', ' -    25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7507AC51-2395-4C00-BCC3-04EB6CEA35DB', 'FF8FA656-7C83-4B50-986D-7276EAE79760', '8805178111891', ' luplast  2,5c500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1473D5B-9982-4282-B118-0215785E7E21', 'B0E7005E-5FF9-4D98-928D-30D7E4FF3B40', '4607101208708                       ', ' benovy    / l - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63E1EB6A-9F24-4604-884E-834AA1DEDD61', '2B04E14A-4374-46C0-B1FD-63A05CB96B35', '4607011665851                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAC90768-E2FF-4622-8097-9BCEE13E694D', '1A13F95D-76C9-48A6-9CE9-E56A4F6B54FA', '4607055565643                       ', '  25  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A296C36-EDD8-4B60-ACF0-14295E1C44EE', '7B9C382D-C49C-4BCE-8C5E-95CC5030DECC', '4627074843638                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12892AB9-11D8-43DD-BC08-1F07FD5651BE', 'F334F4A4-2451-4773-9A69-6304257A32CA', '4650069783213                       ', '     /11011/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E1911DD-8F5D-40BE-B65E-E5738FD7968C', '413232AF-B7B8-4479-ADB2-B4D6968D9AE2', '5900516894139', '   6 x 0,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88AC62B9-EF81-4731-9D78-930D60955D46', '8205ADEE-A8C3-4304-A397-81E24360B45D', '4630006000108                       ', '  -01  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E62FB295-EB5A-42AB-9918-21436C73F509', '48D78163-C776-4C1B-AD38-58838E3301B9', '8585004502467                       ', '   30 - ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('358F1261-3023-41DC-9D71-CF121835A455', '0D31F5A0-B04D-4EC5-B81E-A9F6717968F4', '4607146826998', '  -  /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69666440-A590-48FB-BB10-34FB362414B9', '99E064FD-0587-488F-BC9D-F62BFB89E21A', '4751006752115                       ', ' . /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F77A963B-E992-44DA-89A4-1B5A9286F1EB', '54A262AA-EEC9-4F68-8535-7172AA304716', '4627129213461                       ', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D21AEB0A-9723-4FA2-BE74-726CAE5F69CC', 'B03A965A-D8E6-4062-9E77-FBFAA8123095', '4003583118076', '      100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('454D8EE2-7F77-49F9-A7C0-34A0271462DD', '22E3DA7E-C379-4789-B9CB-840227C5B94A', '5021265243976                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E0DD114-0993-4D19-B004-C3FEA5AEF54C', '89C4FA90-0C2C-4B2F-8683-EFA0BE0CF61A', '4002857002653', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A200272-8F14-42D4-86FB-BC12AEED952C', 'FB86FA3C-1CD3-4251-9AB5-67DF6DAC0BD2', '8710103714620', '  Sonicare adaptiveclean h9042/07 2/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7647E85-37AA-4EFF-BC4C-C100C23BAE76', 'A3D0B93F-F1EA-4A96-ACD4-4C251579DFB6', '3582910130062                       ', '   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E137669-595F-427D-9841-0FEADB7900CA', '38AD7F40-8CB0-44AF-B32C-76757D0545DC', '8718951016859', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD2E8932-76B6-4383-A842-8B8CBB0CFB4B', '123ECF40-D464-4F26-82DF-80FD594A1327', '4601798060946', '  / 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E1D3ECD-5C5D-440C-AA6E-4BDC4A967D51', '38479552-EE35-40F5-BF0F-1F531DE65F77', '4606257000150                       ', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5A06335-6A76-4CCF-B6C3-37C2F4611C4E', 'FA6DF15F-791C-45DB-9C31-F107A255A7F1', '4620010796500', ' velvet / /     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3218BDDD-8203-4F28-98E5-73148E4DC21E', '7DB58EB8-3C24-49F4-8DEA-344194463CCF', '4607087850694                       ', ' velvet /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91CD9291-1DFE-4E95-A295-119736051420', 'E45AEB9A-18E8-4D1D-A43C-81B0DCC0AE6B', '4640018640957                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2064495-15F0-4B79-AB4E-ADED57EB7E3F', 'FD899192-D6C7-49D4-8917-BDC1A7DD2314', '4750232009987', ' 100/ 5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EAEB0B9-E6C5-4A71-A044-F67AC3A0C518', '299CEF2C-0B80-4F36-9E24-ACA5314290C7', '4612613500059', '    2 / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70BFB77B-3D5C-4B8E-9242-2CDBCEDE6692', 'AAC9C947-A6FD-4153-9807-082BA2FC04FF', '4931140010870                       ', ' NISSEI DS-500   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D84D145-FBB9-423B-8567-E1006DC962BD', 'DCEDEDA4-E81F-481B-BD16-2BD625E9E4D7', '4015400224211', '      4-9 58', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5F4AFB8-65F1-482A-B41A-B5742C6DBD53', 'FBAB6280-0621-4527-984C-70693BA60DB9', '4607013790568                       ', '    1200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5272FE8D-2A8D-4839-8F1A-094CCB50815D', '60B0BF9C-E61C-41FE-85EF-DF4BA2BA6BEB', '8586007540579                       ', '   25  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6850C7A1-FDF3-4AAA-94FC-3C650AD1A4F3', '7C0EABD8-3FA4-4555-9477-458D55853856', '3282770107746                       ', ' /        200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BBD7947-735E-4A58-8872-8B5D0E7F7832', '28EEA763-FF30-4680-BC6A-D3FFCDB0CE1F', '4607045192132', '  2%  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADD53B5A-9540-471E-B4AB-9146ED8D130E', 'ADD61BA0-3513-41C2-99B3-EB39663C4B04', '4049500586412                       ', '     / / 55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69AE6DF8-F35E-40F9-8B17-EF905E6DD8E9', '1A6FFA9D-E971-444E-B244-7BABEB0CADFB', '4670008160530', ' 200/ 2 -  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B59F618-5F02-4E74-A360-86F31D286741', '95BCC606-342C-4403-B740-BE6AE33D5DE8', '4607020904934                       ', '  37  2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C9646EB-217E-4E44-BE84-B2B93056D7CA', 'DC662A53-AB00-4A36-984E-C54A4A1EB153', '4602435006808                       ', '    55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('269BA03B-E144-413C-A485-3B735BF14229', '26C3F6C7-EBB4-4A7F-995E-62493587B578', '4015630004713                       ', '-   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B871485-4CB9-45D7-83BE-8F36CB9094E7', '1F195D89-9867-4DE4-9B20-08106AEDBF72', '4603014001764', ' professional      30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87687B33-904B-45BC-881C-96401E1E96AF', '196EE84D-4509-47E4-81BA-E7728EDFD864', '4607086566602', ' - /       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10B29402-FED1-49E8-9FD2-AD451BFB60D6', '67223479-F2B7-4E0E-93C9-1A09BEA0614A', '8009315043377                       ', '    / 4337', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16AE5CCA-D7C1-4F98-9B9D-AF3979C61502', '6A8E37E7-ABAE-4D8B-93C5-F9296C6347BE', '4603988013213                       ', '  15 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCEBE4CE-61E0-4B0F-A5FD-9D4421272306', '67FB1999-40E0-44E7-BCDC-59423E210306', '8009315000028                       ', '   //,./, ,/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65AD25BF-20D0-4FF6-96A5-E03702B4AAD1', 'E9EAB32D-3659-4CAC-9400-F3F543F75583', '8588000133963                       ', '    / 1,25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C661069-9B8E-4DF0-B8F9-9A0177D21B95', 'DCF822E4-1DF8-465F-B9B1-F1074FABF905', '4810201014081', ' 200/ 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0D408BA-5D44-4B0B-8D3B-645E6D6AE6EE', '34B6583F-D447-4A9D-B023-42E7BE7D5684', '4620001090471', '   / / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29180FD8-A320-4A87-9202-BA1BD6D8FBED', 'CBE28F90-BD08-46EA-B34A-27387C6B25A5', '3594459300226', ' 10+1,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A4DB50A-E137-480B-92A5-A5CBF8E50392', 'EFC4B0D1-EA14-4443-9DC4-711E1AB8C55E', '4607094177746                       ', '      6+250  5110', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0C246BBC-4D0E-4D9E-99A6-93CB13A00373', 'AED0A6E1-BF03-42F8-ABB8-94896F09C05A', '4902011851458                       ', ' goon- cheerful  8-14 /l 48', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02FFF982-95A7-4517-AE84-A167D6EFA58A', 'A66BDD77-C786-4D63-89E1-6CE885593F51', '4810910001426                       ', '   900   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00DAFB01-7E5D-468F-8D96-F603F1D46695', '2E07FBC9-0B0D-4AA4-A312-13DC51509689', '4607014000161                       ', '    16   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8CD81CE-51A3-4CDD-AD2B-6631EC8F2752', '739026C5-2657-4708-8256-28BE87BC695F', '4607089540067                       ', '  L', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A3318A4-B418-4BC8-BDE1-54E111F56A98', '2C005ED0-4A59-4BBD-9385-67B246D0A869', '3504105030940                       ', '         spf50+200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CCE2038-9C35-487E-A57C-BE2AAFB41522', '2CF4C11A-D549-4361-83A1-A6F23E2CB724', '4600908021631                       ', ' 306   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA349CD1-D602-4873-B303-31CA51A05042', '218DC9FC-3727-4414-9B17-A28712DC9AB5', '4015400740698                       ', '    /8-14 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79FFDA4F-EA11-4E33-B8E6-CF167044DEA8', '11041D9B-B501-4F18-9913-D6A689FED9C5', '4607003246051', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CC58595-F30A-4C40-BCFC-913952856C6C', '62A35EDB-56B2-4850-9E60-16000ABC75DD', '4602866097932                       ', ' /-1555/  XL ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6118D03-4D13-4B43-8B9E-489DB23EAA8E', '448B12A8-00B9-4DC0-9E24-BE6E3FDC6944', '4602809004331                       ', '- 50  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6EC12D0-30C0-4204-BF2E-531BA10C4FC1', 'C289C6DD-3ADA-4762-ADEB-C2498511C39E', '4607041069940                       ', '      2  697', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33DC900A-E703-4D88-AA02-0DBBBE0EF019', 'CEA64C5E-6036-4129-8BFE-F657B304D87A', '4605964003652                       ', ' 8  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09D18F87-D49A-4197-A122-01F5CB2F556C', 'F1DBADC6-D89C-448D-A1E9-5DB75E3A7F2C', '4603423001133                       ', '   95   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7C3D426-6C30-45C5-B409-3F9D0B3D369D', 'EA18A15A-17E7-4C62-9ACE-21E77B7E3C3E', '4603188000754                       ', '- . 1 -2 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99ACFB6F-C402-4F4E-B3B8-DFCC8AF7797F', '95D77512-2A1B-4BCB-810B-D0AFA90610F2', '4607126030865                       ', '  1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49967539-2FC5-43D6-9B9D-F834D0DEEE2C', '2EB46EEA-AFA3-4123-B87A-0D53479F3A82', '4601774005589', ' 28   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF2E8BDE-A0F1-46BB-936C-C98D86FA9B7F', '2E27A9C2-18D8-4049-9779-A581DEA72ADD', '4630009186434                       ', '  80    5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4A41A3E6-C63A-4D1E-9D37-725A14D76472', 'F58F1A80-3F1B-414C-8F81-F4AAA58030A6', '4605319001548', ' /  135', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC4F4E9C-9CB2-445E-B7C4-4CDCA9AA71A0', '1159EFA0-3DFE-4355-8C4E-668C9649B66A', '4603188000778                       ', '- . 1 -3 //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('670D8C4B-019E-41B4-95A1-C0134F0613A6', '8C8750A3-3373-4194-8C3D-A1EE53339582', '4607070029649                       ', '    spf50+2  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92EE757E-F99B-4B0E-87AC-339C913FE6D0', 'F811677C-E2C2-4EB9-B341-1B318EEDF475', '4607086562574                       ', '     /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5628BEEE-446B-4C49-8304-FD1AB5E6DDFD', '23F66402-00D3-4644-8CF7-B00FDA359B6D', '4003583075843                       ', '      . 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E23F975D-D1B3-4CBC-9703-091B3EE39E8D', 'A8C6B332-5223-4C25-B737-58BACCC14BC0', '4603720251125                       ', '     40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BBB5D851-B35D-4B91-B0ED-3E0ED7C8E6D3', 'CEE4E502-489A-4EBA-BB60-3D72C6A69A1A', '4712803561799                       ', '-  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('942C5A8E-0A8C-44BB-BE34-6052CD44CFBC', '0C107F0A-CD82-4010-9C67-F05AB1EA89E5', '4680007211522', '  / 11466/12021/ + - 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF0615F2-AB97-4113-846A-3437109EEF02', '74FD9246-5FF1-45BE-B867-DBC920048116', '4751023292069', '   - 12+ 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D6AB400-E096-43B1-8BCE-756ACA1BACE8', '6A249733-D930-4DE3-8408-348ED4B2E737', '4680007751134', '  6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A94C0F0-EA43-44E8-BC1A-428C26A42120', 'FDF5AB70-11F8-4012-BCEB-C25D733910AD', '4607172377075', '-       30 / 3-7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('409FC9F1-0AA9-4101-81D9-91BD20B1366D', 'CD184BA0-D692-4546-AE4B-CDAD2400B677', '3760001050011                       ', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FE57390-61FE-48A5-8099-C532455E0DE5', '8206E8DA-72C4-4453-8B4F-72A43128316D', '4605077010271                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A5ED79F-BCA0-42C5-88E2-CC14506FB15C', '03253C20-5845-446C-983B-B24C953AAD07', '7613033688959                       ', '     25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBFB7460-5F88-4F03-ABAD-DF53C1D48476', '3A72BDCF-F2DB-4EA5-A6F8-DE7EA314BC3B', '4610021170161                       ', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AF69676-07AC-4C8D-9C93-50E8BB29EAF2', '061AEA47-07C8-4C85-A524-B33B976F1202', '4607051793484', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D434D23D-48FD-4C3C-A5EB-97C9DEC81F25', '97094EE1-F0B6-44BF-A73D-AFBC417A45CC', '4603726763240                       ', '-       - 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DB2095B-95A3-4CA2-A481-376D2EF1A90D', 'A5FC3D18-370B-4056-A6CA-CB5D8188C8AC', '4670017926820                       ', '   /  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('675BF2BB-69C8-4C07-9D95-861C78AD0489', '66B7EAFA-22EE-4167-AE6C-2CF62AC92048', '4605738004816                       ', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C2C3987-F6CC-43AA-AAD0-2D06DFF6F087', '5DB365FB-6BF2-4AEF-8EA8-05AE46148006', '4602509005409', ' 10/ 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84D63DD1-6DD2-46AF-80E7-A561E69122FE', 'C8ADCADC-8BBF-42D6-8E73-1A410CB1DF01', '5900516006921                       ', ' .  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E04BD50E-76A8-4204-8BB6-25D28B3B5842', 'C0116DC8-682F-4E10-A2F3-6B034FD7B458', '4650001792716                       ', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70A6174B-60D4-4D6B-BF3D-B07B01888854', '8910D97F-490C-4EAC-95E3-028F74B315E3', '4607037190689                       ', ' 5000/ 5 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('995A647C-53B6-4B18-BAB8-EC160593820D', '64D0B2EC-97AD-4E05-8A80-43BB053001B0', '4602233006888                       ', ' 50/  120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F77CDF6-DFCB-47DE-AA7F-53610CB33E8F', '83780C2B-77D9-4494-B32F-E8449D1B4242', '8901387001821                       ', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BAF66B70-C6EE-49BE-BCBE-60E62C2CFAE2', '116AF549-EDF7-4203-8F41-19C2F4C0CD0E', '9607058010244', '5         35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('090FD610-4255-446C-81B5-B0922BF75929', '29C28CE3-5367-49E0-A7C5-E167333BF141', '5900516421106                       ', '    "bella baby Happy" A?40+40 "". ( UA.10.00273 , 10.05.2014)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83A113E8-5719-4A4E-B8A2-AFA7216CA236', 'A0078C2D-9EA4-4126-B393-680BC13213A1', '4607101209347                       ', '    " ".  0 . 120-125 ./, 12012/144/12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D3073B0-DF10-46D0-951E-F39224A94447', '09782574-530A-40BD-8981-89CC907936E8', '4903111243976                       ', ' moony 6-11 62/m', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('290D998A-7E45-4EB3-8DC1-CD1CAB8355BF', '97BD8349-4843-4AF9-98B9-AB8A2064D22E', '4903111184293                       ', ' moonyman-  58/m', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CDA06ED-AEAF-4AA9-A018-917A97974F48', 'D9E30DC8-5169-423C-815B-4593D663F9C8', '4600702092332', '  -     40 N 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE327D0F-7FD7-4E49-8AF3-9E5303245B6B', '62737BA9-36C3-4186-973B-CD91E71D9D62', '5060038502247', '   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F023E0D-3935-4737-A1B6-11916221BE17', 'A320851D-A587-4604-AE48-488AD07F4C06', '4810201017419', '   700  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1944F285-84A5-4D0F-B852-84AC2609C66E', '918CD9D5-6421-40BA-BD45-B022A1DA036D', '8714100706336', '    / 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('779432EA-8770-4C64-866B-C1CFD27FDA83', 'D0A0B85B-E175-4B29-B556-0B60E994D86B', '4620004951809                       ', '      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('011AB204-7BA3-47C6-950C-B5A0E79B88F3', '74D48D98-722A-4E88-972D-C4FA1793E63C', '4602212010035                       ', '       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54DC6162-A0D5-44C1-B796-85E00FDDFB91', '9C5057FF-9F16-4A43-8C42-29228252E3FC', '4607003247140', '  2  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74522CC0-1DD9-42B6-8C9B-037360B7EEF1', 'B95A3DEE-E38C-4FB6-AD60-A4FE2A959C8E', '8032779759348                       ', '   /       500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F4ADF6A8-6A76-42F0-BBFF-5157FDC36621', '9F99EC47-6E4C-4EB9-8293-4D6EBAF37790', '4606982002139', '   - 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F929C293-A520-4C29-8FE7-8601563A047B', '2DF61DD9-BE98-44C2-8FD3-561ED3B9A5E0', '4607155640271                       ', ' leiko 5x500 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BF13332-CEC5-4FDB-A007-0D6288F28801', '0B4BAA30-DC05-4462-AB22-DB1209D62858', '3574661064536', '        20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5179703-05BE-4419-A70D-C7BB9268F5E9', 'D4C422AD-6D1D-4999-97B2-60DFE77DA8A2', '4607011662508', '  2 30 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA119A4A-75F5-4FB0-995D-681684ED7B8A', 'D85D6F88-1534-4E31-8E94-EDB4E9B44C49', '7038319109100                       ', '   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04F15421-56BA-4CE5-B697-568AA13E8A32', '9551D7C9-93A1-4BAE-9F32-95508C678611', '4650069782025                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('94EB0544-F3DC-485E-ACFE-3DBD6738F121', 'FD626901-2784-41BD-9344-2ACEF13552CE', '4660000109231', '  -  /. .. 17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AAB8598-2058-4343-87DD-3E9B6A4A332F', 'BA9BD0F9-A6F2-4EDC-BB6B-0BB78FA0DD58', '7350028706105                       ', ' / cb12 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D168C50D-4C7F-4467-88F0-E68A40BEE64E', '64204390-0769-4253-B9BB-D5BE213A9ED7', '4607005891976                       ', '- 50  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63FF76B0-2ADE-4B77-8CFE-EE15BC9DBF5D', 'C0702D4D-DA85-47CB-A3F6-6AADD91A0D2A', '4605446001510                       ', '   /    70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E0792DC-CAF5-4060-84BF-50003E2041E4', 'D2A51843-A15A-49D3-BA18-A19235CA32D9', '4601669000644', '  250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D841FF06-124C-4FBA-BF30-B617081146BF', 'AF286C11-E294-452E-AE91-86E04AF3CEDE', '4607005322043                       ', '  /  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD4CC5A2-BB39-431F-8C79-FF85984E727E', 'E056EAFB-8170-412F-A2A0-525D646B4D28', '5411416043553', '    6090 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0E92E78-D1A4-428D-848B-BFBC1CBAEA95', '93FA0B01-38B5-41B1-951E-F73BA072A995', '4607027768942                       ', ' 15%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D3E1F77-A050-499C-98BF-0E90379635C1', 'AD0FE8BD-7743-49D8-B3DD-373FB9FD3113', '4600689601404', '  200        5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5BF199D-E772-441F-B841-49ED3E4BF069', '37DB9AA1-40AE-480B-B042-C671DC10067C', '4600689603460                       ', '  200 -    5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B5DDDA89-D6FE-4F17-9CED-7AD21B06506E', 'F604DF8A-9A24-48CB-86BF-7E7712D66491', '4612741480926', '  55 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43FE42E1-65A0-46AA-ACF2-34F2BF665B45', '3C4B81C2-B205-44FA-B52B-8E8C79392521', '4612744700038                       ', '-        20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9A03E27-DFF2-4927-B852-09CF6613E503', '86117801-F0EC-4884-9F6D-5C36DE96772F', '4670010370026', '      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF5186FE-7244-436E-8581-6E2B1987C752', '99113CB8-0B86-4EBE-B910-EC9A1481A5E0', '4607061253381                       ', '      25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F8F2A75-A38E-49AA-A5F5-37CBEF038806', '2E4A1F18-AF5B-4421-A06C-2AD07B8DECF5', '4605581007989                       ', ' -    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91E3C83D-FF45-4AF4-B1C6-A689F301145B', 'C12593F0-C2D4-4FCD-9018-C7968577C405', '4603860000966                       ', '   1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2B1B6F05-B333-4D33-8CB0-3BFB5A86E019', '4452138F-2CBD-4023-93FE-20C3581F2802', '8030009500982                       ', '  - /  200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A65849C-47D3-4A14-891B-53221D0A1980', '9BA9D096-C6D7-46D2-83BE-079D82AFA7DA', '4823017800670                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63591CB3-DA39-4CC0-A230-8BC7A4DA4900', '5B14D234-D4A3-48D6-AC40-87DCCCE7EDA8', '4602441016600                       ', '    0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8594A53E-8029-40AA-B4A8-781B039A7AED', '7DAD8083-0A61-44D7-9001-3088502673B3', '4620006501842                       ', '        10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B635EEE1-6DAD-4ACE-9C9D-DDA531BC9BD0', '688CC339-3413-4878-8C4E-259F38B1A251', '4049500770385                       ', ' cosmopor  advance /.  barrier  2010 25/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0F7B81E-4C1F-4AC6-B56D-F400FED168BF', '17AF5208-CF75-40AD-9793-C074B0B6FE80', '3337871323257                       ', ' ,    3  1, 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('819964D6-1E4A-46CB-AEBA-D450D70B3F3A', '916337DF-CAC5-46F0-A784-A733AD91E2AE', '4607152730609                       ', '   PRO Gold Edition ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E1E1AC4-890E-4564-82FF-B588A774FC66', '2D966801-3262-43E9-8529-C1C8CF6DE78A', '3850343026956', ' 15  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82593E2F-8B7F-4BA3-959A-39D09FDBCD43', '6E01F1AA-6ADB-4C12-8108-B8064A8F16AC', '4602902000469                       ', '  1016', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2863E33C-C404-474F-8E5E-F95C2C46578E', 'BE2F5341-0C82-46A7-B9C1-08FEDAC2A8D7', '4902011751383                       ', ' goon- 9-14  /l 44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CB93F71-D465-412A-BE82-9C3F9F46BDA8', '7C557233-2129-4106-9FFC-2BACB165650A', '4627074840101                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEA7C566-810A-4B33-8C38-7636486EB538', '82069368-4FD3-4972-9B8B-062836A0295E', '4610012370549                       ', '    /  /716413 0/ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A17F48C-C330-4543-B4BE-0012E1BFB3B1', '692BA21F-A3F5-471B-BF07-EFE511A9D5B1', '4605342002260', ' . . 250,0 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFEFF9C4-5586-4A95-9AED-A7847813C1D5', 'EDF7D209-8355-4832-AAD4-729442626024', '3014260265861                       ', '   ii   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('515BCD88-BD3C-435A-B896-FF6F542588DE', 'D1AD755C-0D4D-4F38-BBE2-31859760A955', '4680013241131', ' - 500  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78825A13-DB7B-4214-AE59-58C39F6EF65F', 'BAEDEE58-C01A-4069-9623-28ED9AE7E591', '3282779017893                       ', ' +  -   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14A9D62E-7D10-4023-BE1C-61375699C714', 'B35264A8-89A0-498C-B279-188E98FE81AD', '3282779234832                       ', '     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A4CC1509-CC27-4DD2-BB27-EC4A078968D0', '45BDC4C0-16C9-4E1A-976F-869F4836ABB2', '8901148240728', '  12,5+80  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('951A20B3-6D68-4290-B589-5CBD99356F28', 'FBD5EBAE-C8CE-4F91-9742-4E458A96ED41', '4605446002104', '     / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A26EC342-20D7-4812-A8F3-F4647B8F978A', '7D9DEFFE-A5A0-4D14-9575-17F5C84C12AE', '4602779004256                       ', ' 0,001  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B1E2290-084D-4430-9B21-BE191726584A', '16F1059F-4A9B-4451-AA87-65995EBE462B', '5900002072294                       ', '    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6E0DB79-B235-4B9B-AA6F-156475C78030', '97D072A9-FE50-41CF-9E2F-8DE14B890464', '4606249000212', '  /     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31636FB9-4AD9-458B-BC25-FDDD6314A585', '36960DCA-E5D8-442A-89BA-E646BD3D0B84', '4603184004480', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB3436AE-F934-454F-B83F-7F086BCA7EAF', '1DB22329-DD0E-4F00-A884-FEC9A77F2103', '4602435006709                       ', '  2x500 ( -)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C79CA48-1320-42AB-82FC-099EB56FC56E', '3405F9C9-173C-4F8C-8D4D-A72965B966E5', '5702191012682                       ', ' 0,03%  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D99B8649-E441-4E44-A1B8-48F476A369CF', 'B535E5C2-B2EE-4E51-8E71-6EE91E421D86', '3282779043137                       ', '     200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('238F4BE1-2F18-4349-8828-64D5880F3B23', '3156EFBB-77BA-4DD2-B16F-010EB83C5A2A', '4605185001260                       ', ' /100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5448BD13-6E37-4C73-879E-B25DA23FA365', 'A16DD432-898F-4706-9249-93D19DC3020E', '4823002000153                       ', '   0.6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51531971-94E4-44C4-8102-65E31791C69A', '9B404B6C-7D28-4744-8272-6788426D1726', '4630009180432                       ', '  950  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F096988-BE4A-409A-BB21-35B7D70FAD88', '7FF5BF7E-8241-461A-A319-946D8242EF45', '4610012280404', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72234B44-A92D-429F-8E5A-3F93CAB79249', '3996D4B8-66EA-485F-B8E9-0BE153847F53', '4680287517895                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1502611-DD5C-465D-B0F4-D606D2DBC730', 'A0A860FE-24EB-4F9A-8C73-68819166C82F', '5310001190965                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1A75570-2158-466D-8912-73BD5153CADC', 'DAA48F30-A724-4465-9DDD-0F8A7F5BBAD7', '4670017926783                       ', '     155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B24FF5F9-846B-4CF8-B1AC-399E3DFE5C04', '09B30EE0-471A-46B0-A9B0-0E0514CA18DA', '3700281701906                       ', ' organic   21  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7F03E27-3217-4D5C-B408-5437452F5DE8', '1199B6BF-4AC1-405A-9382-2AB534F93387', '4640013300306                       ', '   2 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4518359B-20D7-4AB2-94EE-00797793828B', '15581E6E-6ADD-4878-A0BE-D13EE2525D16', '4602822000549                       ', ' 40 /  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F836AD4C-68B5-48D5-B8C4-60993FAA01EE', '8E6142DB-EF07-4A48-BF0B-9871B0B2A3E3', '4603423009788                       ', '-   ,   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88B9496C-85BC-417B-BFA7-D905F0F95C7E', '40013391-C925-4793-A0F3-1DD54250365B', '8058664009923                       ', ' .. ., .,.,0.+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7BB472A-1D3D-46F4-B2C4-32ADAA44DCB6', '4E711F66-0264-4119-B3B0-CBEE721CF2DF', '4607010248758', '      /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BCD7DC9F-42AF-48CB-987E-A006C11D7959', '06255162-0099-44B4-A325-9E6422B370BE', '4607005899002                       ', '- 16  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('197A61D0-9AE6-4F16-BAFA-6F4B0B437183', '882EEDAE-BD6C-425B-9B4F-54C2A4520254', '5907609333513                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('412B26A1-4996-4A40-947A-73D1285EB7AF', 'C97868DA-790C-4C81-8D81-BB912CB3671F', '4650001688989                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4356171-1A1F-44B1-BF4B-032A086715B2', '790C34F3-FD41-4DC5-963A-1564A29B1315', '4660011214412                       ', ' -  -    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DEB8B39-A20D-4C6A-91C6-018D555C1DAC', 'FE30DCA1-22B5-44A3-B9AB-C012B17C041A', '4607172377082                       ', '-       30 / 7-14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADE5EBEF-E865-4C1D-A635-FF9F6BD6AA0C', '1103D272-A7F1-4483-8BFE-307AD6325A58', '4607154693148                       ', ' Little rabbit - 2--1     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BD610D5-8361-411D-A11D-18C39A6B38C5', 'B7FB8259-6E26-4EA7-8941-55DF91B445C7', '4607154692806                       ', '    -     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3712131F-90F6-43CC-935B-FA2A12C5D257', '5D4C74DB-B86C-47EF-9416-C4E078F5C78A', '4680019290089                       ', ' ./  12 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6E24AF7-B0F6-4C75-9617-B3A731914336', '3EF9F525-AC27-4F75-AFE8-3D255B184F55', '4823017803121                       ', ' 1,97,2,', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3B299B2-1C7C-4821-BDB2-3151F7076C6B', '169E65B0-A331-4340-9707-1A6182EC6456', '4030539103794                       ', '    / / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7543FFB-5E6B-4CFC-98C0-34475B8496F6', 'FB7200E1-9A89-435D-B946-D9335336EF1F', '4607086568903                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DC7534C-8513-4DDA-B577-2CE7BAF8717C', '46124273-69B6-4592-8018-160724C6DF65', '4607027215958', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDF35CE1-2E00-463C-BAC8-C4AAD83C1846', '70FE259E-33A1-4D06-BD33-54496F733C5D', '4607027214456                       ', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6B38DFD-7FF9-4573-B2B6-363671FE4EA8', '39C66663-F3CE-4AD0-A967-14743105052E', '4607101202577                       ', '    "" /13828', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17F8079E-E2AE-4B95-9E23-0275DED42646', 'D6E8E393-F89C-420F-AB6C-A91CB08BD9C0', '4607061252872', '  bona   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('006DCF10-1ED6-4C6C-AB25-A9715C5121AF', '7B4C6A83-D27C-409D-A910-BB619B92FD4D', '4605635002397', '- 500  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('931CBD39-0CC0-4346-9186-D2D8B6083E8F', '2D642EFE-ED88-4EEC-8C1B-0BD5CB8A7080', '4603276009447                       ', ' 75  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22014180-9CDD-4060-83F2-FF024D718E1E', '8A1399F2-339F-4AD6-A330-DFC96D5DB6DD', '4607136210028', '    120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E9066CD-32D1-4E72-9B2A-5EEBFBE8CD07', 'D41378BC-87D8-4B28-819D-967CD54905AD', '4640013557717                       ', '     " . ". 17,5*3 ,  6 ., ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C94F969-B6F4-4D75-9429-C3313CCF09BB', 'BF097434-7903-4C30-8C3D-DA7C7E950C65', '4640013557731                       ', '    12.200 /16434', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C99084F4-9FD2-4756-85AC-1DD3FBE78A4A', 'B90E0371-9DCB-4219-A049-21C2323214BD', '4640021710081', '   /  spf35+60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73C68CB3-260D-409F-B2AD-9587936BFECE', 'C65B751E-56E4-406F-A689-1D2F90963F16', '2000001146415                       ', '  g 8,2510   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4044A81C-8BC7-4771-8945-EC3B0914A47C', 'C1235491-9DAD-4406-8381-399F61275465', '4820037960568                       ', '   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A51BD794-B4E1-4463-A215-3385F86A3085', '4B05ABEE-F1AB-4900-9CF6-20E34A25467F', '4627090491462', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12ABCABA-24E8-4B71-A853-DF14A463F5BD', '1631B669-D4F0-49A9-BB2B-7FDA594D65CC', '4607154692820', '     -     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3795EACF-9BF1-4BA2-A8DC-0E0282FB66AC', '1CA5EDD5-DD54-42E3-8DAE-CEA92C9D902A', '2910014720109                       ', '    5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C11965E5-7570-4B1E-9093-9D3210E76814', '7B878B6B-4DB0-4FA6-8428-19C5C15AB351', '4893949230555', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FD6A6D6-3858-4488-8145-63CA3367F702', '1C405319-F9D3-45ED-A5A0-6EF9377F4451', '4607069220033                       ', '  0,9% 1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C9DB337-6584-4B96-B761-B87C196E3CB3', '57B9BB0F-76C3-4C3F-B3DF-A4C2EFEE2CA2', '4607169221718', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CFEF15E-1CE8-4EA9-BA39-546A2C21BA55', 'F6E1449A-0D12-4711-ADA9-23F36BCC1D23', '4650001790842                       ', '  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1DCD3E1-DD30-49D9-951E-656ED9369CAF', 'C475400E-8B36-49D9-AD2A-60151A011507', '8030009701341                       ', '  defense .0134,02 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA168F12-571B-4F61-BE7D-CB659B8C71C5', 'B6C848D1-50E0-4DEB-BE34-7782CA5B502C', '4605658195090', '  / /19509/+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69FE1C16-384C-4308-A3AB-D26DA485D5D4', '2E36DF5D-14A8-418D-9B16-D4DBB53E3816', '3337875551977', '        100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D97F057-65A0-4684-A76A-870897E58ED1', '8A974A45-32F1-46D1-80E0-F180ACD44B4D', '4003583075560', '  /   ..  . 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A976B90-57E3-436C-A91E-5A892FB47BF7', '0A5BD9B6-ECCA-41F9-ACD8-31D1091A326D', '4602435007140                       ', '   2,5x7,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('404E6E55-F260-481F-9C8E-8F9B062E99D9', 'C504C02C-76AC-4000-861B-28BE80A8D95A', '4603905012930', '- 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('155C7C63-08FC-4259-AF91-DFEEE6C8C8E1', '2C2FFF4A-5803-4B99-88CC-6F5EDA96FCB3', '8718164960406', '  2- .-16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEDE7DDE-C8B2-43BD-BB78-827626F28D1B', '52A2673E-9892-447D-ADB4-67EEBCFD3387', '8901387007939', '   16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E73FA951-0D5F-4D15-9AB3-1127EAF5B651', 'EB0B5744-AD8A-4ABD-ADC1-8B639B0E1090', '4601654000895', '  ch 2,2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BF14662-81B1-4356-AAB4-1D34F4ABACD3', 'FCEA1F27-CB54-452C-A22C-D7AD849496FD', '4650069783183                       ', '    18001', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9C8D8A5-2591-4865-9A0E-8A9AA66E7DF4', '5B568DE2-0438-4CA7-A631-ADA27C51606C', '4607154693360                       ', '  - hot blackhead  1+ / cool pure pore  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B28512C-FCA9-47C2-814B-EFED9F9D5FE1', 'C6B0EBB9-6CBF-4B58-9E92-0D771C3F4609', '4607008130430', ' 50/ 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62E315E6-4769-4238-B680-F9A8BA00DBD3', '37F93AD5-BAE3-4E4E-9A96-744086226253', '4601498002840                       ', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD92F6A8-E13C-445D-8538-71EDF3350DF6', '292915E8-FD1D-49D6-A18C-30B751210417', '4600702091434                       ', '  -     50  N 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01253F90-B8D2-4B6B-94B3-3648B8C53732', '2BD78E95-501E-4B48-A245-9F0B26FFB502', '3282779402941                       ', '   . spf30 /  /c52480/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95B5FBB7-B98A-4ACC-B895-D1F9B829AC11', 'B98D79E6-9B79-4DA5-B673-7733F98003E3', '4627129213249                       ', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DCAFE34-244D-4847-AE84-7781B20BBC5A', '1FC6DF24-BA5A-473B-97AB-8B6127B84016', '4603915000798', '  240 +     2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA78F746-D77A-481C-88C7-C8B289AD7B91', '35BE567E-D4EF-470E-B49F-0202F53E252C', '4650002420069                       ', '     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('088EE7F3-5662-46C4-A50C-34CB9CEDED0C', '10921C8A-3403-4529-822F-97A5F4E70845', '5907594027701', '- 10+12,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('472364F9-5347-491E-8A48-C0CF057B9FBE', 'CBD4A154-FC5B-472C-8843-806DE1D6EA9D', '7613034993816', '  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73CC7E3B-9384-4312-8D38-D568696590CB', 'C41D69FF-F869-4454-80F8-13672C71D807', '8806325616764                       ', '  cj lion systema tartar /    120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6166E28A-2E90-49D2-ACB6-CBED53FEDBAC', 'DF6C016A-CDC6-4B2F-BFF0-23945F82F6FA', '4612729880205                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3778908F-5655-4AF7-AF7F-7886B49861D0', '8289F8C2-6EA0-4228-AFE2-823361AE7A53', '4005808246236', '   /     .  /80201/ 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61D543C0-F1F9-4174-9B9D-21E237440B11', '3326FE87-05C5-4819-B7EB-A4A93C304B47', '4008600117742                       ', '     10256256', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF8CF428-8C58-4EEF-8B07-E1C908C81769', '2DD3AE6A-BF9D-4DFB-89B6-73AF0247AE65', '5900516320270                       ', '     /. 8 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8054C108-C87C-4DC1-9B02-C069212D237B', '6CE5AD1D-90B1-49D4-A6A1-1753B941770C', '4602666700605                       ', '   /+ 45 30/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75CAE724-8CC4-418B-9275-D2FA12AC0D3C', '39CBFA3B-5C40-45E7-9AF2-0763288CC1A3', '4627100135270                       ', '   / ( )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A541C4C3-E022-4B17-993E-66F16E9805E2', '573F245D-37AC-4602-A3B6-EDB895B3EF00', '4049500266536                       ', '   84 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA311133-6F38-43E1-9039-8957896CE264', '35A7716A-2EF3-492E-A070-38D5268E7FEF', '4605319003344                       ', '- - /    31 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF82C71F-F1E8-4C4B-993F-C7E7E9486F85', '3B7D8D00-8F65-4B18-9160-09459BF299C8', '4008233114804', '  /      200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6317230-5C45-4D94-837B-B4DBF1F9C010', '91FE1EAB-4B9F-4516-88DD-0AD13A243ED6', '4008233119205                       ', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B207BF8A-5458-46AE-A14E-8A288509AD34', '689B0089-D62A-4944-BFF4-7F9217071980', '4607091481198                       ', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D07B4961-407C-42CB-9583-50A20E93DF13', '1601252A-FAC9-472C-B837-6D626E5909B6', '8901091000059                       ', ' 6 100   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E55FC53-22C5-4AC1-B64E-0111725045E6', 'EEEFE676-A6C1-4B6D-9D57-5F15E5D56499', '0000046025302                       ', ' 0,007%   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B26303A-56CB-4A56-A8F1-6B632FAAAADB', 'DA27F370-E4FC-4F83-A214-E2696A651C5A', '4680038243189', '    /    220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79BD964A-4250-4EFF-96F2-7876466694F9', 'BC402280-6A09-4300-8E81-9A6C46A27F44', '4680038243165                       ', '    /    220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED3050C8-E9B3-4A80-850D-11A9B5A67857', '45AF0913-6F40-4434-89F1-2E118FA4ACA5', '4607154692790                       ', '    -     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0202324-6DFC-4600-AAF8-3998DC527FC5', '6F43CAE9-1328-4B7A-A25D-A75D50D8AF38', '4823015911729                       ', '   ////  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D797B56D-F119-4DB6-ADD2-0729D03CDD02', '80945CC2-E02A-49B0-B5A6-3FA12D2947E1', '4620018875184', '  retinol forte -  / 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EB87138-9145-4F0B-A5C0-9D4D6238ADD9', '9A4D5D98-4530-436C-9F9E-70259401A0C8', '4607154691663                       ', '  /  therapy         75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7ED9A2E-1FD9-45F2-9B21-9BBAB1E8CDC7', '5EDDDE34-278A-49B0-B70D-9ADA3281D326', '4606486001065                       ', '  35  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6FAEF6E-9993-427C-8B7D-EFC66C7B9397', '67DF979B-6C19-41DC-9BF0-491589BA12CE', '4606522009161', ' /    / 2,7 /orto/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFE871F8-EFCA-45D7-87A9-06035522ECD7', '384EDD84-F6CD-427C-A5A0-D5F9CA5831B1', '8594737187513                       ', ' 20  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E804FD94-DA6C-4EE9-96A2-C87CA5E1FDB0', '172641BD-B9C4-45D3-83F4-2437BBA47D65', '3800041903301                       ', ' 50  / 90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B84F329A-8375-4C68-9FDF-B8CB69260029', '30A3CB71-474E-4A23-B28A-412D2842F2C2', '9003576000406                       ', ' 90  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('978DC82F-3535-46A6-8026-9DF0C6DAF3D9', 'DFEAD8ED-9BDA-433C-A1FC-C1CB9CFC3F36', '4680007632662                       ', '   . Light - 60 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E817EA50-2675-4AF8-B03B-5424DF2F2261', 'C2C8B3A2-ABDB-48C0-9842-8FF8D42A6577', '4606033051284', '   2 .zo-FG02-10-Case', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B1380E1-0A8E-45D4-8C22-FA1DCC66FCF9', '51FA6399-68C5-4AE8-9244-093AD05CE29B', '3600541897526                       ', '      - 50 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0192364A-60EB-44BC-B9AA-3D7C5A89FAC0', '8096D103-AC40-4451-B20E-DA4AEA32CFC5', '4605579003290                       ', '  55', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A2F375C1-D4D8-4AFA-B37F-9A4BFECD3B70', '879A7131-AC92-42DF-89DC-6AE1E48DD42B', '3337872419683                       ', '    , SPF30+ 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('709F697C-6E48-4521-BBCA-207117350E21', '47FC88DD-CCC5-4454-9244-644160E4047C', '4607056261087', '    170', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('56241962-5D06-4360-B680-62B0F608BBA3', 'FD3D0F95-41C2-4E76-91F1-0041FF575AD6', '4036534462201                       ', ' .. /highrisk29/ ...l 25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A88693D-0D9F-4D28-B244-53D900983B19', '67A42B12-738D-4678-8FB0-55741336679E', '4605319011691                       ', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C06F4510-55EF-48FE-BB1D-F7707BDFA10C', '8B2B4F8D-2BB7-48C0-9290-85B47331BEEB', '4015672103870', '   omron bf508 /hbf-508-e/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BA8E803-E890-4402-B7EC-3332C7EA280D', '4395F592-9003-4FCE-BBA5-54296FDC254B', '4605086000249', ' 4,58    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F73E12A-E995-4CAF-8EC8-5668ECD61601', 'B2D122EF-79E7-4B91-BD20-8C3749D46983', '4601026125225                       ', ' 50  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('315EFF69-C079-475F-8FE3-369C6A62553E', '75FADA90-99D3-4E15-9386-80CFFF1DF2A6', '4603014001290                       ', ' professional    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC8D1330-4CB4-49E2-AD5D-D4A21F7A82FF', 'FF5045A1-6F00-4899-BBBD-F1794C409A31', '2000103608934', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2CD679A7-F5DF-4A56-8B66-0931C99313C2', '8F2BE0C3-B8C1-41CE-B086-E591EBE618E4', '8699536090269', '+  12,5+50  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('363AD90A-75DB-480E-B97B-C3B3CED644C6', '4CB3EC7B-0C81-44F3-8E1E-5A42FB865177', '4607027769710                       ', ' 80  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('14CB151C-F19B-44DB-BCDA-1D6A764FA91E', '219A1DD5-55B7-4550-AE0A-130D52A05349', '5903267902474', 'Veet  /    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10625D43-3EDB-4FE6-8606-6B5E4384DBF0', '421E7737-39D4-4601-858D-5AF54EA04663', '4650057002982                       ', '  /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1E62A60-D608-4C3D-96D1-9252F92A6874', '7BD0EB90-D21A-4893-9FCA-D3C2E544ADE7', '4607086565049                       ', '       90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BF21D2E-EBB7-4FB1-A256-16C468462D3E', 'F3A76979-D06A-479A-9CEB-9A419A8C8ED9', '4603423002529                       ', '-      120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('579CD566-25CE-4842-9C68-8E4D15D44AA4', '73D808DE-4C1D-4A8F-ACB7-79693EC5BDD8', '3337872418730                       ', '  5, 15 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('34D4BD1C-5C10-497B-9659-1503A7261326', '7F276A8F-EE80-4620-AF6C-D1F49C46EB73', '3337872418570                       ', '    + 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3EAFDF75-3DF5-4ED6-AD5A-FF2AA147C9D9', 'BE95733C-CAF3-47F5-B58C-C30FBAB00EE9', '3337875537315                       ', ',          + 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DF51649-AAFC-40B4-BF72-02C2476D5FBF', 'EAC1B9EC-EA44-467A-8CE5-349E009ED30B', '3337875519724', ',      150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6753387-4BB6-4273-BB65-3809D685F54A', '1FBB029A-F0BB-4E67-95EB-67681FD2F92B', '3337875574389                       ', ' -         150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF0F42E4-53B6-4270-8400-CDBB6FE480E6', '523EF25D-2EC5-4C95-BCAE-6842C9B8440B', '3337875574358                       ', ' -         250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('465A92C5-297A-4A1D-9D75-26013A13261D', '84F48DD8-C722-4DB5-B682-AD6B194F2AE7', '8901148241305                       ', ' 20  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BC67006-3001-4B82-A8B0-E7520C05578F', 'B3F8E9F7-5479-4AD3-B25F-65B5271CB12F', '8427030003580                       ', '-1  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A51B5BA9-04D8-4427-9215-CA5B7E2F3384', '53C17122-3373-4F8A-B0C6-5ABC3B0F5B60', '8717163566282', ' -    135', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CDE3D1D-1763-47C4-8F2D-911440B9A335', '9152EBFC-2B85-48FB-843B-632CB5F7372C', '4603423001072                       ', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E2402B4-4CE7-4D85-A1C5-C4E8E16AA9AE', 'E9017EAC-36AC-4674-BDEE-9CD0595CF558', '4607083728461', '   20 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1808618-1A39-4F09-8EAB-4A00F652DBB3', '2CC968D4-618B-4982-BF26-ECA6E58D57F0', '6933315515584                       ', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6BD4CA11-CF26-4BFA-9459-B0341ED4CE74', '69AE0BD1-E57C-439A-A279-1499F5D087E7', '5903407421018', '   240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CC29595-7E28-42E7-89EC-A4BBAE0B07BE', '249651DF-CEC6-4F07-A172-CA54FE6E4773', '4603276009461                       ', ' 50  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('59E317CE-F27A-45C2-84CF-C8CFDAB0B6C7', '5E489C1A-5A44-4C9F-AA2C-F1A990B00B18', '4601026307201                       ', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA46839F-5DC6-4185-9AC6-3BF20B3C1FD1', 'B60ADC36-0BA0-48EB-9273-D5C06BADCDAF', '3282779224178', '    SPF 30 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9BE29F6-43C9-4DBA-8E3E-6A3921DED6C0', '4517824F-C842-4A67-92D2-9FB0CB289D56', '5903407041124                       ', '     320  12+ 4/112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D00BB4E8-3647-4AD9-8BB7-8B2644AF96D2', 'A5E0470A-44EF-47F9-ABA2-F20BED970E78', '4602676004472', ' 250  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF6A81D0-C157-4F8E-BE53-4DFDC467A7EF', '110FDE99-3B38-4571-8A6D-6EB0628E713E', '4620002186012', ' brg+ 3 --       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60A42FFB-0624-4725-AE9D-AE11FDCCF3DD', '3A7CABF3-F7E7-4386-BCC1-15A8F7E62E66', '0382900909035                       ', ' 1 bd   u-100 0,3312,7 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B78128B7-27EC-411E-81F8-44C60A4887A1', 'D9834225-F209-43BE-B0AE-0AB5846BDE82', '4670016720269                       ', '  waterflow 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EAA88F0E-2850-4055-AA68-728D50F67B97', '90535594-C8C8-4384-AB4F-6CADA5DE4638', '8184280040009', '        25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('088D1CCC-9BCF-43DB-A6F2-D4F3FDAC2379', '40939FDA-32F2-4521-AA22-99D70B5A8CD2', '4605370004113', '   ./  3  6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87008859-3A12-42A6-AF5E-7B48A3BEDD01', '6EE7D5D3-564F-4DED-AB24-469A12F47757', '4607027210458                       ', '  -  .. /6-12./ 11021', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C51EE62-534F-499D-B8E5-6D8CC8CEAA81', '4C5B8C1B-C765-4A25-AD8E-8D9E9B8A3943', '8030009741293', '   "XX Fine" 1.8  . 4129.02', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88D22E98-617D-4768-871B-55A1ADCF6438', 'F5CB6BAC-899B-4E82-ACBE-30DD97E3456A', '4604060997384', ' 25%  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04B46B62-76CD-4FC0-94FF-4E2C5F87EE40', '2C4CDAC3-34B1-4AB7-8CDB-6E93C7E6AA99', '4008600122807                       ', '    trendline  3 10737601', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2141777-A488-425E-B523-B03B0165B449', 'FE62C60D-A868-4C8F-952F-F79459447DF3', '5025970023496                       ', '   /    spf30 /85133/ 4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D770D6ED-B0BF-4401-A897-8B8E1C21DE46', '0B20BD90-65E8-48C9-8312-B9DBC0DFC5BA', '4607006670198', '     16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('355F494E-9686-47FF-8343-85EF5DD05525', '43823E13-05EE-4150-B7F5-A072204A6863', '8904102204903                       ', ' 0,01  // 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E8F5E9A-B929-4049-A3F5-08193800E7C3', '9C9815D6-6C97-4FEA-8E2A-FA283A8D1B62', '8904102203685                       ', ' 0,02  // 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('867F0944-9335-4F66-A2F2-85B97A831E59', '99B6E4C5-4185-4709-8BCB-4A5565456874', '4607054703213                       ', '  cleanland  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CA2B511-288C-4C11-A9C8-B072E91E6A5F', 'AF307963-2E37-4611-A506-9B184388D4CD', '2910002470016                       ', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C78C25C6-B1E6-46CE-81CD-03D1A103BB18', '83502E98-1CB5-4816-97B4-058271AE2E6C', '4620006940498', ' /pompidu/     /  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88020C08-797C-4F90-A6D6-C9A3EC97AC2F', '041A0E50-0F7D-4A1F-8EE7-B30D685EDE8B', '3282779008693', '       /c00869/ 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E35CEAB6-7141-4925-B92F-C3D90EE56267', 'D2A2AAB6-B168-442F-B2FC-6BC7B0252FC5', '4607039970029', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D8FADE9B-3852-4B7F-BF7D-B5028B09F1CD', 'B324190D-3E2D-47B6-AE14-28E205989533', '4028694000256', '   0,18% 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('72BB3F26-5E06-46C1-999F-F8209D605539', 'F6E8B9DF-49EC-4D8F-808A-2A2AD6FB4DE1', '5029053540092', '       16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2FD0DBA-2DF2-4C8E-BD30-548E4DDC19F9', '51C35B61-6FCF-49D4-9215-8372C98609AF', '4680003060438', '    2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A3438D6-AC57-40A8-B25A-9AB364ECD27C', '71E18A71-ED2A-4B26-9311-78F74B98F644', '4812317000095                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('638DBF92-00A8-4321-9738-544BBD90F512', '1466836D-D142-42BA-90E5-427ECAB87F07', '4602866025645', '  ( 5 ) -105', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('392A6923-CF50-473F-819D-73A802285F36', '5D179DD5-9C96-4B35-90CF-097247FB2EF9', '4620020880343                       ', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('960FA3E7-35DC-4914-B02C-0B6803FDB460', '07324ACB-A15B-4209-A0E8-822568D5E4F6', '4670005861010                       ', '  - 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('188EA294-93A8-408A-B8BC-A9FBEDDFF384', '1D2CDB76-5D1E-4695-96FF-038D74760B75', '4640021710142', '   /  spf45+ 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCC80A05-1026-4FFB-BC3B-2E33DE304317', '7129D1D0-7A7A-4170-8C45-0BF25FF59BA7', '4603726719650                       ', '      7219 N20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2742F6AC-1055-433C-A7E8-9558ADE391B8', '4BDDFDA6-6F41-4105-9640-8248C30FCFB6', '4603933004471', '-  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8059337D-35CF-4478-BB4B-1395AEE1B6DB', '4BF46F49-66E4-439F-8BC8-382F73E17747', '0382900910031                       ', ' 1   u-40    30g /0,38/ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFFC4776-3871-49D2-801B-00B691217A9A', 'EFEE3FCD-C56F-4CED-9A90-7522B44C4487', '4660041990553', '    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F8046438-220A-44B3-BC62-3CAC52292467', '0D953D97-069A-4B20-86A1-D92A3956675E', '4603720587255', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A161A55-3D17-4070-BBBA-97F09D941EDD', '2D08E710-834A-4743-BD19-33B62AAABFC7', '2000002651031                       ', '  /   52-54', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8251CE99-1689-4BE1-B31F-C983B6512644', 'E53359AB-88B6-4DB2-A4E9-2BEC1549E02C', '4650001792129', '      / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07DBF72D-9B22-4BA3-A209-908B9EE136C2', '3633EF53-9EFC-4A48-A019-5FC68164CE47', '4607092930831                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81107E66-2B7C-40F4-ADFF-8F880F0C83DA', 'DDC8DF7E-2BD8-4C36-873C-DCFD9EE2D12F', '4607016284606                       ', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D1CD554-0A4F-4E2F-B0A6-3284ED48CD96', '141D5FBF-1AAF-4401-BDA6-129B24B309FE', '4607001500742                       ', '  0,05% 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0790D2E9-1F1F-4FE5-B79F-DA7F499A21D4', 'A517E65E-9D99-4041-8352-E726F75485B0', '4931140011372', ' NISSEI DS-1011   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1811BC28-817D-452E-AE55-8F527216C8DE', '40236800-41C9-4A29-BC1F-7EBBD0109B2F', '4605319007403                       ', '316  -    .150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80F5C9C8-ABF3-4BE5-A95F-1DE730F76C87', 'AAA773EB-3B3B-4AF9-B64C-EB42584ACB39', '4640001383762', '     C  100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7B4D54A-75F5-4544-BF39-3E39E83CB183', '96AE2044-850C-4C67-8B94-C57EF9A7E1BF', '4603727955132', '        7219 N10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06426980-6BE1-4537-BD7B-4DB0AB70C07C', 'A31C1FAA-186F-4836-9F99-B79AEDDF301C', '7702018429622                       ', '   simple3  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('876597C3-652D-4D2E-8409-5D6E9411262F', '4829E71A-CF9C-4376-91E8-8F0DA91DD713', '4670010370347                       ', '      .s 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0BB8F69-C424-48C3-9D3E-083C7975EAEE', 'ADD22297-E768-4610-A5E6-290B0E349689', '4610017501245                       ', '   C   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40FFB3E5-32DB-4836-97E5-68E5345D1122', '5DEA9587-D60E-4CB0-A2BD-4ABB45B26BA4', '4620020880367                       ', '       10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BC12C36-CADC-4CA8-ADED-599A1E5076DC', 'FD47E7A8-6FEC-4575-B4FD-459F0856D126', '4690419012358                       ', '    /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F996240-B130-4464-9F99-9A799E2BA17F', '32CAA376-EB7E-425A-9EAA-CAE267CE154A', '4607021271066                       ', '    7,510 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('519F03C6-62F0-4FD5-A671-AF0C2F32E103', 'B14E4EE7-AF28-44D8-9D63-D8D285153E21', '4680013240172', ' - 0,9% 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4BA269C-333D-4887-8A13-45B3037B86EA', '8A1F9EAF-F999-4C54-9395-2D84590FF612', '4850001740070                       ', ' 50/ 5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6B27F10-5AE1-46C6-9370-E9B1DE6574D5', '62D3FF11-1CE7-4ECC-A756-61F66E550B51', '2000002677451                       ', '  ( 52-54,  , -)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6150E74-E6FE-4A8F-871A-E9FA95799B16', 'BEBBF7E2-0706-482E-A54D-45F7A49B0C2C', '4602242004738', '    40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C3FFFC4-109B-4144-8DCB-6D327E5A8C1D', '6307C363-D662-4851-A484-C21A6744E091', '4602212004737                       ', '  2,57,2 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A5B1D51-97E1-44C3-BDA8-19FDD11EB72B', '535AD08F-0F1A-4BF3-A1A0-A3797A0E6908', '4640013550091', ' Lubby   6+ (13953)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFA8C7B1-7AFD-440B-836E-F349CE397269', '0443CFAE-8008-4BD8-AA8C-621051A92300', '5292452002922                       ', '       5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('995530C4-4B13-450C-A9B9-B079DFA179A1', 'EB7D0ACF-D077-4D0E-BB41-2602C8D0A61B', '4670015726071                       ', '  /  / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E8891DF-1F1E-464A-BA24-9AA67131C9F7', '4B57CED9-F490-46CD-823D-FA50E1044876', '4607014000109                       ', '    10 /   / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FFB31D59-BC12-499C-86E2-05611BBF5AC7', '5463C32B-6E08-4EE6-AE0A-37887F3A4AA1', '5907811430833                       ', '  /   8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('181560E8-998D-43A5-BCA0-905E0216F0F6', 'C6361596-847E-42E1-A653-E196CAC08531', '4607101205288                       ', ' -  . 0+ 11832', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BFC0BFD8-7D24-40E1-9689-5D5200951A9E', 'E329CFEC-D23C-42AB-9BB4-F5DD4644DCD6', '6940079069673                       ', ' 7 days  /        1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22CAD5F1-F001-4068-8B44-3FD6708BE8D5', '5F8C111E-0248-486A-975B-34522BA59496', '6940079069642                       ', ' 7 days  /       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D3C53D21-277E-4E5C-A9F9-7631980D3965', 'C8DE1689-851B-4F1B-9C22-3FD0E95FE75D', '6940079069635                       ', ' 7 days  /         1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BD7675F-DB26-40B2-823D-0A4B9472D04F', '9EB5FEC3-4C67-435C-B32C-7F6C8F8EF51D', '4610017700259', '- 10+2,5+8  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE1C7FD7-743A-44E2-8A99-F6CC9D7C756B', '065994F4-4E1E-4376-89B4-57719C945953', '4605176000180', ' 0,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF980467-23ED-43B8-AE89-C17D52644226', '756BDC5C-1F07-4EE2-B873-C4806E95507E', '2000103610937                       ', '    18+ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35845448-BB52-47B1-9A1B-2A9165102814', '0AA754CC-25F3-49C4-A419-4969284D476F', '5052197029291                       ', ' Durex Magic Box    18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('266E9031-5239-4219-B700-AD0D15C36A24', 'A8434EF6-2094-4FE4-B926-BE67E4ACC4B7', '4870203881005', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63E40DDF-40E0-44AF-9FCB-58C908929E41', '7584F783-CEDD-4DA0-BD0E-0B45D0F2F173', '4670010370033                       ', '    6% 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E236B475-1437-4A0A-8AFC-DCF0567CB445', '05D1FC99-F7A8-496B-ACD1-372AD0C80E8F', '4640000903534                       ', '   2510 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC667FD6-81DF-4F3C-8AB5-8707573A9C80', '0FA54C46-2E8D-4B06-9E1E-BC3CDE40C38A', '4660041990546', '     150   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61E4D00E-73A0-42E8-BE75-5135416C35AA', 'DC23C4E7-CCAF-49A0-89CF-BB4EB42AD88C', '7290106065109                       ', '  500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A03F31E6-7265-4F2C-BAFD-3E77C135D178', '7C0F8D73-E54C-413E-BB5D-AACD4A267E79', '4104480705090                       ', '       .M N5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('481D0AA7-FDCB-4286-9896-1D94B58E1C41', '9B233BC4-4F43-4F5B-A9B0-37354F155023', '4606486025153', '  75  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60421F08-298C-42E1-9612-5E3B9AC090F0', 'B9E65287-F4EF-46C7-8360-B8B0DF3227C9', '4606249000403                       ', '  /      250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B37FFE4F-589C-4186-8281-60F8A47F4264', '29A6CB7C-BBE9-4B6E-B27E-9EF4E60CB947', '4601498000457', '  2 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D7ADCD5-DA73-4515-A092-383F47C3CC5D', 'AB157EBA-133D-4B40-96BB-B4DB6CBC0C50', '4680381034212                       ', '   5x10 ( )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('011FB626-8817-4E63-93D2-F346A0DCB3DC', '22DA1D49-5515-4C34-A26C-5A45ACA05EAE', '4605964006653', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73489C0F-0A88-4624-84BD-8174950A5850', '0B945254-1AAF-445F-AEEE-63460CB15DAF', '4620002621384                       ', '  -  /  130', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA4504E4-5AB8-4C2F-AA90-77482BC5EBCE', '505BE063-BD15-44FD-805E-85CB7BDB641B', '2410000000005                       ', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BAECC9D-7BC9-40A1-90AA-46B843388B9A', '8CA70968-BBB0-42B1-A2C7-D61C0B8F76C5', '4019338602592                       ', ' 1%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2B40B9E-B07F-4778-866D-668A0971DD63', 'FA016A7D-02F0-44AE-BF48-6B6479BD85B6', '4604461001819                       ', '  /   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DEAB1C35-0060-4FAC-8A65-C6D04E1F17E9', '79AEF1C2-DDE4-428D-8681-AE6FE09A52F4', '2910011670025                       ', '  M2 Basic  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0043F3CD-6554-4459-B68B-7DA0F37D3BA8', '8AEF2C0C-1815-4864-B29E-35B565B0F87E', '4610021170215                       ', '-    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CD4ADCC-182F-45CF-8428-4EE666C65C5A', '1A3BA91A-575F-4448-988C-71BC08FE6007', '4607059540646', '  120 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69D011E9-7234-4015-869F-82AD0684C5A4', '9B0B3ABA-759E-41DB-AC91-649C3B6E04BA', '4606486027232                       ', '  75  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E872D0F3-D431-4D83-9735-89E3756F3657', '21A2EDD5-ED4F-4C15-8B78-DA4001852E82', '4627090903873', '  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C5DA8A4-33BE-444F-B265-004C55259374', 'B88BA15B-0CC4-45E1-AA88-935CD932B0A5', '8001040097670                       ', '  340   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C07A5899-A299-4659-AA34-5A44D0CA91D7', 'C3D9D83A-1FDE-4614-896D-B150704444E0', '4607066410444', ' 3  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB53FEAA-97E2-4A5A-9781-7DCC478A176A', 'CE903527-BD45-4B5B-86C4-7F3F05F84E70', '4627119620101                       ', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFF26764-5F55-4A04-998C-7DC09A7E4A32', 'E9C69190-C065-4B4C-BC3B-1DE1EA35F445', '4605086011382', '    103,0 // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37C76A43-A78D-4803-90D4-3245D49BD48B', 'C7BE701A-33EE-4406-8F3A-EAD2F96F5D78', '4640016740024                       ', '  -      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6EA3287-C3E2-4E0F-BE59-7B697D65BAA7', '0879C174-37AF-4910-967A-E5CE78BD99DD', '5029053543109                       ', '   4-9 58', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AFD3AD3-E4DD-4B0D-B6E2-E96781135608', 'C1BA237F-1031-480A-B911-0B5994DC541D', '8001090784636', '      8-14/9-14 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E68ACA1D-AECD-4D81-B548-DA10C25C6A48', '3B1039FB-8B49-4AB2-95EF-BE0D5DFA4A4B', '4607155640356                       ', ' leiko  6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7BC172F1-A97F-45D3-A07E-03EB631DD429', '2006E06D-A9BD-4BE8-A200-EE70D775E825', '4603373003744                       ', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD94B766-3667-4214-B3CC-62E888CEF960', '3724E9DE-7E14-4674-8B78-76E8E995537F', '4607097013508', '  .      N120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BB7B2F2-C12C-4917-8668-9AEC4C5FA7AB', 'AC795156-86A6-4611-B567-5B3A334631A0', '4607003244637                       ', '  2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB03624A-C231-4222-B943-7220EB282FAD', 'A46BB703-94E4-434F-B1D1-2E8864F1CC9C', '8710103789383                       ', '   / 6-18   scf180/28 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F696E8AF-E2E1-4270-BD0A-EE7A2A8B4A13', '579DC2C3-839F-4270-8296-141F1BEA1BF2', '4600728009505                       ', '  ,    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BC58688-79B2-45FA-82CE-649DEE0C7161', '3330275D-C1CA-43F3-B233-D36A662DB57F', '4607027218102                       ', ' - 1659 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('48A61C16-4309-4188-B07C-157BD0E9E412', '8FF849ED-640D-4007-9076-664019217311', '4680381034267', '   16x14 10 ( )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E28E8B1-25E9-4FD7-AD87-7D4CFB106551', '103C7993-D1E0-4545-94C2-4E2B80026988', '4680381034250                       ', '   45x29 5 ( )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('590F6AC0-3557-4044-A463-289BCFF73098', '332613EA-E466-4E71-958D-DED56965B66B', '4603014004819                       ', ' professional    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('57CFCE8A-D1A4-4765-BC77-9F09E31208DC', '56CF41C8-B385-4AE8-8501-FD36FD6076A8', '4603728106359', '    //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A11C5325-EEBD-469A-8857-4B8017F17BA4', '66AF9427-3370-4D22-962A-E232AC2531B2', '4049500340243', '  Menalind  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3B4EC240-E696-4703-85D5-BD0199717A2D', '68677A8F-B07E-485D-8A98-85B1CF3476F4', '4016369666128                       ', '  /       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('15708DF7-1368-4508-BDF8-F590B5339C34', 'A1278863-4B5A-4075-8073-2317791392ED', '4008976501152                       ', '     322', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2E99C914-DC83-447B-8ED0-E0571BCA76AE', '54F489E3-9654-4037-9A20-3AE9D186BEE9', '4660019933889                       ', ' / .  .l high risk 25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1849F14-795D-48A2-B638-DDFB10EC0F80', '1B7248CE-29EC-425F-9339-EAB1D2EBDCEB', '4008233123783', '     15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17AF0598-6EB4-424A-96B8-9F800C89C04C', '93FF6CBF-8F0C-46FA-90B3-356140289632', '4607017268780                       ', '  350   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7E83C08B-8313-4F3A-9708-5CFF0B8536C7', 'E2943F0D-0204-47E7-86BA-BF5C8744FB73', '6933298200309', '  -18 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0354007-0622-4423-BC7D-BA59FA46BBFC', '2894D72D-3CCC-48FE-BB7D-E5555EA0ADB6', '4606033025957                       ', '   .2 . zo-ra-02', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5793596D-78E8-42F0-9B58-DE5DB8C64F8E', '314081DD-926E-4859-95A1-F243AD13E06D', '4607086569849', '  -   ,     400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F69E39C-507D-41FE-AC74-787482F038E7', '3885B20F-55F7-4934-BA78-81401A2FC38D', '4670017924949                       ', '  /       270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5534BFCA-320E-43BA-8192-2F9D216B8278', '01B87B8F-4717-4171-92B3-6DD48EE8FF26', '4601429001683                       ', '-   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C404EA3-1D56-43E9-830F-D8374891EBC1', '208242EE-2B9F-4D1E-AFC7-6ADD7CF1BEEA', '4600999006319                       ', '    /  240', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('746FC5E6-E835-41B3-A278-E6754539D644', '90D0F0C2-1F27-44C7-A6A0-7A4B5650249F', '4607176000184                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0147F861-7F6B-471A-A692-1BA28F9002C1', 'AB0DEA13-F548-477B-B801-586DF34D8149', '4607174650992                       ', '   7580 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('748100A6-FA55-430A-9C4C-D28248AA56A0', '9C58056C-7F11-4458-8E9D-735669B55C27', '4260090445365                       ', ' 20 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C325399F-20B9-4556-BE2B-9755EC4D3036', '57795D2E-10B4-47B3-9788-C8EB40114AC0', '4660000412157                       ', '     81', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A1E7BC9A-E36A-48C6-833F-191FDF4D9700', 'C10124F8-A999-4B89-AA66-6EEDFA09FDCC', '3433422405295', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('540E858C-2EF6-4E77-879C-00A2404FB952', '52750035-08E4-4DC1-9863-B8834A90D336', '4607010247409                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB758999-B3CA-41E8-85CA-42B4D15F051E', '9CE82493-28DC-40BA-8908-97E28E100C25', '4605446001756                       ', '  / 90-60-90 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D70A5D7-B1B5-472E-A310-B04B639A0A12', '7ACF8423-5C47-4E35-9E9B-038B942EC146', '2910016620186                       ', '     3500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FDE44EF-4146-4E2B-A796-BAA950831043', '7EA2C4C8-21F4-427E-9C25-473D0E6C44AB', '4015630008025', '-   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('708FEC9E-AAA5-4C17-8C7A-0C3E020E6A13', '631045C0-3DE5-442E-9F66-FBD9B9E81187', '4620002621872                       ', '  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7654F2E2-4DC9-4FE0-8733-135DF376C8D2', '0585AF14-BA00-4A0A-AFEC-E502EE013477', '4610017501023                       ', '   20  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26D934DE-D29E-4C0E-BFCE-30450C866798', '97485B4B-8844-4278-A33B-233BAE374FCC', '4049500744003                       ', ' Peha-soft nitril  s', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1DE6FD7D-710D-418C-90BB-A850BB2EF208', 'CDFB467A-3691-4E57-B934-06C036E15090', '4607005897985                       ', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('865FEA0E-1CC0-456C-9EEC-C6A75744BFD3', '28D9FE5E-901B-4A97-A41E-817F5A4BF820', '4602565009694                       ', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BC68B5C-D34B-4427-AFD4-0997CC533DAD', '6669FF0C-2800-4E66-A616-811E79119DF7', '4650001681355                       ', '     6060 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CD5DDAB-C6A0-4F3B-919D-2E4DE16600E4', 'F7FAF32F-F5A1-4BEC-9EEE-BCEF84244868', '4627129210644', '        125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('821F86A4-B8BF-43CF-846F-CAC296AB32F7', 'F88BC82B-6301-46B3-A0DE-9ED0A87B96A3', '4008600122623', '    .. .1  10725876', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1942BC61-CBD7-4D9E-873D-ABE82C627FC0', 'BAE679F7-C557-46DE-90D1-A7F19D4B7204', '9021600168137                       ', '   / C/ 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F96E38F-ABF7-40B3-B697-21AC0DE56473', '10CDC4F8-6D5D-408D-BC16-034B6D6D838B', '5903407740195                       ', '       +12 74/019', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3849F329-CCB7-41D0-8FBE-7941DE8255E3', 'F087B061-5718-4ED6-B4D2-B96D00536BDB', '4603726719629                       ', '      7219 N20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4ED373F-959C-49C3-81A5-6109DD5463A2', '16B9A329-1DB2-4E02-BBFF-06B729D4F19E', '3337871322595', ' ,   / ., 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2784537B-F6A9-498E-AEBF-3A8ADDFD9088', '9B46DBDB-118B-42CE-B8CB-4F9D8C4427DC', '4601669002273                       ', ' 20  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AA18C0C-87B7-4C07-93B2-3EEE47B76F2F', '12F4E47F-EB54-413A-94EB-4DD0FF3CCDBC', '4670015726088                       ', '  /    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F3F8D9F-EF36-4CD9-A70B-E63EE83850FE', 'D5300AB3-27AF-4DFB-B01D-173A5B6E9A28', '4607172376276                       ', '  500   50 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6CB0D9B-5C01-4D80-BCB9-A95AE3FA0B3E', 'D2D214C4-560B-4921-A54E-99D50235E9C0', '4005900378026', '  - /   spf6 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13CE160B-A4C7-4D55-BBA6-328281D15C89', 'AD7ADC3D-CC1A-4166-A461-AC95737C642B', '4620002187576                       ', '   /   spf30 50  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52C7B1B9-7BA2-4E77-A735-BD7C268EC308', 'C43684A3-155E-4A25-8B70-69E01DBDF463', '4607086564134', ' - / photoshop50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('136E410A-363A-4CF8-B55B-628E0C60BC6A', '4CB8EE30-F480-44D5-AEEE-44AA1D6D8C6B', '4640021388099                       ', '   . / /-/ 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC16AA66-6742-4397-9D0D-71152C5A1A8E', '18E2C09C-A3F7-4DBC-9043-0B4A9271245F', '4049500812573                       ', '  410 / 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F40EC2C-EE16-432F-92F1-79E5176E5EB3', '3CED953F-3EB7-4D2F-BA0F-048B44E5230A', '4670015726095                       ', '  /     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A05CC26-C086-4F52-AF76-66FA9AD10053', '247911CC-0085-4937-98FA-BA86B2E91BE5', '4607070931980                       ', '   300 spa', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('839BA3FF-D981-4D74-BBBD-D86F375FC729', '9344F6A2-91D0-4DB5-9B61-FD96DCE0A13F', '4607075793804                       ', '  Veiro   4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('89C16273-C0FA-4194-9415-F7DFECCA5F8B', 'A5264C83-331E-414C-9FCA-CF945B785378', '5029053542676                       ', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A3E8111-3D8A-4984-AEF8-CC579A1433EE', '748DB8B9-F178-4AEE-B161-A81F0D5470D8', '6430046750159                       ', '     / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF215C9D-A7E8-485F-83F1-F1C753514290', '02792372-3E30-4BFF-A71C-26ACFA2066A7', '4607174437272', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5091FCAD-E28C-4645-8D2E-17EB871B3DE2', 'E0DC12A1-29EA-4B1A-BB93-B35911FED070', '4015400674023                       ', ' -  /     44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3614D704-CBB5-479A-9E0E-7551D82BC9EC', 'F5964D8B-9FFD-4A09-B13F-AE4AFEF48017', '9007253102667                       ', '  ---- 1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18E42051-ED51-493E-9E80-E5855599B72B', 'F318A885-D1D9-44E3-AFA2-C662D16921F7', '4607136740808', '    90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9B5A18D-2BD4-4FB0-8CFC-6F251B2F8452', 'ECA07647-8440-4A55-A5F7-00DD4102422E', '3282779402927', '   spf30 200 /c22992/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2451FF6D-7E00-42A9-846D-65E6C630ECCE', 'BF1D0E9F-6B3D-4E72-A5D8-849729E12BE0', '4820121901415                       ', '     35*23 1037', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6927028-B29C-47C2-9EFF-3881A0664FC7', 'FD11AB14-FBBF-4A4B-8B6A-3BE9F93D8066', '4605319000589                       ', ' -107      125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B646940-F8D1-4504-A32D-ADB2E4B8C9B2', '8A51FBA3-C647-4472-B1B0-850FD05C2BF9', '8009315006648', '   / Kids Brush 2-6  .664', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F46933B-7368-461D-A1C8-2F86E7F2E447', 'FC316B33-608D-4609-A50A-ECB67ED2CA68', '4605994029820', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F91AD4A-AFF2-47BB-8A07-F5B76BE3563B', 'D19E675E-5E19-4F68-B9C1-5F8D5DD36D9F', '4601498000747                       ', '  3 2 / 20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9D947B1-B2C9-4749-AD12-C17B9BCA4CE3', '51AC24E9-6EF6-4AE2-91A0-D2753D748AE5', '2000103613334                       ', '  9/501/ ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D621EC17-C987-49A2-AFCE-9DDADE820E18', 'B4A5BC61-1FF8-44A2-AF5D-205EF54318E7', '4607088741441', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4F7984A-C8D9-4523-BFEB-CDADD98BA58C', '644F6894-FBA0-471F-A6B4-D6365FB56F51', '4810598000117                       ', '  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13A1CC35-240D-4A22-B422-1CC2FFF7AB5A', 'A31A035D-80AD-47A9-BE14-973DC5C91BA8', '4640016741670', '    350 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71BB738C-2A00-45D3-B56B-7813D43665F2', '512268D3-B35B-45D3-8003-F59F7BC16265', '4600171107636', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('28E2775A-3F4C-461B-B5BA-695BFD34C562', '97FC0866-B8A9-46A8-9E51-6CE3B1A6ADCF', '4660000412164                       ', '     81.5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66234628-20E8-4983-881B-1A2E16C9532D', '031F4054-1113-4B61-9BB6-6A5EF6D6C59C', '5900516692414', '   90x60 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A90BF57D-039C-40E3-A8B1-353007D75AAF', '691AE5D7-D4EE-4EA4-83B3-3E1EB428707A', '4610011894817                       ', '    100 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C1D0361B-F830-4506-A2BC-97C3C9CB5561', 'F3E8932B-9C03-4DA8-A5A8-50F46807C33B', '4003583161188                       ', ' /     82 5% ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86698430-1621-4E3C-B3AD-2DD73FC8C4E8', '17C0E0BC-D936-4EC5-BE3C-3A1FE7898DEB', '4607124540489                       ', '     "" (0489)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5061CB61-8E85-4865-96AB-7A7B737A9E42', '8EAF9641-F0C7-4C3A-96D2-B69F6E041405', '3504105002305                       ', '   /    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F60DC36-9543-4443-84B4-D04338C8C123', '343B1D9F-982E-442A-B5D3-A04B65730262', '4603149000328                       ', ' 100/ - 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A1942AF-2060-4876-A698-A7B5753A3597', '0A411434-6D76-4BB4-B578-6A7FCD5DB2FF', '4680381034205                       ', '   7x14 ( )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('03F8E336-6EFE-4A15-A39F-E78AB61E5479', '7962287A-A568-4104-83D8-3A13C7FE1CE0', '4605658271626                       ', '   /  (27162)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AE0F117-1C67-494A-8D3B-996893905428', '7F1225CF-C5B9-45D2-B69E-EBE1D62CD952', '4610008495836                       ', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F1FD32D9-2093-4FA2-85DE-20D6E654F458', '3C4A886D-B0EA-4F3F-9238-177334C8394C', '1460717465032', '   3060 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F813896-5D60-4C61-B1EE-76F92DCEE707', '7629292C-63A4-43AD-9111-9D3260A16A71', '4600936241247', '    124 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E032C8E7-7A11-4EB8-A4CD-3414D77BCACF', '6FE54519-F646-479D-B80F-D5DA331EB033', '6414100794501                       ', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0CA55E3-C361-4DA1-94BD-34BDCB43EC92', '32522C5F-30B7-47B4-9B24-C6E330F096AE', '4823015904967', '       /  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18857F00-A193-474D-A6D2-8A440A402655', '9C4F2203-E255-4F4B-8B7D-79F11497E121', '4690419007231                       ', ' /sway/  /   13', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AA22A34-A891-4774-96B4-2056F13FBD72', '7D66962D-3B97-4024-980E-1375B3DB89A1', '4610017501207                       ', '  100  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEDA510F-6020-40E2-A81E-784463BA3859', '2DD2225A-080B-4756-AAE5-E460D1195CF1', '9120008080017                       ', '  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77080292-8C39-46B8-A67F-295B90F29608', '89324402-7EEF-41D8-98A7-54EF8F294B11', '4612750380071                       ', ' /  .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC2503A1-D813-4AC6-9159-F341E16A521F', '8064708A-3E40-4D25-8846-728DB52FDADB', '4893949192051', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A807BFB0-3F0A-4069-9D56-7B1294A8191F', '1BB17B40-73EA-443B-B80D-BEE061A76FE0', '3838957499854', '  50/ 2  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E649039-E9B5-4367-9C6E-D4D87CF78F62', '3649B0D3-D7A3-4403-92B8-18FA0700CD69', '4650001687364', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33851F08-F445-4B77-8BDC-080DA3DDBC3A', '539D7D52-5511-4D41-BECE-8E9B8A7BEC67', '7290005211973                       ', '      /  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('311E24A8-5636-4A0C-BDE6-C494DE10DC94', 'DEC972EA-92AB-4ACF-A6F1-EAB5067E2913', '3838989502683', '- 12,5+20  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('407A71BA-4E71-4F07-800D-68A19C720E6F', 'A5585DA5-EB72-4BB9-8EEB-FA528658597C', '4605180003863                       ', '  2  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB181C49-C741-4390-9177-6CF2EFC81B03', '72FF17FB-A353-495F-894D-D5A779CF71E2', '4607055563236', '    5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA0D134E-04D2-4976-B00D-DEC350D6982A', '6113AD22-F8E3-40BC-905F-EA76CF82912B', '4602212004720                       ', '-  1,97,2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBAE4E4B-E9CA-4A52-8B3C-B7DC405B8ED5', 'C0D6DE74-4918-4F0D-9B5C-6F7C15DA0735', '2000103611910                       ', '    6-18 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65A21867-497B-4DFD-8745-96290AA81E21', 'B7B4BE7B-5739-4D0B-98A2-DF4E03FF5C0F', '4823015905827                       ', '   /      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('91A0A17D-5AC7-448D-9060-A147E54E098E', '00BF13B8-DB25-484A-8B77-276F55A9ED67', '4603726763301                       ', '-        F 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED546052-6D5D-4CA1-9602-9BED589CBE0A', '78C115FD-D026-4F2B-822D-E7C3CEFE2926', '4607027218195                       ', '   1930 340', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2AE5D14F-FCBE-4B98-B3D0-CABFE1E39E02', 'E4EDFB47-3914-4DDC-8AC5-69FAF3F4D164', '4602866025683                       ', '-401    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4271FB04-3F63-47CB-9194-0C1D248E2FAB', 'BB30D230-EEEC-4176-BC92-BAD864AF3D36', '3574661259611                       ', ' le petit marseil   / /250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E10EF06-F48C-4B38-BED1-4D2219FEA1A9', '2BA5B563-6B0F-48AA-8CC9-AA59DA0D9F80', '3517360012781                       ', ' / sobio etic    650', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C60F8F8-90F3-4AC6-8CCC-3C332521E5E6', '6A501864-E46E-491E-A38C-1918A82E42CB', '4605108005030                       ', '       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDEC4C87-19BD-426D-B4C9-63F86A2F6C4F', 'EA8C8179-FD99-439F-97BF-3A597107F2F2', '4680038243288                       ', '     / /   220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF34781C-F95E-4B5D-9AAE-B6DE01630842', 'CE447C3A-7BAB-4C74-AC78-C0431CE0A692', '4603727955071                       ', '          6843 N5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A7A498B-DB00-4B64-A79E-EE595D024DED', 'A7BEAD81-1D40-4D28-9C5F-E82AD529408B', '4810046001451                       ', ' 100  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9166F5D-EFD1-4067-A0FA-7FF361947347', '2DFA9ABB-4D75-42B8-8D1C-C1CAF41DBA6C', '4605319006260                       ', '  /.      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61F0840D-F454-4462-9368-E2D647638AEA', '1376D0C9-BF6A-4BEE-A31C-757DF973301B', '4607154691656', '  /       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1954D833-7CA7-413B-98CB-5CD6088BCF93', '174EA1A3-4F33-459C-9F6B-EE6B26DB6B99', '4603423003113', '      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC28C355-3C1E-444D-8994-92DD30E1D41E', '1A45D5B6-2CB6-40F2-A90B-4ED4221D2DAD', '3282779003124', '   150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AC02129-DE65-4CB3-8791-277F42CCE437', 'F0FF5DA6-3FB4-443F-B0D1-46C289B89915', '4600104007743', '   120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('715D883C-197A-4689-840C-F5CBCD6137F7', '90095C2B-1796-4CF7-A16A-F75B831E37D0', '4607136740631', '    3-8   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('446C4E76-26AF-4F50-AA41-FCD91A8141D8', '0FD69295-6340-4198-9823-6DBB3D77F1FF', '8021961001464', ' 1000   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42C646F5-D419-4896-A010-E6F504E76413', 'A2405C4A-415A-4B0F-A8DA-22F2FD4969CF', '4607005320940', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F5A0A2F7-1BEC-4914-A659-3FDC4ECF70FA', 'DF938CD6-EFF0-4AD2-BA58-B3F4454326B7', '4602666740175', '        60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DFD8D8D-7E96-4D3C-854A-5B9D0B927EF4', '25DBB72A-FC5F-46F6-AE2B-56EB65DBE20B', '4030841008800                       ', '- one touch select 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0BCC490-3906-4B5E-B408-62F60DDCB5ED', '187FB6ED-3AE7-45BA-8A63-CDE59EC6C103', '4008500127087                       ', ' 250  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B28EDC6E-F0EF-45E2-82DF-9E38245F81F2', 'E8B1BF72-6DA9-4D32-AB7B-0BA9CA444C23', '4605319008622                       ', '  /  / 200+/ / 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95147128-D401-4CF9-B572-DD2521B61048', 'AF5B3766-05F3-4821-BE99-C50BC1ABF278', '7613033594670                       ', '  200 3     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('926A6113-DEBF-4EEF-8098-599B308DA8BF', 'D5C882ED-5702-47A7-8490-11117164A458', '4602441016587                       ', '    0,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C85C94D-6A15-407C-B998-6090EAF6F9E3', '6D3EC29B-5833-4728-9862-4F14768BFB92', '4602656000937                       ', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7CF89D8-1148-406E-95CA-B3B769D9181F', 'E4DFD94D-CDD5-451B-AA7E-5FBC585E5A2E', '6904566040453', '     .  3 / /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F954E0A-A175-4210-A3E6-E6049C9E660D', 'DF554818-ED03-4269-9AB4-50FF12CF60B1', '4823002004502', '       50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('61CA8624-42B8-4D78-9E0C-57373C5E9E41', 'E03B3E94-1EDC-4746-853F-69735D6F173A', '4607064299195', ' / //   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFC3E54A-6FA1-479F-97E5-BB9DA6E1399D', '9B20EB7E-B828-4EED-890A-1835251D1227', '4603726763325                       ', '-        250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('906A22A6-3EF5-4CC8-BC31-03B695D7510F', 'C1DC20D2-C404-45D6-994D-F700639D22AA', '8717627108775                       ', '       17', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D742DAC-F161-4D1D-99D3-C3D1D63A13DC', '89294834-454A-4AAD-A1B0-A75B020E3658', '3574660623000', ' ..    16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F380965-6DEC-469F-B38C-4B59611E17A9', '052EFA7B-1499-4E45-BC73-A80D76B00BF1', '4602159017487                       ', '  -     4,2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A5AF816-03EE-45D6-8FD9-823981B4E6C5', 'AFAD7439-079A-4092-BDA1-EB05AD465383', '4620003081729                       ', '      2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E76387C2-59A1-4DD0-AAD8-F4F25B2A86EB', '44E28A19-F78E-44A2-A1E9-47A05F5E1CBB', '4640001380044                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C971B88C-21AA-47C8-AEC7-48039F46C1B1', '1E51E356-0229-44EA-A76E-74B3E63AA5CB', '4820064560601', '   / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED79111E-CA3D-41D6-B0B0-7044EA532ECF', 'A147D2FE-67F8-453B-86C1-ED6E1554944E', '3504105028497', '    -  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('337C97E0-F613-4D79-9C9C-6DE976AED05F', '9D92D1A6-42C6-4B68-B05B-8F065A82AF64', '3504105026493                       ', '  /  / 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5F9E657-988E-4342-920E-ED00047C4368', '652D8D46-B9CE-40C1-95A5-05944519D9F7', '4607141997594                       ', ' 5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3CA0FFAE-6AE1-4948-A786-E9B1D4A8AD0F', 'A35C1C1A-F8D4-44B0-85E4-E839165089CE', '4680013246983', '- 20/   7', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AA26367-4B4B-463D-A2D2-E94AD88AE8B2', 'EEBF15F8-629B-473B-9DF1-CCCCC22CAE65', '4811248002796', '      190', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('53C34A41-939D-4667-BAB3-60F6112054AD', '66F8DC9A-75DD-4D17-9FC4-AA415EB80786', '4811248002499                       ', '         200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECA65251-317B-4519-851E-E49FC02D24F1', '7ADAC839-5E05-41C7-8B0E-155B6C646BAA', '4607013791930                       ', ' /  50  350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7123F398-9783-4564-9D15-F397A11C227D', '2FE87761-E652-4934-99E6-70B985A618B1', '4009932557602                       ', '        30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DE0816C-44FB-44B0-9F02-1315F200AEB2', '4580EDC2-BE71-4D4E-9113-D3D60310C8E2', '4627083480015', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27400EA0-39AD-4D0D-853D-05A5FAD8E1F0', '50ACDBBB-F83C-4260-8388-5E1FC00EE502', '5292452005534                       ', '       5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6433B30E-0B9D-4D84-A555-F9DA93450434', 'F5A88C1F-65D3-42DB-8389-B31AC00EDAC7', '5292452002878                       ', '     /.+ 3 6 9++ +', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33A25190-23C2-45CF-A453-02C6CB851BFE', '8836C84F-319A-4804-AFB7-217D596BE205', '3577051070902                       ', '     100/75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DACF0070-761E-44D5-8106-D4361D4CD163', '64046DC0-858D-4F6E-A028-E89BA948730E', '4601164001139                       ', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58C0631A-A589-419D-9B17-6268459AC86A', '5E4AEC03-12A1-4C00-97D0-CF6AADB88A6F', '4605086011368                       ', '   8500 // ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B22F3680-58C1-48E4-9107-C1FAEF578D21', 'EABC77B2-8F51-4E50-94A5-BD1D2CFEE844', '4607066410505', ' 1,1  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6217039E-73A9-48DB-9CF5-D206B48FC0E2', 'B1A186E8-3858-464C-BB51-E5AD0ADB6D35', '4640013556918', ' LUBBY   60*90  0.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F437EE4-9104-419B-A019-A7FD7FED4BA2', '784A76A7-8A46-4E9D-BCF0-955985D52BD0', '4660041990447                       ', '   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3E38117-56DC-4718-85BB-80711321B277', '80D8DFA5-5D56-4463-8ABF-C644C6B93C77', '4607174434882                       ', '   / . // 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A28D1A94-24E6-409D-92D6-A2DCBDB09735', 'C6348907-B840-452E-A547-5749A410F5A7', '4607174434875                       ', '   /   / /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AA8E708-6757-4027-AAA2-0F915C548FED', 'BEDDADE2-1678-4D86-891F-9C7A3CC8FFAB', '4606982000593', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('508FE998-6C8B-4F08-8518-8805201230AB', '25A5388C-40D0-4536-892F-AF4E90A8185F', '4603988014210                       ', '   40/ 10  100 (renewal)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('292824FD-449B-4E64-A480-BC52E8BA4492', 'DCBC0167-EAD3-49BA-9C67-4F6341E4ABEB', '4650002420137                       ', '     2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C3C469F-28A3-4259-8485-14C9531A1AFC', 'AF26A057-8245-412D-BB1C-11CE58C94BA4', '4601669011237                       ', '-  2  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('02625FF9-3FCC-4745-B3D3-DC14560084A4', '624896EB-EAF4-49D8-B617-644116A9B519', '8809541190032', ' -    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3B233E8-8FAB-4B83-9070-B0D3215657B4', 'D6A6B86B-4499-4D25-BE04-C95F8722BD53', '8809411184949                       ', ' -  7 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8608BD7D-7B28-4C9B-83FF-3F528DDA4F09', '93D5B817-90E4-4B7E-BCFD-1DEAEA63A19D', '4600104033452                       ', '         ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6823DB6-FEF6-46A4-8AD8-B8CA351A0147', 'D9F158CF-C1D5-42AE-8D84-F8DB90A711AD', '4607131422310                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7A28313-ED6A-4978-B8E3-B0F934A3B067', 'D2AF8355-AD85-43C6-A366-AB4F0546964E', '4607086565513                       ', '    in gel    snail repair 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A44B433F-5641-4220-B672-9CA97427FAE5', '6667A0F0-9456-4426-8E69-7AA97A51CAB4', '4607086565537', '  /      snail repair 70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5595A92-4BC7-4330-9E2B-877288C72EC7', '5CCC9ED6-F3F9-479C-A451-84EF94F4B921', '4607086565544                       ', ' - /     snail repair 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7A516AC-818C-4BEE-818D-61EC37A7C135', 'EDFFE3F5-BDAA-472A-9239-E8426361848D', '4601499000838', '    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('067BA735-A27B-47F1-854D-1AD052286A84', 'E1C294E8-F1B2-4A44-87F7-E021DF5CFE9A', '4607054703329', '  hunky dory  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDE3D94F-9468-4E19-8FFF-111CB49A3E3B', '5C3140CF-FC5B-44E7-8A83-BC01C2A8614E', '4604461001826                       ', '  /     60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('686952FA-1709-49FD-B151-190DC8CE24BF', '675321F7-02F5-4562-B781-2CD5E9BC3CD2', '4607021271691', '    1,97,2 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45715E9D-8DAC-44BB-940B-8052D5F845C9', 'ADB0D6D5-1316-430F-882E-E3D94ED3BE78', '8009315901080', '    // 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D103CF2E-054C-47FD-8697-8DC4117EEEAD', 'A2B00B09-40E1-4495-80DA-BD3E4FA803AA', '4605258002545                       ', ' - 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD4BCE9E-28C7-4F1E-9586-110277356CB2', 'E235D27E-F223-49CA-B03B-C0C133CDEFD8', '4210201746447                       ', '-  /       ebs17 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BB15D9E0-ED33-4CAD-83E3-03D6B9C13E1E', 'A73D6F27-D651-46CD-82C6-4A53B0087ED1', '8009315011024', '    50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FDA819E-396D-42A9-8C46-D53579395E41', '4ED2F865-CCF9-4EE6-9AC2-AD27DF67FC04', '4607015890594                       ', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3B091C9-33A8-4B81-BD90-B2F40A7281DC', '56354540-18F9-4B06-92FB-92D27B2C5C6B', '4603276009973', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5B47534-94CB-4689-AE05-079A5ED25EF3', 'D7F980FC-E710-4515-95AC-EA504A60144B', '7930043490649                       ', '  /  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EE6C16A-C591-4487-9E84-6716D28AB951', '0F847FDD-0D32-4B9B-A4FE-05D5B3825BE0', '4607106001847', '   315', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F7D899DC-8B0F-40E2-A484-0291759078ED', '76EC1581-07BD-4AAE-9330-C4826EE4111F', '4603726719681                       ', '        N20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('147EAD72-9020-488B-81D0-0A0394EF07D0', '972A4D32-F384-49B0-85EC-5E8D152E71A9', '4820008318381', '    / // 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8328DF7-651C-4FAB-B8C2-651BC37A4DA6', '6D4F62E8-F826-4BBF-8F46-1BC8D384CD5E', '4607109407349', 'Veet   / ()    18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35C083EB-F179-4A5B-8594-D0AEE06B3499', '56B5FD2E-1918-4289-964D-2C4036457CF0', '4751006756694                       ', '  / 4*10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1ED02C2-B78D-4940-BFDE-6C9E2A1E83F2', '29E74578-3144-4879-910E-C888F87BD489', '4660018603653                       ', '     /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5936A437-8EC5-4A31-A7FE-018B57A66F44', 'CB18AAC0-522C-4ABF-B904-100531247D8C', '4607010248895                       ', '911       150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCADAE79-74BC-421B-9FE2-099CCCDEC5E9', '141DB648-5DC3-4A05-BB86-452331F1AC3D', '4600908021174', '-917 //  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('05816907-127B-4857-BEC2-932ACF7FFF08', 'CB9AC02F-C6A9-4F61-8E34-82A8442FDE65', '4607097013492                       ', '  .  /    N120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D42A0C8-5999-484E-B086-819D764CF707', 'CBB10E03-56D5-4B48-A154-49DCC7F41A58', '4660000412171                       ', '     83', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC4E85AA-FBB4-4B33-92D1-CC45892843CF', '323B7C04-FF1B-4233-9C29-17712F0268F6', '8992781610719                       ', '  modi  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C57FBC98-CD50-4D28-83D2-82289B9AC6AD', '9D5C57AB-3C1F-4DB4-8821-D59C296288B3', '5903407028125', '     0+  2/812', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('49EFDD37-5530-4E36-93B5-5B68DB060871', 'C88F760F-3448-43F3-9B13-A43F8AE6A5FB', '3760102851067                       ', '  /   spf15/uva-pf7,5 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80E26E65-62B6-4A80-A5E1-0966497E213A', 'FAE07976-99F5-480B-9ACF-252649123D28', '4605994030611', ' - /       // 160 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60F7E9FB-7C78-4AA4-B699-1BD28F15AC02', '457EAB2B-2DBA-486B-A63F-737223733820', '4650057000476                       ', '  /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6029EA61-46F3-4C14-B48A-1F78CCBBDCC1', 'D7771CE5-F9AB-4602-9E8A-8EE05EE44627', '4660018601451                       ', '   /  spf50160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A433EC4D-D7CA-4038-9B45-E0ADBA4F29A6', 'C1BCC069-6451-41FC-AD24-37D89DB6F1F8', '4601654000932                       ', ' 1,1  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD5A08C0-3DB4-402C-B762-82C5B51D8B99', '96FDB218-C6A9-427F-A2EC-8222813C95AE', '5414874007808', '    .2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('45EF2509-BC48-41D4-B19F-8F982D131074', '7AA7DA63-DAD1-412E-AF8C-B72F66A31553', '4607100622284                       ', ' 100   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('210868A8-CD67-4736-A387-762A58F5280A', '2FA045A2-C352-4EF4-839A-17DE6817CE9D', '4607070028024', '   /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8105A5A-FA5F-419F-837B-96AEBEF30BED', '03077C94-3035-4826-87CF-057032CE4CF8', '8901397012916                       ', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4DBD02DB-B268-4E70-8A40-714DA9CCD212', '38820787-BD53-4EAC-99C7-F41B074BDB73', '5903407016511                       ', '  /      40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E03BB52-DAC1-4A8A-8D2C-7D2C14E36480', 'B9A8F761-3BC2-4E7B-9CA7-A9969A8F36D9', '4605319006819', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22306027-BAC1-401C-A353-B9EC21F733E6', '5A12317E-B92F-4A49-833B-2C824FDB748D', '4603727955040', '          2065 N10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FD02B3D-90BD-40E5-82CE-FE7813CD2C6B', '2B90B4AD-53BA-4928-8355-3B2D48AC14FE', '4610014630122                       ', '  -212  4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBAAFD8E-A285-415B-AFE7-3B36CBC1492A', 'FE83488C-94EA-4482-8242-D923AEB043CE', '4603671003316', '- 2,5% 5   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6A093C8-46A1-4FC0-A3D8-BB8856B7A262', 'FF456304-9E58-427F-9C94-B1F178E2DCC0', '3600540087133                       ', '       /c1501110/1501111/ 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AF77ACCA-C249-4A15-9993-07DA23B71E71', 'A76B738A-95FE-44E8-85CD-2FB7B142AE13', '4640001380204                       ', '      10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70FEC6A6-8C48-4ADF-9CA3-CB9747BB649D', '9383212A-ADCA-4E43-8346-493B1E742961', '4600104031014                       ', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A7151AFE-2E83-4C29-B580-405E5BA04341', '78A86C33-51FF-4D9B-9BC3-F09336CA8CE4', '3282779206297                       ', '   UV    spf20 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08056F39-BC90-4B33-9F35-355D8AC895A9', '3BC96C63-C35C-484D-9527-A3279AF89CC4', '4603679007446', '  215', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22884B60-D4F5-41A0-A39E-0EEDD915D47F', '5BC9D9C7-31AC-44F7-8111-9682DD608C6E', '4603695001367', '  50+500  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCDBFD53-D990-4C6B-AD27-63D40511A0F1', 'C8E13287-7FBD-4BDC-ADCA-234745297682', '4605446001459                       ', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC9BD490-4A04-4AF3-90F8-C13F034737B9', 'A1DA1972-F4EA-4E9B-A673-F130391540A6', '4603569721155                       ', '  -  1 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ECCF072D-EDB5-41A8-8ADE-32D8876ECE61', 'CBF5D4AB-142A-4D24-B924-FE989A48FFC2', '4607136740372                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF152AED-FAE1-4893-A805-2B8964E9EDA2', '304E1A03-3A13-4FD4-B344-BFB9876FEC5D', '4820008318565', '   -off   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5EDC7031-9567-4A67-837D-8678346A3501', '27843448-6EE7-42D8-8D4A-E588A510CA13', '4607174430426                       ', '   /      . 400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A9D016D-13A3-4D36-8D1C-8E2E0ED04060', '7205A372-2484-4501-B214-590EDF43F1B7', '4605319011424                       ', '286  -   .100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D40DDE1-3A7A-42C5-BD55-3F3385F8A702', 'D873DC14-787E-41A5-8188-D58D73080538', '4650001795007                       ', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A832FF0B-AA8B-424A-AAA6-FADD9E5B1ED4', '49EA85C6-E396-4B24-A3C7-8DE4A9C966A4', '3662042001901', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('69057B87-E4A6-47BC-985C-4BF1A4498D35', '53DD8040-7EEE-40E9-9565-1BC1A73FCE81', '5292452000614', '  /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67969986-1114-4708-90AE-D04B6ABC98D1', 'D1C42E32-F34B-44F0-B546-B575ADB5CB0D', '8428235019697                       ', ' 5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D58E68C-E425-42FD-9DA1-67F5A5F315DB', 'A6732751-698E-42F1-8D9A-93444238FA6E', '8710103562016', '   /     86595 ( SCF693/27) 260 2 Philips', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8CFD1A3-CCFE-4825-802E-D967465026B6', '87DD31F7-F256-4F8C-BDE5-926EAF0F63D6', '4610017820919', '   doct   72    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A6BEDD8-B1EC-45BB-AAA9-DFDBEE9AEDB5', 'B99DE604-DD74-43CF-B23C-EA8FA6CA9A20', '4602822000723                       ', '-  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D3B03AE-C849-48ED-8A90-CBCA286D4AAA', 'A0FD73EC-B231-4A80-B459-8023D947E323', '4627114672006', 'Pellesana  net    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED8E3691-D5E5-4DC1-AA9F-D1C8C31F1A36', 'C1AFCA8C-5EB3-426C-BAD5-70DD2AA8B033', '4607070020837                       ', '     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A8DF2CF4-75E0-4CA0-B3A9-60F6F5EF5E32', '53C161B4-11D2-468C-BA98-7ABFD98E7F16', '9062300104223', '     6  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C4E38B3-2DC2-4E39-87F0-F9696CA0D05A', '4F5271A1-EDBC-48F1-9056-62140D4D298F', '4605319005409', ' -226  -   ./ 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C65FAEC-DAE4-42CA-A6F2-1A49064ED39A', 'D91DDACB-8686-4712-93C6-33ABC60CF7DF', '2000621487196                       ', '473   -   75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA883C96-A311-4583-BE9B-BA2C8AD7A5C3', '39E1918D-00F0-4001-8F5C-080B1221567A', '4600908020856', '-125 //  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5362AE9E-B48A-4701-BDAE-A58C24FA0A5F', 'C2F86378-4416-4C52-84A6-3791E009EC48', '8901138825614                       ', '      /8256 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A714D61-4D60-4C7C-AA36-0FD6BFED30F3', '6A1E07D8-7CF4-4906-B082-DD3F9ACEBA05', '4602666730978                       ', '     45', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E2B2635-679C-46C7-B7E9-8396AA501AB0', '12D98B3A-DFA9-4BEC-9F3A-4AF19DADBB1B', '4607154692288                       ', '  / /   bloom 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AF5A452-405E-4959-8F21-768289ADC217', '8D1F2C48-FADD-421E-B0FB-8BF933A1A1D7', '7322540546323                       ', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E4AD7A1-81B8-4E5E-AADF-9596852057D4', 'E5E44831-707E-47BC-B27B-D81B4018CF19', '4610017820902', '   doct   72   ,  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9033751-C226-40B3-981F-A6622270ED7A', '393B38DF-5C36-46F3-AFBF-6075950CE6DB', '4607011633881', '- 5  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC540C28-9CD9-4F69-9BE1-5EDFFF9B0236', 'C0E69298-405E-477E-BEBB-1C1784F7B900', '4606982005628', '   / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('407F6C4B-98A8-4373-A281-930DE6BBF723', '075A1325-B71B-468B-A4B3-07D0D5C999C3', '4607154693018', '  mos sos     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75032AC4-5CF6-4D66-9510-03B9C0B0F7A6', '5FADA84E-A5CF-4103-92AB-FDAA87A106B3', '4820008319883                       ', '     spf 30 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCD5400E-AFCA-47A8-BDDB-212193D21B75', 'E9FDE1F3-C80F-4B93-9DC6-C17EF71C8EB2', '5944728002777', ' 2   28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F103DC27-A204-4135-9EDD-1BCEB81E1636', '7E80D526-9214-462F-B97E-C8E4E6F8EDE7', '4603905013203                       ', ' 1,24  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8C4C3B0-DA18-4C8E-A4D4-6B3598B645A1', 'D6C89C56-F05C-4EC4-B84F-0F07D8AFB252', '4601811003158                       ', '    / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FF3EE925-BBC6-47DA-B21B-6D29F83EAE2C', '9AB1DEE7-8860-4E76-8BD4-F38AE0341CD2', '4640001380242                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B71DE6D9-3DD1-4EF7-8962-0C38B90CCF44', 'D40F59E3-E704-4451-81E3-4927F9CC02DC', '4607070027942', ' /  spf45+100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E9DA7A5-D861-4DF7-8FD3-423174BA9981', '05735BB8-EF5E-49BD-8E33-69893D5CE285', '4670001384612', ' 1       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('054BB45E-1935-4379-BC96-DD41FCC7287D', '04BD9E8E-1D79-48EE-BEA0-EA8435A4CBD7', '4627090498256', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4573B02-4BCB-4DB9-AFE4-981C82D51D62', '5797178C-94E0-4406-924A-835839493992', '4650065880381', '   Bugstop  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EE5C33E-7C3A-472A-BDBD-C93ACD30AECA', 'AFCDB623-DB62-4F67-A162-2D8F33C37E27', '4607010248253                       ', '      /     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('58821163-591A-496F-B452-EBFF7BD07B8F', '697FFD27-F505-4906-8D28-68E88A6FF2C0', '5000204549430', '    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A85883DA-696C-49BC-ADB4-F63169A50D77', 'CB0B77D0-6AD6-4ABE-B600-C442FA30B7C6', '4650057001862                       ', '   /   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17A72CB2-D4F8-484C-AD48-7602543B46BE', '5674618D-C068-43FC-B0C6-D0CE7A62501D', '4627129213409', '  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47240124-A6B5-4492-9455-907387CC927C', 'FE288609-B5A8-41F5-A065-227AFC6D5556', '9556807331126                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6A375D11-C58C-439F-BB81-3392EE47DE49', '49BC9F2C-7D6B-4431-9B43-64238E820BD1', '4607051799592                       ', '   /   15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E11977F6-4FE5-4826-95A2-8328EDCBE2BE', '395D0653-CFFA-4EB9-83BB-D5DBACD35A49', '4607085315799', ' 1  / 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AD5A21BA-6553-4CDD-AA1D-AFA7EE60CD92', '48056F59-05B3-4C31-966E-A93DED9DB6FA', '4605370006568', '     (6-12 ) / 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F6646B44-63E2-4A73-92D8-227392CD7778', 'A4357EC6-3662-4DCD-95FB-98F427E43BAD', '4602676004908                       ', ' 1%   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6165E0C4-D060-4D03-B144-11D25C72CA50', '258ABD89-B23C-4259-9498-26E048521268', '5029053005713                       ', '    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE20555A-C890-4E34-9FDF-0F6E4BDAFC68', '6B8B0BC3-6960-435C-8E26-60443B8F630A', '4627100135294                       ', '   / ( )', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('928E7A76-BA6F-4637-877A-6C155D0C7E76', '2E0DA669-910A-43EC-993D-67FFB024E036', '4607055560082                       ', '    100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55BF8A24-B909-4DEE-A140-1DE0E9F0AA82', 'F85D3086-1BCA-40C3-B5A6-C4FDCB3BA2CE', '4600104030024                       ', '   180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C91DDEE7-9509-428B-87A2-7165D629B8ED', '0D5AFA36-5BC1-4E11-A0BA-853E67286207', '8431306002702                       ', ' / avizor aquasoft    /  . + / 120 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F609CA6-A4FB-4E72-836C-3974F3E1A9C4', '5093DE1B-FE1A-4755-B5CF-2D66D73F46E1', '4680381039712                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DE2CA0A9-517F-4C11-A49D-B2E1BF904CBE', '49BD4F32-1242-4036-A404-05EB5E8C5EFF', '4680038243172', '    / /   220', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD641310-3BBA-44F0-B2F9-12307C693027', '85294629-9996-45EF-A531-3BAF65DAF08E', '4607174650053                       ', '   13,5  18,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65E5FFFC-820F-4BDE-BEA2-CE7D1205CC13', '02535183-71F2-4A40-9987-F0BE7AAE3D8E', '8001090604002                       ', '     34', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DB63364-C6EF-4094-923C-3903BD8240B9', '6E846973-F85F-423A-B27C-439491BF67BE', '4710425920031                       ', '   S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1A14B2F7-7D7E-421F-9584-3130D3D95EC8', 'FA48E0F3-2B96-4AFE-A1DF-564733FB0A9C', '8718164960383', '  2- . -30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB65AA77-B76C-47B3-8FFA-2A11FB45049D', '76FC7807-E39C-4330-9DC9-007C06ADCD61', '4660041990539                       ', '    C  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DF9F45D9-F526-416D-9AC6-350DE197555B', '0A0E2FF2-F757-497D-95FD-319B79A06008', '4602435000738                       ', '  1,25x500 ( -)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BB904CE-44A8-4D1D-872A-A53BE3936764', '18C66E3F-F631-4C9E-9EE5-85E71DB94180', '4620765781578                       ', '     12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97C970F3-10A4-42D0-923F-514B3261F16D', '17832B16-8811-4FE6-B86B-D6AFC0C674F4', '4660018600256', '   /  spf30  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DEA8AA5-ABE8-4074-846C-7C74E08731F8', '5064AEA7-9465-4067-9FDC-A7885C14A1E9', '4607021931434', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA1A20AA-49F2-4DC9-BFEC-80BDBD8CECBF', '8B50E716-7F65-4C42-8A8C-E7BF3545B123', '4602212009633                       ', '  27', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('061505BA-1B77-49D4-B482-8F0B4C9CD622', 'CBD37392-2185-4158-8960-23A48C4628EF', '5054563042385                       ', '     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AD81628-0744-47AC-A84A-C5821A6BC2DF', '5B532621-374E-4E16-BE72-F3261B6E5382', '3337875588560                       ', '   SPF 50+ 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('121883CE-AA69-4DCA-A5B5-F10CAEF0C8F7', 'E48ACADC-D58E-43E6-A3BA-43B2E7190305', '3337872411922                       ', '    , SPF30 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5D47CE38-20DE-4DFA-9C8B-C337E52ECCA1', '86D05B35-6221-4209-919A-FD299A1EFB60', '4680003690147                       ', ' 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('388CFFBE-BBC5-4115-A090-10FBF94FD1DA', 'C9BDAA21-1594-497F-8039-2CBB228D2844', '4606033000015                       ', '  .. /sis-1/ /17+f6/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5AA71534-3318-4A5A-848B-87D87B9E8549', '781D6575-42ED-475A-88D1-F64C79D43D8B', '8809270626987                       ', '  institute estelare - /  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B63EC9F-3F74-4BDF-87F2-B5A280383772', '30A96198-1434-461B-9255-2E9AD99AA96A', '4627090498898', ' pellesana   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BDF3CCA-5F7A-4802-AC2F-37D0EBA117DB', '300B9319-35E8-4EC3-8D59-E9328C486868', '4610017820933                       ', '   doct    /5-72, 2-3,83,8, 3-2,5/ 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C7E0833-12B1-4AD9-9D8D-C03083B25FFF', '766928C0-EEBE-42D0-8E6A-3BFE1AF77C98', '8901091000028', ' 1%  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D0C9892-FC3C-43F0-9800-CEA017D326EE', '6C1F7E7F-DD6F-4352-9850-4313BCC0CABC', '8030009741187', '   0.30 . 4118.02', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E594B50-09D1-460F-ABFB-E8877A461D43', 'A2265C18-AD42-408F-B268-B77BF18D452B', '4690655004773                       ', '- 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F3EBDC8B-B436-4956-B88A-6BB539E32CA7', '3AA91EB6-8235-4E1D-9698-025B0D94F598', '4660018600171', '  /  spf 40 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67F06676-0F69-441B-826F-F6128B9612CB', '093C001A-BD9B-47E1-9D75-96DA3BBB4B3F', '4650057000131                       ', '  / 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E0AB657-5DFE-4BC4-BE3B-F4462A0DD48D', '8212BD21-905F-492E-B5E9-8A5545610852', '4606677128823                       ', '      75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5187F1E9-3B67-4DD1-919F-F184FEC5EF8A', 'D89421CF-F5FF-450E-892A-13CE05CD800C', '4602824004729', '  10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0790300F-FCE5-41F6-B70F-3BF7C10E3053', '4833C8A1-794D-4290-8BFA-A8FFF455B00B', '5292452000102                       ', '  /    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('38FED47C-064B-42F8-81BF-EFE21155689E', '049AEA5E-6980-43B8-AD88-E91C599F0FFD', '4680381047915', '  90  5 ..', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A1146D6-EB08-47A1-8E96-FB90A75D6D80', '6AF914F7-CA30-44D7-BA5F-7A55B132B44D', '4601214000242                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B5F6448-8BE0-46A5-BE0A-70A1EDB0F45C', '0B2A7F3C-F67B-4317-A311-304E747C59D9', '5391523054645', '-4   900', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('643DFDFA-A630-42A4-93FF-A847DACA7D24', 'B9E9B675-FBC9-4D9A-AD39-0418959440ED', '5997001302491                       ', ' 160  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE1BA9AB-2BED-4C01-AF30-CB3C7630E965', '7FDEA320-4587-411B-B172-58CA25A2D56C', '4600104030048', '    10+2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C9E1203-B997-489C-A20E-0BBF3E60BEAD', 'BA2653F8-F32A-477D-AD4C-AF0B1915B9F4', '4670008162985', ' 4 5  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D30F5C54-6BBE-4F30-9482-223B73EDAF34', 'B5C6801F-F4BC-49E6-B005-0B547EBB222F', '4601811002670', ' - /    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6915AF41-29C8-4E70-B3BD-F69B5509B7F0', 'DC1B1A10-8DAB-42B1-9C66-FF0688CE873F', '8805178113147                       ', '     1972 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6296F552-9F63-469F-BED9-A9B02D517B5C', '837778F6-DA24-4F0C-9705-3A734D6E7678', '4660018602274', '    31   / 120', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('11A313B2-CEBA-4AD5-8219-4619D972493E', '4EFCB687-6944-49C8-A1A6-11A7DEDEFB59', '8594739221567', ' 3+0,02  / 84', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25E0F411-F311-4908-9FDF-C4554B47D737', '3869A476-DE1E-48C6-A546-E253E0BECD62', '4607027410018                       ', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE2A2487-F406-46E9-A7A5-46DF44BCC6E9', '2549CE2A-9E44-4201-AB82-614B52EACB12', '4607172376252', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3975E35-CF77-4675-BDBF-2785709A7E8B', '409B5FC3-2FA2-4942-8A6E-57F54B68176D', '4029438020035', '   /    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('634C31E0-817F-4F6E-A35E-AB10C2A23386', '312AC767-161A-4B2E-9B5A-DDC7F7F55CE9', '4607101209699', '      0+ (12008)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('913DF0AB-1C83-4D3D-A753-34F05CA4720B', 'A3AC2881-738C-468C-A788-848FD51AB221', '4600104023118                       ', '  +-   45 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A822DFE-C5F6-40CE-A605-E4B5776E5522', '070DFE3B-6D71-46B5-A216-A8DC0FF04984', '4607094171751                       ', '     4+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('42C75586-2AD3-4351-9A28-6989CC163C29', 'E2D9C0AC-51F4-446E-B9A0-12E235EAB7C5', '4603726175050                       ', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F46911A7-E9A8-4B4A-B7FD-89F6A60B72F4', '8C11C179-85A7-4272-879E-0A115840DB9B', '4600689604702                       ', '      180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CFA50CE-BB55-4C86-935F-92C4CC06E7EA', 'D7A5A244-85F1-4427-9D13-4745C258879D', '4600999005879                       ', '   250   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9CC44A9C-B9EC-4F60-BD66-F551F5AA48E1', '89F6797B-4F10-4135-A845-FD22E4E5D6B1', '8695860003449                       ', '        30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55916509-F574-470B-B963-C9EFA129EE1F', '37D2DCC0-741F-4595-954B-6268601A8169', '4607040649402                       ', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DA4933C-3904-4E5C-A29E-E10019243F2C', 'C95A092E-8D62-4AB3-870F-293EED668B26', '4640021710104                       ', '  /golden sun/  /   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FCA1131-1F56-45E1-87EF-012CC06F7EA0', 'DA5DC24B-00A2-44AC-87FE-744B8DA7973E', '4620016303214', '     10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('956606BB-D74F-4FAE-9E31-CFBCDFFBECB9', 'A12EE697-6129-4701-B93F-E10B03E16208', '3282779355773', '   spf 50+    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27CA0F86-56CC-4101-9022-F66E4AA5B153', '9CEEF50E-2A30-42AD-97E1-93760CB0B7AE', '7322540836509', '    2-5 26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E2F623C-AD95-4DEE-AFDB-48F7001A0622', 'BCFBFC3E-4DDF-4162-8E43-7FF95F6CD146', '5411416045625                       ', '      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BDFF4A4-6961-43ED-8DFF-0FD5ABEB33A5', '375874B9-81A8-46C4-886C-F04054D89754', '8908000435032                       ', '   960  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4899E203-BB4D-4D91-92A1-F89DB37E92CA', '394B54F9-C24F-4E53-9E4B-03479F50C1C1', '4606486022329                       ', ' 10  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8ED1408A-E3FF-4D2A-B37A-AB79EE20E076', '705F71E8-5146-4759-9E15-0F6A4CEB5974', '4607109407332', 'Veet  s     / easy-gelwa 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36A558A2-9DF7-4E7D-85AB-80E64E970D09', '2EA636B3-9B47-4A77-AE0E-A9377B4A26C4', '3800225901017                       ', '   /   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE2F35C0-0B5F-40A7-9A60-0A7BF60CDDB3', 'A0775C9A-C590-4F6F-AD12-6B71F9A68B76', '4013006101158', '  safety  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('595707DA-A133-40C7-9079-47347A3CF6EC', 'E0B4EE90-8400-4C46-8A97-DA27BA670D26', '4607010249700', '911     0,3%  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('826B82A2-E143-4C3B-ACC1-11F6A2CBC5A7', '646BFEC7-A41C-43BF-AE5E-2CF3A812A58A', '4670000473072                       ', '  /    530', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74253544-F920-4EFC-A8FD-3326C5DA1A8A', 'EC818BBE-AB7A-44DD-A81D-50A6BC753DBB', '4602666701305                       ', '     45 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39EDC403-EBDF-440D-BA38-0D46CD044036', 'D5826578-F145-4D3C-BFC5-DE7D8AF26565', '4607174650534                       ', '   ..  135185   /firstaid/ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0A3D526-2E79-43C1-A530-6BB45CFAD5BA', '8B73D638-0E53-4547-9ECF-5F4C11BF8D80', '4650062882029                       ', ' /   / .m /38-40/ 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('065BB016-FC51-420B-8DBE-0844831936D3', 'FDFA7999-1654-4AEE-A958-9622E0473D1C', '4607155643050', ' leiko   610 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41DD5439-FE69-4B12-A9C0-76C212049470', 'B2A40B4D-E534-4E86-ABF2-1A41DAAA57B1', '4606453043302                       ', '  hair lab  booster    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB2E485E-B575-4E4E-814C-AFB56F1BF97F', 'D49B5268-0F9C-475B-83AB-CFDB213AE5C6', '5016533650211                       ', '      400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('10E4D2A2-55E4-4C26-97B8-E4D38D677461', '826D76EB-75BF-4F1C-80AA-E5B2E0D6BBD0', '4614171150974                       ', '  /   /./ 50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2E5E058-3900-4BA4-B052-D8BAE1921E94', '4B55B31D-FB9B-4BD5-B357-72201144FA9D', '4602866025652                       ', '  ( 6 ) -106', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DDF4BDB9-A180-4D0D-B373-7A682B6EB729', 'E4E1B1D3-595E-4F93-90EA-3ED950D4F03F', '8906072523114                       ', ' 75  / 14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D4592CF-F6B1-4329-97DA-A8A9758EA906', '71DF7EE8-BEF2-4374-83EA-43ECF92BB242', '4605370014976                       ', ' -      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2BDE2E57-F457-4DE6-BC5D-3108A8FCF771', '3852B992-A96F-475A-8055-EBBE635C1E9F', '5907724574150                       ', '  .  3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DD9D5879-FB79-4215-8051-9E1E169B31EE', '7EA3EFD6-39AE-43BD-8FFF-F4A05D6E4D0E', '4670001384629                       ', ' 2     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B37C7F59-7391-4265-95EA-98803239E71F', 'DD11EE42-095A-47E9-864D-1B67840FCB1E', '4605526004653                       ', ' 100  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('13015CDF-B7DE-400A-858A-01ECBDEFDE45', 'DC864068-4073-4C94-A78B-2DBB85C2FA4E', '4607016282442                       ', '  amra 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('480673BE-9D47-4ADD-8B2C-BEE86A6B80F7', 'F960FE10-98E7-4E7B-A2CB-9D5654E8D06C', '4650001798084                       ', ' 03 - /     75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7201F557-D2F0-49F7-8CCA-C27C3D4A651D', 'FDB09500-4CD4-419D-A723-21C4BE5717C6', '4005900458971                       ', '      4,8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FA9C05C-16AA-40A6-8258-B429411509AB', '153075EB-3554-4A22-AFC9-7B4C47EBB560', '4630009186380', '  80   4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C58F6200-36E1-4918-909E-2C4FBCA0C2D3', 'F70AEA8C-667A-4811-816C-4AFADE03FAEF', '4630009186373                       ', '  80   4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('248C3B64-4916-4497-9BE8-8B59C76369ED', '5E7C17D1-2A88-419E-BA68-D63BA2E6DF53', '4603905013647', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('32EC3E00-F820-47BF-A1DD-E8F9BC386612', 'D7CADAB9-90DE-47B6-94FB-804CBD9F2656', '4607051797055                       ', '-        50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CCF7605-2F6F-4872-83B7-EB9D930E8306', '11762C39-116C-401D-AB21-AFA66B1503B5', '4605059012903                       ', '5      25  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED1D2E4D-8AA7-4D63-A24C-FF1CEA4EEF1D', '2DF0522A-399E-49C7-A58B-BACED20A5642', '3760102850985                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8903A61E-DC2F-4CE7-A53D-ACA33172328A', 'F1DFDF32-86FC-47D1-82D3-EC0AFCAE4032', '4823015907012                       ', '     -. 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3F96333-BC21-4AB6-9E3E-160C83C87A45', '722D156E-2EDF-400A-99BD-11B514699DBD', '4607003244651                       ', '  5  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5ED4E846-F499-45A5-B8DF-BE84BD5A1E05', 'AA2C4936-03D8-42ED-AE33-5D5F469C6A33', '4820160032576', '  /   / 45+ 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('373F4437-BCC1-4999-8C58-01BB679A0DAE', 'C5EBC2C4-1306-47E6-B721-50E4F2F757C8', '4820160032552                       ', '   / 45+50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C31151A1-86B6-465D-A6D3-052E57BE3688', '1D636DF4-9005-449B-BAF1-87EC442EAEAE', '4820160032569                       ', '   /  45+50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('151984D9-AED1-4E1C-A5E3-FD662E373867', '495A5993-ED17-4FDE-AFE1-585680EA3A87', '4820160035348                       ', '     40+50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B00E344-0306-4B8B-8E5D-C22291EF84A2', '6453CC0F-E1F1-478B-ADC8-CEEC3846953A', '4820160034792                       ', '    /   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76DED2E7-32B0-471B-A4E9-F79CBC23610F', '71A36344-C6C1-4CEE-92A2-D4B5446ACBF2', '4820160034761                       ', '     /    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BD2F13B5-BC1E-4905-9E16-270DAD90DC99', '9FB1E34C-3303-4782-B5D8-A6F440B11F28', '3574660049152                       ', '    200*12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F606AB3E-815B-4C87-B9AC-3EDB615E6E8F', '404D69EA-DCC0-4BC1-838C-16323B3D751F', '4607094171874                       ', '  /   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C866C1B8-22B4-40FF-9CAC-D0382EA04360', '52765227-59C4-452E-B007-7C93471BBE4A', '4260202922470                       ', '- 23', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86E05F07-B64E-4C17-B71D-6C4080E15740', '08F01415-566D-4B93-90A5-89311416AFA6', '4602666701206                       ', '   /    45 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9B8478CD-F990-4209-863A-35A57D033BEB', '591316C6-2B95-478D-AFAE-E62B2BF24BCF', '4606982002719                       ', '      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F21B68B7-3E64-41DC-84FC-6F99478489C2', '5654E971-8C4E-4436-8425-80B27C270BC4', '4260202921114', '  2- . -14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B047E007-E54D-492C-ADE4-4F857B1BF51D', 'C42AE9F3-5C14-4782-80C7-8F8ED28823FC', '4603726719995', '    2.5500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E4CF708-F7EA-4623-B4C9-23B2166E91CD', '38F36834-F081-44FE-ABC5-9FD8E6D7D3AD', '4607051793040', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63945F17-0E41-47A9-A5FB-9EDCF2C6A004', '8CCC9C9F-D7ED-44C2-B646-7D0C37FD77AA', '5903407028590                       ', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1184FAEC-5EB3-4519-A25E-02062F9A4DF6', '1DB08D26-E6C7-41BA-AA41-1EA9F4AB4743', '4610007620581                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51058EDE-C96F-4427-A735-167CC97732EA', '59ADC0B8-53AE-47C9-BB8B-0CFECA1277BE', '4650084610013', '+  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D50739B1-3027-4985-95C1-4694497FCC07', 'B7F415ED-0BCB-4D9C-B4E3-3FC814C4BAAC', '4620002188535', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABB186CB-7485-4344-9B31-0A597596A38E', 'B91BE7F3-169B-494E-B841-B47B95C36A45', '4620013400053', '-  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('82FF1135-6297-4E44-B259-A411AC7C5B5F', 'B6804D5C-2A56-4B9F-A677-981CAA6460D1', '7038319109162                       ', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E8D0620-F6A1-4D5C-A7D9-138EE0A253A1', 'F0B66A11-165B-4C7C-B0CD-D4B453F7DC4F', '4607171780135                       ', '  /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0EC4FC3-6079-4972-BD9C-BE239D2ACF03', 'EE07BC0D-5F8A-4E38-AFB1-6FD70E9C232C', '4627088980077                       ', '  - -3  500  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E988913F-6D8E-4DCC-B2AF-D49F1B15B171', '97084D40-FBF5-4584-A51D-CC5392A030E6', '2000103565923                       ', '    4 .  rela   /310411099/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9D66EA76-AA4A-4312-A670-0EEC23C94CC1', '2A776A9A-136D-406C-ADE3-5E398A936A44', '4893949195786                       ', ' / /19578/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A1A9502-EBFD-4544-81BB-7E5EB28793BF', '75CAC8A4-819A-4F34-9D0E-277155897572', '4640013557144                       ', ' - "" (15765)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0BDF07E-CD3C-4DBB-9C18-91FBD9D3C1CE', '82288225-EC94-4C0B-A31B-CE796FA718AC', '4640000903633                       ', '   36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('239196EE-91C7-47AA-8C7E-94A5F46D27E8', '0F4AB02E-E5AA-4D97-BFD9-C7B1AB4ED6D3', '4607154693056                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('27BBB6E6-A4E6-421A-A14A-955A1F73C7D9', 'F6AA0B1A-6FB4-40C7-8A3F-BBEE70E34316', '4607155640370', ' leiko 1,25x500 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D86FF7E-0107-4956-9C92-A6B316FE4AD9', '1DEBC6AB-FF1F-4461-A4BA-440E8B5E0FD6', '4750283020214', ' /   2 /23-28 / ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E279EFCF-29AA-4FEC-84FE-EB2FD5FD4BFB', 'D0B1F06E-10A4-4816-94AA-BDE109A23D4C', '4680013247522', '  . 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FC12C57C-3AB6-494E-B5A3-2B20B9C7BC2E', '1E318664-6559-4E5D-A98C-BF5E5BB05939', '4620000430353                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18CC6493-ED13-44FB-8B53-F4BBD21EB445', '1579138C-2595-4345-A220-E156106950A2', '4823015917936                       ', '     / -/ 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54DED5C6-4797-4A90-8F4D-5313E414CFDA', '7E50820E-C30B-4E07-BFA6-368169566DF6', '4104480705083', '       .L N5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85C751B4-83AF-4FDE-B015-41638A6A75FF', '4814ECCD-50AD-4733-9223-3B5CCB074437', '4009932558739                       ', '   q10++ 1355  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BF9D9CAE-067F-4838-8406-5C5897B661BC', 'B962B6DA-241A-4E9B-82BF-C4BE51351E90', '5292452002311                       ', '    /   6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5788928C-787D-4EA5-9358-06B62144F59A', '030D0B38-FF4D-4346-8869-6109CA8D3A80', '4603727955163', '       1963 N6  . . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC73D733-6B37-49DB-98A7-B6757DA67D86', '8B11165F-F9F1-47B2-AEC7-BD5F9542C5C2', '4605964000620', '  500  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BA12AF2-A26A-4A07-8DF6-456A1EAE10D9', '07A69D59-BD22-4CFC-979B-6D341BB3A75D', '4606033043470                       ', '   -165-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C45A2E6-024A-4A88-8DF8-62DDBEAB7930', '0AEE5071-46CD-44C5-A64B-31F581D33EBA', '4650069650676', '  12,5+40  98', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2992949-9447-405D-B783-06B4561C159E', '8C9112B2-C893-45C0-96AA-7A143C0068C7', '4650063970077', '-   / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F1BDF9D-5DD2-4D9F-BEAF-CA21F717FABA', '44020F68-7507-4B38-92B7-408A5D95B3EF', '4603738388011', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BE5A8FF0-3941-497C-95D3-35FD7CBEF080', '3FD49B18-8FCE-4702-AA77-B11E005AC9FF', '5292452001628                       ', '  /   2-   -    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C654124-8ED4-4FFC-A52C-2412AFC94AE0', '229006E3-C861-4752-89AE-7C2E2122D5AD', '4250369504459                       ', '   12 ( -)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E136083-EA30-4C9B-9DC2-698F3A393DA4', '27AE39B5-C95D-4041-AF06-46F17ABD81A5', '4052500102506', '  Iney  Wind ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D4AF8AA8-5145-4CA3-80D2-E63E7B8A339D', '8637AE45-C374-47A0-A52C-8DD6F3C70A64', '4052500102520                       ', '  Iney  Dream ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('08843954-9A24-4765-A3C2-7D3C32357B6E', '0A4EDB4B-BFA5-4255-87C1-4DBC638C75B5', '4603149000458', ' 5  / 7 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('358D3E0F-3DEC-4FF1-A887-4F3DFF5F8622', '0BDE18C3-1B74-42CC-88A6-D903767FA151', '4606033006604                       ', '  /  /fb-40 /5//  emb.1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C752543-8000-416C-9389-602EA54B5AB7', '8AD40C29-4743-4AA8-9867-B53A94EC1E4E', '8712400737029', '-1  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79EA7ECD-F9F8-465C-9D32-7BA442651D2E', 'EEC08301-BFF5-4121-8450-B3BC777F40E8', '4627129211283                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9B77939-8979-4ADF-8216-009C7C445708', 'C7F6FE60-B01E-4A04-B8B9-8004DBD07808', '4606982004737                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A45C190D-0ECF-4A30-94B1-769A00471E6A', '58FC91D8-DBAD-4BC6-8213-C31FD24980B1', '4607078792903', '   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24FF6B60-B279-49F1-8D6B-B099C74BB84C', '3C5D7F85-FF8A-445E-B3E8-96A5665385A1', '4603726719988                       ', '    1.25500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0CF07E33-9777-4761-9CC4-2DE798B3AF02', '3205FD85-7356-493B-B043-7EB3E4386CAB', '4640000902759                       ', ' /firstaid/       s 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66FD35BE-9744-4008-9738-70D07E6FA43B', '4BF53BA8-F7E5-4E4C-84C5-BCB559B178BB', '4607086565520                       ', ' - /     snail repair 100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D05E7D93-29D2-4FF9-95A4-C6F4EBDC0256', 'FACA9279-BBF4-473C-994A-6A6A6F69FC6C', '4627090497143                       ', 'Pellesana biohyaluron     / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C075D71C-94B6-4EBD-9751-A24819A2447C', '174C062F-6030-40D1-80DF-6602D3219D24', '4605964006813                       ', '-    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16EFE57E-A03A-49CE-AFB4-4EA650F73CBD', 'CAE1FDD9-C03F-4ADF-8704-B18124F954CB', '7640156392173                       ', ' med jw-222   22-32   /2 / 2/natural/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33A75504-A20C-4D0D-9B36-0A50F70DD6EE', '8AA68F8B-599E-4FDD-8666-9F2098857D59', '3629002756066', '    / 60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A906C6D-0E09-4488-8322-30D4F92C33F1', '3612BC3F-A03F-4A51-A536-D8049E4EC8B7', '5904913544031                       ', '  - /   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE95F15B-0C34-4539-922C-785D3A057AFE', '4CA34BEC-3B6B-49CC-AB49-2231AB41B4CB', '4602509000688                       ', ' - /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F920EC1-E57E-4308-8476-DE7DD87DB5D0', 'C52F24C5-491B-4CAB-A12E-18965EDDAF30', '4640018640162', ' 2,4%  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DC9E0AE-513F-470D-A941-767BCB2129D1', '90AE371B-2AEE-4208-80BC-561B2C1F4C3B', '4605319007502', ' -254     // 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E325968C-E488-4D08-BD1F-DA47207C03E6', 'F95A64DE-BFB1-44E0-AEBE-198ED9D35432', '4607131422914                       ', '  /+ 30/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE4F7AB8-8C5C-4639-80BA-6868A3EE1310', '47091ADD-E324-4F08-A9FC-49E59BDAE72A', '4603720177135                       ', '    13     1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2B26D46-C7ED-494D-A908-61813195006D', 'BEB87144-0F3D-451A-BA9A-8F277102B707', '4627074841238                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87290EED-39FF-4142-9841-4D4D4249800D', '2ED575E9-A35E-4DD8-9D7D-D7A83A79DA29', '4603720937166', '  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C0D11D00-7B09-42D4-B115-844550A0B161', '5891C135-2346-4259-9D14-387B50F9F40A', '4016369354162                       ', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('54532B95-51B9-488D-A1E6-AB9731F2F13E', 'B8B2756C-71BD-40B7-85A8-F1949A9329C6', '4016369354131                       ', '  /  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C84D7398-724F-496A-BAB5-3BDD94BC7D23', 'B3BDAD99-65E3-4DD2-9849-85E0BDFBE581', '4025612664637                       ', '   200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A78C9E7A-6992-444C-A935-17CAE3113C32', 'FED4E4C6-FF6D-403C-ACF1-00F610FC286A', '5292452001635', '   8     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B58A6BDA-EB85-4798-B9F5-158FD67912A1', '34A65BD4-6E04-4F1C-AE1F-B40F68CA3111', '4751023299655', '      / 0+/  54', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2D97F9B-B4A1-4B93-B751-A0679A2FF9B1', 'F3606E9B-6B7B-4F72-B46F-CF7779EAD7E9', '5903407225128', '    6-18  22/512', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDEBABA3-B650-40BE-B633-5B6E4257F9D1', '6AFD792B-F646-4452-9F67-20B0793D50F0', '4931140011518', ' NISSEI DS-700   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2376C1FA-B21A-47D3-BC98-D7897316D8FD', '016F85B8-D142-4D9B-8061-6CB67B516CA8', '4605342002413                       ', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E910D961-54F3-4AAA-B6FC-E28B48A5D916', '3E61F57F-5FEE-42EA-BF4B-4F456B42D478', '4690214116718                       ', '     200 +200   %50 %   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1B8650CA-93C8-4EEF-8946-52949C20BB74', 'DF37123D-318B-492E-9B89-8D317133AFC9', '4605169212859                       ', '  - 35   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('658D60FC-34E7-4631-B257-AD34B6435758', '44D255AF-C914-42C4-94C4-6CCF82E790D2', '9556807412177', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADC8EDFB-C500-4C3A-9E48-1DD0202B6155', 'FF5945FC-F228-49A7-B6B1-BC5D96C34D3A', '4640016743681                       ', '  only   /      14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07D38C05-4803-47FC-AD7A-89853736DEDD', '5EAB59B7-4044-4726-A992-B366BE72F7DB', '4610010010522                       ', ' /   70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2F3C148D-3FE5-4F55-AC65-44FE2C1C0301', '57614B24-2A4F-45F7-B500-AB3631EBBC64', '4607048760192                       ', '-      5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D508F4B-808D-46AA-983E-90E8B9E4DEA0', '74017828-FF57-4988-8567-CA65843DBD72', '5903407022550                       ', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37317889-57F5-4DB0-AB52-5348910622C7', '60ECBAC5-43E2-4583-B240-70C7E713A585', '4607163090440                       ', '  125      6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('151F1819-1286-4DA9-902E-3CA74DD10D87', 'B18AA2F7-2269-4F82-B6E2-798121144BA9', '4601774006494                       ', ' -    /n4/ 331', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DC6F74B-C61C-4F93-8656-01AD95A8F52C', '72CCAEA4-489D-436E-8306-F3D160495CE0', '4605086011337                       ', '  83   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D2ABEDF0-F684-4F87-9B34-34B948F35E96', '419F25AF-556E-4F2A-9BD1-55D40C370926', '4813870002205', ' /    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F41A3589-BF45-40E8-82F6-ABFBB8669894', 'D2F1E5B5-E23F-4282-BD62-07A523A44303', '3282779181587                       ', '  .      150 + .      150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E0F9E92-7651-44C9-972C-0C1801811CDE', '02322158-2AB5-4579-9491-5BAD6126DCF6', '4602509000572                       ', ' 10% 200  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('017812A0-3448-48D9-ADA7-51EB14B20DC0', '6CBB14A8-051D-419C-8E53-0CA02DAA0401', '4606711484724                       ', '    140', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('559DF98D-32EA-4CEF-A1DE-EEE56186B2B7', '7C658192-2263-400C-ADE9-9BF4CDD3EC0C', '4650069650386                       ', '  50/12,5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DDE7B0C-5FFA-40FC-A485-CB16204C2199', '539E9897-3D04-4206-AEF3-E59D0F4B9F16', '4602866000550', ' /-1332 / 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3769DEDA-DD4E-4605-954B-8BB72A5E60C5', '68A5BFDE-3C2D-495E-AFB2-A46350E11582', '4049500950213                       ', '    510 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('25B35BD8-3CE7-4F41-95CD-B43C33C4E231', '3F085B6A-375E-4D46-9CEA-66623F03FB9E', '8934901730198                       ', '  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F90CFE40-905E-4785-93C1-C68E0E885C92', 'E593A74E-CB2C-4A5F-A408-C35A5BB824C4', '8805178111990                       ', '  40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC929E15-2BB0-4C70-B089-94C385E567F2', '00898836-DBD3-4922-A0AD-1DC5AE67E7DC', '5000204649000', '  /  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5D3D674-5E90-457F-91DF-2FB29B137CE2', 'A41325F7-3424-494B-8DA8-11E31607E34E', '4620764700549                       ', ' - / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('982754A7-D925-4731-A502-00AC1FA009F3', '41340DF8-63B0-45CE-A938-73A2A0B8C2D6', '4601835000720', '   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47002A45-7D39-472B-AFA6-801AF0BBA213', '9734C6B0-6158-45D0-9499-C97A6093D280', '4605738007657                       ', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAB00B4B-A8F1-4D28-9E4A-9AB016D2051B', 'ED6321ED-C2A3-4D5C-8A6D-88A68C9A9BF4', '4607097013065', '-3 700  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3E66102-913C-42E2-96AC-EDB93E8AF7CE', 'EBEE0868-0914-4339-B036-6C9361A0F2CE', '4605658271619                       ', '     ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29760D4B-B15B-467F-889C-A1EDC7822C72', '60D0819C-7CD5-48FF-94FA-A1103B7D692B', '4605319006222                       ', '  /.     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C5244736-0B41-4871-BCFE-F12849CA89B9', '7A026E50-39D8-4F43-8451-20581552FD65', '4607155643340                       ', ' leiko 2x500 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C24B3AEE-BE2F-4027-A734-DFC97A8259B7', '4C0945FF-D4E8-4D72-8E70-C36940C1FD46', '4800888179210', ' -      // 45 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1ED429C6-3E30-4684-BF4C-372B80E48976', '0C0F5200-8687-4671-B6F2-0D1D0DEA428E', '4605658170400', '-    /17040/ 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D06F9713-1691-4258-97DF-D3452E49AC26', 'C6C2C4FD-69D9-40D9-BFA3-2B8FA2C67D7D', '4680381047892                       ', '  90  3 ..', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7C347CEC-9AC4-401E-A906-5746B005461A', '035FBFEE-C84B-4BAA-96D7-7B0D950FEB6A', '4607094177722                       ', '      4+125  4910', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA6E062D-EAA8-48F3-B2CF-3500A7DC6BB0', '54E4C7D0-FC81-4D35-BE1E-DCD6E844C75E', '4987188507223                       ', '    138,4 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3A70C2D-E489-4A62-B256-9E1CA5724E89', '2A7DAC69-0EAA-4A15-BEE9-32147CE26879', '4260202921121', '  2- . -16', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2597F2C2-A365-43D0-9969-7F2BA2634CD9', '820C1AB9-1C4E-4023-A3C4-7C79084FF3F6', '2000000018096', '-8102   (L)', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('23E49F41-5CC4-4269-BE4B-EC72DA3F6A6F', '231250EE-7550-493A-9945-F6D22C92EF7F', '4104480705045                       ', '     .   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00EEC91D-BB29-4DA8-A09B-04A2816722BD', '6F6845FA-620D-48B5-90CC-A2FA03F94F4F', '4610007620512', '  875  4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80CB088B-8F32-4CB3-B86E-E5D2D66507BB', 'A6BE9C41-5229-434F-A021-A45EB9C0E563', '4607070020844                       ', ' -     125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('961490BC-7185-423A-81C5-90EB33326455', '039D3AB8-1294-4858-B050-71754A6F4E9B', '4607074610294                       ', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F50D1817-3A87-49C3-A879-36877B673506', 'AFF45BC1-4240-411D-B590-448F986B4408', '4605964001931                       ', ' 40/ 5  5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC6368C4-2345-4184-BD9B-DA04BA219FB2', 'CF2ADBBE-32B9-4FA4-A1A4-AFCD401DA2F5', '4603726763141                       ', '-    200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED97D52A-A3D7-48C8-9FDA-D59BC9FC5F54', 'C374F63E-D433-408B-A1F9-EDD32FB50E4D', '4680007213984                       ', ' shop  carrot organic  250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B7596FB-5F4E-438D-B8A0-393502A76FCF', '5717521C-2030-4F8A-A1AA-14E33AD7F742', '4630000890217', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('628D426F-3334-4F33-8FD9-96BD4482B1CA', 'AD4CE216-254D-446A-93AA-A9EBC868E314', '4019338601564', '  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D8374D6-DB24-4959-8E69-8D22FC115350', '20DD98CE-3588-4BF0-AEC2-B5DEFC69028B', '2080000000406                       ', '  406    spf50 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('95FD1A15-E063-485B-8F99-8CB97C4BEDF8', 'A6951685-984B-4B83-B60E-6F1CA1E3B4F1', '0837524001158                       ', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66A5CF76-3660-44BD-B27F-07B5AE51B30E', '8E353AAC-46B0-4D53-890B-A6022E9BF072', '4605370004854                       ', '  Normal /  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41DBADC1-B839-49E1-8E23-006028686EA4', '4E4FA700-929B-4FD0-8E35-0E2F81708329', '4610017500941                       ', ' 400  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B37BD5B-D8FB-4145-B0C0-FFC1B90C66E0', '3ADBC206-54F1-4288-A0EB-9CFBB45D7974', '4620017365228                       ', ' 10 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('31FA8CF4-9898-4F7B-8B16-1E8036AAFA53', 'AE0B602E-D638-4D75-AE36-5D099F1D827B', '4015400856917', '/ - -   100 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F718B9E-7EA6-4387-9203-AD08D56F7A27', '70F15EFC-060D-4D37-835C-F95067C10DA5', '4606453043296                       ', '  hair lab  push-up / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('914013EA-E959-47B1-847E-44CD3A9834E6', '87109025-9CE3-46E3-8561-46C86645AEE0', '4607091481334                       ', '   15// ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E3D1A843-0C06-4FC3-8DE7-511FA52CDDAF', '2570D603-B850-4BEE-8041-1D41C0D9A718', '3282770049510', '  /  SPF50+ 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('464328D1-ACBD-45CB-8C3D-5C3C57C554EE', '87FDD94D-6FA0-4D89-A085-53199F5F596D', '4603276000826', ' 50  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('773368D9-5E7B-417C-B82D-B9EDC73BFD7D', '5E1C9D54-DD33-4706-A2A5-8B13C82E6B53', '3000000220030                       ', '  /  -    hydro comfort   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EE9C3890-AD97-4CE6-9202-8D9B78B09F17', 'AA312989-8074-49AA-8AA4-B69E6FF6ABD6', '6430046750265', '    14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07A79ADB-15D2-41A9-9CA3-3A594C74A6C4', '8CEB68AF-B6FE-4304-A3E4-07C68B493AE0', '4623720904746                       ', '    250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E8F96C11-2082-4E1E-B85E-207C154A1363', '742F9E78-A30A-4ADD-A449-065BD153ACC9', '3000000220092', '  /      lifting effect  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3B96A8C-3085-437B-BADC-9DC926A705FB', 'EB02B8B2-E26D-4568-8309-71087FE9134D', '3000000220054                       ', '  /        radiant skin   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('025CD172-E09D-4990-8726-1EFD19711F27', 'D64C63BE-A81E-4C45-83B4-323BB516721F', '4620006946698                       ', '       26 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E85A34E-9623-4371-A6A4-3FC7868D3329', 'B05A387B-9CD5-40A4-95A2-BF3A55150586', '4620006946711                       ', '       26 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A10E83B0-2030-4CCC-9D1B-0787AD8815B9', '67C7F7DE-1703-470B-8782-68499287AA77', '4620006946735                       ', '       26', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FBB74DA-AF0C-41DD-B4D5-3F847B763C58', 'A809561D-5626-4880-B7C1-0E6609EF3F1C', '4630012468183                       ', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00E8B390-AD20-4B4B-9458-AA3054EA5AE2', '69C0A1A1-C797-4B9F-AB36-4F768DF6A01D', '8032665597658', '     250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C352CCA-4908-4D39-8767-EADDA9FDC55B', 'BFFF6016-70AF-4E0C-90B4-3148B3AB3C34', '8032665597603                       ', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2465100C-F0FF-4477-A1B5-23FE72EAC580', '4B59FD4C-0FAD-4F61-BE70-DAC06455FEB7', '4630012468213', '    / / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('480C9A9F-5E71-4110-872B-33BF73E4F5CF', '5E961A66-AF0A-4F9B-8631-4A88736EB315', '4630012468237                       ', '  anatomic / 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D48F32E8-E0B3-4B80-A964-89C9DD16D7AD', '3860725A-499A-418B-9689-047F9EC3EF6A', '3594453300253                       ', '  - 10+2,5  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8D3C24B6-6486-4888-826C-FB9A6045A5A6', '15D14278-F365-4DB2-B68D-A6007062922E', '2910012070190', '  2 30 /  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92D6491B-F02D-4BD3-80CA-D1C53C7C20DA', 'FE17984B-F46C-4A62-A270-02A7BF99F99F', '4605658250805', '   /  6+/25080/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF589ABC-BD83-4DBA-BAC9-21FA37861641', '541662BF-A69F-40B1-AE46-216B0BD5AFCF', '4605658173210                       ', '    5+  /17321/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30CA0FE6-27EB-4550-B265-429B2CC93DC9', 'D39438DD-AE73-4C19-A8F5-AE41C5D39603', '4602072021783', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B36268A1-E18A-46F8-9C34-7154C301D18C', '7C9304AB-1500-4E7F-A910-158F2D317D79', '6920354818639', '       75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F43156E-1F27-4267-9D2B-FDFE99937D3B', '979864EB-359C-4D39-A322-F7E8BA022589', '4670016770349                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E9D326CB-FDB0-43DA-B22B-D59BD4B173B9', 'B185EAE2-D36C-48F7-B4BE-68953E1E1EF3', '4607086220962', ' / 350', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1828FADE-BFB2-47B0-A3E7-CFD7E019D711', 'EBE083C5-005C-4053-8303-3FF6BDC2A028', '4606982003228                       ', '        75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92CBCFDB-487C-403C-AAC4-A02A33A95D3E', 'A9A3895B-FC08-49DB-B6FF-5FC5A5B4E6B7', '4612729880670                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D72D5E3B-1CD0-47DA-AB39-BBFBAF2ABBC9', '7543FD91-104B-4FA2-97D6-705F6B1C41B1', '4600908000278', '-127 //  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAAB65B8-8A50-4EB3-9679-A5D682797C24', 'F387E14C-A5D3-4DBB-B56B-956D6232821E', '4607155640035', ' leiko 1,25x500 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('838EC2FD-CD1B-424A-8D43-1574E16B00E9', '739CC8B0-2D81-402C-B42E-C56AA2E7C935', '4620006946704                       ', '        26 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8AC25C3B-36FF-4B6E-A4C9-2EFD1AAD8112', '54B420D8-8408-45AF-9699-AE35BEF22DC1', '4605658111311', '  /11131/   250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E1F5F5F-68DC-4838-B6B8-9F118BFF1A91', '1E06716E-D870-41C7-95E6-E236D95666FB', '4630012468190                       ', '   thin // 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7CA6128-C42B-4565-A4E9-D288BE22D7BB', '2B5CCE1C-037D-4791-A164-46A8BCC97CDA', '4605342002284', '       250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76BF8791-E481-4012-80C8-87A2A9A0B73E', '27F10267-7F6D-469E-A65D-C0663964AED0', '3000000220023                       ', '  /         skin rescue  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('493FD015-9588-4EFE-A554-1D1639C2D417', 'A612EF05-C556-4648-9EE9-75AC3DDFB1A4', '4602565010294                       ', '-5 1,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B11D634-6DD7-4B74-821D-1D4783D1F462', '5764D733-018A-4852-8FB9-F7E1EBC93170', '4607078976341                       ', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CDEF79B5-8C4D-45FD-8D20-CDB2F2CC9F1D', 'EEF72DD7-F43C-4EF9-BF36-2804C01C73C1', '4627129213621                       ', '       40 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17923BED-2D59-4A1D-A605-2EF7C88A29B5', 'F5775FFA-645A-48A6-A744-5F7EA77F13DE', '4623720904760', '   010', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF6AB3F3-BBDF-4702-A1CD-211436221B90', '0C55BE9F-9768-4432-B1B2-B1D6B3ECB953', '4602521009164', ' 1000   / 1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F6D8E7B-3ACD-4814-A003-050B5E1C28E5', 'B1322AF8-4802-453F-985C-2685785E351A', '4607078792057                       ', '    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B06A1B15-FA96-4EA6-9D32-F46BACD00E9F', 'B6C42622-12A3-430D-96EC-90EB422BBFE6', '4015400458982                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1598E176-994B-4677-AFCB-A7879B3C81AD', '94D05531-E3E9-4646-8498-669D5F0BB11E', '4607154693155                       ', '  / /     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E6F08223-9F4B-48D3-9458-38CEC00FF2F2', '884BC264-C230-4068-B4F9-5AAF549580A1', '4627126380326                       ', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BC271671-8584-4C7B-A93F-21C57A711572', '7A4F2404-3A61-4B0B-825F-1357563F3C3C', '4620002186180                       ', '   / spf 30 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5937613F-ADC3-4A70-AC1E-0D9BC8D77B5A', '524A0A8D-59D6-4DE4-9D54-AD7911E7F525', '4607174650398                       ', '   6060', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51054487-18F3-49CC-B73A-9B7E835F6D40', '32BAC905-59BB-4E9F-9004-B8F17029F306', '4620017860853                       ', '  0,9% 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F491B98D-0E7A-4CDA-A57A-7116E9D605EF', '29150618-1349-4675-BA66-66A176573600', '4680381047939', '  90  10 ..', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63DA468D-C20C-4DAF-ABEE-FF6A0B192F96', '8AEE9E21-ED77-4F30-9110-B840195DE7C1', '4640013551920                       ', '    S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('433EF4A8-7394-4706-BD44-E52AFA1AF969', 'C3184BE5-F8A8-428E-BEB0-EA26CC0CAAA8', '7611645339030', '  /   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1CCC69DE-4729-4834-8E90-3E0CCDD43859', 'D16DBC7F-703B-4749-A596-AD41E759D69D', '4036185001576', '      100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64877C6E-FE54-4CF8-BA09-4EFC52F34B1A', '4E033A46-FF0F-4F7D-993A-81095854E4F6', '3000000220085                       ', '  /     ,    eye c ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47303DE1-7D1B-4829-AA68-ED1EA3B47940', 'ABCE424F-85DE-4F73-8542-3A63DD4AF581', '4630012468176', '   3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A6440E7-2FF3-4874-AEF6-047179933B77', '6ACDF2BF-C959-487B-93C1-8B96C89F4FD8', '4008600147848                       ', '     /-', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98EB2163-04F8-40DD-B38E-FBC5E628A637', '31F8B94B-BAE1-4B51-B9DD-9F487084F5BA', '4620003220791', ' maneki fantasi 6-11 62/m', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0D7F963-F0A1-4B1C-9EC9-B2AF2645B6D0', 'ED9A431C-922D-4B07-A1CC-BB287B07DBDA', '4607141993848                       ', ' 80  28 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6957F9A9-B692-49B4-9F86-2D7DB72A45C9', '210CA09A-9DDD-4AA5-BFD0-EF6FF03E37FF', '4620018875146                       ', '     ///   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('83A7F82C-EF50-4D09-BBFF-AEEE8763B963', '9D076B1C-4B48-4719-B771-3F0C3584708E', '4600689604764                       ', '  250   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('812354D5-C118-495E-970D-393A60E5110F', 'B83E3591-4A5C-4D98-8117-D79639AB4BC7', '4627129213393', '  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEA92E01-1993-4B5F-992A-CD86E118AA22', '7FBC985C-4A83-4C95-9FAE-EEAD8B1078F5', '4751006750869                       ', '    / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('920A7D4A-B49B-4688-A732-297ED67FCBB4', 'F5C0E37C-30DE-4AB9-B963-1ACCC454BB26', '8901083020119', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('436CF585-1939-4FF5-AA16-74C8491C153D', 'EB30E87D-1926-4938-8F42-40B32687228C', '0016401012061', '      15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('904B2738-DE34-4AF7-ABB5-46CDE3CB3376', '7346A17F-2370-4796-ADBA-10F34E4990D7', '5900516692094                       ', '    S 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8647ECB2-69B2-46E9-8018-93C944C5C9EB', '3416704C-0D00-4F74-A73F-7D37BB4879C1', '4607094176206                       ', '  //  0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EEF42160-AF59-406A-944D-23DB27F6FFA7', '733E13C3-B5FE-4E4D-B14F-E2D8C86E6942', '4607174431324                       ', '     /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35569CBA-A5F3-4230-BAA6-E116A83E8920', '132A86A8-E5B4-4667-B01D-F675B8018CBC', '4750283000438', ' 0,60,06 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8F8DBD3E-43EF-46B1-9DC0-610E385B4F77', 'A31DB7DE-C52E-4A62-A734-104C983B66B0', '4604060201535', '  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A7F14BB-5A7C-4FB1-BBF0-B9598F9A2FA1', '09AF4535-B564-4B45-86E5-77E5891B4267', '4660009150067                       ', '  103', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BEF2ECE9-5C79-44C5-99A7-A891F4E24CDC', '577FA34D-5469-4353-B371-3530CF7CFB77', '4605077010264                       ', ' 20  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E4E125EA-038E-4D7C-8E6E-ED2C6AFDF840', 'A538B804-DF2E-4E7C-AC5F-2869A6F7317A', '5999038510504', '    4   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A24E3503-3ECF-40CA-AB00-3342EFAD01FB', 'B1C41FA4-3798-4026-A84F-C7D914644B20', '4607035392245', ' 3   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6567ABE3-F890-4A39-AD63-4C9C5A765EB1', 'A46B1B3B-5EFD-4D45-918B-018276EC2D9A', '4008600248576                       ', '-  Adore    0-6   1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8EA580F1-BE22-4654-B069-6854D5F71BBC', 'BDAF7323-A886-4094-8CD0-1B9BFC90D68E', '4607054703183                       ', '  cleanland  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C59BA172-B9D4-4F1C-A7C7-1AFCF4996622', '960EDB9C-364E-463C-A78C-6B48E4A7AE58', '8019561160513', '-   - 2,5  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AAF4095-03D1-4F16-A71E-EFB6354A07DA', 'AC51C0D8-9F9A-4B2B-A193-AFC7F10B7898', '2524726495912                       ', '  6% - 5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('751C06FD-B20E-4B7B-AE5E-23D27BBBD335', 'CA61B367-60A8-465E-AF9D-AB2EBE7DFF8A', '4607141998652                       ', '  2,5  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA0FA321-4106-4C95-8F83-B3F641ED95D5', '6314349C-2E65-4429-A6B4-ED1B5AF40FFE', '4660000412188                       ', '     85', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C4F46516-F379-481E-95F3-2B9510730221', 'B600304C-0FB4-43E0-8CBF-E0EB742FEC30', '4612730250318', '-   /1001/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABA97687-38A6-42D7-AB25-EA5321F1590F', '775D958F-FB9E-46B4-8C90-EC5D3F6D148A', '4620006946681                       ', '      26 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B14013F-88A3-4BDB-B8C6-06B0BED05312', '6EFD9594-E99E-44D6-9066-91276AE15C03', '4620006946728                       ', '        26 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BE3280B-851E-441D-B185-ED205C5A6F9D', '19BD9B2A-DD35-4449-B38E-8D21147F0F93', '8901236020300                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B15B3D6B-A342-46D1-9D5B-B355FE5D89C8', '93C0BF41-158B-450D-86A9-E091D148A4ED', '4607136740846                       ', ' 3-6-9  1600  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9909CC16-DF77-4FBD-9085-AA05F0FA618B', 'E41B2DB5-8647-4D38-AE2B-9719750A3166', '6910021100099                       ', '       ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB9BECF6-CC2D-4271-A2EC-220DD5774E27', '1FD86F68-AB15-43D6-98C2-00F812D9511F', '4606453043289                       ', '  hair lab -  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FFD7CA8-AFB7-4EC8-A225-89C0B1D21BB2', 'FB2FEC23-24D1-47D4-85DE-ADCA1DB4BCDF', '5900516310431                       ', '     20 TZMO S.A.', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3DCFA1BC-80E5-4242-8C0D-1AEE7BB2D6DF', '0DD729C5-813B-4F45-8B70-EC898263EE4A', '1460224200416', '    20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B45DE26B-3A2C-46EC-907B-127B7BAF3933', 'FBB7116C-5845-4E91-8E35-3800D567C4B1', '4603726719711                       ', '       7219 N20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65BA4FAD-4CC2-49A2-97A8-F3624B689BB6', '0E9FF549-DAF1-4D33-B6E4-363F26A792D8', '8030009741248                       ', '   "Medium" 3.2  . 4124.02', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AFA2EC20-EE6C-4C23-AF3E-310E629E6280', '40FD9354-3CEB-4BBC-8463-D56CC205A4CD', '4630012468251', '  dotted // 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EDFB0B69-0EBA-44CF-8520-76459CD7179D', 'BC730D11-B381-43C5-93FD-46108FA337AA', '3574661042732', '  /le petit marseillais/  /      ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB6CFDD2-8943-4F2E-84B6-469FF730DC23', '8E7AB46C-1AE3-440D-91A0-2733C6FED264', '3574661043210                       ', '   (LE PETIT MARSEILLAIS) /     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('226DA4B7-7C71-436A-9771-EDC1594C46E2', '165AB666-F9B6-4203-80BD-725E12494441', '3574661063799                       ', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F15697B-FE9B-44A4-A87E-BD9EB4596314', '7561ECEB-4DF7-4C5E-B574-7E3593198AD8', '4650057003002                       ', '  sos / 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('41180864-D637-4122-AB51-BF1BB4CBD42E', '7E3F7A13-E18C-426E-BE7D-EDA7CD260C8A', '4009932558722', ' Vip   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B12497B7-3D70-4E1D-95FB-638D062EAEB3', '67A45513-DDA9-48A1-BBE0-53A4AE795F80', '4008233134222                       ', '   / 21  .  2    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C267682A-C0A0-4DB9-88CA-AB9F0228E2D5', '2CE86FA4-83DA-4C65-B445-5078C2123CBD', '4260107478270', '  / 2  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B52C4627-87DF-498C-AC59-9AFE795F2269', '60C5B6EE-5F78-4F82-B40C-9F20A3673741', '4680003060254                       ', '  - 2 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('80EE25F9-14C7-4CD7-B187-8477CF80A4DE', '572704A0-8F10-4DB8-9150-970F822CC91F', '4607174437296                       ', '  bb- /  /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88BCD511-4799-48B1-9E42-149B76CABFD2', 'F477EFAD-09FF-44E2-91B5-B2479844695E', '8061841009050', '  15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFA34590-F0D2-4C75-A125-61FBF016539D', '8C077A67-9112-4708-A99F-46C39CA09414', '4600999004827', '    /  ..125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F6B6353-B3C1-4AF4-BCC0-5954027AC321', 'BC0968E4-852B-4A1A-B077-CEBE6ABAC326', '4627129211047', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FE809B7-C795-4B54-A661-8027AA2110A8', 'DCB7D650-7680-4F21-A575-F13A2FAEE456', '4623721921872                       ', '   - 1403', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3316ED0E-0365-4AAD-A760-96D210F64BD5', '4AA2D6F1-50FB-483E-934F-60D59B383C55', '4606982000531                       ', '  45   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0034512B-DE7F-41B9-B1A8-2D74849C30C8', '1342240F-A061-4BB1-ADBB-F85C77A4A16E', '4607076218153                       ', '          500/009401', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('814863E1-B29A-4BF2-A615-F600DC432DA1', '2AFFC7A5-01FE-406B-9EFD-B411D0695CC8', '4607176002577                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('942DB5F8-8DC5-4A7A-B39C-3B9694075B9B', 'F78CB9EE-DC24-4ADC-86A5-29208C57E1E8', '3337872420269', ',  /   195', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('727F695B-D0AC-4619-AB94-3D7F0E21D8E3', '765514E0-A4ED-41C1-8D7C-EB070341D7B4', '4602676008104', ' 0,5%   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('110BBF3B-075B-4A0F-93B1-9407A2D7E8DE', '8C4F8426-3181-4169-9750-104B7012FE50', '8594739010970', ' 10/ - / 0,2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8148C72-5C5B-4DBC-82FD-1F7535901C58', 'E97005E2-04B5-4290-8EEA-9F169FC25A73', '4603720177159', '    15 / / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AA106202-2E34-45D7-B8D8-DD7453FBDDA1', 'C3CFB1B0-6130-4751-8C01-93B51E571C7E', '4620016240106', '    / 160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D353184-DAF9-4431-82F4-0FD3B5FFE32A', 'E5D2A99F-F90F-4BD9-BD2F-177D6B444B19', '4600936241261', '     124', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E86CBE6-7E1C-4E37-8AAB-6852CCD99EF0', '69D256C8-5F7A-4E75-8CAE-40A55923C94F', '4607001012818                       ', '  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED337074-3E77-4101-AE42-934AEF8A0B0C', 'A1B9AE9C-C72B-4419-BEBA-87322586A4DB', '4600702081541', '   250 /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FB6CDDD-CAE5-42C8-9557-747B59311A89', '7E063378-0061-4A3B-B26C-E9121FBBB4F7', '4600702089745                       ', '    /  400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF3BD50C-A7A0-415A-BCDF-F2199BCF2FCE', '0862D892-12A4-4615-9855-3BA72A10BCAF', '4600702081985                       ', '    ,.,. 250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0BE0D5BF-9327-4D21-A8BE-C94DF50C1C53', 'D5356074-E08E-4924-80FD-1D2645A92662', '4607174437043                       ', '  -   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DCE0FBDF-2F9B-42C8-BAE9-DA6B891BECFC', 'BD373BD7-DC78-43D5-9D9A-0E089139B420', '4007965146008                       ', '     6-12 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5C559084-FA34-4E37-924B-B8861F7A27CB', 'A8E8C0C3-3D3C-4DBF-B999-8B192C20534F', '4631139626746                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('29961F3C-AA96-47D7-95C8-0A4D99A3C3D3', '85FE75F2-1F6A-4C1D-9D42-D83628ED2AD1', '4670028220122                       ', ' 0,255/  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('278F66BB-8D99-486C-ACA5-27EC6ECADD20', '04192748-B95B-40DF-A49D-19D570548A8C', '5900516896928                       ', '  "" Fixopore S 6,5x9,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('737997A5-8100-4F65-BA17-2709D0D26EB0', '9879454E-4D19-4E66-A4CE-694858B56330', '4507027410059', '   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('287E3D77-8D46-4CFB-AEDF-8407A7D473B7', 'EF925E39-B5CF-4DA6-8928-C984F4B8D8A7', '4901301230638                       ', ' merries- 9-14/l 44', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C05E067-0E9F-41F4-A6AA-3FB88C5881B5', '209F5412-1347-461A-B572-9B8ED621B92C', '4605370015393                       ', '  31/- 20+ / 15+  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7A5F272B-E4E3-4C33-B363-186FAE271987', 'E020A2B2-443D-456E-BCBA-4E919C277DB6', '4607174432420', ' siberica    /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('479C8B11-677D-41DA-97DE-51DDF825B82A', '5E1D41E9-2C6D-4007-A57B-E05E6EB71FB7', '4607155643357                       ', ' leiko 3x500 ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FB4E54B-15C8-42E8-B8A8-DF415DD23386', '321922CC-08CA-456E-82F6-DF6558B6B27D', '3337875548533                       ', ' XL       50+, 250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E01C04D-55B8-47BD-9AEF-3FF53A5601C6', 'B6AB7097-2840-42B0-A44F-07AC33125C48', '4600665204490                       ', '   6060 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('252394B8-45A3-4140-B7C4-97BD9D64CFBC', 'B075DCEB-1E6E-4825-BF78-46EC49B9B2BB', '5010182990728', '    8  300 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('52A71999-B77F-4ED2-B2F4-13C5D88807F5', 'BC755B9E-FD6D-464F-ABE5-3776DD7DDA31', '4607131422341                       ', '    275 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('383E3AAA-5952-41CC-B70A-9D32ADF166A2', '602C1F8C-DB32-485B-9AA0-AF8EEB1EE693', '4049500303644                       ', ' peha-crepp  /. 124/  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5BC68949-86AC-42A9-82B5-75DFE089C071', '5B719DAB-4D7A-4B12-8DD2-F0AAC225D396', '4820160034235                       ', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F5862A3-C63B-4C76-ACD7-8E1EF68D5F1E', '827E8679-1364-4355-8711-0532B1C72030', '4820160034815                       ', '  /    150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('598DF451-E4FB-42B7-A540-3A57FB4C481E', 'EF233566-2AF7-46E9-AD4A-7027AE5BD8EE', '4036534427200', ' SFM    m', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('422ABD18-41B1-4DD3-A5BE-4451234782AD', '64B211DF-F238-4C9C-86E1-9BDAFC0F0A20', '4640014200230                       ', '    6090 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1128137-EAED-4269-ACCD-9B2BF00D32B8', '12FE0860-98E9-4CC6-AC5E-B3BC532EF4EE', '4620000860006', '- -1 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18E8239F-BEC0-4275-8E7A-D39A285D195A', 'D0ECA857-21D0-410E-8F26-AD43A9E7929A', '4030729003682', '  20  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C46DFB7-5C11-4408-AFF8-07A747956DD6', '1CED11D6-D7C2-47A0-A45B-330CFAE3BD1D', '4650001790453', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60DE4712-F3A4-4198-8224-EB249FA9A84E', '782B9A46-0ED1-4D99-9AF2-D4B697B29E16', '5052197029321                       ', ' Durex Magic Box    18', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B29FE7B-9E4A-4B12-9B73-0D5577C338F9', '3B1DD91B-25E6-4DD1-BFEA-BDE96222F234', '3282779277143                       ', '     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B241BAF1-2200-43E8-8895-0CEDC9DAC5B4', '1D819C87-9C1B-4788-A437-03A124624D03', '4607174434905                       ', '   /   / /  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('025C0888-1978-4ABB-BF46-C20AC830827A', '3915ED02-EF06-4C90-BAF3-2A409AB233FF', '4601654002295', '     20 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B9DC5B1-9F15-4A91-BB20-E6692131FB17', '419B7F17-9A7F-4890-8A46-6ECB88C3287B', '4630000891306', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B1C153B-93CD-486A-9FDE-C246B7DE88C6', '35183609-4BF4-43C2-A136-DACE6EF5C030', '4630015180013                       ', '      1 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BA4E7E23-7F36-4780-8E14-491CB520C41F', '26A5829D-8FC6-4AC8-9A63-9877C74C39CA', '4607040649662                       ', '.  // 3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5B977895-0E2F-45ED-9B53-B1DB5004A870', '0EB5D895-BD89-498F-8A37-F34CB3825BEF', '4607131421290', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A73B1B0-0EFC-47C9-95EA-41A7B5763713', 'D958C817-7811-483B-91D5-29794614D75A', '4607131422945                       ', '    30 / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B3E5E6AE-7C39-487A-B5CB-F291D56D4A8D', '62497584-96BE-4738-978C-4AD30BC53879', '4620000431947                       ', '     300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A906B12F-37E0-4874-8ECE-5379E0A343FD', '672DD5DA-E24E-4641-B18F-3A659415D0BC', '4620000431763                       ', '  45    /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F31E267D-22D9-4598-A1DF-B91D69B09181', '61301F99-5E84-4052-938F-9460C06B9F7D', '4612730250271                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('786F0B88-C789-4DC3-B1B9-C1754D5DF5BC', '521914FE-7A40-46E2-92C4-F8E449F35B54', '4603734784022', ' slami   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9E9B613-B845-4D00-B796-05F2750849C6', 'E2452B25-3315-43C2-809F-934C394F35E9', '3337872413346                       ', '   ,  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A344B474-8B6A-4538-BE77-7A7E564210B2', 'DA6EA44A-BD03-4C24-9DD5-C448AB537AB3', '4600622001612                       ', '     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABACF85D-173F-4BC5-88B9-581329ECACC2', '0367E7D7-C395-4C70-B904-591DF7767650', '4620018874743                       ', ' /compliment/   - / 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB7FF664-923C-41C5-92CC-26BC7F512F73', 'E8BECAE8-D0DA-41D4-AA9F-D28BD8880879', '4620006946667                       ', '       26 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A26B22E5-6367-4E80-98D7-612C4B5C2E17', '6DE5476C-9188-452C-9C1B-B36EDDF81D34', '4680004854395                       ', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D9D66432-0B1F-49A5-A591-655FBFFA7F1C', '54269FF0-5ADD-4974-AFB2-7CF742152E45', '3282779236966                       ', ' klorane       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C204BB0-369B-41AA-BD3F-BBE815BCCA5B', 'CB1365A5-5E10-4785-A259-2D6B33BD2055', '5901691811454                       ', '    0-6 . space /23/221/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('219DAEA5-D466-4DFA-BAC5-5E21EB83FCD6', 'BA146976-59AF-41D0-97C5-DE4BF9332A7C', '4602866000567                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6FE139A6-4C1F-47F8-BC2D-D29FEFBEEDA5', '9F6DFE77-A11E-426F-B6F0-89D0B0962C2C', '4603014005427                       ', '     275', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('92D070C0-4474-475A-AACD-F0BF5D27C44D', '2C530986-ED9B-4CA8-8888-5198A8F1EC1F', '4606249000724                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('669E6913-1E3F-4AAD-8785-F3033F8BF280', 'D5FED519-6457-4AEC-AD97-B1C8BC5275D7', '4607055074602                       ', '  074602   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('362BD0DF-727A-4CEB-9B5D-58DC78239E99', '5440282D-B86A-486D-AC3F-7FFD8A763B21', '4607102611187                       ', '    1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A74B7A80-4248-48CA-ADE2-ACA821524AD8', 'E3727439-DF36-46FA-A4F5-38EF96E8AE43', '5900516894023                       ', '    10 x 10cm 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A0C5B38-8A25-4E34-9DD0-81DD4430C381', '31D2E2C5-7F3E-4892-87A2-CDFC731A3CF9', '4620008620046', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1E8BA00F-52EE-43D4-9D56-E89DD38EDB88', '17B2B305-919E-4F1F-9E7A-69CCB464E7AE', '4607028010019                       ', '  /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C1C1BE2-AE51-4B37-A07A-52981FD42C5C', '1058781B-051A-404E-AE40-AD280391701D', '4620002184285', '   - /     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E01172A9-AEC9-4E68-8B47-E0EB4E0767D0', 'E43F1D06-A663-4A75-98AF-5CF730AB7C48', '4607051796416                       ', ' / -    110', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21E5BA75-224D-4CC0-B4EA-A4ADA2C7A04C', 'A2934197-A967-4D42-B182-B603B8877915', '4987123010351', '  /   0,75 + - 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC770E3B-7ECC-4D53-88E2-311B2312DD4F', '56C11334-32B8-48CD-A3D7-E089FB80EFF7', '4603695004115', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1C8A1A20-7485-441A-8AA0-A9F6A4171978', '1B3E5D9E-2599-4972-8CCA-862F0F19DF4E', '8809052585037                       ', 'Skinlite   /   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B0040067-89FC-4E52-AD14-9162A1CA94EF', 'FEC2003D-7FE9-4190-9204-1957ED962BB0', '4612748580094                       ', ' sey life  +2-   molecules  10 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16E4372E-2EEC-4AC0-B8B9-F1FD155F5F98', '9E3AB074-0428-4EC1-941C-E9CD498B86AE', '4650055920059                       ', '-  helicobacter pylori', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C9CC66D-0FB7-440C-9B2A-A052FE5DEF9E', 'D25BDF36-77C5-49A5-8367-FEC213D067A3', '4607068629196                       ', '   /    15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9465C9F8-8EF5-48A1-8853-FABAA00F23AF', '53B18474-E5EC-4D91-A3DC-CFC5A84B59AF', '4607027410049', '     5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7EF929D7-D7E8-4461-BE9A-42A295B50BE7', '4B14F2B0-34AD-4E8A-8298-9A6FA643952A', '4627090498553', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C6D1C5EE-B61B-4054-9A2D-35B6F8156BDC', 'E72FC287-A5DE-4B94-A584-166CCF6530C8', '4627090498157                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6AE5998C-BBE0-48C3-9058-FAF821BE7A6C', '6E6C2155-B2C9-4F9E-9F18-4DE30C34449D', '4607017841556                       ', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('714B7883-BD8C-43F8-BE64-422390771588', 'AF565D88-74D4-4BA4-90ED-16D1C9935E10', '4602242020233', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7609659E-6A31-4698-803A-64931A082880', '934CB5D6-2B8A-4534-8FF2-CCC4A32D7C6B', '4607174432444', '    /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A72DF7AB-9C6D-4AB2-A387-FEDDD341A628', '6BBE8278-E042-4CD4-A2B4-8500DA38DC52', '3582910016458', ' 5/ - /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAA032E1-609B-4992-8946-9856ACAF3277', '32B98367-E062-40DE-BB8C-452BD2DC048E', '4607078792484                       ', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CF0F7625-3034-460F-AB15-65F10DBBCD36', '0EED19A3-B6BB-48BD-9F07-F302CF7141F0', '8712400360395', '   1000', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('822FDBD8-E825-4883-BCA4-C08DAB1E2A0F', 'C5EEE55A-18A3-4B67-8202-0F8F9EC82147', '4602243001781                       ', ' 16  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CE4C294-95AF-4776-80A1-275DF555CC77', '56ACC9E4-24A6-4E87-9D51-5A7D7F12A44F', '3800225904124', ' black mask - / pro-collagen 80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76C481C4-DCA7-4102-9DE5-986D16339F01', '838614C8-E538-4E47-9363-1D1C1CE47433', '4627088980626                       ', '  - -3  500  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('77E33B04-5F15-4B51-A7B4-C02CDFBDC250', '671E5CDC-6B5B-415D-812A-F81159AD29C6', '4607078791999                       ', '    40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40C50B26-D53E-4407-BEED-ED1D78A56E93', '251C7B9B-30FD-407B-A1EE-C85E4D531871', '4604060997773                       ', ' 25%  30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D588EC6E-ABB2-4EDA-908D-6D0BF3BA0A3E', 'A5D3A33C-25B5-4E29-A00B-8669D70593A7', '4606486027980', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DA090C1D-C425-4F92-B2D1-02C40607D22A', '3EF96A4B-E324-42A0-9C4F-966892A53B3D', '4603014000989', ' special    75 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35BBF782-96D8-4B9B-B9F8-ADF88A290CF7', '49C54C9B-91AB-4616-ADF6-5048243B8604', '4036534431245                       ', ' .   .6  1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E2C56E54-2B9F-4F2A-9421-5E779669BC88', '2959600B-8094-4616-A8D1-2C8BD525D62F', '4606711701579                       ', '  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('90D67ECC-7B7D-4BE9-B9AF-1AA13D8BEBC0', '21D55389-9DFE-4DAA-8D3A-05BB2EB64792', '4607143560765                       ', ' 150+30,39  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB516068-C6D5-461F-A160-2315C5685CF9', '6C0CE2BA-1F57-4E94-8D24-5F0F5CBE23EF', '4670004410288', '  100/ 3 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D0F900B6-245F-4CED-9BE1-E9DB9CAD3884', 'BA136CD8-F068-4199-82A5-1B938DEBD5F1', '0382900930015                       ', ' Micro-Fine Plus 0,5  u-100 g30 0,38 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('04EA596D-7AE3-4DFB-AB80-F77C4ECA36A1', '4FE2B79F-0688-4E45-96CC-16E644383B61', '4670017926646', '     . // 155', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7DFA40C6-5166-4907-9676-8E74D4C2C871', '9FF429F0-5176-4F29-8CE5-2EC591074245', '4620006946599                       ', '          /   3, ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('578DBBFE-CDC7-492E-B0E3-053CA7C84AFB', '22F7E1C1-E2F0-4383-B580-61C2B0E4B992', '4620006946605                       ', '      /  . 3, ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65764150-701A-4322-864B-5E6052F0916F', 'C7BC00B1-B74C-4FE1-B646-90E3920855F4', '4813870002144                       ', '  /dentorol/ 65  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('30F0D6AB-9DFF-4D2B-AD54-E98F2402D36D', '6EE66E2C-7FBB-4AF5-9159-5635439BE4A6', '4811379000265', ' . "" 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('19B68C3C-65B4-4340-B3E3-C9381885B271', 'EDDE09AE-CA5C-45FF-BB06-9C9685B112D1', '4680013249120                       ', ' 1 % 2  - / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73E94DBE-7995-4382-ADE5-EF1837E63743', '18E9DC3E-D000-48D6-A923-3C6363C3267D', '3582910030942', ' 4%  125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C0CCD30-9F37-48D8-8921-37B48746860B', '100CDDB0-7B46-4A0E-8364-6D4C8CCBC8EE', '4601437053728                       ', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C9560DFE-D16A-4C88-9825-2FBE428DF156', '823DC9B7-0182-4E5E-8DAC-EA31730ECCF9', '3337871330118', '  ,           50 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3D707324-1E5F-42A5-A857-B48F1AA43156', 'D74AAD6F-CCFF-4353-95FE-057CF223C1B2', '3337871323547                       ', '  - // , 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('66EA83A4-86E6-43AC-B745-C2389907E9D7', '4FF24823-63FF-43FD-BBA1-8F5CC88F62CE', '4607034474164', ' PRO    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64104CCD-9CF5-4D56-AFAE-26C3A751811F', 'CCC97EC9-847B-4428-802F-951CB56254AD', '4030841003843', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('51DAD916-043D-44A4-A498-B7126A45F6DA', 'A2AF5C21-0307-4904-9B32-52BC3E7C0397', '4823060800993', '   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60F9B2CF-F100-48C3-8A30-8262BF2D0D84', '06BD770E-3081-4EE9-B015-5BF1B2FE0160', '5907506237112                       ', '  Medlance Plus Universal 1,8 21G', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17291BF9-5BD2-4D9C-844D-0D04F533F9BB', '7D5B8B91-D791-4307-848A-797ABF866919', '4016369665817                       ', '  /   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('37E7C405-9856-40A9-B759-E19AFFE59E6B', 'C658E6A4-A6E3-4A14-A50E-7598376F2B3D', '4607102136642                       ', '  B-157-HG', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ABB11BA6-2ABB-4380-A02B-3B68470A3419', 'E3B62482-60D4-455E-AF46-49E7DF009F3E', '8000036022771                       ', '  3      20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40A88BE0-BB19-4396-9652-5741C5D8A6C6', '6805F807-6232-463A-9B0A-62A491272D35', '4811248002321                       ', ' -    200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('022E0624-14E5-48A8-B8FC-4CD1D1DC8F90', 'C51D94D5-CE17-4501-92F2-1B8DB493FB7D', '4601834002367                       ', '   12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('277483F7-8DA0-41E3-BD87-9747AC232727', '89F2CAF3-0481-4B79-802E-6CEBFA73489A', '4607017941638', '      70', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8BFEE0E7-C50C-427A-9A61-D4E83B169294', 'EDDD4642-6ACD-4365-A3BC-0E79DAD2397E', '4030041000178                       ', '-  280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('448249D8-3A11-4B43-AE51-711F2CF5E37D', '0BE7E0AF-1D6A-4003-9E0C-03EEB4E3C544', '4607156611423                       ', '          3,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('302D3C88-526A-4F2C-A96D-AFC2BA5C40B6', 'C74717E6-2917-45F7-B11A-582D78816BC3', '4250431901414', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B7317A03-D816-4C46-8625-AB99BD614CA4', '9E0BB3DA-3E4E-4959-8E08-E281CE6DBEAE', '4607051797376                       ', '   / / /  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FE45C70B-0EF3-4981-BC1B-9A704F0B5A4B', '197F17A2-8A5C-476C-9BD2-3D826D5287E3', '4670000471931', ' - /  280', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAFE8012-C92E-4147-8830-4D9B6D7062C2', 'DF6D1C42-C9EE-4F61-BE73-1995B5A2C695', '8887786400727', '    Cuff-LDA Little Doctor', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('79204014-EECC-404F-BC88-434C9BCAB56C', '0901F696-6734-4CB4-B035-5C749E1868AD', '4250431915176', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9F653B87-E308-4B90-9EFD-B089AA03E160', '3D34B9FF-714D-4F20-ABC0-D490BC31564E', '3337875398961                       ', ' H  - 200 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('63C281A7-0699-494B-80E3-029141AF4F61', 'AF0D6305-ADEB-49BF-8648-8B962555F573', '8901148242791', '  10+80  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('407E16C6-709E-45E6-B454-3FF735DD7D3A', 'BC3CFB24-3578-4890-A480-AB4326321F01', '8901148242807                       ', '  5+80  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1AFB902E-EABE-4404-B15D-558938218867', '5E31830E-0F5A-426E-85FE-DB85DCC85480', '4670017924888                       ', '       //  270', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99603831-EAB5-4AB1-91C8-20B77E47CB33', '0EEA03AA-2F8F-4B22-8D8B-754F32DF3A7C', '4607136740662                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('527C7D2E-93FE-4608-A0F2-FD064960B9CB', '09F432EB-335E-4133-86BA-960041DCAF04', '3000000220061                       ', '  /        clear skin  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65DBDEA6-079F-46CE-9B06-F90489CFA161', '2B3DF5FD-B6B3-411A-9602-C4157F7A8C09', '8699502091580                       ', '  250  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12A93F0F-E7C8-4651-88B2-2B0308880297', '3EF6CDA4-70EA-4EA5-9792-846C76736760', '4605086014376                       ', ' 2,510   /   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F0E7341-9E4E-4160-99C2-284F2B046ECC', '1DACAE12-9C16-40E0-BF82-5D025F0A696A', '4603423001379', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7358FB75-D099-486D-8AA6-8C075742C728', '452C4933-9AB7-4C28-A96D-62A8E3499664', '4602565015169                       ', ' 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C3D832F2-7DD2-47D5-B47C-31610A2DA0A2', '2E89BF4A-6C3C-4B76-BE87-52DEC5A0E56E', '4601969007596                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CFBCAB6B-D149-44AB-A407-C5EF3E12FA98', '13495141-4CC2-417A-8E1A-CBBCBE19993E', '4601774007620                       ', '   -    -, ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('303B080B-852E-497E-AA9C-057939BB80A7', 'E7AB3258-284D-4848-B0C7-472E9AED31CF', '4030729001572', ' 600  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A955E01-4F9A-401A-A365-2F1345D7B38E', '0F54290A-0DC9-4B5C-9221-75073AB1526E', '4607011633737', ' 10  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2541699F-6984-40F2-A896-A807DA40CCC5', '42664FCF-BCDF-44C7-86A4-D81639E3316B', '4606677009498                       ', '    / 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('46DF9538-9043-43E6-B8EA-FE01CB913E96', '08A4D722-893B-4110-92A9-C5A9EED2DC8F', '4607011633843                       ', ' 15  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8219BE46-DECA-462F-AE8B-4899FD8FBE74', '7CD148C4-D934-449C-95AD-CA201D4AF4DC', '3800212711537                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('890FDA23-184B-4529-BBDA-541A65FF476C', '76C81E2A-C187-49DA-B939-7870E34E0049', '4607020333499', ' 50  90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4E111C04-A322-4995-8198-C3449A1DAF6B', '5F3D9F12-3CFF-4E3F-9359-2A507E2D6F90', '4680038241932                       ', '         45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40C85F13-C0C3-436F-9EAD-36B2C17526E3', '7765E253-72BC-48BD-8368-2E3221F91B7D', '4605964006820                       ', '-    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B3EFCEE-7F82-4B8E-842A-10EE8B604D6A', '853C1632-5664-4000-B76E-5185F3F664D4', '4260107451402                       ', ' / fabrik cosmetology collagen crystal mask bio gold 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('168E2491-CFE3-4FFC-9DFD-9E6F178FF984', 'B66A26AF-EA5D-4AAA-990A-6186C51F146F', '5060040309308                       ', ' Durex Avanti 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C26EA14-F1CA-4473-96A5-3F4E75D74488', 'C3DD26B0-52F8-45F1-B6B7-E3F4ABE5FFC0', '8809052584511', ' -  // 40-45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('26E678CD-3EDE-48D7-991C-E996511F0DB7', 'F17D04CD-AAF0-4356-BEC3-D0735CB6881C', '4607174432352                       ', '    //400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EF7C5E06-863F-465F-80B6-65A2C4500C04', 'A81385A6-E9A6-444B-8DDD-7533B985B826', '4605964006837', '-    6', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAE526D1-1627-4330-A27C-6BE28F56572E', 'C5427818-FBAE-4D85-B18F-43EF157F5BA1', '3600541309579                       ', '       spf30 200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18D4E499-5D20-4E54-BDCC-744CD21B1CA1', '903F0BD3-FEB0-4106-8F9E-0F0BB88C8172', '4600338008486                       ', '    / 500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C006D484-CB5B-4C79-823B-2765C2F76969', '1B21C556-7832-4982-856E-DEC4E2613C39', '3282779206310', '   uv20  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B2514D03-CC34-4872-AE43-CA27B4400535', 'F40DFA94-8968-4660-92F2-049E64182E7F', '4605738006193', '  40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB42C290-3AFE-481D-A437-973E60A3C517', 'D74BD93A-73A5-4738-B02C-06D2D21FF885', '5903407022598', ' - 2/259', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D12592A-37F2-48A9-A000-31816D8697BA', '4110E142-E268-460D-A3C4-2899BF74C06D', '4626018162583                       ', '   .  500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76BBD8A6-72B2-4D1D-A0DE-7EB8A8E76E2B', 'DD5C93BD-E7C6-42FF-B3DD-AEFF5C32A038', '4607003249083', '-  - 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('78A46244-FE92-473A-8CCD-9FACCD397C98', '52AD778E-1EDA-46B5-817D-985461B9C592', '4820121900463                       ', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9DD89483-064D-41C4-8721-C65E8F08B1E2', '893BEC32-B9A7-4A9A-8522-F274E9D29405', '8030009040075                       ', '     20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('22F80A7E-AE39-42BB-94BB-9906DB00AAE8', '1F6B1B81-4644-4DAC-8B9B-8339F6DA7AF4', '4607068626065                       ', '  AURA antibacterial 72', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8E1EA876-B704-4006-A6DB-051C15C5A325', '914283C8-F45F-4713-AB1B-FB9A1AAAAAD6', '4601499004157', '    160', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B752A326-0C90-4A57-B128-C3869E7F6790', 'AD64D4E5-10C2-4E5E-BAA0-8AB188E2A5BE', '4605964006844', '-    12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CB57DF51-95CB-407A-BCE0-D2DA2A7039AB', '2D081E54-A383-44F7-BC2C-38E884F63D2C', '4710614722132                       ', '- easy touch  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('50DB3130-FF82-4F31-B09F-5F91B35E5747', '86EFF33E-8A25-4818-87EE-C63FAEB80CBA', '8901302057490                       ', ' 180  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4C0D4275-BFE4-4D3E-BED0-6FC3357A1E3D', '364E33C1-D5E5-43F0-ADD1-4F385AE725CF', '4607011633751                       ', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FCFBE460-1A16-420C-B4B5-36F73E9E94A2', '6F3FA2D2-558A-4166-BAF1-BA85CD1174D2', '4601907000795', ' 0,25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('70F8D860-F438-4ADE-B815-03D893840862', '8F12B155-EFAE-4015-8FF1-F1A725197E2E', '3856013221164                       ', ' 0,4%   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB2F6160-B549-4A6A-ADDD-A33D63E55F36', '807353DE-4FB2-4F2B-8BF9-0E1E65F0464C', '4607092930015                       ', '   0,9% 250', '2000-01-01 00:00:00');
COMMIT WORK;
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6E1357B3-36AF-41E8-B1C9-CDF28E78A6F8', '9763A91F-1C5D-4F7F-9751-76EBE7A39436', '4607051352612                       ', '    ..   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7AFFA771-864A-491F-9F38-69E1529082B0', 'D288745B-0492-4F6F-AF3D-5F30FB51B8A7', '4607010244507', '911 KIDS       150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('64979447-1CD2-454E-BFA9-0579E2CF7A22', 'F1D08509-10AB-423E-91CE-AC3FD8132D93', '4602212009916', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BC27C49-A73A-4E28-86D4-8592DB026DA3', '3EF99FBE-98F7-465D-95C4-3D576E045E95', '4640006304311                       ', '   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3FF01AD1-3C74-4F79-8AAA-1F6F698C0981', '8B18F529-1EEB-4846-8B01-396A16E5BFC2', '4810201017426', '   700  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9BAC047D-DBDE-47B2-8972-DB577CEB20BE', 'D5B9FE4B-FC4D-4829-8B32-79274AE30739', '4680038816352                       ', ' 7%   5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('536E30B7-D9CD-4B43-A4C3-70A4695D8A92', 'C7094B1E-9E20-4368-B30A-50BC47C2D1E0', '5054563010483', '   Intense Clean ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A004CD73-B999-4C7B-A11A-705837DC1BEB', '0CF6AE7C-9BCB-48B0-91A1-3704D9106256', '4820121900043                       ', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDCAD7B1-7B19-4C82-85BA-57F8E66F70D4', 'DB5E5BAC-2266-42EE-9C53-4421B218F65C', '4680038247514                       ', '  -   /     50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('558E15A5-99D7-49C2-8371-32AF8B89E49D', '28FE85F0-B3B5-45F5-845F-1B47C9EB75B1', '4680013248093                       ', '- 7,5/  2 - 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('17497761-8D94-4AAD-98C6-84D639E6299D', '44F82F45-AF7F-45B2-B489-ADBF0515AA6F', '4607011632549                       ', ' 25  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0567E417-A0D0-4D4F-9C94-0650A98BFC9E', 'EFAA0395-883C-4F87-8157-6298AF024AC7', '4627118070013', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AB4D108A-843E-406A-BCF8-1F69BFFF01AD', '22AE8B85-E0F9-464E-BAE2-1C3DC935B654', '4627100138851                       ', '   / /', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B9F06AA1-9D9D-48DD-83FB-168DBAAACCFB', 'AF82BD8F-A29A-4F35-A478-689F6D3C0551', '4607132560462', '  - /   /zn,s,/ 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A34CCB6F-C311-4448-94D3-54F2A62E31DF', 'CE012E5C-2BB7-4583-B044-942EAEC9763F', '4605894004019                       ', ' 2  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CC6D2866-9BE0-4368-85EC-A7C93CAFE410', '3F44FABD-CB78-469C-A58E-3C7D1EC6CDA0', '5029053006611                       ', '   80', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8141EF1E-31A5-4C16-B1D1-BB8AFCDC46D7', '12F289F4-6ED6-44A3-A35A-3A01EAF0C510', '4607022180220                       ', ' /  . 96 / 0845/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('06680822-B6B6-4394-9E4A-F9216F811418', '77838842-3D96-434C-9BF8-831A95F7D0F4', '4627090498454                       ', '    10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1F1B6EE4-B3A4-48A8-ACE3-C8B29950485B', 'B22FE6A6-7799-4250-8AE4-3050FF60E94A', '4603726719803', '   /  .   7219 N10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('070D2FBD-E611-42ED-8163-AB8FF48CCBF7', 'DC6143FA-B8DC-453F-95FF-7CB5BF18B176', '4603727955101                       ', '   /    7219 N20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A9FA4B0-1B4F-45E7-9D3F-FE055D79FA8A', '6E48388C-EA45-459D-B36D-4421DA401E45', '4607003249199                       ', ' 80  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5777423-AC88-4D92-9F4C-9FBB869D12AC', '30CE20E1-2295-499E-8786-1BA1C4546F76', '4607040319282                       ', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DBF97179-A9B1-466C-B9A7-D142F3873944', '12029818-22F1-4A9F-8A28-28FBEFD0222D', '4607016282015', '  premial / 15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('43029060-205A-4207-92AE-2D4A8F3A4101', '86A827AE-80EF-4095-836D-5F84BDFE560B', '4607010246549                       ', '     /  / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1BEE309A-10D6-406E-A16C-A3DACC93194D', 'B46D11C6-ACB0-4CC6-8CC0-BE02AF8DFC50', '4601661001403', '+   60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D651A6E9-8A50-4DE5-ACF3-4F68DC781775', '4A8F8E0A-B3D5-4982-A22D-E18E7CD51498', '4680287525654                       ', '  /     2 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC8D2159-018D-41F4-A446-50905F6EDF74', '389C8C43-B8C7-4F90-A0DB-4E5FED52678A', '4620003081774                       ', '     1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('55C41FAD-C618-4C2B-9A23-F93FFBC17642', '80C53881-AC7D-4B67-8D36-778412389BFF', '4049500954136                       ', '     28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('09DC02FE-FF6B-454D-BDC3-7EAE915A75F1', '0E2EE882-3C62-421E-8980-FA8F79917D4C', '4680002950112                       ', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4BB635E8-867E-48E8-A7DF-7657828B5ACA', '9421CCC7-9BB4-4DF0-A384-C4D981B0621E', '4660003400335                       ', '-   //', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4355D9F0-811A-45B5-AB56-BAFC13735B32', '77F70C6B-7E4C-4D24-A2D9-13752783D061', '5411416044796', '  terezamed   3/ 28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7214403F-C3A6-498A-B947-C17BB8176187', '04E54CCF-18F8-4C6F-BD8A-BFE574809AB2', '4627126380951                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('96BE435E-0166-4AA5-88D8-9FB900DF0CBD', 'D9D33927-5676-409D-BB26-892BAF6E690B', '4627126380432                       ', '  /  300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('270D842B-B2E3-4495-AE56-25C55B3AC0E5', 'EAE02606-8413-47D9-AB1A-47BDABDC4B49', '9006968008325', ' 5+40  28', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('529A1E4D-9B1E-4869-8660-BFB15AF77554', 'A15F9B24-3788-4CD7-A51E-868CDB70B212', '4605059017861                       ', '5        50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4B91CA2C-7301-4CB4-8870-85704AA4BEED', '0860E6F5-3C46-48BB-A2A2-454457E7F8FD', '4620002185558                       ', '  - /     250 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0F1121C5-EC96-4FBD-A5F5-B0C0EDE6DC3A', '458CEF07-D403-4125-BAD2-61AF243A5F10', '5900516421489                       ', '    224', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('87184758-6B0D-4BA0-B78B-4A20D362ABD6', '7B7401A3-784F-4BE6-9E10-D54A7EB9EFF8', '7610108006830                       ', ' /     400 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CEA0871-86C6-4150-B035-C6EC9A48666E', 'C1E99D15-B435-427D-9ECC-1F40CF4DC78D', '4607143560758                       ', ' 150+30,39  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D1DE963-BB4B-4E42-95F2-AE32528103BF', '0012AAF1-62B7-40BA-8730-A2EB9BECC193', '4650069840893                       ', '  . / / 11 52', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71FFBACC-3A8B-441B-9AA5-622649C7EA11', '406D9A61-A6C7-4E9F-82ED-77A731D2F8EC', '4607011633799                       ', ' 7,5  20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E1FB1928-7024-426C-BDD2-632B4F1E769A', '3DDFA7BE-9AA1-4613-A933-AA0C2045BC3D', '8032568302458                       ', '   /.   3-6-9    spf 50+150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E21CB56-64EE-45D2-A594-04B1ABFDFA6E', '1D000AFF-08ED-4A10-A4D5-BC5180B7E77D', '4607022893069                       ', '    1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9EE077AB-FE40-40B9-8F51-9FF718550E28', 'D2884AF9-0975-48B0-8809-017B5EB7A414', '4607094177715                       ', '  /   0+125 4810', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6175CE6A-C310-4ED8-8615-E66CEA5E52AC', 'C5B9EA3C-D0AA-48F2-AB35-6EB2EE0F95D8', '5999518577409                       ', '   Clean Deep  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1984D5CB-8F88-4AB1-B0E1-32EC2A775E79', 'F548DECF-F861-452E-B892-1688BB460AE3', '4607011633836                       ', ' 15  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A0BF781B-95DA-42A0-811B-8A539794A4E2', 'A3DFD909-823A-4B85-9129-C20DE798B7FD', '4607027218218', '-  1903 180', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0EA5A8CB-AE4D-45AF-A548-B260B7FD42D0', '987B7548-350F-43F7-875C-0D59A3FA0FD2', '4607091489460                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6DAF7011-DB67-470B-BCF3-118F8AEEB64E', 'BEA53A29-454E-4C31-9CAB-788AE1B9AE07', '5411416045687                       ', '      24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('740EDAC0-D8E1-4171-BFD5-6293108AD4B3', '33A8C56F-CF72-4F06-8D13-A887C549117D', '4660011214511                       ', '  100   100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FBA831D-67B7-48F9-AE5A-CF2E58346E17', '955689BB-429D-475F-A524-6C7478A3CBD8', '4660042340012                       ', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C8BB99B9-3763-455B-8D71-C854D56E9E3B', '9AF08271-E200-4C5F-9EF5-1A20C84B28CE', '3515450013601', '    / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C8E747A-D21E-474E-BFD8-FC07B9470C0D', 'E47FCAC6-040F-490F-A745-617F593FC4EC', '4660011214818                       ', '-    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('88F2446A-122B-48C6-A6F8-CD5BE7A9E581', '981A9444-6CCA-4F37-BC05-F359A5E0F22C', '4680020180911', ' 50  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('044408EC-0C0E-4FE3-957A-F5D786C641C9', '16C9F2B9-47D0-4D89-8F76-854A400875CB', '5060255351406                       ', '     90', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FDC6FA86-DA6A-4844-BFE9-310E17C22BED', 'FD876B38-3A93-439F-AF40-BE6228EB2D9F', '4605052000785', '-  /       15', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEDF9468-1029-4D45-8311-ECAB5142BEE9', 'D0E686A9-86F5-4360-B4A2-847490A41F89', '4603728106502', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0AA2A2D2-C33E-404F-A31F-A3C0EE98DBF0', 'DAE58715-81B9-4B47-9AE3-AE642A49A095', '4650001793645', ' 03 -  75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B8716007-8A0B-4F6B-AEE7-74FBF293E130', '0AE2BDE9-B719-4423-82A2-F52DC639047B', '4015400264613', '      /3-6 / 94', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('36200E25-AD91-4CD4-97E5-DB57E6A74558', 'B03A73FE-E0E0-4EFC-AA90-A3044F11E3A1', '4660011214658                       ', '   25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E5F09335-C1A3-4004-AAF6-48DB90DED394', '043C2C09-BB0C-4C04-AFAA-A0CE6B8DEA52', '3574661335520                       ', '        112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A398724D-A317-4D15-84E3-BAB98E660FDD', 'CFEDE511-605B-42D8-BDA7-C06306636099', '4603732050044                       ', '   M', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C2023021-0E3E-4D88-AB7F-D62B1812AAC4', '98B1F361-13EE-4C79-8F60-03BD296983D9', '7612367003346', '    / .S 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65F667EF-8F43-4C2E-8934-C24E39BDE1C1', 'E294F1C4-33EC-4643-99DD-7DB6A179F8C8', '8032665597443', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('84007D15-0519-4951-873C-68806B1FC0B8', '38E5D663-0060-46DB-87A1-2500D436380B', '4607061508283', '     2 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4837B0A8-459D-458E-9F33-038A5F2E8A73', 'EB39CE6D-D71C-4559-98CC-3F8AE065EE13', '5901845500586', ' elfapharm 7  / 71 /  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB1E15EC-A9C2-46BE-9C93-805BAA8D114B', '0AE7A276-BCBD-4686-BB63-9FABDDE51C03', '4607041020231', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFD90B48-D4EC-40A0-BB7F-F6A850A683C3', '4158F6EE-D180-4F04-914A-CF99F6441E10', '4603423003168                       ', '    10   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DAA865D2-45C6-45D5-979A-B420BC827A39', 'D1B49AC0-98BA-4687-BDF9-030D79FDD887', '4670004410431                       ', '   /// 300   - 1,5 / - 3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ADC0BFD2-F5D3-4468-B9BC-473FDAF8E415', '5F6AC5FF-4E41-4253-88CB-63FCD2C55E42', '4601969008005                       ', '   2,5% 100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4FD48F41-39E5-4C68-876F-0B40E674346B', 'D3CAEE30-ED29-4E0E-9544-DFA8FE3DCB1B', '4823015938283                       ', '  coconut hair  / 300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ACE84EE4-2B8F-47F0-AE07-B24C75DDDCC2', '41414A8B-FCAC-4456-B284-E6AA3467890B', '4823015928239                       ', '      250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3E011FEC-27EE-4974-86BE-A7E543804D1B', '290CEA15-379D-421E-A34B-9F3DC89ED8B6', '5907609313133                       ', '     81 3   q10  r 125', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA62DD6A-E9D8-423D-84FB-FF5ABE2A34C8', 'EED6E401-182A-442F-A734-6B8B51045728', '4640016743278                       ', '    /  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B70602D5-006A-47BA-BBD1-C82EF0F99D87', 'E4BBFCDF-86A0-444A-A186-7C4AAA44CE99', '4680038241802                       ', '   - / /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('40EEAAAC-52BD-4269-8405-5598C6AEF380', 'C88E2164-0B3F-42B9-8F08-738A82138DC3', '3282770037524', '     30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C52DEFDA-4203-4811-9131-B34B8B3C415B', 'AE385679-EA13-4159-81ED-17B1F6677D4B', '3282779184144                       ', '      30 +   40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FA18BD91-C863-4FD7-84E1-DF5C0657E7E2', '1AFDBAD6-57C1-4C23-822D-5194C31A859D', '4601969008449                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBBE8189-0741-42B2-9DD7-14C43856C67E', '65E4F031-90BC-4C0D-91FE-46467490D7F5', '4607024944356', ' 200  3', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7D984329-3667-411D-87E8-950275F1F963', 'FBD3B0FB-EA9E-4298-A3F2-CD2038432527', '4607024942819                       ', ' 200 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F97C7219-3FB1-4F01-ABE2-D40E5A6316DF', 'C82713B7-A2F3-46E8-927C-1C1BC7E0614F', '5052197023664                       ', '   /   2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC6F5CCF-F163-491C-B1A7-65CA74718C0C', '57562B62-FDCA-4010-8D2D-89F28879A793', '8030009703345', ' Teens /   12  . 334', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A9DE031-C3F7-40C7-86A4-A4751B5EEEFF', 'B578FD35-4F28-4B4A-8183-6F1673B7980A', '4603569721018                       ', ' +3 0,62  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('114621FE-C70A-461D-88B8-240AEE23FECC', 'FC2BF189-B7E2-48B0-88F7-15296AC1C94A', '4811248006046', ' -       190', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B4F712D-7E90-4DD4-BD38-FD3F832F519E', '4DEE5BC1-F7ED-42E6-A271-4DB209EB9AA6', '8030009700016', ' - ()', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4505E820-5929-4F0D-85B9-6E781623C48C', '36F3DF6E-74E9-47E9-9C72-CF70647CA3EC', '4605080000757                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86D5EF35-C669-410A-AE51-E9125ABAFB30', '00E34285-CB16-4F43-97F4-AFB701354D9B', '4607174430839', '   / /      150 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9E153463-DA0B-4D21-8B63-E86E16791616', '67A00C9B-1C92-4BBB-8B2F-5C523368792B', '4607027410117                       ', '     1010 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B4490028-F546-4086-91BA-B94843FAC5C2', 'F4E40DB6-1009-4EB3-B014-DF9C7B911D0D', '4640013550206', '   Just .M  3./13964', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('347FA30E-F22A-4E77-A6C2-5CD455F18B0A', '6A552908-DF65-40AB-A63F-73BF1EA744F3', '4605738005769                       ', '    4  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('ED66AA2C-B383-422D-A584-183FEE4401CB', '4F1D28AB-6D26-4EF7-B037-8444A8F42037', '3856013221171                       ', ' 0,21%   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C820E2EA-B143-42B1-B2E8-F0611FE5EF2D', 'FABB26BA-ACAB-4B12-A3A4-6DAB6A3F1AA1', '4660028030043                       ', '   5  5 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7F3ABCE6-6E0C-46BF-990F-CF4B245B8D49', '9B2F97E5-FEEB-4765-BBBA-F4DE3E049EE5', '4607146822181', ' -  /  35', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('21532619-3C5B-4F9E-A8D1-7F59748C5FBC', 'D6850F1B-C0D3-4C0F-B238-3B707661998C', '4620006501378                       ', ' 3    30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C956C527-0E75-4114-8DA9-81C94EBE13F3', '7AA1E47A-205C-4971-885A-4937E10F2FE5', '4620001091362                       ', '    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A6BBC17A-27A8-4BC5-A25A-131DCC1B036E', '8C65E73A-3202-4BC6-8956-8D7A106C51A7', '4630017310227                       ', '   24', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F10CDB7C-7FFD-4D65-B8B5-C2B9FBB81CD7', '6A8928C3-18A8-415D-86C9-E0ABFA4DF619', '0033984010413                       ', '   500 60 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C7EE4FF2-2721-47DA-A602-CED8BF6490FD', '8B85ABEE-527A-41A9-AAAA-4873270A2D3E', '4607051790285                       ', '  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6B923B00-7FE1-401D-8F6F-80A1C0241D68', 'DA440B9C-67DB-4256-8E26-4118E3FB1F0F', '5903407234571                       ', ' -   6-18 23/457', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4615F7C6-D384-42B5-A100-946563C33416', 'C8B0F507-E872-4D73-B72E-C4A4AB08EF4E', '6950570782544                       ', ' Arlette  12', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9FC16763-1B54-47E0-827F-869BB38E3D5F', 'D0DC1A25-21E8-463F-8A55-FCCE498A76A8', '4104480705038                       ', '     . L  5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('60678540-986A-4639-A892-F279BCCA387A', 'AA242D45-8762-47B4-B76F-44D744EF4139', '4607043670717', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D782D7E4-E2C3-4B99-8AC5-EC882A0ACA31', '7A1B70DB-EE0C-43DF-BA9F-0EF1C3F4F662', '4601669011831', '-  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EBC3FA95-3954-464B-B424-A10E0322B97C', '53BF80AA-567F-4402-B96C-F55418AB1913', '4607006490086', '  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CE60B64F-58DF-4697-A1BE-A9FD9831F485', 'AC8B753C-B58D-4DAC-B464-BF2327F33038', '3760102850039', '  /   . ,   - 7,5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7FFFA2E2-124B-410A-AE65-003AD54D9508', '0E7F6BD9-D64B-444A-A41E-56B7BE8B68EF', '1460709417667                       ', '     5+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('71DECB18-3408-45FE-9B68-A45457310AD3', 'DB380ED0-DD53-4E36-804D-BE75DEED85F9', '4607086565490                       ', '    gel trap    snail repair 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6EFE6107-F890-4763-A211-D82F0C0FFC27', 'B29D6B5A-3BC8-44DD-BBB3-80AD9410907D', '4607086565483                       ', '   panna cotta    snail repair  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0E9EE449-C15C-464B-9BE0-AD8A1AA51A17', '42D9243F-7722-4AF6-92D0-776276223FD5', '7891024129937', '  -     100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99A2DECA-E2BA-42E0-AD62-C354CBEDEFB1', 'AAFFFC4C-1059-4D03-BEDA-17BED306B944', '4680002553849                       ', '  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6C80B78C-E12F-47BE-B00E-CF06861AD477', '716E6269-6CE0-41C7-874F-F8A1D7BDBA3F', '2056000009473                       ', '-201   severa . 45', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D80DA3EF-4121-4CC4-AA3D-1CC782DF8C28', 'A212ED48-CE3D-4899-80F1-DE7E2E75DC08', '4013742015429                       ', '  21', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B5EF3B7-9A49-4B13-B0F8-5B7E913CFC56', 'AA73C129-B2C3-4620-8F44-AF38D563D44B', '8003670815976', '   ""   4 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('97DE0F4E-38CC-4E68-A9E5-B5B52691798F', '4D3CC213-97CB-4E79-B27E-E199898F8FC9', '4603732050143', '   M', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('86534BEA-A1AD-4B35-91E0-4E8FDAEBF1C1', '84F4167A-3329-48C0-A56C-D170DA9EFCE0', '4601774004186', '  81,5 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5E7D1F10-6728-4487-B06A-8DC6D7C95D82', '6BB7A37B-03CC-4706-AD95-363D87868D0E', '4680020180720', ' 100  14', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FB95156-448A-4B95-B7DB-2D55DE7CD9FC', '1E5859D2-A2F2-4C5B-9C2A-A4080B8C4CF3', '4604060000046', '  380  / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0046E75B-C4C4-40E9-86AC-E065C4F40348', '67B6E3DB-3AD1-41DB-ACF5-F855A3A7916F', '4601951000758                       ', '- 500 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B96EC674-9A26-403C-9A86-03F76C6F6540', '81C23D93-2349-433F-8CED-747EA6CE6513', '4650001798053', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('39064395-FDFF-48D4-8EEE-C9D1DBC43D21', '587FBBDE-D284-497A-943C-299B7F6F3B62', '4627129211351                       ', '   30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CCB4A468-D62D-4E80-8170-15E37DBD9D89', 'B8C1FC9E-3415-4242-85A9-3C29974039E0', '4607075798472                       ', '  Veiro   4 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07F4621B-2BA4-4D6F-9B38-FF4D771AA212', '618BEE37-DFA5-47A5-BA79-4E9B52352472', '4627090492032                       ', 'Pellesana    25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7B61F4C3-926C-4178-B506-75F3FA8C4226', 'DA533F89-3AFB-4BD1-818C-579F167BF0D6', '4670010371399                       ', '  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D196BAC7-F6B0-4F41-AEFD-F7911D3BB46E', '1EE201C7-6973-4BB1-AC29-8C3D535185D7', '4602656001026                       ', ' 50  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EB90DF1B-EBED-490F-A8CC-5BAB8EB4D967', 'DF1D5166-B9FB-4BAF-971C-5742917BEC89', '4607102611606                       ', '   50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA65099D-F1CE-45E0-BA2A-367A836BC5E2', 'CAEFD5B4-EDA1-4577-B4DB-C99632505D8E', '4680004853107                       ', '      / 1,5 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC0FA8A7-9F55-4AB9-97B7-B8B7C783677E', 'FEE4C703-145A-4BBA-AF57-779BA52BB3BC', '3574660460988', '  16  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('737DD81D-AD1A-4DE1-83A5-69AD3598A04B', '3E2C487C-3E8F-46B9-AE82-C45C4F4AE65A', '4008233144429                       ', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C0AE021-510E-47BC-B5BC-9180680E2726', '6E2E0F9C-91C3-4174-9482-C5172F065B9C', '4008233126326                       ', '       200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6F518C4C-EB6D-419D-8549-53D24F635C54', 'D97B8B09-A3F5-4BAF-9D2B-0283BDC48E50', '4605319004976', '    / -500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('07F7571B-C9CE-4A59-BCBA-DCBBE12AAF30', 'C5F60139-A859-450F-A966-5C725AB8C223', '4607172376290', ' 3 1500    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FBC29140-DF58-46BC-BDDE-32F62C202796', 'EA66B4C7-2292-4847-9F28-BB096DD88913', '4005900169877                       ', '      50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5965AE79-B092-43C0-BFD4-3E5B98394E9E', '52CFE268-5A48-4F7D-9B28-232AD9EFA9C7', '4750282912329                       ', '      5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('75AEB955-43A0-4595-8730-459A06A03771', '110B9E5B-0C17-44FF-9F89-F10AA3BFBF30', '8588006036671', '        100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1D267F21-FB84-45C9-AE47-31F34DD22D86', '22077A46-EBDB-4A45-9FCC-3E2C024F1928', '4610012280381                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A3F1DA0A-413C-479E-BF40-605AE74E6A0F', '6D17D612-2768-4896-865B-54903BA433A7', '4607025840077                       ', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('387BE372-7522-4807-9B09-8445A6C1E59C', '08191233-794D-486D-9C0D-09D74A05692B', '9007253102537', '     200  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5F85CECA-0E75-4181-93F9-8D9F762CF7DF', '5B6F73EA-8C71-4C47-A599-2078C85EC1F2', '8001090775597                       ', '      (11-16) 11', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F06B606-7EEF-4B24-93B5-F54E305223F8', '09853DE9-F4B3-4ACF-9014-23E8DD5D1D74', '4620750540258                       ', '      10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9CEDBB1-65D0-4C78-A100-6CDA5B99D3EB', 'BBF7945E-7247-4963-85A0-10BB18CD03AF', '4607102135560                       ', '  . . zo-MC-351-D-SH', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('98EC915B-C11E-477D-9882-AFE1C28FBE6B', 'BF475A0E-1EEC-4A95-999E-366286C086A3', '4604060995533                       ', '   20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4AA80E5D-278B-48C2-8269-9754BD8F6F9A', 'A1911C24-0186-4C8E-9480-82CF177307E2', '5391520948411                       ', '  1%  2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9C918A59-72F0-4157-B3C1-767D14F606A1', '50CE8A3A-13D8-47A2-A7DA-2D6FF31306A6', '3499320003872                       ', ' 5%    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D10D6893-BABB-4AF4-8B77-F8B8FAF5308A', 'D8B03233-26FA-44B1-B353-86E4C05C418B', '4603679002021                       ', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99DB651E-2BB1-43D5-91AC-E5ABBD78568B', '1711C737-EF71-4A24-9359-29982E8138B5', '4602832000119                       ', '     . ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CAC9AB96-A563-4640-B03A-31F8569B5352', '41F840BD-C034-4BF5-ACB1-825CD98A849F', '3282770053135                       ', '    /    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C11A7311-C144-4B73-9ACE-59E5ECBC2343', 'D3ED4B17-38AF-489F-B898-8DCEA1E4BB0B', '4051895000459                       ', '     200 4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B1F4B131-DD56-495D-A518-B0102E647D5A', '425D2CD3-9BAA-4CE8-90C3-26B0A9A01C1A', '8710103568155', '     .80520 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('18E36AA5-1F3B-4540-BF48-790345F904A1', '674B0424-7611-4CF4-923B-C0873A53B304', '4602565019150', ' 400  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E17A6593-AC9E-4F6C-B356-E0D5D274541D', '46B286F0-D9B1-43F0-9276-C2C57879BBED', '8710103662389                       ', '       6 .83840 2', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DFD0FB9D-929C-4BCC-A7C1-4267DBFE24CD', '0DA4A727-B08D-445D-85E0-B14E6187A78F', '4607003249205                       ', ' 160  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('67D90DD2-8222-45FE-B4D6-85CCF4064772', '48E0FFC2-811B-490D-BA0A-625644E558AA', '4620002185251                       ', ' bb  /   10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FEC4E560-7872-4F0E-B695-050BB2961D96', 'C5C76C18-F240-4AFD-9810-9ABA879BA428', '4607061253008                       ', ' bodybar          50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8DD9AA76-91B1-4C09-AC4C-AE437EABB992', 'FAC5277B-547A-4F10-BE54-79DE9CC25E0E', '4607098451668                       ', ' 400  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3F5CB00A-1266-427B-B45E-FF394D5537EA', 'FDD956B5-818F-4091-AE70-84B356559DAF', '4627129213096', '   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2A00BB1B-86BB-428C-A5ED-C2028A95EB7F', '29554F95-AD78-4030-97BA-93F78222FA67', '4607027410179', '   /.  8', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62B72A0F-08AF-4F58-9D1F-E52DF43BD2A6', 'B47D0E62-16AD-4879-9E32-8566892B2E59', '4627129213805                       ', '    30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('EA33782F-A28E-4B59-953E-3B1F85011858', '4C3E5A43-EF66-4325-A643-59EC74BD2E38', '4607034474201                       ', '    94', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E7D035C4-B65E-4F23-8424-ED346BA4F908', 'AFA26FEF-C11C-4BEB-9202-F008E9F62E83', '4620004951779                       ', '     150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('12F9585E-E379-4681-9B27-E030FA828177', '354BB273-9A13-44EA-A218-E1BC51349359', '4602441016594                       ', '      0.33  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B2C566C-49B0-4C07-A1BD-D1F27DA4C589', '3C9660A2-0F39-474D-8387-4AD89784F990', '8588006036442', '          100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B07EB4A7-6415-42B7-AAEB-2F62D59C68DB', 'C4BDE83B-E620-490D-98CD-7374F3620009', '8588006036480                       ', '         100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0D4FF4CC-128D-4D42-A0D3-5181FD231C79', 'C7185791-1460-4C18-B4AA-8F81EF6DF938', '4607174430860                       ', '    /  150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('FB53E0D8-4077-42A0-B5F6-76119A4D06D6', 'D393BF87-77F0-467F-99DA-3F7B3AE2C443', '4607061253022                       ', ' bodybar     -    50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('62BBF27A-D3CA-46E6-8B21-0F51A58C32C7', 'ABF830F4-66FF-4569-9494-FD4879EE06D4', '4603726175135', '  /  25 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F743238C-B7E2-471D-9E4B-FD50F85BD528', '8416FC05-5115-4F0C-80B2-86BABC15FA34', '4660041990560', '  1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('74A9E382-7F1B-4BFB-B299-257E4A1727C5', 'D4F8410A-A781-4097-84F1-7BC0C0465DEA', '8001090431738                       ', '   60  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A61DA4D-8FCD-45CD-878D-CA438ED36357', '5E07AB12-8E7C-443D-915F-DECA66BAF1DC', '4605319010427                       ', '  -   10 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3C793DFC-BCDB-4FC7-916C-0DB59AF57792', '5D148E52-5553-44D2-9C23-A53876B6EE5C', '4607010249588                       ', '911      85', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('533350CE-EE78-4F21-9959-3637156C7B35', 'A220A348-B9CA-4B32-93FD-F2932FC4B9C4', '4607056520177', '     250', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('73AD5FF1-56EA-4E8C-9DBF-2A81AA5D3607', '3474A536-CD2B-4E33-B92E-209343400CDB', '4650070510358                       ', '     - //  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5FAF6A24-A979-415C-9C91-FD8ED64E5093', '122A95F3-551E-4DF4-A0CF-721FC78DC140', '8051406418960                       ', '   /       500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0DFE1875-3EC8-4338-ABA6-393F5B10C718', '61044AD3-6DC7-48BE-A568-FCA1CBDB8127', '8032779759607                       ', ' /          500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('35C2DD12-387E-40E2-9126-361FE651C02C', '836FA236-57FF-4B78-A59A-6DE77D68D7D5', '3574661378572', '     /   300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AEF80C1D-706C-428E-83B1-19751A7BF612', '0D7D3CA4-82C8-4411-88D3-219C7BB0E404', '3282770073638                       ', '   /  200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24DE6290-B575-44B2-8043-FA3B0F646CFD', '04999B28-33B9-4301-86BD-DF8F3D0D4A82', '8030009701150                       ', '  "Active"  . 1115.02 25 .', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('1FF6DE36-FF8E-4697-BCE8-4A57525C1D14', 'B3114B38-8B74-4AB9-8F2C-BDB6F4D34907', '4601654000437                       ', ' - 30 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6CDB8E1-10DB-4F55-96AA-341562926DC5', '14A5DE21-E12C-40BA-8F5E-F28DEF4587C1', '4680004854388                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D15E35E0-531F-47F6-AC22-56F2778E12D6', '55B4448A-EDC4-4BA3-9D60-C562D3F51CB4', '4620002187484', '   120  (1+1)  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('47E114FA-7AC1-4E0F-B837-7D1C8BF6289B', '4CA9ED88-3B7D-4743-B253-444C07A3A400', '4711146553287', ' - .    55328', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A2C18FC-DA03-4122-95C9-81995024485B', '962F34DE-C670-4401-BD07-955118AB3C41', '4607010248505                       ', '   ///  3     f 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('85159619-212D-4335-BBDC-37BAB2E0DF6E', '0C63FB2C-E241-492A-9052-064AEB76CC09', '4823015938252                       ', '  coconut hair  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5DA53C6D-B087-4F11-9973-C3D625CA3FA1', 'B20B37FA-3287-4CB6-A17C-00EA6491AB97', '4823015938238                       ', '  coconut hair  / 150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5A8AEC41-B521-44B4-AE02-3559C0D0FC66', '48237B68-8969-4256-84E5-7E59C5E2BF32', '4607024945377', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4F9C9562-5051-4114-8945-1A96AA5A8242', '8727FD59-C185-4CA1-896E-2C40DF6C92AB', '4603423001089                       ', ' 0,2  60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('A56E1896-9E1D-4F21-B7CE-F9DF02B6D871', 'A7F0D70D-2AEF-4620-9DC4-2794E817FA95', '8001090378293                       ', '     36', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D6CF9117-A664-47C5-B03B-23B2E39C43F9', '8B84C07B-ED16-4205-B078-BE86E4F344B2', '4605370007718                       ', 'Water   /+     500', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2C1B892D-C6BF-45D6-B037-692A68C2D85F', '6D981524-4560-49EE-9DB1-54C92C9682FC', '3577056007347                       ', '    ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0A6D0E7F-A03E-4DC8-933E-C2AEB0F1BB97', 'B9AA6560-456B-46DC-9B69-3251AD37DF5B', '4670026950120                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('00B461BA-5CD9-4929-AE17-3BB461E358AA', '0D3F4159-2F0A-48E9-AD16-94D9FDA2D858', '4820121901057', ' -  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('33263B2A-23F1-4527-B69E-3105E61D873E', '33BA8E56-0F63-459B-A351-8BD50E72889A', '6958627516067', '   2500  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CD4DD238-8ED2-4AFE-8406-71A30661B004', 'AF21CEF1-002E-4CCC-84C5-A5F36EFC9575', '4607083725972                       ', ' Silver - /  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DC3C366F-7ABC-4571-9061-7BD7DC8AB783', '2406FBD1-FA98-4DF8-98EC-86F670F3AF32', '4605658195175                       ', '   /   /19537/', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A829292-08CB-46E6-A483-7128A99BB93D', '478F6656-9608-409E-811F-F1F18C19AE97', '4650001795144', ',   -  / ... / 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AC6BA7E4-D38F-489C-91E8-8B27C74F18FB', '888905FA-C112-4024-8D5A-AD519CAA1F24', '4607075000841', '   "" ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8A2B59BC-5AB2-48C0-BC2A-3BC0B6EF5C4B', 'E7D1B7C1-730C-46BB-BD75-C258BB6DA23E', '4022551309889                       ', '   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('AE7A17EE-AF7C-42B4-8814-1908613FDF6F', 'DA7230E8-DBD4-46C7-8143-30D021372C16', '4750282910028', '   - 2 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('069FFA17-A9B3-46BC-AFF8-4BF30E57AFC1', 'E41FFEAE-ACC9-41A5-83DC-EF7DC5EF96F8', '4603188000815                       ', '-   1 -5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3A97CF9B-489E-4E65-B869-4834AFBE7382', '40FC124B-5361-4CFB-878A-5DE8E7CA6B13', '3433422407374                       ', ',         400', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('694FC88C-B6B9-4172-8CD0-3EAB24BF352E', '85D1E019-6B5A-4E2F-B80A-A8F19590A481', '4607136740792', '    60', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('3AD356F1-05E0-4A19-BB28-882B5BE0BD31', '7DF00A47-6043-4F16-A609-DA32A0AF7B1F', '4605319008257', ' 103   / spf 10 170 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F9ECDE56-DF13-4A4B-833B-91653F58BC08', 'D18D71DB-9DFB-4388-8FBD-D1D6B4824785', '4009800005204                       ', '    100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('380751E9-1EB5-4D8F-B651-765E07DF8A5C', '3E5CA5BC-DE7B-4F1D-9AEC-AB70E286EE33', '4032717001090                       ', ' 500  / 50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('F0462D6D-B6D8-4C95-9E3D-A5E22E1F2E14', '140783BF-6844-492F-80D2-798B55FB4A2E', '4627074843997                       ', '    5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8C5837A5-9C47-45EB-A36F-7AED6F82A6C2', '9A89539B-EA2D-46CC-ADA9-A6F40C707490', '4607085319940                       ', ' 250  50', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('489E71B4-8F58-4EED-8274-19B260A84F3B', 'BC29D58F-5AB6-4A82-821D-8C708A17B714', '5010706007208                       ', ' 500  / 10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B6B8C222-3519-4EA0-BCF2-2205A93DFAF8', '57B9A4E4-0E04-42F2-9339-869C1D2AF32C', '4607094177685                       ', '      4+125  4510', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0FC27181-F96D-48CA-82D1-17F2CD624DAB', '12E7F413-D953-4AA5-94B6-F4F166AAA4DA', '4603732050020', '   S', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D7003BE4-B9E7-426C-A2C5-10E4AE573CE3', 'B3C95154-1677-4D04-A45B-14CA25060265', '8809270626970                       ', ' estelare inst  /    4', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2080939F-0BD2-42BD-A75A-72DB8F8EE565', 'DD84E340-9C9C-4470-8B09-A639BA804AED', '4605994033124', '       100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('65D4D41B-E9E1-4F03-9E5F-D7D2C0B39CA0', '654FF1E0-561E-4F5E-A495-9DA501EAE1D6', '4036534001813                       ', ' /   SF', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('01A26036-525B-4107-B3E4-2933958AF59B', 'FA277606-337B-4A8D-8B07-17A35BFD4C43', '4620002186777', '   /     200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('6D9200B8-BAC7-418D-9FED-D2ACEB525A09', 'F78F0B0E-2508-45FD-BD65-B6B779F4A795', '4260108299096                       ', ' /    fabrik cosmetology snail etract mask 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('D337CCA5-8AC5-4CCA-8238-72CBB7F820FF', '62FD3210-0F65-4CEC-BD76-D0607A54D4D5', '4605370015836                       ', '   /  40 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('16024882-A388-4BD0-8EE0-59FA21F8B34D', 'DC69950D-1AED-46B3-A938-4240DCAA5814', '4605658195212                       ', '  + 0+', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('76B5B10F-D06F-4030-8826-D361D3EC1EF3', '9D891068-C8A4-4423-8109-4CA5A2A0344B', '4607086565506                       ', ' snail repair  - aqua keep 20  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('B23702E3-8A8E-4572-8468-0C746611256C', '2F1A2200-A8DF-4D24-98D0-1DB17723F288', '4600689603262                       ', '  200  3       6 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C09AFCBA-355D-4B42-A5AB-BAA8F307CC41', 'B747B5AF-D7E1-4ED7-A5CE-FEF7FDE541AE', '4607094175131                       ', '    6+300', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('279AD771-A19A-471C-92C2-E7B2B7BEB98B', '2164696E-D542-4DFA-B389-F97171C2197B', '4605126006088                       ', '   1,5 / 20', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('BDC2C791-6C0A-4AB1-8F45-26222E4A1116', '804C2225-E7CE-4EAF-A99C-8B13C67D41A7', '4711146221124                       ', '  2 , 2 - 22112/52112', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8B082610-D044-44E6-B86D-E069D58A5E10', 'FE987F69-D79F-49FF-8402-7EF9E25DF359', '4607086561409                       ', '    -    75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('24393A97-B22C-4E35-A814-A06EDD60B61E', '6A7D8701-C10C-4AAE-9B85-5C9635F4E9A0', '4680007750052', '   6060 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('99EC6137-EAB0-4F9B-9933-3FB4B3AB8637', '1B6D9B23-82D3-47B8-AE96-5E5810D0537C', '4607025840473', ' ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8CCA7A7B-8E7C-4256-BDD7-A1DED625131D', '2936B45A-EE9D-45EB-8BB0-CCD65DDDCBE3', '4607010248864', '911       150', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5CDAD59F-DD23-4DC8-87B3-34E1A83C561C', 'FDA449D1-839C-469A-AFA4-D473F17F0B91', '4601969008395                       ', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E0CA7B49-F96A-4E3D-8E89-952F892A58DF', 'FD02AE2C-39FA-4536-8C87-938EF6B08808', '4751006750890                       ', '  / /  1 ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('991C9F4B-CC1F-4432-A2FE-4DF63B55994F', '33CEB605-1708-4922-9772-B151EA104A5E', '4601669013064', ' 40', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4CA89CF1-7DC8-4E04-8588-8CF99671196B', '39696E0B-6CFE-4466-9036-3B63AF1C8053', '4607094171591                       ', '  /   .  4+ 1', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('8FD38780-927D-4EC3-934E-4A0A45C9F67B', '25464A7A-54A2-4778-9002-BDC7F6AF2551', '3850343026987', ' 10  30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('4D867B2C-CA5B-466F-97B8-1222D8833E44', 'C96FDBDC-5B79-4ADB-B465-677A5188B336', '4660000410511                       ', '  . / / - 5', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('0B37277A-982E-4FC4-97CD-6EC2F11EC1C5', '4D4DBEFB-FBD1-4133-BF16-AF255CDEAA37', '4607013792555', '    1200', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('935688A1-5DE5-4CC3-B5B6-335FFFFD83B4', '1644A408-8074-4491-9437-D6BAFB142794', '8717185947656                       ', ' /    360', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('5ADBF493-5632-4902-8806-43ECAE3852F4', '2084C0B1-2507-43E2-ACF1-2BC00B01097F', '3700281702392                       ', '    - 75', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('CA84EF07-3403-40CD-BA90-67D5EB9B6EA0', 'D79C037E-81E2-4EE7-8DBE-0F56653E8AD5', '4620006946803                       ', '   //     5  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('E514E241-F51C-48B7-B676-BA7B89113B6E', '1420C036-3906-48DE-898C-9975C1B55C76', '4601774005831', '  7  ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('C657659C-6B2D-4F30-8A9D-AA1926C5963C', '65D1DE4C-8F69-4EBF-8CC6-13D214B6A8AB', '4620011583130', NULL, '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('2D831614-6F27-4C1C-B4BA-75605C4AD9DB', 'A8848F03-05A4-443C-A5BA-202D1434A0A0', '3582910082613                       ', ' 30/5  100', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('7920CF40-4FF9-4B77-8390-0B37A433ED4A', '49AA9DEE-878F-44DC-870A-848BF4EED119', '4630019880018                       ', ' 2,5  / 30', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('9A4A6643-6478-48E9-8E79-09C6E0B92CE4', '5ABBCC30-6EFB-43E4-BC29-8637DB0B5EE7', '4601669011374                       ', '- 500  10', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('81BBD205-37C2-477B-82B4-8A67D4B2D7D9', '3960FABC-3221-4078-B70C-BFE356DDB288', '4650070110572                       ', '   1,5  25', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('188284C8-C259-429B-B009-234D7C7D5921', 'CEFE1D21-1631-4BBF-A48F-5E2998A84BC9', '4823060803581                       ', '-   ', '2000-01-01 00:00:00');
INSERT INTO DP_GBCLINKS (D$UUID, POSITION_UUID, BARCODE, SNAME, D$SRVUPDDT)
                 VALUES ('DB438CEE-5F70-4C7C-81DF-8AAEB7765E8D', '200189C9-31BB-47FF-9672-12E2AA72002F', '3337871330569', '    /  200 ', '2000-01-01 00:00:00');
				 
COMMIT WORK;
*/
